BalanceTransferResponseStatusEnum class

Inheritance
  • Object
  • EnumClass
  • BalanceTransferResponseStatusEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BalanceTransferResponseStatusEnum>
no setter
values → BuiltSet<BalanceTransferResponseStatusEnum>
no setter

Constants

error → const BalanceTransferResponseStatusEnum
The status of the balance transfer. Possible values: transferred, failed, error, and notEnoughBalance.
failed → const BalanceTransferResponseStatusEnum
The status of the balance transfer. Possible values: transferred, failed, error, and notEnoughBalance.
notEnoughBalance → const BalanceTransferResponseStatusEnum
The status of the balance transfer. Possible values: transferred, failed, error, and notEnoughBalance.
transferred → const BalanceTransferResponseStatusEnum
The status of the balance transfer. Possible values: transferred, failed, error, and notEnoughBalance.
unknownDefaultOpenApi → const BalanceTransferResponseStatusEnum
The status of the balance transfer. Possible values: transferred, failed, error, and notEnoughBalance.