$WebhookSetting class abstract

a concrete implementation of WebhookSetting, since WebhookSetting is not instantiable

Implemented types
Available extensions
Annotations
  • @BuiltValue.new(instantiable: true)

Constructors

$WebhookSetting([void updates($WebhookSettingBuilder)?])
factory

Properties

currency → String
The three-character ISO currency code of the balance.
no setterinherited
discriminatorValue → String?

Available on WebhookSetting, provided by the WebhookSettingDiscriminatorExt extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier of the webhook setting.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
The status of the webhook setting. Possible values: * active: You receive a balance webhook if any of the conditions in this setting are met. * inactive: You do not receive a balance webhook even if the conditions in this settings are met.
no setterinherited
target → Target
The resource about whose balance change you want to get notified.
no setterinherited
type → SettingType
The type of the webhook setting.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates($WebhookSettingBuilder)) → $WebhookSetting
Rebuilds the instance.
inherited
toBuilder() → $WebhookSettingBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<$WebhookSetting>
no setter