$WebhookSettingBuilder class

Implemented types
Available extensions

Constructors

$WebhookSettingBuilder()

Properties

currency ↔ String?
covariantgetter/setter pairoverride
discriminatorValue → String?

Available on WebhookSettingBuilder, provided by the WebhookSettingBuilderDiscriminatorExt extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
covariantgetter/setter pairoverride
target ↔ TargetBuilder
covariantgetter/setter pairoverride
type ↔ SettingType?
covariantgetter/setter pairoverride

Methods

build() → $WebhookSetting
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant $WebhookSetting other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates($WebhookSettingBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited