AULocalAccountIdentification class abstract

AULocalAccountIdentification

Properties:

Annotations
  • @BuiltValue.new()

Constructors

AULocalAccountIdentification([void updates(AULocalAccountIdentificationBuilder b)])
factory

Properties

accountNumber → String
The bank account number, without separators or whitespace.
no setter
bsbCode → String
The 6-digit Bank State Branch (BSB) code, without separators or whitespace.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AULocalAccountIdentificationTypeEnum
auLocal
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AULocalAccountIdentificationBuilder)) → AULocalAccountIdentification
Rebuilds the instance.
inherited
toBuilder() → AULocalAccountIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AULocalAccountIdentification>
no setter