AdditionalBankIdentificationRequirement class abstract

AdditionalBankIdentificationRequirement

Properties:

Annotations
  • @BuiltValue.new()

Properties

additionalBankIdentificationType → AdditionalBankIdentificationRequirementAdditionalBankIdentificationTypeEnum?
The type of additional bank identification, depending on the country. Possible values: * auBsbCode: The 6-digit Australian Bank State Branch (BSB) code, without separators or spaces. * caRoutingNumber: The 9-digit Canadian routing number, in EFT format, without separators or spaces. * gbSortCode: The 6-digit UK sort code, without separators or spaces * usRoutingNumber: The 9-digit routing number, without separators or spaces.
no setter
description → String?
The description of the additional bank identification requirement.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AdditionalBankIdentificationRequirementTypeEnum
additionalBankIdentificationRequirement
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AdditionalBankIdentificationRequirementBuilder)) → AdditionalBankIdentificationRequirement
Rebuilds the instance.
inherited
toBuilder() → AdditionalBankIdentificationRequirementBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AdditionalBankIdentificationRequirement>
no setter