AddressRequirement class abstract

AddressRequirement

Properties:

Annotations
  • @BuiltValue.new()

Constructors

AddressRequirement([void updates(AddressRequirementBuilder b)])
factory

Properties

description → String?
Specifies the required address related fields for a particular route.
no setter
hashCode → int
The hash code for this object.
no setterinherited
requiredAddressFields → BuiltList<AddressRequirementRequiredAddressFieldsEnum>?
List of address fields.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AddressRequirementTypeEnum
addressRequirement
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AddressRequirementBuilder)) → AddressRequirement
Rebuilds the instance.
inherited
toBuilder() → AddressRequirementBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AddressRequirement>
no setter