AmountMinMaxRequirement class abstract

AmountMinMaxRequirement

Properties:

  • description - Specifies the eligible amounts for a particular route.
  • max - Maximum amount.
  • min - Minimum amount.
  • type - amountMinMaxRequirement
Annotations
  • @BuiltValue.new()

Constructors

AmountMinMaxRequirement([void updates(AmountMinMaxRequirementBuilder b)])
factory

Properties

description → String?
Specifies the eligible amounts for a particular route.
no setter
hashCode → int
The hash code for this object.
no setterinherited
max → int?
Maximum amount.
no setter
min → int?
Minimum amount.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AmountMinMaxRequirementTypeEnum
amountMinMaxRequirement
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AmountMinMaxRequirementBuilder)) → AmountMinMaxRequirement
Rebuilds the instance.
inherited
toBuilder() → AmountMinMaxRequirementBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AmountMinMaxRequirement>
no setter