AmountNonZeroDecimalsRequirement class abstract

AmountNonZeroDecimalsRequirement

Properties:

  • description - Specifies for which routes the amount in a transfer request must have no non-zero decimal places, so the transfer can only be processed if the amount consists of round numbers.
  • type - amountNonZeroDecimalsRequirement
Annotations
  • @BuiltValue.new()

Properties

description → String?
Specifies for which routes the amount in a transfer request must have no non-zero decimal places, so the transfer can only be processed if the amount consists of round numbers.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AmountNonZeroDecimalsRequirementTypeEnum
amountNonZeroDecimalsRequirement
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AmountNonZeroDecimalsRequirementBuilder)) → AmountNonZeroDecimalsRequirement
Rebuilds the instance.
inherited
toBuilder() → AmountNonZeroDecimalsRequirementBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AmountNonZeroDecimalsRequirement>
no setter