ApproveAssociationRequest class abstract

ApproveAssociationRequest

Properties:

  • entityId - The unique identifier of the entity.
  • entityType - The type of the entity. Possible values: accountHolder or paymentInstrument.
  • scaDeviceIds - List of device ids associated to the entity that will be approved.
  • status - The status of the association. Possible values: active or pendingApproval.
Annotations
  • @BuiltValue.new()

Constructors

ApproveAssociationRequest([void updates(ApproveAssociationRequestBuilder b)])
factory

Properties

entityId → String
The unique identifier of the entity.
no setter
entityType → ScaEntityType
The type of the entity. Possible values: accountHolder or paymentInstrument.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaDeviceIds → BuiltList<String>
List of device ids associated to the entity that will be approved.
no setter
status → AssociationStatus
The status of the association. Possible values: active or pendingApproval.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ApproveAssociationRequestBuilder)) → ApproveAssociationRequest
Rebuilds the instance.
inherited
toBuilder() → ApproveAssociationRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ApproveAssociationRequest>
no setter