AssociationFinaliseRequest class abstract

AssociationFinaliseRequest

Properties:

  • ids - The list of unique identifiers of the resources that you are associating with the SCA device. Maximum: 5 strings.
  • strongCustomerAuthentication - Contains authentication information required to associate the resource with the SCA device.
  • type - The type of resource that you are associating with the SCA device. Possible value: PaymentInstrument
Annotations
  • @BuiltValue.new()

Constructors

AssociationFinaliseRequest([void updates(AssociationFinaliseRequestBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ids → BuiltList<String>
The list of unique identifiers of the resources that you are associating with the SCA device. Maximum: 5 strings.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strongCustomerAuthentication → AssociationDelegatedAuthenticationData
Contains authentication information required to associate the resource with the SCA device.
no setter
type → AssociationFinaliseRequestTypeEnum
The type of resource that you are associating with the SCA device. Possible value: PaymentInstrument
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AssociationFinaliseRequestBuilder)) → AssociationFinaliseRequest
Rebuilds the instance.
inherited
toBuilder() → AssociationFinaliseRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AssociationFinaliseRequest>
no setter