AssociationListing class abstract

AssociationListing

Properties:

  • createdAt - The date and time when the association was created.
  • entityId - The unique identifier of the entity.
  • entityType - The type of the entity. Possible values: accountHolder or paymentInstrument.
  • scaDeviceId - The unique identifier of the SCA device.
  • scaDeviceName - The human-readable name for the SCA device that was registered.
  • scaDeviceType - The type of the device.
  • status - The status of the association. Possible values: active or pendingApproval.
Annotations
  • @BuiltValue.new()

Constructors

AssociationListing([void updates(AssociationListingBuilder b)])
factory

Properties

createdAt → DateTime
The date and time when the association was created.
no setter
entityId → String
The unique identifier of the entity.
no setter
entityType → ScaEntityType
The type of the entity. Possible values: accountHolder or paymentInstrument.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaDeviceId → String
The unique identifier of the SCA device.
no setter
scaDeviceName → String?
The human-readable name for the SCA device that was registered.
no setter
scaDeviceType → ScaDeviceType
The type of the device.
no setter
status → AssociationStatus
The status of the association. Possible values: active or pendingApproval.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AssociationListingBuilder)) → AssociationListing
Rebuilds the instance.
inherited
toBuilder() → AssociationListingBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AssociationListing>
no setter