legalEntityIds property
The legal entity IDs of the authorized card users linked to the specified payment instrument.
Implementation
@BuiltValueField(wireName: r'legalEntityIds')
BuiltList<String>? get legalEntityIds;
The legal entity IDs of the authorized card users linked to the specified payment instrument.
@BuiltValueField(wireName: r'legalEntityIds')
BuiltList<String>? get legalEntityIds;