BRLocalAccountIdentification class abstract

BRLocalAccountIdentification

Properties:

  • accountNumber - The bank account number, without separators or whitespace.
  • bankCode - The 3-digit bank code, with leading zeros.
  • branchNumber - The bank account branch number, without separators or whitespace.
  • ispb - The 8-digit ISPB, with leading zeros.
  • type - brLocal
Annotations
  • @BuiltValue.new()

Constructors

BRLocalAccountIdentification([void updates(BRLocalAccountIdentificationBuilder b)])
factory

Properties

accountNumber → String
The bank account number, without separators or whitespace.
no setter
bankCode → String
The 3-digit bank code, with leading zeros.
no setter
branchNumber → String
The bank account branch number, without separators or whitespace.
no setter
hashCode → int
The hash code for this object.
no setterinherited
ispb → String?
The 8-digit ISPB, with leading zeros.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → BRLocalAccountIdentificationTypeEnum
brLocal
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BRLocalAccountIdentificationBuilder)) → BRLocalAccountIdentification
Rebuilds the instance.
inherited
toBuilder() → BRLocalAccountIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BRLocalAccountIdentification>
no setter