BalanceAccountInfo class abstract

BalanceAccountInfo

Properties:

  • accountHolderId - The unique identifier of the account holder associated with the balance account.
  • defaultCurrencyCode - The default three-character ISO currency code of the balance account. This is the currency displayed on the Balance Account overview page in your Customer Area. The default value is EUR. > After a balance account is created, you cannot change its default currency.
  • description - A human-readable description of the balance account, maximum 300 characters. You can use this parameter to distinguish between multiple balance accounts under an account holder.
  • metadata - A set of key and value pairs for general use. The keys do not have specific names and may be used for storing miscellaneous data as desired. > Note that during an update of metadata, the omission of existing key-value pairs will result in the deletion of those key-value pairs.
  • migratedAccountCode - The unique identifier of the account of the migrated account holder in the classic integration.
  • platformPaymentConfiguration - Contains key-value pairs to configure the sales day closing time and settlement delay for a balance account.
  • reference - Your reference for the balance account, maximum 150 characters.
  • timeZone - The time zone of the balance account. For example, Europe/Amsterdam. Defaults to the time zone of the account holder if no time zone is set. For possible values, see the list of time zone codes.
Annotations
  • @BuiltValue.new()

Constructors

BalanceAccountInfo([void updates(BalanceAccountInfoBuilder b)])
factory

Properties

accountHolderId → String
The unique identifier of the account holder associated with the balance account.
no setter
defaultCurrencyCode → String?
The default three-character ISO currency code of the balance account. This is the currency displayed on the Balance Account overview page in your Customer Area. The default value is EUR. > After a balance account is created, you cannot change its default currency.
no setter
description → String?
A human-readable description of the balance account, maximum 300 characters. You can use this parameter to distinguish between multiple balance accounts under an account holder.
no setter
hashCode → int
The hash code for this object.
no setterinherited
metadata → BuiltMap<String, String>?
A set of key and value pairs for general use. The keys do not have specific names and may be used for storing miscellaneous data as desired. > Note that during an update of metadata, the omission of existing key-value pairs will result in the deletion of those key-value pairs.
no setter
migratedAccountCode → String?
The unique identifier of the account of the migrated account holder in the classic integration.
no setter
platformPaymentConfiguration → PlatformPaymentConfiguration?
Contains key-value pairs to configure the sales day closing time and settlement delay for a balance account.
no setter
reference → String?
Your reference for the balance account, maximum 150 characters.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeZone → String?
The time zone of the balance account. For example, Europe/Amsterdam. Defaults to the time zone of the account holder if no time zone is set. For possible values, see the list of time zone codes.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BalanceAccountInfoBuilder)) → BalanceAccountInfo
Rebuilds the instance.
inherited
toBuilder() → BalanceAccountInfoBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BalanceAccountInfo>
no setter