BalanceAccountUpdateRequest class abstract

BalanceAccountUpdateRequest

Properties:

  • accountHolderId - The unique identifier of the account holder associated with the balance account.
  • description - A human-readable description of the balance account. You can use this parameter to distinguish between multiple balance accounts under an account holder.
  • metadata - A set of key and value pairs for general use. The keys do not have specific names and may be used for storing miscellaneous data as desired. > Note that during an update of metadata, the omission of existing key-value pairs will result in the deletion of those key-value pairs.
  • platformPaymentConfiguration - Contains key-value pairs to configure the sales day closing time and settlement delay for a balance account.
  • reference - Your reference to the balance account.
  • status - The status of the balance account. Payment instruments linked to the balance account can only be used if the balance account status is active. Possible values: active, closed, suspended.
  • timeZone - The time zone of the balance account. For example, Europe/Amsterdam. Defaults to the time zone of the account holder if no time zone is set. For possible values, see the list of time zone codes.
Annotations
  • @BuiltValue.new()

Constructors

BalanceAccountUpdateRequest([void updates(BalanceAccountUpdateRequestBuilder b)])
factory

Properties

accountHolderId → String?
The unique identifier of the account holder associated with the balance account.
no setter
description → String?
A human-readable description of the balance account. You can use this parameter to distinguish between multiple balance accounts under an account holder.
no setter
hashCode → int
The hash code for this object.
no setterinherited
metadata → BuiltMap<String, String>?
A set of key and value pairs for general use. The keys do not have specific names and may be used for storing miscellaneous data as desired. > Note that during an update of metadata, the omission of existing key-value pairs will result in the deletion of those key-value pairs.
no setter
platformPaymentConfiguration → PlatformPaymentConfiguration?
Contains key-value pairs to configure the sales day closing time and settlement delay for a balance account.
no setter
reference → String?
Your reference to the balance account.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → BalanceAccountUpdateRequestStatusEnum?
The status of the balance account. Payment instruments linked to the balance account can only be used if the balance account status is active. Possible values: active, closed, suspended.
no setter
timeZone → String?
The time zone of the balance account. For example, Europe/Amsterdam. Defaults to the time zone of the account holder if no time zone is set. For possible values, see the list of time zone codes.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BalanceAccountUpdateRequestBuilder)) → BalanceAccountUpdateRequest
Rebuilds the instance.
inherited
toBuilder() → BalanceAccountUpdateRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BalanceAccountUpdateRequest>
no setter