BalanceAccountUpdateRequestBuilder class

Properties

accountHolderId ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ MapBuilder<String, String>
getter/setter pair
platformPaymentConfiguration ↔ PlatformPaymentConfigurationBuilder
getter/setter pair
reference ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ BalanceAccountUpdateRequestStatusEnum?
getter/setter pair
timeZone ↔ String?
getter/setter pair

Methods

build() → BalanceAccountUpdateRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(BalanceAccountUpdateRequest other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(BalanceAccountUpdateRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited