BalancePlatform class abstract

BalancePlatform

Properties:

  • description - Your description of the balance platform.
  • id - The unique identifier of the balance platform.
  • status - The status of the balance platform. Possible values: Active, Inactive, Closed, Suspended.
Annotations
  • @BuiltValue.new()

Constructors

BalancePlatform([void updates(BalancePlatformBuilder b)])
factory

Properties

description → String?
Your description of the balance platform.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier of the balance platform.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The status of the balance platform. Possible values: Active, Inactive, Closed, Suspended.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BalancePlatformBuilder)) → BalancePlatform
Rebuilds the instance.
inherited
toBuilder() → BalancePlatformBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BalancePlatform>
no setter