BalanceSweepConfigurationsResponse class abstract

BalanceSweepConfigurationsResponse

Properties:

  • hasNext - Indicates whether there are more items on the next page.
  • hasPrevious - Indicates whether there are more items on the previous page.
  • sweeps - List of sweeps associated with the balance account.
Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasNext → bool
Indicates whether there are more items on the next page.
no setter
hasPrevious → bool
Indicates whether there are more items on the previous page.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sweeps → BuiltList<SweepConfigurationV2>
List of sweeps associated with the balance account.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BalanceSweepConfigurationsResponseBuilder)) → BalanceSweepConfigurationsResponse
Rebuilds the instance.
inherited
toBuilder() → BalanceSweepConfigurationsResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BalanceSweepConfigurationsResponse>
no setter