conditions property
The list of settings and criteria for triggering the balance webhook.
Implementation
@BuiltValueField(wireName: r'conditions')
BuiltList<Condition>? get conditions;
The list of settings and criteria for triggering the balance webhook.
@BuiltValueField(wireName: r'conditions')
BuiltList<Condition>? get conditions;