BalanceWebhookSettingInfoBuilder class

Properties

conditions ↔ ListBuilder<Condition>
getter/setter pair
currency ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ BalanceWebhookSettingInfoStatusEnum?
getter/setter pair
target ↔ TargetBuilder
getter/setter pair
type ↔ BalanceWebhookSettingInfoTypeEnum?
getter/setter pair

Methods

build() → BalanceWebhookSettingInfo
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(BalanceWebhookSettingInfo other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(BalanceWebhookSettingInfoBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited