BalanceWebhookSettingInfoUpdate class abstract

BalanceWebhookSettingInfoUpdate

Properties:

  • conditions - The array of conditions a balance change must meet for Adyen to send the webhook.
  • currency - The three-character ISO currency code of the balance.
  • status - The status of the webhook setting. Possible values: * active: You receive a balance webhook if any of the conditions in this setting are met. * inactive: You do not receive a balance webhook even if the conditions in this settings are met.
  • target - The type and ID of the resource about whose balance changes you want to be notified.
  • type - The type of the webhook you are configuring. Set to balance.
Annotations
  • @BuiltValue.new()

Properties

conditions → BuiltList<Condition>?
The array of conditions a balance change must meet for Adyen to send the webhook.
no setter
currency → String?
The three-character ISO currency code of the balance.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → BalanceWebhookSettingInfoUpdateStatusEnum?
The status of the webhook setting. Possible values: * active: You receive a balance webhook if any of the conditions in this setting are met. * inactive: You do not receive a balance webhook even if the conditions in this settings are met.
no setter
target → TargetUpdate?
The type and ID of the resource about whose balance changes you want to be notified.
no setter
type → BalanceWebhookSettingInfoUpdateTypeEnum?
The type of the webhook you are configuring. Set to balance.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BalanceWebhookSettingInfoUpdateBuilder)) → BalanceWebhookSettingInfoUpdate
Rebuilds the instance.
inherited
toBuilder() → BalanceWebhookSettingInfoUpdateBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BalanceWebhookSettingInfoUpdate>
no setter