BankAccountDetailsBuilder class

Constructors

BankAccountDetailsBuilder()

Properties

accountNumber ↔ String?
getter/setter pair
accountType ↔ String?
getter/setter pair
branchNumber ↔ String?
getter/setter pair
formFactor ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iban ↔ String?
getter/setter pair
routingNumber ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortCode ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

build() → BankAccountDetails
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(BankAccountDetails other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(BankAccountDetailsBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited