BankIdentification class abstract

BankIdentification

Properties:

Annotations
  • @BuiltValue.new()

Constructors

BankIdentification([void updates(BankIdentificationBuilder b)])
factory

Properties

country → String?
Two-character ISO 3166-1 alpha-2 country code.
no setter
hashCode → int
The hash code for this object.
no setterinherited
identification → String?
The bank identification code.
no setter
identificationType → BankIdentificationIdentificationTypeEnum?
The type of the identification. Possible values: iban, routingNumber, sortCode, bic.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BankIdentificationBuilder)) → BankIdentification
Rebuilds the instance.
inherited
toBuilder() → BankIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BankIdentification>
no setter