BeginScaDeviceRegistrationResponse class abstract

BeginScaDeviceRegistrationResponse

Properties:

  • scaDevice
  • sdkInput - A string that you must pass to the authentication SDK to continue with the registration process.
Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaDevice → ScaDevice?
no setter
sdkInput → String?
A string that you must pass to the authentication SDK to continue with the registration process.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BeginScaDeviceRegistrationResponseBuilder)) → BeginScaDeviceRegistrationResponse
Rebuilds the instance.
inherited
toBuilder() → BeginScaDeviceRegistrationResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BeginScaDeviceRegistrationResponse>
no setter