CALocalAccountIdentificationBuilder class

Properties

accountNumber ↔ String?
getter/setter pair
accountType ↔ CALocalAccountIdentificationAccountTypeEnum?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
institutionNumber ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transitNumber ↔ String?
getter/setter pair
type ↔ CALocalAccountIdentificationTypeEnum?
getter/setter pair

Methods

build() → CALocalAccountIdentification
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CALocalAccountIdentification other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CALocalAccountIdentificationBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited