CZLocalAccountIdentification class abstract

CZLocalAccountIdentification

Properties:

  • accountNumber - The 2- to 16-digit bank account number (Číslo účtu) in the following format: - The optional prefix (předčíslí). - The required second part (základní část) which must be at least two non-zero digits. Examples: - 19-123457 (with prefix) - 123457 (without prefix) - 000019-0000123457 (with prefix, normalized) - 000000-0000123457 (without prefix, normalized)
  • bankCode - The 4-digit bank code (Kód banky), without separators or whitespace.
  • type - czLocal
Annotations
  • @BuiltValue.new()

Constructors

CZLocalAccountIdentification([void updates(CZLocalAccountIdentificationBuilder b)])
factory

Properties

accountNumber → String
The 2- to 16-digit bank account number (Číslo účtu) in the following format: - The optional prefix (předčíslí). - The required second part (základní část) which must be at least two non-zero digits. Examples: - 19-123457 (with prefix) - 123457 (without prefix) - 000019-0000123457 (with prefix, normalized) - 000000-0000123457 (without prefix, normalized)
no setter
bankCode → String
The 4-digit bank code (Kód banky), without separators or whitespace.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CZLocalAccountIdentificationTypeEnum
czLocal
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CZLocalAccountIdentificationBuilder)) → CZLocalAccountIdentification
Rebuilds the instance.
inherited
toBuilder() → CZLocalAccountIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CZLocalAccountIdentification>
no setter