CapabilityProblemBuilder class

Constructors

CapabilityProblemBuilder()

Properties

entity ↔ CapabilityProblemEntityBuilder
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verificationErrors ↔ ListBuilder<VerificationError>
getter/setter pair

Methods

build() → CapabilityProblem
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CapabilityProblem other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CapabilityProblemBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited