CapabilityProblemEntityRecursive class abstract

CapabilityProblemEntityRecursive

Properties:

  • documents - List of document IDs to which the verification errors related to the capabilities correspond to.
  • id - The ID of the entity.
  • type - Type of entity. Possible values: LegalEntity, BankAccount, Document.
Annotations
  • @BuiltValue.new()

Properties

documents → BuiltList<String>?
List of document IDs to which the verification errors related to the capabilities correspond to.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the entity.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CapabilityProblemEntityRecursiveTypeEnum?
Type of entity. Possible values: LegalEntity, BankAccount, Document.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CapabilityProblemEntityRecursiveBuilder)) → CapabilityProblemEntityRecursive
Rebuilds the instance.
inherited
toBuilder() → CapabilityProblemEntityRecursiveBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CapabilityProblemEntityRecursive>
no setter