CapitalBalance class abstract

CapitalBalance

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CapitalBalance([void updates(CapitalBalanceBuilder b)])
factory

Properties

currency → String
The three-character ISO currency code.
no setter
fee → int
Fee amount.
no setter
hashCode → int
The hash code for this object.
no setterinherited
principal → int
Principal amount.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → int
Total amount. A sum of principal amount and fee amount.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CapitalBalanceBuilder)) → CapitalBalance
Rebuilds the instance.
inherited
toBuilder() → CapitalBalanceBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CapitalBalance>
no setter