CapitalGrantAccount class abstract

CapitalGrantAccount

Properties:

  • balances - The balances of the grant account.
  • fundingBalanceAccountId - The unique identifier of the balance account used to fund the grant.
  • id - The identifier of the grant account.
  • limits - The limits of the grant account.
Annotations
  • @BuiltValue.new()

Constructors

CapitalGrantAccount([void updates(CapitalGrantAccountBuilder b)])
factory

Properties

balances → BuiltList<CapitalBalance>?
The balances of the grant account.
no setter
fundingBalanceAccountId → String?
The unique identifier of the balance account used to fund the grant.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The identifier of the grant account.
no setter
limits → BuiltList<GrantLimit>?
The limits of the grant account.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CapitalGrantAccountBuilder)) → CapitalGrantAccount
Rebuilds the instance.
inherited
toBuilder() → CapitalGrantAccountBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CapitalGrantAccount>
no setter