fundingBalanceAccountId property
The unique identifier of the balance account used to fund the grant.
Implementation
@BuiltValueField(wireName: r'fundingBalanceAccountId')
String? get fundingBalanceAccountId;
The unique identifier of the balance account used to fund the grant.
@BuiltValueField(wireName: r'fundingBalanceAccountId')
String? get fundingBalanceAccountId;