CardInfoBuilder class

Constructors

CardInfoBuilder()

Properties

authentication ↔ AuthenticationBuilder
getter/setter pair
brand ↔ String?
getter/setter pair
brandVariant ↔ String?
getter/setter pair
cardholderName ↔ String?
getter/setter pair
configuration ↔ CardConfigurationBuilder
getter/setter pair
deliveryContact ↔ DeliveryContactBuilder
getter/setter pair
formFactor ↔ CardInfoFormFactorEnum?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threeDSecure ↔ String?
getter/setter pair
usage ↔ String?
getter/setter pair

Methods

build() → CardInfo
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CardInfo other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CardInfoBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited