Counterparty class abstract

Counterparty

Properties:

Annotations
  • @BuiltValue.new()

Constructors

Counterparty([void updates(CounterpartyBuilder b)])
factory

Properties

bankAccount → BankAccount?
Contains information about the bank account.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transferInstrumentId → String?
The unique identifier of the transfer instrument.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CounterpartyBuilder)) → Counterparty
Rebuilds the instance.
inherited
toBuilder() → CounterpartyBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Counterparty>
no setter