CreateScaInformation class abstract

CreateScaInformation

Properties:

  • exemption - The type of exemption for Strong Customer Authentication (SCA). Possible values: * lowerLimit: the newly created limit is lower than the existing limit. * notRegulated: the limit is created in a country, region, or industry where it is not mandated by law to use SCA. * setByPlatform: you set a limit for one of your user's balance accounts, or for your balance platform. * initialLimit: there are no existing transfer limits set on the balance account or balance platform. * alreadyPerformed: you are confident about your user's identity and do not need to verify this using SCA.
  • scaOnApproval - Indicates whether to initiate Strong Customer Authentication (SCA) later, during approval, or immediately after you submit this request. Possible values: * true: you can initiate SCA later, during approval, for all pending transfer limits. * false (default): you initiate SCA immediately after submitting the transfer limit request.
Annotations
  • @BuiltValue.new()

Constructors

CreateScaInformation([void updates(CreateScaInformationBuilder b)])
factory

Properties

exemption → ScaExemption?
The type of exemption for Strong Customer Authentication (SCA). Possible values: * lowerLimit: the newly created limit is lower than the existing limit. * notRegulated: the limit is created in a country, region, or industry where it is not mandated by law to use SCA. * setByPlatform: you set a limit for one of your user's balance accounts, or for your balance platform. * initialLimit: there are no existing transfer limits set on the balance account or balance platform. * alreadyPerformed: you are confident about your user's identity and do not need to verify this using SCA.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaOnApproval → bool?
Indicates whether to initiate Strong Customer Authentication (SCA) later, during approval, or immediately after you submit this request. Possible values: * true: you can initiate SCA later, during approval, for all pending transfer limits. * false (default): you initiate SCA immediately after submitting the transfer limit request.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CreateScaInformationBuilder)) → CreateScaInformation
Rebuilds the instance.
inherited
toBuilder() → CreateScaInformationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreateScaInformation>
no setter