CreateSweepConfigurationV2Builder class

Properties

category ↔ CreateSweepConfigurationV2CategoryEnum?
getter/setter pair
counterparty ↔ SweepCounterpartyBuilder
getter/setter pair
currency ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
priorities ↔ ListBuilder<CreateSweepConfigurationV2PrioritiesEnum>
getter/setter pair
reason ↔ CreateSweepConfigurationV2ReasonEnum?
getter/setter pair
reasonDetail ↔ String?
getter/setter pair
reference ↔ String?
getter/setter pair
referenceForBeneficiary ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule ↔ SweepScheduleBuilder
getter/setter pair
status ↔ CreateSweepConfigurationV2StatusEnum?
getter/setter pair
sweepAmount ↔ AmountBuilder
getter/setter pair
targetAmount ↔ AmountBuilder
getter/setter pair
triggerAmount ↔ AmountBuilder
getter/setter pair
type ↔ CreateSweepConfigurationV2TypeEnum?
getter/setter pair

Methods

build() → CreateSweepConfigurationV2
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CreateSweepConfigurationV2 other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CreateSweepConfigurationV2Builder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited