DKLocalAccountIdentification class abstract

DKLocalAccountIdentification

Properties:

  • accountNumber - The 4-10 digits bank account number (Kontonummer) (without separators or whitespace).
  • bankCode - The 4-digit bank code (Registreringsnummer) (without separators or whitespace).
  • type - dkLocal
Annotations
  • @BuiltValue.new()

Constructors

DKLocalAccountIdentification([void updates(DKLocalAccountIdentificationBuilder b)])
factory

Properties

accountNumber → String
The 4-10 digits bank account number (Kontonummer) (without separators or whitespace).
no setter
bankCode → String
The 4-digit bank code (Registreringsnummer) (without separators or whitespace).
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DKLocalAccountIdentificationTypeEnum
dkLocal
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DKLocalAccountIdentificationBuilder)) → DKLocalAccountIdentification
Rebuilds the instance.
inherited
toBuilder() → DKLocalAccountIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DKLocalAccountIdentification>
no setter