Device class abstract

Device

Properties:

  • id - The unique identifier of the SCA device.
  • name_ - The name of the SCA device. You can show this name to your user to help them identify the device.
  • paymentInstrumentId - The unique identifier of the payment instrument that is associated with the SCA device.
  • type - The type of device. Possible values: ios, android, browser.
Annotations
  • @BuiltValue.new()

Constructors

Device([void updates(DeviceBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the SCA device.
no setter
name_ → String?
The name of the SCA device. You can show this name to your user to help them identify the device.
no setter
paymentInstrumentId → String?
The unique identifier of the payment instrument that is associated with the SCA device.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DeviceTypeEnum?
The type of device. Possible values: ios, android, browser.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DeviceBuilder)) → Device
Rebuilds the instance.
inherited
toBuilder() → DeviceBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Device>
no setter