DeviceInfo class abstract

DeviceInfo

Properties:

  • formFactor - The type of device used to provision the network token.
  • osName - The operating system of the device used to provision the network token.
Annotations
  • @BuiltValue.new()

Constructors

DeviceInfo([void updates(DeviceInfoBuilder b)])
factory

Properties

formFactor → String?
The type of device used to provision the network token.
no setter
hashCode → int
The hash code for this object.
no setterinherited
osName → String?
The operating system of the device used to provision the network token.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DeviceInfoBuilder)) → DeviceInfo
Rebuilds the instance.
inherited
toBuilder() → DeviceInfoBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DeviceInfo>
no setter