Duration class abstract

Duration

Properties:

  • unit - The unit of time. You can only use minutes and hours if the interval.type is sliding. Possible values: minutes, hours, days, weeks, or months
  • value - The length of time by the unit. For example, 5 days. The maximum duration is 90 days or an equivalent in other units. For example, 3 months.
Annotations
  • @BuiltValue.new()

Constructors

Duration([void updates(DurationBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → DurationUnitEnum?
The unit of time. You can only use minutes and hours if the interval.type is sliding. Possible values: minutes, hours, days, weeks, or months
no setter
value → int?
The length of time by the unit. For example, 5 days. The maximum duration is 90 days or an equivalent in other units. For example, 3 months.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DurationBuilder)) → Duration
Rebuilds the instance.
inherited
toBuilder() → DurationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Duration>
no setter