GrantOffer class abstract

GrantOffer

Properties:

  • accountHolderId - The identifier of the account holder to which the grant is offered.
  • amount - The principal amount of the grant.
  • contractType - The contract type of the grant offer. Possible value: cashAdvance, loan.
  • expiresAt - The end date of the grant offer validity period.
  • fee - Details of the fee configuration.
  • id - The unique identifier of the grant offer.
  • repayment - Details of the repayment configuration.
  • startsAt - The starting date of the grant offer validity period.
Annotations
  • @BuiltValue.new()

Constructors

GrantOffer([void updates(GrantOfferBuilder b)])
factory

Properties

accountHolderId → String
The identifier of the account holder to which the grant is offered.
no setter
amount → Amount?
The principal amount of the grant.
no setter
contractType → GrantOfferContractTypeEnum?
The contract type of the grant offer. Possible value: cashAdvance, loan.
no setter
expiresAt → DateTime?
The end date of the grant offer validity period.
no setter
fee → Fee?
Details of the fee configuration.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the grant offer.
no setter
repayment → Repayment?
Details of the repayment configuration.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startsAt → DateTime?
The starting date of the grant offer validity period.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GrantOfferBuilder)) → GrantOffer
Rebuilds the instance.
inherited
toBuilder() → GrantOfferBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GrantOffer>
no setter