HULocalAccountIdentification class abstract

HULocalAccountIdentification

Properties:

  • accountNumber - The 24-digit bank account number, without separators or whitespace.
  • type - huLocal
Annotations
  • @BuiltValue.new()

Constructors

HULocalAccountIdentification([void updates(HULocalAccountIdentificationBuilder b)])
factory

Properties

accountNumber → String
The 24-digit bank account number, without separators or whitespace.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → HULocalAccountIdentificationTypeEnum
huLocal
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(HULocalAccountIdentificationBuilder)) → HULocalAccountIdentification
Rebuilds the instance.
inherited
toBuilder() → HULocalAccountIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<HULocalAccountIdentification>
no setter