IbanAccountIdentification class abstract

IbanAccountIdentification

Properties:

  • iban - The international bank account number as defined in the ISO-13616 standard.
  • type - iban
Annotations
  • @BuiltValue.new()

Constructors

IbanAccountIdentification([void updates(IbanAccountIdentificationBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
iban → String
The international bank account number as defined in the ISO-13616 standard.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → IbanAccountIdentificationTypeEnum
iban
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(IbanAccountIdentificationBuilder)) → IbanAccountIdentification
Rebuilds the instance.
inherited
toBuilder() → IbanAccountIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<IbanAccountIdentification>
no setter