Link class abstract

Link

Properties:

  • first - The link to the first page of the list.
  • last - The link to the last page of the list.
  • next - The link to the next page of the list.
  • previous - The link to the previous page of the list.
  • self - The link to the list page you are currently viewing.
Annotations
  • @BuiltValue.new()

Constructors

Link([void updates(LinkBuilder b)])
factory

Properties

first → Href?
The link to the first page of the list.
no setter
hashCode → int
The hash code for this object.
no setterinherited
last → Href?
The link to the last page of the list.
no setter
next → Href?
The link to the next page of the list.
no setter
previous → Href?
The link to the previous page of the list.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
self → Href?
The link to the list page you are currently viewing.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(LinkBuilder)) → Link
Rebuilds the instance.
inherited
toBuilder() → LinkBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Link>
no setter