MatchingTransactionsRestriction class abstract

MatchingTransactionsRestriction

Properties:

  • operation - Defines how the condition must be evaluated.
  • value - The number of transactions.
Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
operation → String
Defines how the condition must be evaluated.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int?
The number of transactions.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(MatchingTransactionsRestrictionBuilder)) → MatchingTransactionsRestriction
Rebuilds the instance.
inherited
toBuilder() → MatchingTransactionsRestrictionBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<MatchingTransactionsRestriction>
no setter