MccsRestriction class abstract

MccsRestriction

Properties:

  • operation - Defines how the condition must be evaluated.
  • value - List of merchant category codes (MCCs).
Annotations
  • @BuiltValue.new()

Constructors

MccsRestriction([void updates(MccsRestrictionBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
operation → String
Defines how the condition must be evaluated.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → BuiltList<String>?
List of merchant category codes (MCCs).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(MccsRestrictionBuilder)) → MccsRestriction
Rebuilds the instance.
inherited
toBuilder() → MccsRestrictionBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<MccsRestriction>
no setter