NOLocalAccountIdentification class abstract

NOLocalAccountIdentification

Properties:

  • accountNumber - The 11-digit bank account number, without separators or whitespace.
  • type - noLocal
Annotations
  • @BuiltValue.new()

Constructors

NOLocalAccountIdentification([void updates(NOLocalAccountIdentificationBuilder b)])
factory

Properties

accountNumber → String
The 11-digit bank account number, without separators or whitespace.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → NOLocalAccountIdentificationTypeEnum
noLocal
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NOLocalAccountIdentificationBuilder)) → NOLocalAccountIdentification
Rebuilds the instance.
inherited
toBuilder() → NOLocalAccountIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NOLocalAccountIdentification>
no setter