NetworkToken class abstract

NetworkToken

Properties:

  • brandVariant - The card brand variant of the payment instrument associated with the network token. For example, mc_prepaid_mrw.
  • creationDate - Date and time when the network token was created, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00..
  • device - Contains information about the device used to provision the network token.
  • id - The unique identifier of the network token.
  • paymentInstrumentId - The unique identifier of the payment instrument to which this network token belongs to.
  • status - The status of the network token. Possible values: active, inactive, suspended, closed.
  • tokenLastFour - The last four digits of the network token id.
  • tokenRequestor - The token requestor is an entity who requested tokenization of the card for secure payments.
  • type - The type of network token. For example, wallet, cof.
Annotations
  • @BuiltValue.new()

Constructors

NetworkToken([void updates(NetworkTokenBuilder b)])
factory

Properties

brandVariant → String?
The card brand variant of the payment instrument associated with the network token. For example, mc_prepaid_mrw.
no setter
creationDate → DateTime?
Date and time when the network token was created, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00..
no setter
device → DeviceInfo?
Contains information about the device used to provision the network token.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the network token.
no setter
paymentInstrumentId → String?
The unique identifier of the payment instrument to which this network token belongs to.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → NetworkTokenStatusEnum?
The status of the network token. Possible values: active, inactive, suspended, closed.
no setter
tokenLastFour → String?
The last four digits of the network token id.
no setter
tokenRequestor → NetworkTokenRequestor?
The token requestor is an entity who requested tokenization of the card for secure payments.
no setter
type → String?
The type of network token. For example, wallet, cof.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NetworkTokenBuilder)) → NetworkToken
Rebuilds the instance.
inherited
toBuilder() → NetworkTokenBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NetworkToken>
no setter