NetworkTokenActivationDataResponse class abstract

NetworkTokenActivationDataResponse

Properties:

Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkInput → String?
A block of data that contains the activation data for a network token. This sdkInput is required to initialize Adyen's SDK for network token provisioning. For more information, see the repositories for Adyen's SDKs for network token provisioning: * Adyen Apple Pay Provisioning SDK. * Adyen Google Wallet Provisioning SDK
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NetworkTokenActivationDataResponseBuilder)) → NetworkTokenActivationDataResponse
Rebuilds the instance.
inherited
toBuilder() → NetworkTokenActivationDataResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NetworkTokenActivationDataResponse>
no setter