NumberAndBicAccountIdentification class abstract

NumberAndBicAccountIdentification

Properties:

  • accountNumber - The bank account number, without separators or whitespace. The length and format depends on the bank or country.
  • additionalBankIdentification - Additional identification codes of the bank. Some banks may require these identifiers for cross-border transfers.
  • bic - The bank's 8- or 11-character BIC or SWIFT code.
  • type - numberAndBic
Annotations
  • @BuiltValue.new()

Properties

accountNumber → String
The bank account number, without separators or whitespace. The length and format depends on the bank or country.
no setter
additionalBankIdentification → AdditionalBankIdentification?
Additional identification codes of the bank. Some banks may require these identifiers for cross-border transfers.
no setter
bic → String
The bank's 8- or 11-character BIC or SWIFT code.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → NumberAndBicAccountIdentificationTypeEnum
numberAndBic
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NumberAndBicAccountIdentificationBuilder)) → NumberAndBicAccountIdentification
Rebuilds the instance.
inherited
toBuilder() → NumberAndBicAccountIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NumberAndBicAccountIdentification>
no setter