PLLocalAccountIdentification class abstract

PLLocalAccountIdentification

Properties:

Annotations
  • @BuiltValue.new()

Constructors

PLLocalAccountIdentification([void updates(PLLocalAccountIdentificationBuilder b)])
factory

Properties

accountNumber → String
The 26-digit bank account number (Numer rachunku), without separators or whitespace.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PLLocalAccountIdentificationTypeEnum
plLocal
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PLLocalAccountIdentificationBuilder)) → PLLocalAccountIdentification
Rebuilds the instance.
inherited
toBuilder() → PLLocalAccountIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PLLocalAccountIdentification>
no setter