PaginatedAccountHoldersResponse class abstract

PaginatedAccountHoldersResponse

Properties:

  • accountHolders - List of account holders.
  • hasNext - Indicates whether there are more items on the next page.
  • hasPrevious - Indicates whether there are more items on the previous page.
Annotations
  • @BuiltValue.new()

Properties

accountHolders → BuiltList<AccountHolder>
List of account holders.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasNext bool
Indicates whether there are more items on the next page.
no setter
hasPrevious bool
Indicates whether there are more items on the previous page.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaginatedAccountHoldersResponseBuilder)) PaginatedAccountHoldersResponse
Rebuilds the instance.
inherited
toBuilder() PaginatedAccountHoldersResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaginatedAccountHoldersResponse>
no setter