PaginatedBalanceAccountsResponse class abstract

PaginatedBalanceAccountsResponse

Properties:

  • balanceAccounts - List of balance accounts.
  • hasNext - Indicates whether there are more items on the next page.
  • hasPrevious - Indicates whether there are more items on the previous page.
Annotations
  • @BuiltValue.new()

Properties

balanceAccounts → BuiltList<BalanceAccountBase>
List of balance accounts.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNext → bool
Indicates whether there are more items on the next page.
no setter
hasPrevious → bool
Indicates whether there are more items on the previous page.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaginatedBalanceAccountsResponseBuilder)) → PaginatedBalanceAccountsResponse
Rebuilds the instance.
inherited
toBuilder() → PaginatedBalanceAccountsResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaginatedBalanceAccountsResponse>
no setter