PaginatedGetCardOrderResponse class abstract

PaginatedGetCardOrderResponse

Properties:

  • cardOrders - Contains objects with information about card orders.
  • hasNext - Indicates whether there are more items on the next page.
  • hasPrevious - Indicates whether there are more items on the previous page.
Annotations
  • @BuiltValue.new()

Properties

cardOrders → BuiltList<CardOrder>?
Contains objects with information about card orders.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNext → bool
Indicates whether there are more items on the next page.
no setter
hasPrevious → bool
Indicates whether there are more items on the previous page.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaginatedGetCardOrderResponseBuilder)) → PaginatedGetCardOrderResponse
Rebuilds the instance.
inherited
toBuilder() → PaginatedGetCardOrderResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaginatedGetCardOrderResponse>
no setter