PaginatedPaymentInstrumentsResponse class abstract

PaginatedPaymentInstrumentsResponse

Properties:

  • hasNext - Indicates whether there are more items on the next page.
  • hasPrevious - Indicates whether there are more items on the previous page.
  • paymentInstruments - List of payment instruments associated with the balance account.
Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasNext → bool
Indicates whether there are more items on the next page.
no setter
hasPrevious → bool
Indicates whether there are more items on the previous page.
no setter
paymentInstruments → BuiltList<PaymentInstrument>
List of payment instruments associated with the balance account.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaginatedPaymentInstrumentsResponseBuilder)) → PaginatedPaymentInstrumentsResponse
Rebuilds the instance.
inherited
toBuilder() → PaginatedPaymentInstrumentsResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaginatedPaymentInstrumentsResponse>
no setter