PaymentInstrumentGroup class abstract

PaymentInstrumentGroup

Properties:

  • balancePlatform - The unique identifier of the balance platform to which the payment instrument group belongs.
  • description - Your description for the payment instrument group.
  • id - The unique identifier of the payment instrument group.
  • properties - Properties of the payment instrument group.
  • reference - Your reference for the payment instrument group.
  • txVariant - The tx variant of the payment instrument group.
Annotations
  • @BuiltValue.new()

Constructors

PaymentInstrumentGroup([void updates(PaymentInstrumentGroupBuilder b)])
factory

Properties

balancePlatform → String
The unique identifier of the balance platform to which the payment instrument group belongs.
no setter
description → String?
Your description for the payment instrument group.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the payment instrument group.
no setter
properties → BuiltMap<String, String>?
Properties of the payment instrument group.
no setter
reference → String?
Your reference for the payment instrument group.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txVariant → String
The tx variant of the payment instrument group.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaymentInstrumentGroupBuilder)) → PaymentInstrumentGroup
Rebuilds the instance.
inherited
toBuilder() → PaymentInstrumentGroupBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentInstrumentGroup>
no setter