PaymentInstrumentRevealInfo class abstract

PaymentInstrumentRevealInfo

Properties:

  • cvc - The CVC2 value of the card.
  • expiration - The expiration date of the card.
  • pan - The primary account number (PAN) of the card.
Annotations
  • @BuiltValue.new()

Constructors

PaymentInstrumentRevealInfo([void updates(PaymentInstrumentRevealInfoBuilder b)])
factory

Properties

cvc String
The CVC2 value of the card.
no setter
expiration Expiry
The expiration date of the card.
no setter
hashCode int
The hash code for this object.
no setterinherited
pan String
The primary account number (PAN) of the card.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaymentInstrumentRevealInfoBuilder)) PaymentInstrumentRevealInfo
Rebuilds the instance.
inherited
toBuilder() PaymentInstrumentRevealInfoBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentInstrumentRevealInfo>
no setter