PaymentInstrumentUpdateRequestBuilder class

Properties

balanceAccountId String?
getter/setter pair
card CardInfoBuilder
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PaymentInstrumentUpdateRequestStatusEnum?
getter/setter pair
statusComment String?
getter/setter pair
statusReason PaymentInstrumentUpdateRequestStatusReasonEnum?
getter/setter pair

Methods

build() PaymentInstrumentUpdateRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(PaymentInstrumentUpdateRequest other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(PaymentInstrumentUpdateRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited