endOfLife constant

  1. @BuiltValueEnumConst.new(wireName: r'endOfLife')
PaymentInstrumentUpdateRequestStatusReasonEnum const endOfLife

The reason for updating the status of the payment instrument. Possible values: lost, stolen, damaged, suspectedFraud, expired, endOfLife, accountClosure, other. If the reason is other, you must also send the statusComment parameter describing the status change.

Implementation

@BuiltValueEnumConst(wireName: r'endOfLife')
static const PaymentInstrumentUpdateRequestStatusReasonEnum endOfLife = _$paymentInstrumentUpdateRequestStatusReasonEnum_endOfLife;