suspectedFraud constant
- @BuiltValueEnumConst.new(wireName: r'suspectedFraud')
The reason for updating the status of the payment instrument. Possible values: lost, stolen, damaged, suspectedFraud, expired, endOfLife, accountClosure, other. If the reason is other, you must also send the statusComment parameter describing the status change.
Implementation
@BuiltValueEnumConst(wireName: r'suspectedFraud')
static const PaymentInstrumentUpdateRequestStatusReasonEnum suspectedFraud = _$paymentInstrumentUpdateRequestStatusReasonEnum_suspectedFraud;