PinChangeResponse class abstract

PinChangeResponse

Properties:

  • status - The status of the request for PIN change. Possible values: completed, pending, unavailable.
Annotations
  • @BuiltValue.new()

Constructors

PinChangeResponse([void updates(PinChangeResponseBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → PinChangeResponseStatusEnum
The status of the request for PIN change. Possible values: completed, pending, unavailable.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PinChangeResponseBuilder)) → PinChangeResponse
Rebuilds the instance.
inherited
toBuilder() → PinChangeResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PinChangeResponse>
no setter