PlatformPaymentConfiguration class abstract

PlatformPaymentConfiguration

Properties:

  • salesDayClosingTime - Specifies at what time a sales day ends for this account. Possible values: Time in "HH:MM" format. HH ranges from 00 to 07. MM must be 00. Default value: "00:00".
  • settlementDelayDays - Specifies after how many business days the funds in a settlement batch are made available in this balance account. Possible values: 1 to 20, or null. Default value: null.
Annotations
  • @BuiltValue.new()

Constructors

PlatformPaymentConfiguration([void updates(PlatformPaymentConfigurationBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salesDayClosingTime → String?
Specifies at what time a sales day ends for this account. Possible values: Time in "HH:MM" format. HH ranges from 00 to 07. MM must be 00. Default value: "00:00".
no setter
settlementDelayDays → int?
Specifies after how many business days the funds in a settlement batch are made available in this balance account. Possible values: 1 to 20, or null. Default value: null.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PlatformPaymentConfigurationBuilder)) → PlatformPaymentConfiguration
Rebuilds the instance.
inherited
toBuilder() → PlatformPaymentConfigurationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PlatformPaymentConfiguration>
no setter