RegisterSCAResponse class abstract

RegisterSCAResponse

Properties:

  • id - The unique identifier of the SCA device you are registering.
  • paymentInstrumentId - The unique identifier of the payment instrument for which you are registering the SCA device.
  • sdkInput - A string that you must pass to the authentication SDK to continue with the registration process.
  • success - Specifies if the registration was initiated successfully.
Annotations
  • @BuiltValue.new()

Constructors

RegisterSCAResponse([void updates(RegisterSCAResponseBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the SCA device you are registering.
no setter
paymentInstrumentId → String?
The unique identifier of the payment instrument for which you are registering the SCA device.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkInput → String?
A string that you must pass to the authentication SDK to continue with the registration process.
no setter
success → bool?
Specifies if the registration was initiated successfully.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RegisterSCAResponseBuilder)) → RegisterSCAResponse
Rebuilds the instance.
inherited
toBuilder() → RegisterSCAResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RegisterSCAResponse>
no setter