Repayment class abstract

Repayment

Properties:

  • basisPoints - The repayment that is deducted daily from incoming net volume, in basis points.
  • term - An object containing the details of the configuration for repayment term.
  • threshold - An object containing the details of the 30-day repayment threshold.
Annotations
  • @BuiltValue.new()

Constructors

Repayment([void updates(RepaymentBuilder b)])
factory

Properties

basisPoints → int
The repayment that is deducted daily from incoming net volume, in basis points.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
term → RepaymentTerm?
An object containing the details of the configuration for repayment term.
no setter
threshold → ThresholdRepayment?
An object containing the details of the 30-day repayment threshold.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RepaymentBuilder)) → Repayment
Rebuilds the instance.
inherited
toBuilder() → RepaymentBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Repayment>
no setter