RepaymentTerm class abstract

RepaymentTerm

Properties:

  • estimatedDays - The estimated term for repaying the grant, in days.
  • maximumDays - The maximum term for repaying the grant, in days. Only applies when contractType is loan.
Annotations
  • @BuiltValue.new()

Constructors

RepaymentTerm([void updates(RepaymentTermBuilder b)])
factory

Properties

estimatedDays → int
The estimated term for repaying the grant, in days.
no setter
hashCode → int
The hash code for this object.
no setterinherited
maximumDays → int?
The maximum term for repaying the grant, in days. Only applies when contractType is loan.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RepaymentTermBuilder)) → RepaymentTerm
Rebuilds the instance.
inherited
toBuilder() → RepaymentTermBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RepaymentTerm>
no setter