RestServiceError class abstract

RestServiceError

Properties:

  • detail - A human-readable explanation specific to this occurrence of the problem.
  • errorCode - A code that identifies the problem type.
  • instance - A unique URI that identifies the specific occurrence of the problem.
  • invalidFields - Detailed explanation of each validation error, when applicable.
  • requestId - A unique reference for the request, essentially the same as pspReference.
  • response - JSON response payload.
  • status - The HTTP status code.
  • title - A short, human-readable summary of the problem type.
  • type - A URI that identifies the problem type, pointing to human-readable documentation on this problem type.
Annotations
  • @BuiltValue.new()

Constructors

RestServiceError([void updates(RestServiceErrorBuilder b)])
factory

Properties

detail → String
A human-readable explanation specific to this occurrence of the problem.
no setter
errorCode → String
A code that identifies the problem type.
no setter
hashCode → int
The hash code for this object.
no setterinherited
instance → String?
A unique URI that identifies the specific occurrence of the problem.
no setter
invalidFields → BuiltList<InvalidField>?
Detailed explanation of each validation error, when applicable.
no setter
requestId → String?
A unique reference for the request, essentially the same as pspReference.
no setter
response → JsonObject?
JSON response payload.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int
The HTTP status code.
no setter
title → String
A short, human-readable summary of the problem type.
no setter
type → String
A URI that identifies the problem type, pointing to human-readable documentation on this problem type.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RestServiceErrorBuilder)) → RestServiceError
Rebuilds the instance.
inherited
toBuilder() → RestServiceErrorBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RestServiceError>
no setter