RevealPinRequest class abstract

RevealPinRequest

Properties:

  • encryptedKey - The symmetric session key that you encrypted with the public key that you received from Adyen.
  • paymentInstrumentId - The unique identifier of the payment instrument, which is the card for which you are managing the PIN.
Annotations
  • @BuiltValue.new()

Constructors

RevealPinRequest([void updates(RevealPinRequestBuilder b)])
factory

Properties

encryptedKey → String
The symmetric session key that you encrypted with the public key that you received from Adyen.
no setter
hashCode → int
The hash code for this object.
no setterinherited
paymentInstrumentId → String
The unique identifier of the payment instrument, which is the card for which you are managing the PIN.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RevealPinRequestBuilder)) → RevealPinRequest
Rebuilds the instance.
inherited
toBuilder() → RevealPinRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RevealPinRequest>
no setter