RevealPinResponse class abstract

RevealPinResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

RevealPinResponse([void updates(RevealPinResponseBuilder b)])
factory

Properties

encryptedPinBlock → String
The encrypted PIN block.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
The 16-digit token that you need to extract the encryptedPinBlock.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RevealPinResponseBuilder)) → RevealPinResponse
Rebuilds the instance.
inherited
toBuilder() → RevealPinResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RevealPinResponse>
no setter