RiskScores class abstract

RiskScores

Properties:

  • mastercard - Transaction risk score provided by Mastercard. Values provided by Mastercard range between 0 (lowest risk) to 998 (highest risk).
  • visa - Transaction risk score provided by Visa. Values provided by Visa range between 01 (lowest risk) to 99 (highest risk).
Annotations
  • @BuiltValue.new()

Constructors

RiskScores([void updates(RiskScoresBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
mastercard → int?
Transaction risk score provided by Mastercard. Values provided by Mastercard range between 0 (lowest risk) to 998 (highest risk).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visa → int?
Transaction risk score provided by Visa. Values provided by Visa range between 01 (lowest risk) to 99 (highest risk).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RiskScoresBuilder)) → RiskScores
Rebuilds the instance.
inherited
toBuilder() → RiskScoresBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RiskScores>
no setter