SGLocalAccountIdentification class abstract

SGLocalAccountIdentification

Properties:

  • accountNumber - The 4- to 19-digit bank account number, without separators or whitespace.
  • bic - The bank's 8- or 11-character BIC or SWIFT code.
  • type - sgLocal
Annotations
  • @BuiltValue.new()

Constructors

SGLocalAccountIdentification([void updates(SGLocalAccountIdentificationBuilder b)])
factory

Properties

accountNumber → String
The 4- to 19-digit bank account number, without separators or whitespace.
no setter
bic → String
The bank's 8- or 11-character BIC or SWIFT code.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → SGLocalAccountIdentificationTypeEnum?
sgLocal
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SGLocalAccountIdentificationBuilder)) → SGLocalAccountIdentification
Rebuilds the instance.
inherited
toBuilder() → SGLocalAccountIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SGLocalAccountIdentification>
no setter