ScaEntity class abstract

ScaEntity

Properties:

  • id - The unique identifier of the entity.
  • type - The type of the entity that you are associating with the SCA device. Possible values: accountHolder or paymentInstrument.
Annotations
  • @BuiltValue.new()

Constructors

ScaEntity([void updates(ScaEntityBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier of the entity.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ScaEntityType
The type of the entity that you are associating with the SCA device. Possible values: accountHolder or paymentInstrument.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ScaEntityBuilder)) → ScaEntity
Rebuilds the instance.
inherited
toBuilder() → ScaEntityBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ScaEntity>
no setter