SearchRegisteredDevicesResponse class abstract

SearchRegisteredDevicesResponse

Properties:

  • data - Contains a list of registered SCA devices and their corresponding details.
  • itemsTotal - The total amount of registered SCA devices that match the query parameters.
  • link - Contains links to the list pages.
  • pagesTotal - The total amount of list pages.
Annotations
  • @BuiltValue.new()

Properties

data → BuiltList<Device>?
Contains a list of registered SCA devices and their corresponding details.
no setter
hashCode → int
The hash code for this object.
no setterinherited
itemsTotal → int?
The total amount of registered SCA devices that match the query parameters.
no setter
Contains links to the list pages.
no setter
pagesTotal → int?
The total amount of list pages.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SearchRegisteredDevicesResponseBuilder)) → SearchRegisteredDevicesResponse
Rebuilds the instance.
inherited
toBuilder() → SearchRegisteredDevicesResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SearchRegisteredDevicesResponse>
no setter