SubmitScaAssociationResponse class abstract

SubmitScaAssociationResponse

Properties:

  • scaAssociations - List of associations created to the entities and their statuses.
Annotations
  • @BuiltValue.new()

Constructors

SubmitScaAssociationResponse([void updates(SubmitScaAssociationResponseBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaAssociations → BuiltList<Association>
List of associations created to the entities and their statuses.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SubmitScaAssociationResponseBuilder)) → SubmitScaAssociationResponse
Rebuilds the instance.
inherited
toBuilder() → SubmitScaAssociationResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SubmitScaAssociationResponse>
no setter