TransactionRuleInfoBuilder class

Properties

aggregationLevel ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
endDate ↔ String?
getter/setter pair
entityKey ↔ TransactionRuleEntityKeyBuilder
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interval ↔ TransactionRuleIntervalBuilder
getter/setter pair
outcomeType ↔ TransactionRuleInfoOutcomeTypeEnum?
getter/setter pair
reference ↔ String?
getter/setter pair
requestType ↔ TransactionRuleInfoRequestTypeEnum?
getter/setter pair
ruleRestrictions ↔ TransactionRuleRestrictionsBuilder
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ int?
getter/setter pair
startDate ↔ String?
getter/setter pair
status ↔ TransactionRuleInfoStatusEnum?
getter/setter pair
type ↔ TransactionRuleInfoTypeEnum?
getter/setter pair

Methods

build() → TransactionRuleInfo
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(TransactionRuleInfo other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(TransactionRuleInfoBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited