TransactionRuleIntervalBuilder class

Properties

dayOfMonth ↔ int?
getter/setter pair
dayOfWeek ↔ TransactionRuleIntervalDayOfWeekEnum?
getter/setter pair
duration ↔ DurationBuilder
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeOfDay ↔ String?
getter/setter pair
timeZone ↔ String?
getter/setter pair
type ↔ TransactionRuleIntervalTypeEnum?
getter/setter pair

Methods

build() → TransactionRuleInterval
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(TransactionRuleInterval other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(TransactionRuleIntervalBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited