TransferLimit class abstract

The transfer limit configured to regulate outgoing transfers.

Properties:

  • amount - The amount for the transfer limit. This is the maximum amount allowed per transfer or per day based on the scope of the limit.
  • endsAt - The date and time when the transfer limit becomes inactive. If you do not specify an end date, the limit stays active until you override it with a new limit. Format ISO 8601: YYYY-MM-DDThh:mm:ss.sssTZD
  • id - The unique identifier of the transfer limit.
  • limitStatus - The status of the transfer limit. Possible values: * active: the limit is currently active. * inactive: the limit is currently inactive. * pendingSCA: the limit is pending until your user performs SCA. * scheduled: the limit is scheduled to become active at a future date.
  • reference - Your reference for the transfer limit.
  • scaInformation - Information for the Strong Customer Authentication (SCA)
  • scope - The scope to which the transfer limit applies. Possible values: * perTransaction: you set a maximum amount for each transfer made from the balance account or balance platform. * perDay: you set a maximum total amount for all transfers made from the balance account or balance platform in a day.
  • startsAt - The date and time when the transfer limit becomes active. If you specify a date in the future, we will schedule a transfer limit. Format ISO 8601: YYYY-MM-DDThh:mm:ss.sssTZD
  • transferType - The type of transfer to which the limit applies. Possible values: * instant: the limit applies to transfers with an instant priority. * all: the limit applies to all transfers, regardless of priority.
Annotations
  • @BuiltValue.new()

Constructors

TransferLimit([void updates(TransferLimitBuilder b)])
factory

Properties

amount → Amount
The amount for the transfer limit. This is the maximum amount allowed per transfer or per day based on the scope of the limit.
no setter
endsAt → DateTime?
The date and time when the transfer limit becomes inactive. If you do not specify an end date, the limit stays active until you override it with a new limit. Format ISO 8601: YYYY-MM-DDThh:mm:ss.sssTZD
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier of the transfer limit.
no setter
limitStatus → LimitStatus
The status of the transfer limit. Possible values: * active: the limit is currently active. * inactive: the limit is currently inactive. * pendingSCA: the limit is pending until your user performs SCA. * scheduled: the limit is scheduled to become active at a future date.
no setter
reference → String?
Your reference for the transfer limit.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaInformation → ScaInformation?
Information for the Strong Customer Authentication (SCA)
no setter
scope → Scope
The scope to which the transfer limit applies. Possible values: * perTransaction: you set a maximum amount for each transfer made from the balance account or balance platform. * perDay: you set a maximum total amount for all transfers made from the balance account or balance platform in a day.
no setter
startsAt → DateTime
The date and time when the transfer limit becomes active. If you specify a date in the future, we will schedule a transfer limit. Format ISO 8601: YYYY-MM-DDThh:mm:ss.sssTZD
no setter
transferType → TransferType
The type of transfer to which the limit applies. Possible values: * instant: the limit applies to transfers with an instant priority. * all: the limit applies to all transfers, regardless of priority.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TransferLimitBuilder)) → TransferLimit
Rebuilds the instance.
inherited
toBuilder() → TransferLimitBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TransferLimit>
no setter