TransferLimitBuilder class

Constructors

TransferLimitBuilder()

Properties

amount ↔ AmountBuilder
getter/setter pair
endsAt ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
limitStatus ↔ LimitStatus?
getter/setter pair
reference ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaInformation ↔ ScaInformationBuilder
getter/setter pair
scope ↔ Scope?
getter/setter pair
startsAt ↔ DateTime?
getter/setter pair
transferType ↔ TransferType?
getter/setter pair

Methods

build() → TransferLimit
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(TransferLimit other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(TransferLimitBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited