TransferRouteBuilder class

Constructors

TransferRouteBuilder()

Properties

category ↔ TransferRouteCategoryEnum?
getter/setter pair
country ↔ String?
getter/setter pair
currency ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
priority ↔ TransferRoutePriorityEnum?
getter/setter pair
requirements ↔ ListBuilder<TransferRouteRequirementsInner>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → TransferRoute
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(TransferRoute other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(TransferRouteBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited