TransferRouteRequestBuilder class

Properties

balanceAccountId ↔ String?
getter/setter pair
balancePlatform ↔ String?
getter/setter pair
category ↔ TransferRouteRequestCategoryEnum?
getter/setter pair
counterparty ↔ CounterpartyBuilder
getter/setter pair
country ↔ String?
getter/setter pair
currency ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
priorities ↔ ListBuilder<TransferRouteRequestPrioritiesEnum>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → TransferRouteRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(TransferRouteRequest other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(TransferRouteRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited