UKLocalAccountIdentification class abstract

UKLocalAccountIdentification

Properties:

Annotations
  • @BuiltValue.new()

Constructors

UKLocalAccountIdentification([void updates(UKLocalAccountIdentificationBuilder b)])
factory

Properties

accountNumber → String
The 8-digit bank account number, without separators or whitespace.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortCode → String
The 6-digit sort code, without separators or whitespace.
no setter
type → UKLocalAccountIdentificationTypeEnum
ukLocal
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UKLocalAccountIdentificationBuilder)) → UKLocalAccountIdentification
Rebuilds the instance.
inherited
toBuilder() → UKLocalAccountIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UKLocalAccountIdentification>
no setter