USInstantPayoutAddressRequirement class abstract

USInstantPayoutAddressRequirement

Properties:

  • description - Specifies that you must provide complete street addresses for the party and counterParty for transactions greater than USD 3000.
  • type - usInstantPayoutAddressRequirement
Annotations
  • @BuiltValue.new()

Properties

description → String?
Specifies that you must provide complete street addresses for the party and counterParty for transactions greater than USD 3000.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → USInstantPayoutAddressRequirementTypeEnum
usInstantPayoutAddressRequirement
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(USInstantPayoutAddressRequirementBuilder)) → USInstantPayoutAddressRequirement
Rebuilds the instance.
inherited
toBuilder() → USInstantPayoutAddressRequirementBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<USInstantPayoutAddressRequirement>
no setter