USInternationalAchAddressRequirement class abstract

USInternationalAchAddressRequirement

Properties:

  • description - Specifies that you must provide a complete street address for International ACH (IAT) transactions.
  • type - usInternationalAchAddressRequirement
Annotations
  • @BuiltValue.new()

Properties

description String?
Specifies that you must provide a complete street address for International ACH (IAT) transactions.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type USInternationalAchAddressRequirementTypeEnum
usInternationalAchAddressRequirement
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(USInternationalAchAddressRequirementBuilder)) USInternationalAchAddressRequirement
Rebuilds the instance.
inherited
toBuilder() USInternationalAchAddressRequirementBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<USInternationalAchAddressRequirement>
no setter