USInternationalAchPriorityRequirement class abstract
USInternationalAchPriorityRequirement
Properties:
- description - Specifies that transactions deemed to be International ACH (IAT) per OFAC/NACHA rules cannot have fast priority.
- type - usInternationalAchPriorityRequirement
- Annotations
-
- @BuiltValue.new()
Constructors
- USInternationalAchPriorityRequirement([void updates(USInternationalAchPriorityRequirementBuilder b)])
-
factory
Properties
- description → String?
-
Specifies that transactions deemed to be International ACH (IAT) per OFAC/NACHA rules cannot have fast priority.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → USInternationalAchPriorityRequirementTypeEnum
-
usInternationalAchPriorityRequirement
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(USInternationalAchPriorityRequirementBuilder)) → USInternationalAchPriorityRequirement -
Rebuilds the instance.
inherited
-
toBuilder(
) → USInternationalAchPriorityRequirementBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
USInternationalAchPriorityRequirement> -
no setter