USLocalAccountIdentification class abstract

USLocalAccountIdentification

Properties:

Annotations
  • @BuiltValue.new()

Constructors

USLocalAccountIdentification([void updates(USLocalAccountIdentificationBuilder b)])
factory

Properties

accountNumber → String
The bank account number, without separators or whitespace.
no setter
accountType → USLocalAccountIdentificationAccountTypeEnum?
The bank account type. Possible values: checking or savings. Defaults to checking.
no setter
hashCode → int
The hash code for this object.
no setterinherited
routingNumber → String
The 9-digit routing number, without separators or whitespace.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → USLocalAccountIdentificationTypeEnum
usLocal
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(USLocalAccountIdentificationBuilder)) → USLocalAccountIdentification
Rebuilds the instance.
inherited
toBuilder() → USLocalAccountIdentificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<USLocalAccountIdentification>
no setter