UpdatePaymentInstrumentBuilder class

Properties

additionalBankAccountIdentifications ↔ ListBuilder<IbanAccountIdentification>
getter/setter pair
balanceAccountId ↔ String?
getter/setter pair
bankAccount ↔ BankAccountDetailsBuilder
getter/setter pair
card ↔ CardBuilder
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
issuingCountryCode ↔ String?
getter/setter pair
paymentInstrumentGroupId ↔ String?
getter/setter pair
reference ↔ String?
getter/setter pair
replacedById ↔ String?
getter/setter pair
replacementOfId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ UpdatePaymentInstrumentStatusEnum?
getter/setter pair
statusComment ↔ String?
getter/setter pair
statusReason ↔ UpdatePaymentInstrumentStatusReasonEnum?
getter/setter pair
type ↔ UpdatePaymentInstrumentTypeEnum?
getter/setter pair

Methods

build() → UpdatePaymentInstrument
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(UpdatePaymentInstrument other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(UpdatePaymentInstrumentBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited