other constant

  1. @BuiltValueEnumConst.new(wireName: r'other')
UpdatePaymentInstrumentStatusReasonEnum const other

The reason for the status of the payment instrument. Possible values: accountClosure, damaged, endOfLife, expired, lost, stolen, suspectedFraud, transactionRule, other. If the reason is other, you must also send the statusComment parameter describing the status change.

Implementation

@BuiltValueEnumConst(wireName: r'other')
static const UpdatePaymentInstrumentStatusReasonEnum other = _$updatePaymentInstrumentStatusReasonEnum_other;