WalletProviderAccountScoreRestriction class abstract

WalletProviderAccountScoreRestriction

Properties:

Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
operation → String
Defines how the condition must be evaluated.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(WalletProviderAccountScoreRestrictionBuilder)) → WalletProviderAccountScoreRestriction
Rebuilds the instance.
inherited
toBuilder() → WalletProviderAccountScoreRestrictionBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<WalletProviderAccountScoreRestriction>
no setter