WebhookSetting class abstract

WebhookSetting

Properties:

  • currency - The three-character ISO currency code of the balance.
  • id - The unique identifier of the webhook setting.
  • status - The status of the webhook setting. Possible values: * active: You receive a balance webhook if any of the conditions in this setting are met. * inactive: You do not receive a balance webhook even if the conditions in this settings are met.
  • target - The resource about whose balance change you want to get notified.
  • type - The type of the webhook setting.
Implementers
Available extensions
Annotations
  • @BuiltValue.new(instantiable: false)

Constructors

WebhookSetting()

Properties

currency → String
The three-character ISO currency code of the balance.
no setter
discriminatorValue → String?

Available on WebhookSetting, provided by the WebhookSettingDiscriminatorExt extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier of the webhook setting.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
The status of the webhook setting. Possible values: * active: You receive a balance webhook if any of the conditions in this setting are met. * inactive: You do not receive a balance webhook even if the conditions in this settings are met.
no setter
target → Target
The resource about whose balance change you want to get notified.
no setter
type → SettingType
The type of the webhook setting.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<WebhookSetting>
no setter