WebhookSettingBuilder class abstract mixin

Implementers
Available extensions

Constructors

WebhookSettingBuilder()

Properties

currency ↔ String?
getter/setter pair
discriminatorValue → String?

Available on WebhookSettingBuilder, provided by the WebhookSettingBuilderDiscriminatorExt extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
getter/setter pair
target ↔ TargetBuilder
getter/setter pair
type ↔ SettingType?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(WebhookSetting other) → void
toString() → String
A string representation of this object.
inherited
update(void updates(WebhookSettingBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited