BinDetail class abstract

BinDetail

Properties:

Annotations
  • @BuiltValue.new()

Constructors

BinDetail([void updates(BinDetailBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
issuerCountry String?
The country where the card was issued.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BinDetailBuilder)) BinDetail
Rebuilds the instance.
inherited
toBuilder() BinDetailBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BinDetail>
no setter