threeDSMethodURL property
In a 3D Secure 2 browser-based flow, this is the URL where you should send the device fingerprint to.
Implementation
@BuiltValueField(wireName: r'threeDSMethodURL')
String? get threeDSMethodURL;
In a 3D Secure 2 browser-based flow, this is the URL where you should send the device fingerprint to.
@BuiltValueField(wireName: r'threeDSMethodURL')
String? get threeDSMethodURL;