AcctInfoChAccPwChangeIndEnum class
- Inheritance
-
- Object
- EnumClass
- AcctInfoChAccPwChangeIndEnum
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
n01
→ const AcctInfoChAccPwChangeIndEnum
-
Indicates the length of time since the cardholder’s account with the 3DS Requestor had a password change or account reset. Allowed values: * 01 — No change * 02 — Changed during this transaction * 03 — Less than 30 days * 04 — 30–60 days * 05 — More than 60 days
-
n02
→ const AcctInfoChAccPwChangeIndEnum
-
Indicates the length of time since the cardholder’s account with the 3DS Requestor had a password change or account reset. Allowed values: * 01 — No change * 02 — Changed during this transaction * 03 — Less than 30 days * 04 — 30–60 days * 05 — More than 60 days
-
n03
→ const AcctInfoChAccPwChangeIndEnum
-
Indicates the length of time since the cardholder’s account with the 3DS Requestor had a password change or account reset. Allowed values: * 01 — No change * 02 — Changed during this transaction * 03 — Less than 30 days * 04 — 30–60 days * 05 — More than 60 days
-
n04
→ const AcctInfoChAccPwChangeIndEnum
-
Indicates the length of time since the cardholder’s account with the 3DS Requestor had a password change or account reset. Allowed values: * 01 — No change * 02 — Changed during this transaction * 03 — Less than 30 days * 04 — 30–60 days * 05 — More than 60 days
-
n05
→ const AcctInfoChAccPwChangeIndEnum
-
Indicates the length of time since the cardholder’s account with the 3DS Requestor had a password change or account reset. Allowed values: * 01 — No change * 02 — Changed during this transaction * 03 — Less than 30 days * 04 — 30–60 days * 05 — More than 60 days
-
unknownDefaultOpenApi
→ const AcctInfoChAccPwChangeIndEnum
-
Indicates the length of time since the cardholder’s account with the 3DS Requestor had a password change or account reset. Allowed values: * 01 — No change * 02 — Changed during this transaction * 03 — Less than 30 days * 04 — 30–60 days * 05 — More than 60 days