AchDetailsBuilder class

Constructors

AchDetailsBuilder()

Properties

accountHolderType AchDetailsAccountHolderTypeEnum?
getter/setter pair
bankAccountNumber String?
getter/setter pair
bankAccountType AchDetailsBankAccountTypeEnum?
getter/setter pair
bankLocationId String?
getter/setter pair
checkoutAttemptId String?
getter/setter pair
encryptedBankAccountNumber String?
getter/setter pair
encryptedBankLocationId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ownerName String?
getter/setter pair
recurringDetailReference String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkData String?
getter/setter pair
storedPaymentMethodId String?
getter/setter pair
transferInstrumentId String?
getter/setter pair
type AchDetailsTypeEnum?
getter/setter pair

Methods

build() AchDetails
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(AchDetails other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(AchDetailsBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited