BacsDirectDebitDetails class abstract
BacsDirectDebitDetails
Properties:
- bankAccountNumber - The bank account number (without separators).
- bankLocationId - The bank routing number of the account.
- checkoutAttemptId - The checkout attempt identifier.
- holderName - The name of the bank account holder.
- recurringDetailReference - This is the
recurringDetailReferencereturned in the response when you created the token. - sdkData - Base64-encoded JSON object containing SDK related parameters required by the SDK
- storedPaymentMethodId - This is the
recurringDetailReferencereturned in the response when you created the token. - transferInstrumentId - The unique identifier of your user's verified transfer instrument, which you can use to top up their balance accounts.
- type - directdebit_GB
- Annotations
-
- @BuiltValue.new()
Constructors
- BacsDirectDebitDetails([void updates(BacsDirectDebitDetailsBuilder b)])
-
factory
Properties
- bankAccountNumber → String?
-
The bank account number (without separators).
no setter
- bankLocationId → String?
-
The bank routing number of the account.
no setter
- checkoutAttemptId → String?
-
The checkout attempt identifier.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- holderName → String?
-
The name of the bank account holder.
no setter
- recurringDetailReference → String?
-
This is the
recurringDetailReferencereturned in the response when you created the token.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkData → String?
-
Base64-encoded JSON object containing SDK related parameters required by the SDK
no setter
- storedPaymentMethodId → String?
-
This is the
recurringDetailReferencereturned in the response when you created the token.no setter - transferInstrumentId → String?
-
The unique identifier of your user's verified transfer instrument, which you can use to top up their balance accounts.
no setter
- type → BacsDirectDebitDetailsTypeEnum?
-
directdebit_GB
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(BacsDirectDebitDetailsBuilder)) → BacsDirectDebitDetails -
Rebuilds the instance.
inherited
-
toBuilder(
) → BacsDirectDebitDetailsBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
BacsDirectDebitDetails> -
no setter