BlikDetails class abstract

BlikDetails

Properties:

  • blikCode - BLIK code consisting of 6 digits.
  • checkoutAttemptId - The checkout attempt identifier.
  • recurringDetailReference - This is the recurringDetailReference returned in the response when you created the token.
  • sdkData - Base64-encoded JSON object containing SDK related parameters required by the SDK
  • storedPaymentMethodId - This is the recurringDetailReference returned in the response when you created the token.
  • type - blik
Annotations
  • @BuiltValue.new()

Constructors

BlikDetails([void updates(BlikDetailsBuilder b)])
factory

Properties

blikCode String?
BLIK code consisting of 6 digits.
no setter
checkoutAttemptId String?
The checkout attempt identifier.
no setter
hashCode int
The hash code for this object.
no setterinherited
recurringDetailReference String?
This is the recurringDetailReference returned in the response when you created the token.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkData String?
Base64-encoded JSON object containing SDK related parameters required by the SDK
no setter
storedPaymentMethodId String?
This is the recurringDetailReference returned in the response when you created the token.
no setter
type BlikDetailsTypeEnum?
blik
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BlikDetailsBuilder)) BlikDetails
Rebuilds the instance.
inherited
toBuilder() BlikDetailsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BlikDetails>
no setter