CardDonationsFundingSourceEnum class
- Inheritance
-
- Object
- EnumClass
- CardDonationsFundingSourceEnum
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
credit
→ const CardDonationsFundingSourceEnum
-
The funding source that should be used when multiple sources are available. For Brazilian combo cards, by default the funding source is credit. To use debit, set this value to debit.
-
debit
→ const CardDonationsFundingSourceEnum
-
The funding source that should be used when multiple sources are available. For Brazilian combo cards, by default the funding source is credit. To use debit, set this value to debit.
-
prepaid
→ const CardDonationsFundingSourceEnum
-
The funding source that should be used when multiple sources are available. For Brazilian combo cards, by default the funding source is credit. To use debit, set this value to debit.
-
unknownDefaultOpenApi
→ const CardDonationsFundingSourceEnum
-
The funding source that should be used when multiple sources are available. For Brazilian combo cards, by default the funding source is credit. To use debit, set this value to debit.