CheckoutVoucherActionBuilder class

Properties

alternativeReference String?
getter/setter pair
collectionInstitutionNumber String?
getter/setter pair
downloadUrl String?
getter/setter pair
entity String?
getter/setter pair
expiresAt String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initialAmount AmountBuilder
getter/setter pair
instructionsUrl String?
getter/setter pair
issuer String?
getter/setter pair
maskedTelephoneNumber String?
getter/setter pair
merchantName String?
getter/setter pair
merchantReference String?
getter/setter pair
passCreationToken String?
getter/setter pair
paymentData String?
getter/setter pair
paymentMethodType String?
getter/setter pair
reference String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shopperEmail String?
getter/setter pair
shopperName String?
getter/setter pair
surcharge AmountBuilder
getter/setter pair
totalAmount AmountBuilder
getter/setter pair
type CheckoutVoucherActionTypeEnum?
getter/setter pair
url String?
getter/setter pair

Methods

build() CheckoutVoucherAction
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CheckoutVoucherAction other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(CheckoutVoucherActionBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited