DonationPaymentRequestPaymentMethodFundingSourceEnum class
- Inheritance
-
- Object
- EnumClass
- DonationPaymentRequestPaymentMethodFundingSourceEnum
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
DonationPaymentRequestPaymentMethodFundingSourceEnum> -
no setter
-
values
→ BuiltSet<
DonationPaymentRequestPaymentMethodFundingSourceEnum> -
no setter
Static Methods
Constants
- credit → const DonationPaymentRequestPaymentMethodFundingSourceEnum
- The funding source that should be used when multiple sources are available. For Brazilian combo cards, by default the funding source is credit. To use debit, set this value to debit.
- debit → const DonationPaymentRequestPaymentMethodFundingSourceEnum
- The funding source that should be used when multiple sources are available. For Brazilian combo cards, by default the funding source is credit. To use debit, set this value to debit.
- prepaid → const DonationPaymentRequestPaymentMethodFundingSourceEnum
- The funding source that should be used when multiple sources are available. For Brazilian combo cards, by default the funding source is credit. To use debit, set this value to debit.
- unknownDefaultOpenApi → const DonationPaymentRequestPaymentMethodFundingSourceEnum
- The funding source that should be used when multiple sources are available. For Brazilian combo cards, by default the funding source is credit. To use debit, set this value to debit.