unknownDefaultOpenApi constant

  1. @BuiltValueEnumConst.new(wireName: r'unknown_default_open_api', fallback: true)
DonationPaymentRequestPaymentMethodFundingSourceEnum const unknownDefaultOpenApi

The funding source that should be used when multiple sources are available. For Brazilian combo cards, by default the funding source is credit. To use debit, set this value to debit.

Implementation

@BuiltValueEnumConst(wireName: r'unknown_default_open_api', fallback: true)
static const DonationPaymentRequestPaymentMethodFundingSourceEnum unknownDefaultOpenApi = _$donationPaymentRequestPaymentMethodFundingSourceEnum_unknownDefaultOpenApi;