walletOwnerTaxId property
The tax identifier of the person receiving the funds.
Implementation
@BuiltValueField(wireName: r'walletOwnerTaxId')
String? get walletOwnerTaxId;
The tax identifier of the person receiving the funds.
@BuiltValueField(wireName: r'walletOwnerTaxId')
String? get walletOwnerTaxId;