GooglePayDetailsTypeEnum class

Inheritance
  • Object
  • EnumClass
  • GooglePayDetailsTypeEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GooglePayDetailsTypeEnum>
no setter
values → BuiltSet<GooglePayDetailsTypeEnum>
no setter

Static Methods

valueOf(String name) GooglePayDetailsTypeEnum

Constants

googlepay → const GooglePayDetailsTypeEnum
googlepay, paywithgoogle
unknownDefaultOpenApi → const GooglePayDetailsTypeEnum
googlepay, paywithgoogle