IdealDonations class abstract

IdealDonations

Properties:

  • checkoutAttemptId - The checkout attempt identifier.
  • issuer - The iDEAL issuer value of the shopper's selected bank. Set this to an id of an iDEAL issuer to preselect it.
  • recurringDetailReference - This is the recurringDetailReference returned in the response when you created the token.
  • sdkData - Base64-encoded JSON object containing SDK related parameters required by the SDK
  • storedPaymentMethodId - This is the recurringDetailReference returned in the response when you created the token.
  • type - ideal
Annotations
  • @BuiltValue.new()

Constructors

IdealDonations([void updates(IdealDonationsBuilder b)])
factory

Properties

checkoutAttemptId String?
The checkout attempt identifier.
no setter
hashCode int
The hash code for this object.
no setterinherited
issuer String?
The iDEAL issuer value of the shopper's selected bank. Set this to an id of an iDEAL issuer to preselect it.
no setter
recurringDetailReference String?
This is the recurringDetailReference returned in the response when you created the token.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkData String?
Base64-encoded JSON object containing SDK related parameters required by the SDK
no setter
storedPaymentMethodId String?
This is the recurringDetailReference returned in the response when you created the token.
no setter
type IdealDonationsTypeEnum?
ideal
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(IdealDonationsBuilder)) IdealDonations
Rebuilds the instance.
inherited
toBuilder() IdealDonationsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<IdealDonations>
no setter