customerReferenceNumber property
The reference number to identify the customer and their order. * Format: ASCII * Max length: 25 characters * Must not start with a space or be all spaces. * Must not be all zeros.
Implementation
@BuiltValueField(wireName: r'customerReferenceNumber')
String? get customerReferenceNumber;