MbwayDetails class abstract

MbwayDetails

Properties:

Annotations
  • @BuiltValue.new()

Constructors

MbwayDetails([void updates(MbwayDetailsBuilder b)])
factory

Properties

checkoutAttemptId String?
The checkout attempt identifier.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkData String?
Base64-encoded JSON object containing SDK related parameters required by the SDK
no setter
shopperEmail String
no setter
telephoneNumber String
no setter
type MbwayDetailsTypeEnum?
mbway
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(MbwayDetailsBuilder)) MbwayDetails
Rebuilds the instance.
inherited
toBuilder() MbwayDetailsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<MbwayDetails>
no setter