MolPayDetails class abstract

MolPayDetails

Properties:

  • checkoutAttemptId - The checkout attempt identifier.
  • issuer - The shopper's bank. Specify this with the issuer value that corresponds to this bank.
  • sdkData - Base64-encoded JSON object containing SDK related parameters required by the SDK
  • type - molpay
Annotations
  • @BuiltValue.new()

Constructors

MolPayDetails([void updates(MolPayDetailsBuilder b)])
factory

Properties

checkoutAttemptId String?
The checkout attempt identifier.
no setter
hashCode int
The hash code for this object.
no setterinherited
issuer String
The shopper's bank. Specify this with the issuer value that corresponds to this bank.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkData String?
Base64-encoded JSON object containing SDK related parameters required by the SDK
no setter
type MolPayDetailsTypeEnum
molpay
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(MolPayDetailsBuilder)) MolPayDetails
Rebuilds the instance.
inherited
toBuilder() MolPayDetailsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<MolPayDetails>
no setter