PayPalDetailsSubtypeEnum class

Inheritance
  • Object
  • EnumClass
  • PayPalDetailsSubtypeEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PayPalDetailsSubtypeEnum>
no setter
values → BuiltSet<PayPalDetailsSubtypeEnum>
no setter

Static Methods

valueOf(String name) PayPalDetailsSubtypeEnum

Constants

express → const PayPalDetailsSubtypeEnum
The type of flow to initiate.
redirect → const PayPalDetailsSubtypeEnum
The type of flow to initiate.
sdk → const PayPalDetailsSubtypeEnum
The type of flow to initiate.
unknownDefaultOpenApi → const PayPalDetailsSubtypeEnum
The type of flow to initiate.