PayToPaymentMethod class abstract

PayToPaymentMethod

Properties:

Implemented types
Available extensions
Annotations
  • @BuiltValue.new()

Constructors

PayToPaymentMethod([void updates(PayToPaymentMethodBuilder b)])
factory

Properties

discriminatorValue String?

Available on ShopperIdPaymentMethod, provided by the ShopperIdPaymentMethodDiscriminatorExt extension

no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shopperReference String?
no setter
type String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PayToPaymentMethodBuilder)) PayToPaymentMethod
Rebuilds the instance.
inherited
toBuilder() PayToPaymentMethodBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PayToPaymentMethod>
no setter