PaymentAmountUpdateResponseIndustryUsageEnum class

Inheritance
  • Object
  • EnumClass
  • PaymentAmountUpdateResponseIndustryUsageEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentAmountUpdateResponseIndustryUsageEnum>
no setter
values → BuiltSet<PaymentAmountUpdateResponseIndustryUsageEnum>
no setter

Constants

delayedCharge → const PaymentAmountUpdateResponseIndustryUsageEnum
The reason for the amount update. Possible values: * delayedCharge * noShow * installment
installment → const PaymentAmountUpdateResponseIndustryUsageEnum
The reason for the amount update. Possible values: * delayedCharge * noShow * installment
noShow → const PaymentAmountUpdateResponseIndustryUsageEnum
The reason for the amount update. Possible values: * delayedCharge * noShow * installment
unknownDefaultOpenApi → const PaymentAmountUpdateResponseIndustryUsageEnum
The reason for the amount update. Possible values: * delayedCharge * noShow * installment