PaymentDetailsResponseAction class abstract

Action to be taken for completing the payment. When returned, only the 3D Secure action is needed in most cases.

Properties:

  • authorisationToken - A token needed to authorise a payment.
  • paymentData - Encoded payment data.
  • paymentMethodType - Specifies the payment method.
  • subtype - A subtype of the token.
  • token - A token to pass to the 3DS2 Component to get the fingerprint.
  • type - threeDS2
  • url - Specifies the URL to redirect to.
Annotations
  • @BuiltValue.new()

Constructors

PaymentDetailsResponseAction([void updates(PaymentDetailsResponseActionBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
oneOf → OneOf
One Of CheckoutThreeDS2Action
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaymentDetailsResponseActionBuilder)) PaymentDetailsResponseAction
Rebuilds the instance.
inherited
toBuilder() PaymentDetailsResponseActionBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentDetailsResponseAction>
no setter