PaymentDetailsTypeEnum class

Inheritance
  • Object
  • EnumClass
  • PaymentDetailsTypeEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentDetailsTypeEnum>
no setter
values → BuiltSet<PaymentDetailsTypeEnum>
no setter

Static Methods

valueOf(String name) PaymentDetailsTypeEnum

Constants

affirmPos → const PaymentDetailsTypeEnum
The payment method type.
alipay → const PaymentDetailsTypeEnum
The payment method type.
alipayHk → const PaymentDetailsTypeEnum
The payment method type.
alipayHkWap → const PaymentDetailsTypeEnum
The payment method type.
alipayHkWeb → const PaymentDetailsTypeEnum
The payment method type.
alipayWap → const PaymentDetailsTypeEnum
The payment method type.
alma → const PaymentDetailsTypeEnum
The payment method type.
atome → const PaymentDetailsTypeEnum
The payment method type.
balanceplatform → const PaymentDetailsTypeEnum
The payment method type.
bankTransfer → const PaymentDetailsTypeEnum
The payment method type.
bankTransferIBAN → const PaymentDetailsTypeEnum
The payment method type.
benefit → const PaymentDetailsTypeEnum
The payment method type.
bizum → const PaymentDetailsTypeEnum
The payment method type.
boletobancario → const PaymentDetailsTypeEnum
The payment method type.
boletobancarioBancodobrasil → const PaymentDetailsTypeEnum
The payment method type.
boletobancarioBradesco → const PaymentDetailsTypeEnum
The payment method type.
boletobancarioHsbc → const PaymentDetailsTypeEnum
The payment method type.
boletobancarioItau → const PaymentDetailsTypeEnum
The payment method type.
boletobancarioSantander → const PaymentDetailsTypeEnum
The payment method type.
cashticket → const PaymentDetailsTypeEnum
The payment method type.
directEbanking → const PaymentDetailsTypeEnum
The payment method type.
duitnow → const PaymentDetailsTypeEnum
The payment method type.
facilypay → const PaymentDetailsTypeEnum
The payment method type.
facilypay3x → const PaymentDetailsTypeEnum
The payment method type.
facilypay4x → const PaymentDetailsTypeEnum
The payment method type.
facilypay6x → const PaymentDetailsTypeEnum
The payment method type.
facilypay10x → const PaymentDetailsTypeEnum
The payment method type.
facilypay12x → const PaymentDetailsTypeEnum
The payment method type.
fawry → const PaymentDetailsTypeEnum
The payment method type.
fpxAgrobank → const PaymentDetailsTypeEnum
The payment method type.
gopayWallet → const PaymentDetailsTypeEnum
The payment method type.
ikano → const PaymentDetailsTypeEnum
The payment method type.
iris → const PaymentDetailsTypeEnum
The payment method type.
karenmillen → const PaymentDetailsTypeEnum
The payment method type.
kcpBanktransfer → const PaymentDetailsTypeEnum
The payment method type.
kcpCreditcard → const PaymentDetailsTypeEnum
The payment method type.
kcpNaverpay → const PaymentDetailsTypeEnum
The payment method type.
kcpPayco → const PaymentDetailsTypeEnum
The payment method type.
knet → const PaymentDetailsTypeEnum
The payment method type.
konbini → const PaymentDetailsTypeEnum
The payment method type.
mada → const PaymentDetailsTypeEnum
The payment method type.
maybank2uMae → const PaymentDetailsTypeEnum
The payment method type.
molpayAffinEpg → const PaymentDetailsTypeEnum
The payment method type.
molpayAmb → const PaymentDetailsTypeEnum
The payment method type.
molpayBankislam → const PaymentDetailsTypeEnum
The payment method type.
molpayBoost → const PaymentDetailsTypeEnum
The payment method type.
molpayCimb → const PaymentDetailsTypeEnum
The payment method type.
molpayEbankingDirectMY → const PaymentDetailsTypeEnum
The payment method type.
molpayEbankingMY → const PaymentDetailsTypeEnum
The payment method type.
molpayEbankingVN → const PaymentDetailsTypeEnum
The payment method type.
molpayFpx → const PaymentDetailsTypeEnum
The payment method type.
molpayHlb → const PaymentDetailsTypeEnum
The payment method type.
molpayMaybank2u → const PaymentDetailsTypeEnum
The payment method type.
molpayPublicbank → const PaymentDetailsTypeEnum
The payment method type.
molpayRhb → const PaymentDetailsTypeEnum
The payment method type.
multibanco → const PaymentDetailsTypeEnum
The payment method type.
naps → const PaymentDetailsTypeEnum
The payment method type.
nordea → const PaymentDetailsTypeEnum
The payment method type.
oasis → const PaymentDetailsTypeEnum
The payment method type.
omannet → const PaymentDetailsTypeEnum
The payment method type.
oney → const PaymentDetailsTypeEnum
The payment method type.
paybright → const PaymentDetailsTypeEnum
The payment method type.
payme → const PaymentDetailsTypeEnum
The payment method type.
paymePos → const PaymentDetailsTypeEnum
The payment method type.
paynow → const PaymentDetailsTypeEnum
The payment method type.
paypo → const PaymentDetailsTypeEnum
The payment method type.
paytm → const PaymentDetailsTypeEnum
The payment method type.
payuINCashcard → const PaymentDetailsTypeEnum
The payment method type.
payuINNb → const PaymentDetailsTypeEnum
The payment method type.
primeiropayBoleto → const PaymentDetailsTypeEnum
The payment method type.
promptpay → const PaymentDetailsTypeEnum
The payment method type.
scalapay → const PaymentDetailsTypeEnum
The payment method type.
scalapay3x → const PaymentDetailsTypeEnum
The payment method type.
scalapay4x → const PaymentDetailsTypeEnum
The payment method type.
swish → const PaymentDetailsTypeEnum
The payment method type.
touchngo → const PaymentDetailsTypeEnum
The payment method type.
trustly → const PaymentDetailsTypeEnum
The payment method type.
trustlyvector → const PaymentDetailsTypeEnum
The payment method type.
twintPos → const PaymentDetailsTypeEnum
The payment method type.
unionpay → const PaymentDetailsTypeEnum
The payment method type.
unknownDefaultOpenApi → const PaymentDetailsTypeEnum
The payment method type.
walletIN → const PaymentDetailsTypeEnum
The payment method type.
walley → const PaymentDetailsTypeEnum
The payment method type.
walleyB2b → const PaymentDetailsTypeEnum
The payment method type.
warehouse → const PaymentDetailsTypeEnum
The payment method type.
wechatpayQR → const PaymentDetailsTypeEnum
The payment method type.
wechatpaySDK → const PaymentDetailsTypeEnum
The payment method type.
wechatpayWeb → const PaymentDetailsTypeEnum
The payment method type.