inclusive constant

  1. @BuiltValueEnumConst.new(wireName: r'inclusive')
PaymentMethodsRequestStoreFiltrationModeEnum const inclusive

Specifies how payment methods should be filtered based on the store parameter: - exclusive: Only payment methods belonging to the specified store are returned. - inclusive: Payment methods from the store and those not associated with any other store are returned.

Implementation

@BuiltValueEnumConst(wireName: r'inclusive')
static const PaymentMethodsRequestStoreFiltrationModeEnum inclusive = _$paymentMethodsRequestStoreFiltrationModeEnum_inclusive;