PaymentRefundRequestMerchantRefundReasonEnum class

Inheritance
  • Object
  • EnumClass
  • PaymentRefundRequestMerchantRefundReasonEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentRefundRequestMerchantRefundReasonEnum>
no setter
values → BuiltSet<PaymentRefundRequestMerchantRefundReasonEnum>
no setter

Constants

cUSTOMERREQUEST → const PaymentRefundRequestMerchantRefundReasonEnum
The reason for the refund request. Possible values: * FRAUD * CUSTOMER REQUEST * RETURN * DUPLICATE * OTHER
DUPLICATE → const PaymentRefundRequestMerchantRefundReasonEnum
The reason for the refund request. Possible values: * FRAUD * CUSTOMER REQUEST * RETURN * DUPLICATE * OTHER
FRAUD → const PaymentRefundRequestMerchantRefundReasonEnum
The reason for the refund request. Possible values: * FRAUD * CUSTOMER REQUEST * RETURN * DUPLICATE * OTHER
OTHER → const PaymentRefundRequestMerchantRefundReasonEnum
The reason for the refund request. Possible values: * FRAUD * CUSTOMER REQUEST * RETURN * DUPLICATE * OTHER
RETURN → const PaymentRefundRequestMerchantRefundReasonEnum
The reason for the refund request. Possible values: * FRAUD * CUSTOMER REQUEST * RETURN * DUPLICATE * OTHER
unknownDefaultOpenApi → const PaymentRefundRequestMerchantRefundReasonEnum
The reason for the refund request. Possible values: * FRAUD * CUSTOMER REQUEST * RETURN * DUPLICATE * OTHER