PaymentResultCodeEnum class

Inheritance
  • Object
  • EnumClass
  • PaymentResultCodeEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentResultCodeEnum>
no setter
values → BuiltSet<PaymentResultCodeEnum>
no setter

Static Methods

valueOf(String name) PaymentResultCodeEnum

Constants

authorised → const PaymentResultCodeEnum
The result of the payment. For more information, see Result codes. Possible values: * Authorised – The payment was successfully authorised. This state serves as an indicator to proceed with the delivery of goods and services. This is a final state.
unknownDefaultOpenApi → const PaymentResultCodeEnum
The result of the payment. For more information, see Result codes. Possible values: * Authorised – The payment was successfully authorised. This state serves as an indicator to proceed with the delivery of goods and services. This is a final state.