PaymentReversalRequestBuilder class
Constructors
Properties
- applicationInfo ↔ ApplicationInfoBuilder
-
getter/setter pair
- enhancedSchemeData ↔ EnhancedSchemeDataBuilder
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantAccount ↔ String?
-
getter/setter pair
- reference ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → PaymentReversalRequest -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
PaymentReversalRequest other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(PaymentReversalRequestBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited