quarterly constant
The frequency at which the shopper will be charged.
Implementation
@BuiltValueEnumConst(wireName: r'quarterly')
static const PixRecurringFrequencyEnum quarterly = _$pixRecurringFrequencyEnum_quarterly;
The frequency at which the shopper will be charged.
@BuiltValueEnumConst(wireName: r'quarterly')
static const PixRecurringFrequencyEnum quarterly = _$pixRecurringFrequencyEnum_quarterly;