ResponsePaymentMethod class abstract

ResponsePaymentMethod

Properties:

  • brand - The card brand that the shopper used to pay. Only returned if paymentMethod.type is scheme.
  • type - The paymentMethod.type value used in the request.
Annotations
  • @BuiltValue.new()

Constructors

ResponsePaymentMethod([void updates(ResponsePaymentMethodBuilder b)])
factory

Properties

brand String?
The card brand that the shopper used to pay. Only returned if paymentMethod.type is scheme.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The paymentMethod.type value used in the request.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ResponsePaymentMethodBuilder)) ResponsePaymentMethod
Rebuilds the instance.
inherited
toBuilder() ResponsePaymentMethodBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ResponsePaymentMethod>
no setter