StandalonePaymentCancelRequest class abstract

StandalonePaymentCancelRequest

Properties:

Annotations
  • @BuiltValue.new()

Properties

applicationInfo ApplicationInfo?
Information about your application. For more details, see Building Adyen solutions.
no setter
enhancedSchemeData EnhancedSchemeData?
Enhanced scheme data that may be required for processing the payment. For example, airline information.
no setter
hashCode int
The hash code for this object.
no setterinherited
merchantAccount String
The merchant account that is used to process the payment.
no setter
paymentReference String
The reference of the payment that you want to cancel.
no setter
reference String?
Your reference for the cancel request. Maximum length: 80 characters.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(StandalonePaymentCancelRequestBuilder)) StandalonePaymentCancelRequest
Rebuilds the instance.
inherited
toBuilder() StandalonePaymentCancelRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<StandalonePaymentCancelRequest>
no setter