StoredPaymentMethodDetailsTypeEnum class

Inheritance
  • Object
  • EnumClass
  • StoredPaymentMethodDetailsTypeEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<StoredPaymentMethodDetailsTypeEnum>
no setter
values → BuiltSet<StoredPaymentMethodDetailsTypeEnum>
no setter

Constants

alipayPlus → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
alipayPlusAlipayCn → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
alipayPlusAlipayHk → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
alipayPlusDana → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
alipayPlusGcash → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
alipayPlusKakaopay → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
alipayPlusKplus → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
alipayPlusNaverpay → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
alipayPlusRabbitlinepay → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
alipayPlusTosspay → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
alipayPlusTouchngo → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
alipayPlusTruemoney → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
bcmcMobile → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
bcmcMobileApp → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
bcmcMobileQR → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
dana → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
gcash → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
grabpayID → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
grabpayMY → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
grabpayPH → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
grabpaySG → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
grabpayTH → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
grabpayVN → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
kakaopay → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
momoWallet → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
momoWalletApp → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
oxxo → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
paymayaWallet → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
paysafecard → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
truemoney → const StoredPaymentMethodDetailsTypeEnum
The payment method type.
unknownDefaultOpenApi → const StoredPaymentMethodDetailsTypeEnum
The payment method type.