expiryYear property
The last two digits of the year the card expires. For example, 22 for the year 2022.
Implementation
@BuiltValueField(wireName: r'expiryYear')
String? get expiryYear;
The last two digits of the year the card expires. For example, 22 for the year 2022.
@BuiltValueField(wireName: r'expiryYear')
String? get expiryYear;