TokenMandateBillingAttemptsRuleEnum class

Inheritance
  • Object
  • EnumClass
  • TokenMandateBillingAttemptsRuleEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TokenMandateBillingAttemptsRuleEnum>
no setter
values → BuiltSet<TokenMandateBillingAttemptsRuleEnum>
no setter

Constants

after → const TokenMandateBillingAttemptsRuleEnum
The rule to specify the period, within which the recurring debit can happen, relative to the mandate recurring date. Possible values: * on: On a specific date. * before: Before and on a specific date. * after: On and after a specific date.
before → const TokenMandateBillingAttemptsRuleEnum
The rule to specify the period, within which the recurring debit can happen, relative to the mandate recurring date. Possible values: * on: On a specific date. * before: Before and on a specific date. * after: On and after a specific date.
on_ → const TokenMandateBillingAttemptsRuleEnum
The rule to specify the period, within which the recurring debit can happen, relative to the mandate recurring date. Possible values: * on: On a specific date. * before: Before and on a specific date. * after: On and after a specific date.
unknownDefaultOpenApi → const TokenMandateBillingAttemptsRuleEnum
The rule to specify the period, within which the recurring debit can happen, relative to the mandate recurring date. Possible values: * on: On a specific date. * before: Before and on a specific date. * after: On and after a specific date.