TokenMandateFrequencyEnum class

Inheritance
  • Object
  • EnumClass
  • TokenMandateFrequencyEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TokenMandateFrequencyEnum>
no setter
values → BuiltSet<TokenMandateFrequencyEnum>
no setter

Static Methods

valueOf(String name) TokenMandateFrequencyEnum

Constants

adhoc → const TokenMandateFrequencyEnum
The frequency with which a shopper should be charged. Possible values: adhoc, daily, weekly, biWeekly, monthly, quarterly, halfYearly, yearly.
biWeekly → const TokenMandateFrequencyEnum
The frequency with which a shopper should be charged. Possible values: adhoc, daily, weekly, biWeekly, monthly, quarterly, halfYearly, yearly.
daily → const TokenMandateFrequencyEnum
The frequency with which a shopper should be charged. Possible values: adhoc, daily, weekly, biWeekly, monthly, quarterly, halfYearly, yearly.
halfYearly → const TokenMandateFrequencyEnum
The frequency with which a shopper should be charged. Possible values: adhoc, daily, weekly, biWeekly, monthly, quarterly, halfYearly, yearly.
monthly → const TokenMandateFrequencyEnum
The frequency with which a shopper should be charged. Possible values: adhoc, daily, weekly, biWeekly, monthly, quarterly, halfYearly, yearly.
quarterly → const TokenMandateFrequencyEnum
The frequency with which a shopper should be charged. Possible values: adhoc, daily, weekly, biWeekly, monthly, quarterly, halfYearly, yearly.
unknownDefaultOpenApi → const TokenMandateFrequencyEnum
The frequency with which a shopper should be charged. Possible values: adhoc, daily, weekly, biWeekly, monthly, quarterly, halfYearly, yearly.
weekly → const TokenMandateFrequencyEnum
The frequency with which a shopper should be charged. Possible values: adhoc, daily, weekly, biWeekly, monthly, quarterly, halfYearly, yearly.
yearly → const TokenMandateFrequencyEnum
The frequency with which a shopper should be charged. Possible values: adhoc, daily, weekly, biWeekly, monthly, quarterly, halfYearly, yearly.