UpiIntentDetailsTypeEnum class

Inheritance
  • Object
  • EnumClass
  • UpiIntentDetailsTypeEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UpiIntentDetailsTypeEnum>
no setter
values → BuiltSet<UpiIntentDetailsTypeEnum>
no setter

Static Methods

valueOf(String name) UpiIntentDetailsTypeEnum

Constants

unknownDefaultOpenApi → const UpiIntentDetailsTypeEnum
upi_intent
upiIntent → const UpiIntentDetailsTypeEnum
upi_intent