UpiQrDetails class abstract

UpiQrDetails

Properties:

  • billingSequenceNumber - The sequence number for the debit. For example, send 2 if this is the second debit for the subscription. The sequence number is included in the notification sent to the shopper.
  • checkoutAttemptId - The checkout attempt identifier.
  • recurringDetailReference - This is the recurringDetailReference returned in the response when you created the token.
  • sdkData - Base64-encoded JSON object containing SDK related parameters required by the SDK
  • shopperNotificationReference - The shopperNotificationReference returned in the response when you requested to notify the shopper. Used for recurring payment only.
  • storedPaymentMethodId - This is the recurringDetailReference returned in the response when you created the token.
  • type - upi_qr
Annotations
  • @BuiltValue.new()

Constructors

UpiQrDetails([void updates(UpiQrDetailsBuilder b)])
factory

Properties

billingSequenceNumber String?
The sequence number for the debit. For example, send 2 if this is the second debit for the subscription. The sequence number is included in the notification sent to the shopper.
no setter
checkoutAttemptId String?
The checkout attempt identifier.
no setter
hashCode int
The hash code for this object.
no setterinherited
recurringDetailReference String?
This is the recurringDetailReference returned in the response when you created the token.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkData String?
Base64-encoded JSON object containing SDK related parameters required by the SDK
no setter
shopperNotificationReference String?
The shopperNotificationReference returned in the response when you requested to notify the shopper. Used for recurring payment only.
no setter
storedPaymentMethodId String?
This is the recurringDetailReference returned in the response when you created the token.
no setter
type UpiQrDetailsTypeEnum
upi_qr
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UpiQrDetailsBuilder)) UpiQrDetails
Rebuilds the instance.
inherited
toBuilder() UpiQrDetailsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UpiQrDetails>
no setter