AcceptDisputeRequest class abstract

AcceptDisputeRequest

Properties:

Annotations
  • @BuiltValue.new()

Constructors

AcceptDisputeRequest([void updates(AcceptDisputeRequestBuilder b)])
factory

Properties

disputePspReference String
The PSP reference assigned to the dispute.
no setter
hashCode int
The hash code for this object.
no setterinherited
merchantAccountCode String
The merchant account identifier, for which you want to process the dispute transaction.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AcceptDisputeRequestBuilder)) AcceptDisputeRequest
Rebuilds the instance.
inherited
toBuilder() AcceptDisputeRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AcceptDisputeRequest>
no setter