DefenseDocument class abstract

DefenseDocument

Properties:

Annotations
  • @BuiltValue.new()

Constructors

DefenseDocument([void updates(DefenseDocumentBuilder b)])
factory

Properties

content → String
The content of the defense document.
no setter
contentType → String
The content type of the defense document.
no setter
defenseDocumentTypeCode → String
The document type code of the defense document.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DefenseDocumentBuilder)) → DefenseDocument
Rebuilds the instance.
inherited
toBuilder() → DefenseDocumentBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DefenseDocument>
no setter