DefenseDocumentType class abstract

DefenseDocumentType

Properties:

  • available - When true, you've successfully uploaded this type of defense document. When false, you haven't uploaded this defense document type.
  • defenseDocumentTypeCode - The document type code of the defense document.
  • requirementLevel - Indicates to what extent the defense document is required in the defense process. Possible values: * Required: You must supply the document. * OneOrMore: You must supply at least one of the documents with this label. * Optional: You can choose to supply the document. * AlternativeRequired: You must supply a generic defense document. To enable this functionality, contact our Support Team. When enabled, you can supply a generic defense document for all schemes.
Annotations
  • @BuiltValue.new()

Constructors

DefenseDocumentType([void updates(DefenseDocumentTypeBuilder b)])
factory

Properties

available → bool
When true, you've successfully uploaded this type of defense document. When false, you haven't uploaded this defense document type.
no setter
defenseDocumentTypeCode → String
The document type code of the defense document.
no setter
hashCode → int
The hash code for this object.
no setterinherited
requirementLevel → String
Indicates to what extent the defense document is required in the defense process. Possible values: * Required: You must supply the document. * OneOrMore: You must supply at least one of the documents with this label. * Optional: You can choose to supply the document. * AlternativeRequired: You must supply a generic defense document. To enable this functionality, contact our Support Team. When enabled, you can supply a generic defense document for all schemes.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DefenseDocumentTypeBuilder)) → DefenseDocumentType
Rebuilds the instance.
inherited
toBuilder() → DefenseDocumentTypeBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DefenseDocumentType>
no setter