DefenseReasonsResponse class abstract

DefenseReasonsResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

DefenseReasonsResponse([void updates(DefenseReasonsResponseBuilder b)])
factory

Properties

defenseReasons → BuiltList<DefenseReason>?
The defense reasons that can be used to defend the dispute.
no setter
disputeServiceResult DisputeServiceResult
The result of the dispute service.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DefenseReasonsResponseBuilder)) DefenseReasonsResponse
Rebuilds the instance.
inherited
toBuilder() DefenseReasonsResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DefenseReasonsResponse>
no setter