AcceptTermsOfServiceResponse class abstract

AcceptTermsOfServiceResponse

Properties:

  • acceptedBy - The unique identifier of the user that accepted the Terms of Service.
  • id - The unique identifier of the Terms of Service acceptance.
  • ipAddress - The IP address of the user that accepted the Terms of Service.
  • language - The language used for the Terms of Service document, specified by the two-letter ISO 639-1 language code. Possible value: en for English or fr for French. Note that French is only available for some integration types in certain countries/regions. Reach out to your Adyen contact for more information.
  • termsOfServiceDocumentId - The unique identifier of the Terms of Service document.
  • type - The type of Terms of Service. Possible values: * adyenForPlatformsManage * adyenIssuing * adyenForPlatformsAdvanced * adyenCapital * adyenAccount * adyenCard * adyenFranchisee * adyenPccr * adyenChargeCard * kycOnInvite
Annotations
  • @BuiltValue.new()

Constructors

AcceptTermsOfServiceResponse([void updates(AcceptTermsOfServiceResponseBuilder b)])
factory

Properties

acceptedBy String?
The unique identifier of the user that accepted the Terms of Service.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String?
The unique identifier of the Terms of Service acceptance.
no setter
ipAddress String?
The IP address of the user that accepted the Terms of Service.
no setter
language String?
The language used for the Terms of Service document, specified by the two-letter ISO 639-1 language code. Possible value: en for English or fr for French. Note that French is only available for some integration types in certain countries/regions. Reach out to your Adyen contact for more information.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
termsOfServiceDocumentId String?
The unique identifier of the Terms of Service document.
no setter
type AcceptTermsOfServiceResponseTypeEnum?
The type of Terms of Service. Possible values: * adyenForPlatformsManage * adyenIssuing * adyenForPlatformsAdvanced * adyenCapital * adyenAccount * adyenCard * adyenFranchisee * adyenPccr * adyenChargeCard * kycOnInvite
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AcceptTermsOfServiceResponseBuilder)) AcceptTermsOfServiceResponse
Rebuilds the instance.
inherited
toBuilder() AcceptTermsOfServiceResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AcceptTermsOfServiceResponse>
no setter