CapabilityProblemEntity class abstract

CapabilityProblemEntity

Properties:

  • documents - List of document IDs corresponding to the verification errors from capabilities.
  • id
  • owner
  • type
Annotations
  • @BuiltValue.new()

Constructors

CapabilityProblemEntity([void updates(CapabilityProblemEntityBuilder b)])
factory

Properties

documents → BuiltList<String>?
List of document IDs corresponding to the verification errors from capabilities.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setter
owner → CapabilityProblemEntityRecursive?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CapabilityProblemEntityTypeEnum?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CapabilityProblemEntityBuilder)) → CapabilityProblemEntity
Rebuilds the instance.
inherited
toBuilder() → CapabilityProblemEntityBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CapabilityProblemEntity>
no setter