CapabilitySettings class abstract

CapabilitySettings

Properties:

  • amountPerIndustry - The maximum amount a card holder can spend per industry.
  • authorizedCardUsers - The number of card holders who can use the card.
  • fundingSource - The funding source of the card, for example debit.
  • interval - The period when the rule conditions apply.
  • maxAmount - The maximum amount a card holder can withdraw per day.
Annotations
  • @BuiltValue.new()

Constructors

CapabilitySettings([void updates(CapabilitySettingsBuilder b)])
factory

Properties

amountPerIndustry → BuiltMap<String, Amount>?
The maximum amount a card holder can spend per industry.
no setter
authorizedCardUsers → bool?
The number of card holders who can use the card.
no setter
fundingSource → BuiltList<CapabilitySettingsFundingSourceEnum>?
The funding source of the card, for example debit.
no setter
hashCode → int
The hash code for this object.
no setterinherited
interval → CapabilitySettingsIntervalEnum?
The period when the rule conditions apply.
no setter
maxAmount → Amount?
The maximum amount a card holder can withdraw per day.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CapabilitySettingsBuilder)) → CapabilitySettings
Rebuilds the instance.
inherited
toBuilder() → CapabilitySettingsBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CapabilitySettings>
no setter