Document class abstract

Document

Properties:

  • attachment - Object that contains the document.
  • attachments - Array that contains the document. The array supports multiple attachments for uploading different sides or pages of a document.
  • creationDate - The creation date of the document.
  • description - Your description for the document.
  • expiryDate - The expiry date of the document, in YYYY-MM-DD format.
  • fileName - The filename of the document.
  • id - The unique identifier of the document.
  • issuerCountry - The two-character ISO 3166-1 alpha-2 country code where the document was issued. For example, US.
  • issuerState - The state or province where the document was issued (AU only).
  • modificationDate - The modification date of the document.
  • number - The number in the document.
  • owner - Contains information about the resource that owns the document.
  • type - Type of document, used when providing an ID number or uploading a document. The possible values depend on the legal entity type. * For organization, the type values can be proofOfAddress, registrationDocument, vatDocument, proofOfOrganizationTaxInfo, proofOfOwnership, proofOfIndustry, proofOfSignatory, proofOfDirector, or proofOfFundingOrWealthSource. * For individual, the type values can be identityCard, driversLicense, passport, liveSelfie, proofOfNationalIdNumber, proofOfResidency, proofOfIndustry, proofOfIndividualTaxId, proofOfFundingOrWealthSource or proofOfRelationship. * For soleProprietorship, the type values can be constitutionalDocument, proofOfAddress, or proofOfIndustry. * For trust, the type value is constitutionalDocument. * For unincorporatedPartnership, the type value is constitutionalDocument. * Use bankStatement to upload documents for a transfer instrument.
Annotations
  • @BuiltValue.new()

Constructors

Document([void updates(DocumentBuilder b)])
factory

Properties

attachment → Attachment?
Object that contains the document.
no setter
attachments → BuiltList<Attachment>?
Array that contains the document. The array supports multiple attachments for uploading different sides or pages of a document.
no setter
creationDate → DateTime?
The creation date of the document.
no setter
description → String
Your description for the document.
no setter
expiryDate → String?
The expiry date of the document, in YYYY-MM-DD format.
no setter
fileName → String?
The filename of the document.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the document.
no setter
issuerCountry → String?
The two-character ISO 3166-1 alpha-2 country code where the document was issued. For example, US.
no setter
issuerState → String?
The state or province where the document was issued (AU only).
no setter
modificationDate → DateTime?
The modification date of the document.
no setter
number → String?
The number in the document.
no setter
owner → OwnerEntity?
Contains information about the resource that owns the document.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DocumentTypeEnum
Type of document, used when providing an ID number or uploading a document. The possible values depend on the legal entity type. * For organization, the type values can be proofOfAddress, registrationDocument, vatDocument, proofOfOrganizationTaxInfo, proofOfOwnership, proofOfIndustry, proofOfSignatory, proofOfDirector, or proofOfFundingOrWealthSource. * For individual, the type values can be identityCard, driversLicense, passport, liveSelfie, proofOfNationalIdNumber, proofOfResidency, proofOfIndustry, proofOfIndividualTaxId, proofOfFundingOrWealthSource or proofOfRelationship. * For soleProprietorship, the type values can be constitutionalDocument, proofOfAddress, or proofOfIndustry. * For trust, the type value is constitutionalDocument. * For unincorporatedPartnership, the type value is constitutionalDocument. * Use bankStatement to upload documents for a transfer instrument.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DocumentBuilder)) → Document
Rebuilds the instance.
inherited
toBuilder() → DocumentBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Document>
no setter