DocumentReference class abstract

DocumentReference

Properties:

  • active - Identifies whether the document is active and used for checks.
  • description - Your description for the document.
  • fileName - Document name.
  • id - The unique identifier of the resource.
  • modificationDate - The modification date of the document.
  • pages - List of document pages
  • type - Type of document, used when providing an ID number or uploading a document.
Annotations
  • @BuiltValue.new()

Constructors

DocumentReference([void updates(DocumentReferenceBuilder b)])
factory

Properties

active → bool?
Identifies whether the document is active and used for checks.
no setter
description → String?
Your description for the document.
no setter
fileName → String?
Document name.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the resource.
no setter
modificationDate → DateTime?
The modification date of the document.
no setter
pages → BuiltList<DocumentPage>?
List of document pages
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
Type of document, used when providing an ID number or uploading a document.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DocumentReferenceBuilder)) → DocumentReference
Rebuilds the instance.
inherited
toBuilder() → DocumentReferenceBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DocumentReference>
no setter