DocumentReferenceBuilder class

Constructors

DocumentReferenceBuilder()

Properties

active ↔ bool?
getter/setter pair
description ↔ String?
getter/setter pair
fileName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
modificationDate ↔ DateTime?
getter/setter pair
pages ↔ ListBuilder<DocumentPage>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
getter/setter pair

Methods

build() → DocumentReference
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(DocumentReference other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(DocumentReferenceBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited