FinancialReport class abstract

FinancialReport

Properties:

Annotations
  • @BuiltValue.new()

Constructors

FinancialReport([void updates(FinancialReportBuilder b)])
factory

Properties

annualTurnover → String?
The annual turnover of the business.
no setter
balanceSheetTotal → String?
The balance sheet total of the business.
no setter
currencyOfFinancialData → String?
The currency used for the annual turnover, balance sheet total, and net assets.
no setter
dateOfFinancialData → String?
The date the financial data were provided, in YYYY-MM-DD format.
no setter
employeeCount → String?
The number of employees of the business.
no setter
hashCode → int
The hash code for this object.
no setterinherited
netAssets → String?
The net assets of the business.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(FinancialReportBuilder)) → FinancialReport
Rebuilds the instance.
inherited
toBuilder() → FinancialReportBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<FinancialReport>
no setter