LegalEntityInfoRequiredTypeBuilder class
Constructors
Properties
-
capabilities
↔ MapBuilder<
String, LegalEntityCapability> -
getter/setter pair
-
entityAssociations
↔ ListBuilder<
LegalEntityAssociation> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- individual ↔ IndividualBuilder
-
getter/setter pair
- organization ↔ OrganizationBuilder
-
getter/setter pair
- reference ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- soleProprietorship ↔ SoleProprietorshipBuilder
-
getter/setter pair
- trust ↔ TrustBuilder
-
getter/setter pair
- type ↔ LegalEntityInfoRequiredTypeTypeEnum?
-
getter/setter pair
- unincorporatedPartnership ↔ UnincorporatedPartnershipBuilder
-
getter/setter pair
- verificationPlan ↔ String?
-
getter/setter pair
Methods
-
build(
) → LegalEntityInfoRequiredType -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
LegalEntityInfoRequiredType other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(LegalEntityInfoRequiredTypeBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited