url property

  1. @BuiltValueField.new(wireName: r'url')
String? get url

The URL of the hosted onboarding page where you need to redirect your user. This URL: - Expires after 4 minutes. - Can only be used once. - Can only be clicked once by the user. If the link expires, you need to create a new link.

Implementation

@BuiltValueField(wireName: r'url')
String? get url;