OnboardingLinkSettings class abstract

OnboardingLinkSettings

Properties:

  • acceptedCountries - The list of countries the user can choose from in hosted onboarding when editPrefilledCountry is allowed. The value must be in the two-character ISO 3166-1 alpha-2 country code format. The array is empty by default, allowing all countries and regions supported by hosted onboarding.
  • allowBankAccountFormatSelection - Default value: false Indicates if the user can select the format for their payout account (if applicable).
  • allowDebugUi - Default value: true Indicates whether the debug user interface (UI) is enabled. The debug UI provides information for your support staff to diagnose and resolve user issues during onboarding. It can be accessed using a keyboard shortcut.
  • allowIntraRegionCrossBorderPayout - Default value: false Indicates if the user can select a payout account in a different EU/EEA location (including Switzerland and the UK) than the location of their legal entity.
  • changeLegalEntityType - Default value: true Indicates if the user can change their legal entity type.
  • editPrefilledCountry - Default value: true Indicates if the user can change the country of their legal entity's address, for example the registered address of an organization.
  • enforceLegalAge - Default value: false Indicates if only users above the age of 18 can be onboarded.
  • hideOnboardingIntroductionIndividual - Default value: true Indicates whether the introduction screen is hidden for the user of the individual legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
  • hideOnboardingIntroductionOrganization - Default value: true Indicates whether the introduction screen is hidden for the user of the organization legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
  • hideOnboardingIntroductionSoleProprietor - Default value: true Indicates whether the introduction screen is hidden for the user of the sole proprietorship legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
  • hideOnboardingIntroductionTrust - Default value: true Indicates whether the introduction screen is hidden for the user of the trust legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
  • instantBankVerification - Default value: true Indicates if the user can initiate the verification process through open banking providers, like Plaid or Tink.
  • requirePciSignEcomMoto - Default value: false Indicates if the user is required to sign a PCI questionnaires for the ecomMoto sales channel type.
  • requirePciSignEcommerce - Default value: false Indicates if the user is required to sign a PCI questionnaires for the eCommerce sales channel type.
  • requirePciSignPos - Default value: false Indicates if the user is required to sign a PCI questionnaires for the pos sales channel type.
  • requirePciSignPosMoto - Default value: false Indicates if the user is required to sign a PCI questionnaires for the posMoto sales channel type.
  • transferInstrumentLimit - The maximum number of transfer instruments the user can create.
Annotations
  • @BuiltValue.new()

Constructors

OnboardingLinkSettings([void updates(OnboardingLinkSettingsBuilder b)])
factory

Properties

acceptedCountries → BuiltList<String>?
The list of countries the user can choose from in hosted onboarding when editPrefilledCountry is allowed. The value must be in the two-character ISO 3166-1 alpha-2 country code format. The array is empty by default, allowing all countries and regions supported by hosted onboarding.
no setter
allowBankAccountFormatSelection bool?
Default value: false Indicates if the user can select the format for their payout account (if applicable).
no setter
allowDebugUi bool?
Default value: true Indicates whether the debug user interface (UI) is enabled. The debug UI provides information for your support staff to diagnose and resolve user issues during onboarding. It can be accessed using a keyboard shortcut.
no setter
allowIntraRegionCrossBorderPayout bool?
Default value: false Indicates if the user can select a payout account in a different EU/EEA location (including Switzerland and the UK) than the location of their legal entity.
no setter
changeLegalEntityType bool?
Default value: true Indicates if the user can change their legal entity type.
no setter
editPrefilledCountry bool?
Default value: true Indicates if the user can change the country of their legal entity's address, for example the registered address of an organization.
no setter
enforceLegalAge bool?
Default value: false Indicates if only users above the age of 18 can be onboarded.
no setter
hashCode int
The hash code for this object.
no setterinherited
hideOnboardingIntroductionIndividual bool?
Default value: true Indicates whether the introduction screen is hidden for the user of the individual legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
no setter
hideOnboardingIntroductionOrganization bool?
Default value: true Indicates whether the introduction screen is hidden for the user of the organization legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
no setter
hideOnboardingIntroductionSoleProprietor bool?
Default value: true Indicates whether the introduction screen is hidden for the user of the sole proprietorship legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
no setter
hideOnboardingIntroductionTrust bool?
Default value: true Indicates whether the introduction screen is hidden for the user of the trust legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
no setter
instantBankVerification bool?
Default value: true Indicates if the user can initiate the verification process through open banking providers, like Plaid or Tink.
no setter
requirePciSignEcommerce bool?
Default value: false Indicates if the user is required to sign a PCI questionnaires for the eCommerce sales channel type.
no setter
requirePciSignEcomMoto bool?
Default value: false Indicates if the user is required to sign a PCI questionnaires for the ecomMoto sales channel type.
no setter
requirePciSignPos bool?
Default value: false Indicates if the user is required to sign a PCI questionnaires for the pos sales channel type.
no setter
requirePciSignPosMoto bool?
Default value: false Indicates if the user is required to sign a PCI questionnaires for the posMoto sales channel type.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transferInstrumentLimit int?
The maximum number of transfer instruments the user can create.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(OnboardingLinkSettingsBuilder)) OnboardingLinkSettings
Rebuilds the instance.
inherited
toBuilder() OnboardingLinkSettingsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<OnboardingLinkSettings>
no setter