editPrefilledCountry property

  1. @BuiltValueField.new(wireName: r'editPrefilledCountry')
bool? get editPrefilledCountry

Default value: true Indicates if the user can change the country of their legal entity's address, for example the registered address of an organization.

Implementation

@BuiltValueField(wireName: r'editPrefilledCountry')
bool? get editPrefilledCountry;