hideOnboardingIntroductionIndividual property
- @BuiltValueField.new(wireName: r'hideOnboardingIntroductionIndividual')
Default value: true Indicates whether the introduction screen is hidden for the user of the individual legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
Implementation
@BuiltValueField(wireName: r'hideOnboardingIntroductionIndividual')
bool? get hideOnboardingIntroductionIndividual;