hideOnboardingIntroductionOrganization property
- @BuiltValueField.new(wireName: r'hideOnboardingIntroductionOrganization')
Default value: true Indicates whether the introduction screen is hidden for the user of the organization legal entity type. The introduction screen provides brief instructions for the subsequent steps in the hosted onboarding process.
Implementation
@BuiltValueField(wireName: r'hideOnboardingIntroductionOrganization')
bool? get hideOnboardingIntroductionOrganization;