statusOfLegalProceeding property
- @BuiltValueField.new(wireName: r'statusOfLegalProceeding')
The status of any current or past legal action taken against the legal entity. Possible values: noLegalActionsTaken, underJudicialAdministration, bankruptcyInsolvency, otherLegalMeasures If the value of this field is noLegalActionsTaken, then dateOfInitiationOfLegalProceeding is not required. Otherwise, it is required.
Implementation
@BuiltValueField(wireName: r'statusOfLegalProceeding')
OrganizationStatusOfLegalProceedingEnum? get statusOfLegalProceeding;