OrganizationStatusOfLegalProceedingEnum class

Inheritance
  • Object
  • EnumClass
  • OrganizationStatusOfLegalProceedingEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<OrganizationStatusOfLegalProceedingEnum>
no setter
values → BuiltSet<OrganizationStatusOfLegalProceedingEnum>
no setter

Constants

bankruptcyInsolvency → const OrganizationStatusOfLegalProceedingEnum
The status of any current or past legal action taken against the legal entity. Possible values: noLegalActionsTaken, underJudicialAdministration, bankruptcyInsolvency, otherLegalMeasures If the value of this field is noLegalActionsTaken, then dateOfInitiationOfLegalProceeding is not required. Otherwise, it is required.
noLegalActionsTaken → const OrganizationStatusOfLegalProceedingEnum
The status of any current or past legal action taken against the legal entity. Possible values: noLegalActionsTaken, underJudicialAdministration, bankruptcyInsolvency, otherLegalMeasures If the value of this field is noLegalActionsTaken, then dateOfInitiationOfLegalProceeding is not required. Otherwise, it is required.
otherLegalMeasures → const OrganizationStatusOfLegalProceedingEnum
The status of any current or past legal action taken against the legal entity. Possible values: noLegalActionsTaken, underJudicialAdministration, bankruptcyInsolvency, otherLegalMeasures If the value of this field is noLegalActionsTaken, then dateOfInitiationOfLegalProceeding is not required. Otherwise, it is required.
underJudicialAdministration → const OrganizationStatusOfLegalProceedingEnum
The status of any current or past legal action taken against the legal entity. Possible values: noLegalActionsTaken, underJudicialAdministration, bankruptcyInsolvency, otherLegalMeasures If the value of this field is noLegalActionsTaken, then dateOfInitiationOfLegalProceeding is not required. Otherwise, it is required.
unknownDefaultOpenApi → const OrganizationStatusOfLegalProceedingEnum
The status of any current or past legal action taken against the legal entity. Possible values: noLegalActionsTaken, underJudicialAdministration, bankruptcyInsolvency, otherLegalMeasures If the value of this field is noLegalActionsTaken, then dateOfInitiationOfLegalProceeding is not required. Otherwise, it is required.