PhoneNumber class abstract

PhoneNumber

Properties:

  • number - The full phone number, including the country code. For example, +3112345678.
  • phoneCountryCode - The two-letter ISO 3166-1 alpha-2 country code prefix of the phone number. For example, US or NL. The value of the phoneCountryCode is determined by the country code digit(s) of phone.number
  • type - The type of phone number. Possible values: mobile, landline, sip, fax.
Annotations
  • @BuiltValue.new()

Constructors

PhoneNumber([void updates(PhoneNumberBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
number → String
The full phone number, including the country code. For example, +3112345678.
no setter
phoneCountryCode → String?
The two-letter ISO 3166-1 alpha-2 country code prefix of the phone number. For example, US or NL. The value of the phoneCountryCode is determined by the country code digit(s) of phone.number
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
The type of phone number. Possible values: mobile, landline, sip, fax.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PhoneNumberBuilder)) → PhoneNumber
Rebuilds the instance.
inherited
toBuilder() → PhoneNumberBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PhoneNumber>
no setter