SoleProprietorship class abstract

SoleProprietorship

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SoleProprietorship([void updates(SoleProprietorshipBuilder b)])
factory

Properties

countryOfGoverningLaw String
The two-character ISO 3166-1 alpha-2 country code of the governing country.
no setter
dateOfIncorporation String?
The date when the legal arrangement was incorporated in YYYY-MM-DD format.
no setter
doingBusinessAs String?
The registered name, if different from the name.
no setter
doingBusinessAsAbsent bool?
Set this to true if the legal arrangement does not have a Doing business as name.
no setter
financialReports → BuiltList<FinancialReport>?
The information from the financial report of the sole proprietorship.
no setter
hashCode int
The hash code for this object.
no setterinherited
name_ String
The legal name.
no setter
principalPlaceOfBusiness Address?
The business address. Required if the principal place of business is different from the registeredAddress.
no setter
registeredAddress Address
The address registered at the registrar, such as the Chamber of Commerce.
no setter
registrationNumber String?
The registration number.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taxAbsent bool?
The tax information is absent.
no setter
taxInformation → BuiltList<TaxInformation>?
The tax information of the entity.
no setter
vatAbsenceReason SoleProprietorshipVatAbsenceReasonEnum?
The reason for not providing a VAT number. Possible values: industryExemption, belowTaxThreshold.
no setter
vatNumber String?
The VAT number.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SoleProprietorshipBuilder)) SoleProprietorship
Rebuilds the instance.
inherited
toBuilder() SoleProprietorshipBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SoleProprietorship>
no setter