StockData class abstract

StockData

Properties:

Annotations
  • @BuiltValue.new()

Constructors

StockData([void updates(StockDataBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
marketIdentifier → String?
The four-digit Market Identifier Code of the stock market where the organization's stocks are traded.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stockNumber → String?
The 12-digit International Securities Identification Number (ISIN) of the company, without dashes (-).
no setter
tickerSymbol → String?
The stock ticker symbol.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(StockDataBuilder)) → StockData
Rebuilds the instance.
inherited
toBuilder() → StockDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<StockData>
no setter