TaxReportingClassification class abstract

TaxReportingClassification

Properties:

  • businessType - The organization's business type. Possible values: other, listedPublicCompany, subsidiaryOfListedPublicCompany, governmentalOrganization, internationalOrganization, financialInstitution.
  • financialInstitutionNumber - The Global Intermediary Identification Number (GIIN) required for FATCA. Only required if the organization is a US financial institution and the businessType is financialInstitution.
  • mainSourceOfIncome - The organization's main source of income. Only required if businessType is other. Possible values: businessOperation, realEstateSales, investmentInterestOrRoyalty, propertyRental, other.
  • type - The tax reporting classification type. Possible values: nonFinancialNonReportable, financialNonReportable, nonFinancialActive, nonFinancialPassive.
Annotations
  • @BuiltValue.new()

Constructors

TaxReportingClassification([void updates(TaxReportingClassificationBuilder b)])
factory

Properties

businessType → TaxReportingClassificationBusinessTypeEnum?
The organization's business type. Possible values: other, listedPublicCompany, subsidiaryOfListedPublicCompany, governmentalOrganization, internationalOrganization, financialInstitution.
no setter
financialInstitutionNumber → String?
The Global Intermediary Identification Number (GIIN) required for FATCA. Only required if the organization is a US financial institution and the businessType is financialInstitution.
no setter
hashCode → int
The hash code for this object.
no setterinherited
mainSourceOfIncome → TaxReportingClassificationMainSourceOfIncomeEnum?
The organization's main source of income. Only required if businessType is other. Possible values: businessOperation, realEstateSales, investmentInterestOrRoyalty, propertyRental, other.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TaxReportingClassificationTypeEnum?
The tax reporting classification type. Possible values: nonFinancialNonReportable, financialNonReportable, nonFinancialActive, nonFinancialPassive.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TaxReportingClassificationBuilder)) → TaxReportingClassification
Rebuilds the instance.
inherited
toBuilder() → TaxReportingClassificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TaxReportingClassification>
no setter