TaxReportingClassificationBuilder class

Properties

businessType ↔ TaxReportingClassificationBusinessTypeEnum?
getter/setter pair
financialInstitutionNumber ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mainSourceOfIncome ↔ TaxReportingClassificationMainSourceOfIncomeEnum?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ TaxReportingClassificationTypeEnum?
getter/setter pair

Methods

build() → TaxReportingClassification
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(TaxReportingClassification other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(TaxReportingClassificationBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited