TermsOfServiceAcceptanceInfoBuilder class
Constructors
Properties
- acceptedBy ↔ String?
-
getter/setter pair
- acceptedFor ↔ String?
-
getter/setter pair
- createdAt ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ TermsOfServiceAcceptanceInfoTypeEnum?
-
getter/setter pair
- validTo ↔ DateTime?
-
getter/setter pair
Methods
-
build(
) → TermsOfServiceAcceptanceInfo -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
TermsOfServiceAcceptanceInfo other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(TermsOfServiceAcceptanceInfoBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited