TransferInstrument class abstract

TransferInstrument

Properties:

  • bankAccount - Contains information about the legal entity's bank account.
  • capabilities - List of capabilities for this transfer instrument.
  • documentDetails - List of documents uploaded for the transfer instrument.
  • id - The unique identifier of the transfer instrument.
  • legalEntityId - The unique identifier of the legal entity that owns the transfer instrument.
  • problems - The verification errors related to capabilities for this transfer instrument.
  • type - The type of transfer instrument. Possible value: bankAccount.
Annotations
  • @BuiltValue.new()

Constructors

TransferInstrument([void updates(TransferInstrumentBuilder b)])
factory

Properties

bankAccount → BankAccountInfo
Contains information about the legal entity's bank account.
no setter
capabilities → BuiltMap<String, SupportingEntityCapability>?
List of capabilities for this transfer instrument.
no setter
documentDetails → BuiltList<DocumentReference>?
List of documents uploaded for the transfer instrument.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier of the transfer instrument.
no setter
legalEntityId → String
The unique identifier of the legal entity that owns the transfer instrument.
no setter
problems → BuiltList<CapabilityProblem>?
The verification errors related to capabilities for this transfer instrument.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TransferInstrumentTypeEnum
The type of transfer instrument. Possible value: bankAccount.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TransferInstrumentBuilder)) → TransferInstrument
Rebuilds the instance.
inherited
toBuilder() → TransferInstrumentBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TransferInstrument>
no setter