legalEntityId property
The unique identifier of the legal entity that owns the transfer instrument.
Implementation
@BuiltValueField(wireName: r'legalEntityId')
String get legalEntityId;
The unique identifier of the legal entity that owns the transfer instrument.
@BuiltValueField(wireName: r'legalEntityId')
String get legalEntityId;