entityIds property
The unique identifiers of the legal entity or supporting entities that the deadline applies to
Implementation
@BuiltValueField(wireName: r'entityIds')
BuiltList<String>? get entityIds;
The unique identifiers of the legal entity or supporting entities that the deadline applies to
@BuiltValueField(wireName: r'entityIds')
BuiltList<String>? get entityIds;