VerificationError class abstract

VerificationError

Properties:

  • capabilities - Contains key-value pairs that specify the actions that the legal entity can do in your platform. The key is a capability required for your integration. For example, issueCard for Issuing.The value is an object containing the settings for the capability.
  • code - The general error code.
  • message - The general error message.
  • remediatingActions - An object containing possible solutions to fix a verification error.
  • subErrors - An array containing more granular information about the cause of the verification error.
  • type - The type of error. Possible values: * invalidInput * dataMissing * pendingStatus * rejected * dataReview
Annotations
  • @BuiltValue.new()

Constructors

VerificationError([void updates(VerificationErrorBuilder b)])
factory

Properties

capabilities → BuiltList<VerificationErrorCapabilitiesEnum>?
Contains key-value pairs that specify the actions that the legal entity can do in your platform. The key is a capability required for your integration. For example, issueCard for Issuing.The value is an object containing the settings for the capability.
no setter
code → String?
The general error code.
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The general error message.
no setter
remediatingActions → BuiltList<RemediatingAction>?
An object containing possible solutions to fix a verification error.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subErrors → BuiltList<VerificationErrorRecursive>?
An array containing more granular information about the cause of the verification error.
no setter
type → VerificationErrorTypeEnum?
The type of error. Possible values: * invalidInput * dataMissing * pendingStatus * rejected * dataReview
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(VerificationErrorBuilder)) → VerificationError
Rebuilds the instance.
inherited
toBuilder() → VerificationErrorBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<VerificationError>
no setter