VerificationErrorRecursive class abstract

VerificationErrorRecursive

Properties:

  • capabilities - Contains key-value pairs that specify the actions that the legal entity can do in your platform. The key is a capability required for your integration. For example, issueCard for Issuing.The value is an object containing the settings for the capability.
  • code - The general error code.
  • message - The general error message.
  • type - The type of error. Possible values: * invalidInput * dataMissing * pendingStatus * rejected * dataReview
  • remediatingActions - An object containing possible solutions to fix a verification error.
Annotations
  • @BuiltValue.new()

Constructors

VerificationErrorRecursive([void updates(VerificationErrorRecursiveBuilder b)])
factory

Properties

capabilities → BuiltList<VerificationErrorRecursiveCapabilitiesEnum>?
Contains key-value pairs that specify the actions that the legal entity can do in your platform. The key is a capability required for your integration. For example, issueCard for Issuing.The value is an object containing the settings for the capability.
no setter
code → String?
The general error code.
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The general error message.
no setter
remediatingActions → BuiltList<RemediatingAction>?
An object containing possible solutions to fix a verification error.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → VerificationErrorRecursiveTypeEnum?
The type of error. Possible values: * invalidInput * dataMissing * pendingStatus * rejected * dataReview
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(VerificationErrorRecursiveBuilder)) → VerificationErrorRecursive
Rebuilds the instance.
inherited
toBuilder() → VerificationErrorRecursiveBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<VerificationErrorRecursive>
no setter