WebData class abstract

WebData

Properties:

  • webAddress - The URL of the website or the app store URL.
  • webAddressId - The unique identifier of the web address.
Annotations
  • @BuiltValue.new()

Constructors

WebData([void updates(WebDataBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webAddress → String?
The URL of the website or the app store URL.
no setter
webAddressId → String?
The unique identifier of the web address.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(WebDataBuilder)) → WebData
Rebuilds the instance.
inherited
toBuilder() → WebDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<WebData>
no setter