WebDataExemption class abstract

WebDataExemption

Properties:

  • reason - The reason why the web data was not provided. Possible value: noOnlinePresence.
Annotations
  • @BuiltValue.new()

Constructors

WebDataExemption([void updates(WebDataExemptionBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → WebDataExemptionReasonEnum?
The reason why the web data was not provided. Possible value: noOnlinePresence.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(WebDataExemptionBuilder)) → WebDataExemption
Rebuilds the instance.
inherited
toBuilder() → WebDataExemptionBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<WebDataExemption>
no setter