AffirmInfoPricePlanEnum class

Inheritance
  • Object
  • EnumClass
  • AffirmInfoPricePlanEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AffirmInfoPricePlanEnum>
no setter
values → BuiltSet<AffirmInfoPricePlanEnum>
no setter

Static Methods

valueOf(String name) AffirmInfoPricePlanEnum

Constants

BRONZE → const AffirmInfoPricePlanEnum
Merchant price plan
GOLD → const AffirmInfoPricePlanEnum
Merchant price plan
SILVER → const AffirmInfoPricePlanEnum
Merchant price plan
unknownDefaultOpenApi → const AffirmInfoPricePlanEnum
Merchant price plan