noContract constant
Specifies the service level (settlement type) of this payment method. Possible values: * noContract: Adyen holds the contract with American Express. * gatewayContract: American Express receives the settlement and handles disputes, then pays out to you or your sub-merchant directly. * paymentDesignatorContract: Adyen receives the settlement, and handles disputes and payouts.
Implementation
@BuiltValueEnumConst(wireName: r'noContract')
static const AmexInfoServiceLevelEnum noContract = _$amexInfoServiceLevelEnum_noContract;