ApiCredentialLinks class abstract

ApiCredentialLinks

Properties:

  • allowedOrigins - List of allowed origins.
  • company - Company account that the API credential is linked to. Only present for company-level webhooks.
  • generateApiKey - Generates a new API key. When you generate a new one, the existing key remains valid for 24 hours.
  • generateClientKey - Generates a new client key, used to authenticate client-side requests. When you generate a new one, the existing key remains valid for 24 hours.
  • merchant - The merchant account that the API credential is linked to. Only present for merchant-level API credentials.
  • self - Link to the resource itself.
Annotations
  • @BuiltValue.new()

Constructors

ApiCredentialLinks([void updates(ApiCredentialLinksBuilder b)])
factory

Properties

allowedOrigins LinksElement?
List of allowed origins.
no setter
company LinksElement?
Company account that the API credential is linked to. Only present for company-level webhooks.
no setter
generateApiKey LinksElement?
Generates a new API key. When you generate a new one, the existing key remains valid for 24 hours.
no setter
generateClientKey LinksElement?
Generates a new client key, used to authenticate client-side requests. When you generate a new one, the existing key remains valid for 24 hours.
no setter
hashCode int
The hash code for this object.
no setterinherited
merchant LinksElement?
The merchant account that the API credential is linked to. Only present for merchant-level API credentials.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self LinksElement
Link to the resource itself.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ApiCredentialLinksBuilder)) ApiCredentialLinks
Rebuilds the instance.
inherited
toBuilder() ApiCredentialLinksBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ApiCredentialLinks>
no setter