CartesBancairesInfo class abstract

CartesBancairesInfo

Properties:

  • siret - Cartes Bancaires SIRET. Format: 14 digits.
  • transactionDescription - Information regarding the transaction description. > You cannot configure the transaction description in the test environment.
Annotations
  • @BuiltValue.new()

Constructors

CartesBancairesInfo([void updates(CartesBancairesInfoBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
siret String
Cartes Bancaires SIRET. Format: 14 digits.
no setter
transactionDescription TransactionDescriptionInfo?
Information regarding the transaction description. > You cannot configure the transaction description in the test environment.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CartesBancairesInfoBuilder)) CartesBancairesInfo
Rebuilds the instance.
inherited
toBuilder() CartesBancairesInfoBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CartesBancairesInfo>
no setter