Commission class abstract

Commission

Properties:

Annotations
  • @BuiltValue.new()

Constructors

Commission([void updates(CommissionBuilder b)])
factory

Properties

fixedAmount int?
A fixed commission fee, in minor units.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variablePercentage int?
A variable commission fee, in basis points.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CommissionBuilder)) Commission
Rebuilds the instance.
inherited
toBuilder() CommissionBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Commission>
no setter