associatedMerchantAccounts property

  1. @BuiltValueField.new(wireName: r'associatedMerchantAccounts')
BuiltList<String>? get associatedMerchantAccounts

List of merchant accounts that the API credential has explicit access to. If the credential has access to a company, this implies access to all merchant accounts and no merchants for that company will be included.

Implementation

@BuiltValueField(wireName: r'associatedMerchantAccounts')
BuiltList<String>? get associatedMerchantAccounts;