eventPublicUrls property
One or more public URLs to send event notifications to when using Terminal API.
Implementation
@BuiltValueField(wireName: r'eventPublicUrls')
BuiltList<Url>? get eventPublicUrls;
One or more public URLs to send event notifications to when using Terminal API.
@BuiltValueField(wireName: r'eventPublicUrls')
BuiltList<Url>? get eventPublicUrls;