GooglePayInfo class abstract

GooglePayInfo

Properties:

  • merchantId - Google Pay Merchant ID. Character length and limitations: 16 alphanumeric characters or 20 numeric characters.
  • reuseMerchantId - Indicates whether the Google Pay Merchant ID is used for several merchant accounts. Default value: false.
Annotations
  • @BuiltValue.new()

Constructors

GooglePayInfo([void updates(GooglePayInfoBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
merchantId String
Google Pay Merchant ID. Character length and limitations: 16 alphanumeric characters or 20 numeric characters.
no setter
reuseMerchantId bool?
Indicates whether the Google Pay Merchant ID is used for several merchant accounts. Default value: false.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GooglePayInfoBuilder)) GooglePayInfo
Rebuilds the instance.
inherited
toBuilder() GooglePayInfoBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GooglePayInfo>
no setter