KlarnaInfoBuilder class

Constructors

KlarnaInfoBuilder()

Properties

autoCapture bool?
getter/setter pair
disputeEmail String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
region KlarnaInfoRegionEnum?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportEmail String?
getter/setter pair

Methods

build() KlarnaInfo
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(KlarnaInfo other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(KlarnaInfoBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited