MealVoucherFRInfo class abstract

MealVoucherFRInfo

Properties:

  • conecsId - Meal Voucher conecsId. Format: digits only
  • siret - Meal Voucher siret. Format: 14 digits.
  • subTypes - The list of additional payment methods. Allowed values: mealVoucher_FR_edenred, mealVoucher_FR_groupeup, mealVoucher_FR_natixis, mealVoucher_FR_sodexo.
Annotations
  • @BuiltValue.new()

Constructors

MealVoucherFRInfo([void updates(MealVoucherFRInfoBuilder b)])
factory

Properties

conecsId String
Meal Voucher conecsId. Format: digits only
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
siret String
Meal Voucher siret. Format: 14 digits.
no setter
subTypes → BuiltList<String>
The list of additional payment methods. Allowed values: mealVoucher_FR_edenred, mealVoucher_FR_groupeup, mealVoucher_FR_natixis, mealVoucher_FR_sodexo.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(MealVoucherFRInfoBuilder)) MealVoucherFRInfo
Rebuilds the instance.
inherited
toBuilder() MealVoucherFRInfoBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<MealVoucherFRInfo>
no setter