companyId property
The unique identifier of the company account this merchant belongs to
Implementation
@BuiltValueField(wireName: r'companyId')
String? get companyId;
The unique identifier of the company account this merchant belongs to
@BuiltValueField(wireName: r'companyId')
String? get companyId;