nexoEventUrls property
One or more URLs to send event messages to when using Terminal API.
Implementation
@BuiltValueField(wireName: r'nexoEventUrls')
BuiltList<String>? get nexoEventUrls;
One or more URLs to send event messages to when using Terminal API.
@BuiltValueField(wireName: r'nexoEventUrls')
BuiltList<String>? get nexoEventUrls;