NotificationUrl class abstract

NotificationUrl

Properties:

  • localUrls - One or more local URLs to send notifications to when using Terminal API.
  • publicUrls - One or more public URLs to send notifications to when using Terminal API.
Annotations
  • @BuiltValue.new()

Constructors

NotificationUrl([void updates(NotificationUrlBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
localUrls → BuiltList<Url>?
One or more local URLs to send notifications to when using Terminal API.
no setter
publicUrls → BuiltList<Url>?
One or more public URLs to send notifications to when using Terminal API.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NotificationUrlBuilder)) NotificationUrl
Rebuilds the instance.
inherited
toBuilder() NotificationUrlBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NotificationUrl>
no setter