localUrls property
One or more local URLs to send notifications to when using Terminal API.
Implementation
@BuiltValueField(wireName: r'localUrls')
BuiltList<Url>? get localUrls;
One or more local URLs to send notifications to when using Terminal API.
@BuiltValueField(wireName: r'localUrls')
BuiltList<Url>? get localUrls;