publicUrls property
One or more public URLs to send notifications to when using Terminal API.
Implementation
@BuiltValueField(wireName: r'publicUrls')
BuiltList<Url>? get publicUrls;
One or more public URLs to send notifications to when using Terminal API.
@BuiltValueField(wireName: r'publicUrls')
BuiltList<Url>? get publicUrls;