merchantName property
Merchant name displayed to the shopper in the Agreements
Implementation
@BuiltValueField(wireName: r'merchantName')
String get merchantName;
Merchant name displayed to the shopper in the Agreements
@BuiltValueField(wireName: r'merchantName')
String get merchantName;