moto constant
The sales channel. Required if the merchant account does not have a sales channel. When you provide this field, it overrides the default sales channel set on the merchant account. Possible values: eCommerce, pos, contAuth, and moto.
Implementation
@BuiltValueEnumConst(wireName: r'moto')
static const PaymentMethodSetupInfoShopperInteractionEnum moto = _$paymentMethodSetupInfoShopperInteractionEnum_moto;