first constant

  1. @BuiltValueEnumConst.new(wireName: r'first')
PayoutSettingsPriorityEnum const first

Determines how long it takes for the funds to reach the bank account. Adyen pays out based on the payout frequency. Depending on the currencies and banks involved in transferring the money, it may take up to three days for the payout funds to arrive in the bank account. Possible values: * first: same day. * urgent: the next day. * normal: between 1 and 3 days.

Implementation

@BuiltValueEnumConst(wireName: r'first')
static const PayoutSettingsPriorityEnum first = _$payoutSettingsPriorityEnum_first;