autoWifi property
Indicates whether to automatically select the best authentication method available. Does not work on older terminal models.
Implementation
@BuiltValueField(wireName: r'autoWifi')
bool? get autoWifi;
Indicates whether to automatically select the best authentication method available. Does not work on older terminal models.
@BuiltValueField(wireName: r'autoWifi')
bool? get autoWifi;