defaultProfile property
Indicates whether this is your preferred wireless network. If true, the terminal will try connecting to this network first.
Implementation
@BuiltValueField(wireName: r'defaultProfile')
bool? get defaultProfile;
Indicates whether this is your preferred wireless network. If true, the terminal will try connecting to this network first.
@BuiltValueField(wireName: r'defaultProfile')
bool? get defaultProfile;