eapClientCert property
For eap tls. The certificate chain for the terminals. All terminals in the same network will use the same EAP client certificate.
Implementation
@BuiltValueField(wireName: r'eapClientCert')
File? get eapClientCert;
For eap tls. The certificate chain for the terminals. All terminals in the same network will use the same EAP client certificate.
@BuiltValueField(wireName: r'eapClientCert')
File? get eapClientCert;