hiddenSsid property

  1. @BuiltValueField.new(wireName: r'hiddenSsid')
bool? get hiddenSsid

Indicates if the network doesn't broadcast its SSID. Mandatory for Android terminals, because these terminals rely on this setting to be able to connect to any network.

Implementation

@BuiltValueField(wireName: r'hiddenSsid')
bool? get hiddenSsid;