promptBeforePrinting property
Indicates whether a screen appears asking if you want to print the shopper receipt.
Implementation
@BuiltValueField(wireName: r'promptBeforePrinting')
bool? get promptBeforePrinting;
Indicates whether a screen appears asking if you want to print the shopper receipt.
@BuiltValueField(wireName: r'promptBeforePrinting')
bool? get promptBeforePrinting;