merchantApproved property
Print a merchant receipt when the payment is approved.
Implementation
@BuiltValueField(wireName: r'merchantApproved')
bool? get merchantApproved;
Print a merchant receipt when the payment is approved.
@BuiltValueField(wireName: r'merchantApproved')
bool? get merchantApproved;