shopperCancelled property
Print a shopper receipt when the transaction is cancelled.
Implementation
@BuiltValueField(wireName: r'shopperCancelled')
bool? get shopperCancelled;
Print a shopper receipt when the transaction is cancelled.
@BuiltValueField(wireName: r'shopperCancelled')
bool? get shopperCancelled;