enableStandaloneRefunds property
Indicates whether referenced refunds are enabled on the standalone terminal.
Implementation
@BuiltValueField(wireName: r'enableStandaloneRefunds')
bool? get enableStandaloneRefunds;
Indicates whether referenced refunds are enabled on the standalone terminal.
@BuiltValueField(wireName: r'enableStandaloneRefunds')
bool? get enableStandaloneRefunds;