merchantId property
The unique identifier of the merchant account you requested to activate.
Implementation
@BuiltValueField(wireName: r'merchantId')
String? get merchantId;
The unique identifier of the merchant account you requested to activate.
@BuiltValueField(wireName: r'merchantId')
String? get merchantId;