ScheduleTerminalActionsRequestActionDetailsTypeEnum class

Inheritance
  • Object
  • EnumClass
  • ScheduleTerminalActionsRequestActionDetailsTypeEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

forceReboot → const ScheduleTerminalActionsRequestActionDetailsTypeEnum
Type of terminal action: Force Reboot.
installAndroidApp → const ScheduleTerminalActionsRequestActionDetailsTypeEnum
Type of terminal action: Force Reboot.
installAndroidCertificate → const ScheduleTerminalActionsRequestActionDetailsTypeEnum
Type of terminal action: Force Reboot.
releaseUpdate → const ScheduleTerminalActionsRequestActionDetailsTypeEnum
Type of terminal action: Force Reboot.
uninstallAndroidApp → const ScheduleTerminalActionsRequestActionDetailsTypeEnum
Type of terminal action: Force Reboot.
uninstallAndroidCertificate → const ScheduleTerminalActionsRequestActionDetailsTypeEnum
Type of terminal action: Force Reboot.
unknownDefaultOpenApi → const ScheduleTerminalActionsRequestActionDetailsTypeEnum
Type of terminal action: Force Reboot.