unknownDefaultOpenApi constant

  1. @BuiltValueEnumConst.new(wireName: r'unknown_default_open_api', fallback: true)
StoreStatusEnum const unknownDefaultOpenApi

The status of the store. Possible values are: - active. This value is assigned automatically when a store is created. - inactive. The terminals under the store are blocked from accepting new transactions, but capturing outstanding transactions is still possible. - closed. This status is irreversible. The terminals under the store are reassigned to the merchant inventory.

Implementation

@BuiltValueEnumConst(wireName: r'unknown_default_open_api', fallback: true)
static const StoreStatusEnum unknownDefaultOpenApi = _$storeStatusEnum_unknownDefaultOpenApi;