active property
Sets the status of the user to active (true) or inactive (false).
Implementation
@BuiltValueField(wireName: r'active')
bool? get active;
Sets the status of the user to active (true) or inactive (false).
@BuiltValueField(wireName: r'active')
bool? get active;