ValuelinkInfoBuilder class

Constructors

ValuelinkInfoBuilder()

Properties

authorisationMid String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pinSupport ValuelinkInfoPinSupportEnum?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
submitterId String?
getter/setter pair
terminalId String?
getter/setter pair

Methods

build() ValuelinkInfo
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(ValuelinkInfo other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(ValuelinkInfoBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited