contactPersonName property
The name of the contact person from merchant support.
Implementation
@BuiltValueField(wireName: r'contactPersonName')
String get contactPersonName;
The name of the contact person from merchant support.
@BuiltValueField(wireName: r'contactPersonName')
String get contactPersonName;