company property
The company account that the webhook is configured for. Only present for company-level webhooks.
Implementation
@BuiltValueField(wireName: r'company')
LinksElement? get company;
The company account that the webhook is configured for. Only present for company-level webhooks.
@BuiltValueField(wireName: r'company')
LinksElement? get company;