name_ property
The official or commonly used name of the organization, brand, or entity.
Implementation
@BuiltValueField(wireName: r'name')
String get name_;
The official or commonly used name of the organization, brand, or entity.
@BuiltValueField(wireName: r'name')
String get name_;