bankName property
The name of the banking institution where the bank account is held.
Implementation
@BuiltValueField(wireName: r'bankName')
String? get bankName;
The name of the banking institution where the bank account is held.
@BuiltValueField(wireName: r'bankName')
String? get bankName;