AccountInfoPaymentAccountIndicatorEnum class
- Inheritance
-
- Object
- EnumClass
- AccountInfoPaymentAccountIndicatorEnum
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
AccountInfoPaymentAccountIndicatorEnum> -
no setter
-
values
→ BuiltSet<
AccountInfoPaymentAccountIndicatorEnum> -
no setter
Static Methods
Constants
- from30To60Days → const AccountInfoPaymentAccountIndicatorEnum
- Indicator for the length of time since this payment method was added to this shopper's account. Allowed values: * notApplicable * thisTransaction * lessThan30Days * from30To60Days * moreThan60Days
- lessThan30Days → const AccountInfoPaymentAccountIndicatorEnum
- Indicator for the length of time since this payment method was added to this shopper's account. Allowed values: * notApplicable * thisTransaction * lessThan30Days * from30To60Days * moreThan60Days
- moreThan60Days → const AccountInfoPaymentAccountIndicatorEnum
- Indicator for the length of time since this payment method was added to this shopper's account. Allowed values: * notApplicable * thisTransaction * lessThan30Days * from30To60Days * moreThan60Days
- notApplicable → const AccountInfoPaymentAccountIndicatorEnum
- Indicator for the length of time since this payment method was added to this shopper's account. Allowed values: * notApplicable * thisTransaction * lessThan30Days * from30To60Days * moreThan60Days
- thisTransaction → const AccountInfoPaymentAccountIndicatorEnum
- Indicator for the length of time since this payment method was added to this shopper's account. Allowed values: * notApplicable * thisTransaction * lessThan30Days * from30To60Days * moreThan60Days
- unknownDefaultOpenApi → const AccountInfoPaymentAccountIndicatorEnum
- Indicator for the length of time since this payment method was added to this shopper's account. Allowed values: * notApplicable * thisTransaction * lessThan30Days * from30To60Days * moreThan60Days