chAccPwChange property
Date that cardholder’s account with the 3DS Requestor had a password change or account reset. Format: YYYYMMDD
Implementation
@BuiltValueField(wireName: r'chAccPwChange')
String? get chAccPwChange;
Date that cardholder’s account with the 3DS Requestor had a password change or account reset. Format: YYYYMMDD
@BuiltValueField(wireName: r'chAccPwChange')
String? get chAccPwChange;