AcctInfoPaymentAccIndEnum class

Inheritance
  • Object
  • EnumClass
  • AcctInfoPaymentAccIndEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AcctInfoPaymentAccIndEnum>
no setter
values → BuiltSet<AcctInfoPaymentAccIndEnum>
no setter

Static Methods

valueOf(String name) AcctInfoPaymentAccIndEnum

Constants

n01 → const AcctInfoPaymentAccIndEnum
Indicates the length of time that the payment account was enrolled in the cardholder’s account with the 3DS Requestor. Allowed values: * 01 — No account (guest checkout) * 02 — During this transaction * 03 — Less than 30 days * 04 — 30–60 days * 05 — More than 60 days
n02 → const AcctInfoPaymentAccIndEnum
Indicates the length of time that the payment account was enrolled in the cardholder’s account with the 3DS Requestor. Allowed values: * 01 — No account (guest checkout) * 02 — During this transaction * 03 — Less than 30 days * 04 — 30–60 days * 05 — More than 60 days
n03 → const AcctInfoPaymentAccIndEnum
Indicates the length of time that the payment account was enrolled in the cardholder’s account with the 3DS Requestor. Allowed values: * 01 — No account (guest checkout) * 02 — During this transaction * 03 — Less than 30 days * 04 — 30–60 days * 05 — More than 60 days
n04 → const AcctInfoPaymentAccIndEnum
Indicates the length of time that the payment account was enrolled in the cardholder’s account with the 3DS Requestor. Allowed values: * 01 — No account (guest checkout) * 02 — During this transaction * 03 — Less than 30 days * 04 — 30–60 days * 05 — More than 60 days
n05 → const AcctInfoPaymentAccIndEnum
Indicates the length of time that the payment account was enrolled in the cardholder’s account with the 3DS Requestor. Allowed values: * 01 — No account (guest checkout) * 02 — During this transaction * 03 — Less than 30 days * 04 — 30–60 days * 05 — More than 60 days
unknownDefaultOpenApi → const AcctInfoPaymentAccIndEnum
Indicates the length of time that the payment account was enrolled in the cardholder’s account with the 3DS Requestor. Allowed values: * 01 — No account (guest checkout) * 02 — During this transaction * 03 — Less than 30 days * 04 — 30–60 days * 05 — More than 60 days