AcctInfoSuspiciousAccActivityEnum class
- Inheritance
-
- Object
- EnumClass
- AcctInfoSuspiciousAccActivityEnum
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
n01
→ const AcctInfoSuspiciousAccActivityEnum
-
Indicates whether the 3DS Requestor has experienced suspicious activity (including previous fraud) on the cardholder account. Allowed values: * 01 — No suspicious activity has been observed * 02 — Suspicious activity has been observed
-
n02
→ const AcctInfoSuspiciousAccActivityEnum
-
Indicates whether the 3DS Requestor has experienced suspicious activity (including previous fraud) on the cardholder account. Allowed values: * 01 — No suspicious activity has been observed * 02 — Suspicious activity has been observed
-
unknownDefaultOpenApi
→ const AcctInfoSuspiciousAccActivityEnum
-
Indicates whether the 3DS Requestor has experienced suspicious activity (including previous fraud) on the cardholder account. Allowed values: * 01 — No suspicious activity has been observed * 02 — Suspicious activity has been observed