payPalPeriodProtectionEligibility property
- @BuiltValueField.new(wireName: r'PayPal.ProtectionEligibility')
Allowed values: * Eligible — Merchant is protected by PayPal's Seller Protection Policy for Unauthorized Payments and Item Not Received. * PartiallyEligible — Merchant is protected by PayPal's Seller Protection Policy for Item Not Received. * Ineligible — Merchant is not protected under the Seller Protection Policy.
Implementation
@BuiltValueField(wireName: r'PayPal.ProtectionEligibility')
String? get payPalPeriodProtectionEligibility;