on_ constant
The rule to specify the period, within which the recurring debit can happen, relative to the mandate recurring date. Possible values: * on: On a specific date. * before: Before and on a specific date. * after: On and after a specific date.
Implementation
@BuiltValueEnumConst(wireName: r'on')
static const MandateBillingAttemptsRuleEnum on_ = _$mandateBillingAttemptsRuleEnum_on_;