threeDSAuthenticationOnly property
Required to trigger the authentication-only flow. If set to true, you will only perform the 3D Secure 2 authentication, and will not proceed to the payment authorization.Default: false.
Implementation
@BuiltValueField(wireName: r'threeDSAuthenticationOnly')
bool? get threeDSAuthenticationOnly;