domesticShopperAdvice property
The action the shopper should take, in a local language. Currently available in Japanese, for merchants in Japan.
Implementation
@BuiltValueField(wireName: r'domesticShopperAdvice')
String? get domesticShopperAdvice;
The action the shopper should take, in a local language. Currently available in Japanese, for merchants in Japan.
@BuiltValueField(wireName: r'domesticShopperAdvice')
String? get domesticShopperAdvice;