ThreeDS2ResultChallengeCancelEnum class

Inheritance
  • Object
  • EnumClass
  • ThreeDS2ResultChallengeCancelEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ThreeDS2ResultChallengeCancelEnum>
no setter
values → BuiltSet<ThreeDS2ResultChallengeCancelEnum>
no setter

Constants

n01 → const ThreeDS2ResultChallengeCancelEnum
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. For possible values, refer to 3D Secure API reference.
n02 → const ThreeDS2ResultChallengeCancelEnum
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. For possible values, refer to 3D Secure API reference.
n03 → const ThreeDS2ResultChallengeCancelEnum
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. For possible values, refer to 3D Secure API reference.
n04 → const ThreeDS2ResultChallengeCancelEnum
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. For possible values, refer to 3D Secure API reference.
n05 → const ThreeDS2ResultChallengeCancelEnum
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. For possible values, refer to 3D Secure API reference.
n06 → const ThreeDS2ResultChallengeCancelEnum
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. For possible values, refer to 3D Secure API reference.
n07 → const ThreeDS2ResultChallengeCancelEnum
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. For possible values, refer to 3D Secure API reference.
unknownDefaultOpenApi → const ThreeDS2ResultChallengeCancelEnum
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. For possible values, refer to 3D Secure API reference.