Card class abstract

Card

Properties:

  • cvc - The card verification code (1-20 characters). Depending on the card brand, it is known also as: * CVV2/CVC2 – length: 3 digits * CID – length: 4 digits > If you are using Client-Side Encryption, the CVC code is present in the encrypted data. You must never post the card details to the server. > This field must be always present in a one-click payment request. > When this value is returned in a response, it is always empty because it is not stored.
  • expiryMonth - The card expiry month. Format: 2 digits, zero-padded for single digits. For example: * 03 = March * 11 = November
  • expiryYear - The card expiry year. Format: 4 digits. For example: 2020
  • holderName - The name of the cardholder, as printed on the card.
  • issueNumber - The issue number of the card (for some UK debit cards only).
  • number - The card number (4-19 characters). Do not use any separators. When this value is returned in a response, only the last 4 digits of the card number are returned.
  • startMonth - The month component of the start date (for some UK debit cards only).
  • startYear - The year component of the start date (for some UK debit cards only).
Annotations
  • @BuiltValue.new()

Constructors

Card([void updates(CardBuilder b)])
factory

Properties

cvc → String?
The card verification code (1-20 characters). Depending on the card brand, it is known also as: * CVV2/CVC2 – length: 3 digits * CID – length: 4 digits > If you are using Client-Side Encryption, the CVC code is present in the encrypted data. You must never post the card details to the server. > This field must be always present in a one-click payment request. > When this value is returned in a response, it is always empty because it is not stored.
no setter
expiryMonth → String?
The card expiry month. Format: 2 digits, zero-padded for single digits. For example: * 03 = March * 11 = November
no setter
expiryYear → String?
The card expiry year. Format: 4 digits. For example: 2020
no setter
hashCode → int
The hash code for this object.
no setterinherited
holderName → String?
The name of the cardholder, as printed on the card.
no setter
issueNumber → String?
The issue number of the card (for some UK debit cards only).
no setter
number → String?
The card number (4-19 characters). Do not use any separators. When this value is returned in a response, only the last 4 digits of the card number are returned.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startMonth → String?
The month component of the start date (for some UK debit cards only).
no setter
startYear → String?
The year component of the start date (for some UK debit cards only).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CardBuilder)) → Card
Rebuilds the instance.
inherited
toBuilder() → CardBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Card>
no setter