FraudCheckResult class abstract

FraudCheckResult

Properties:

  • accountScore - The fraud score generated by the risk check.
  • checkId - The ID of the risk check.
  • name_ - The name of the risk check.
Annotations
  • @BuiltValue.new()

Constructors

FraudCheckResult([void updates(FraudCheckResultBuilder b)])
factory

Properties

accountScore → int
The fraud score generated by the risk check.
no setter
checkId → int
The ID of the risk check.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name_ → String
The name of the risk check.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(FraudCheckResultBuilder)) → FraudCheckResult
Rebuilds the instance.
inherited
toBuilder() → FraudCheckResultBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<FraudCheckResult>
no setter