FundSource class abstract

FundSource

Properties:

  • additionalData - A map of name-value pairs for passing additional or industry-specific data.
  • billingAddress - The address where to send the invoice.
  • card - Credit card data. Optional if shopperReference and selectedRecurringDetailReference are provided.
  • shopperEmail - Email address of the person.
  • shopperName - Name of the person.
  • telephoneNumber - Phone number of the person
Annotations
  • @BuiltValue.new()

Constructors

FundSource([void updates(FundSourceBuilder b)])
factory

Properties

additionalData → BuiltMap<String, String>?
A map of name-value pairs for passing additional or industry-specific data.
no setter
billingAddress → Address?
The address where to send the invoice.
no setter
card → Card?
Credit card data. Optional if shopperReference and selectedRecurringDetailReference are provided.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperEmail → String?
Email address of the person.
no setter
shopperName → Name?
Name of the person.
no setter
telephoneNumber → String?
Phone number of the person
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(FundSourceBuilder)) → FundSource
Rebuilds the instance.
inherited
toBuilder() → FundSourceBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<FundSource>
no setter