ModifyResponse class abstract

ModifyResponse

Properties:

  • additionalData - This field contains additional data, which may be returned in a particular response.
  • pspReference - Adyen's 16-character string reference associated with the transaction. This value is globally unique; quote it when communicating with us about this response.
  • response - The response: * In case of success, it is either payout-confirm-received or payout-decline-received. * In case of an error, an informational message is returned.
Annotations
  • @BuiltValue.new()

Constructors

ModifyResponse([void updates(ModifyResponseBuilder b)])
factory

Properties

additionalData → BuiltMap<String, String>?
This field contains additional data, which may be returned in a particular response.
no setter
hashCode int
The hash code for this object.
no setterinherited
pspReference String
Adyen's 16-character string reference associated with the transaction. This value is globally unique; quote it when communicating with us about this response.
no setter
response String
The response: * In case of success, it is either payout-confirm-received or payout-decline-received. * In case of an error, an informational message is returned.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ModifyResponseBuilder)) ModifyResponse
Rebuilds the instance.
inherited
toBuilder() ModifyResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ModifyResponse>
no setter