PayoutRequestBuilder class

Constructors

PayoutRequestBuilder()

Properties

amount AmountBuilder
getter/setter pair
billingAddress AddressBuilder
getter/setter pair
card CardBuilder
getter/setter pair
fraudOffset int?
getter/setter pair
fundSource FundSourceBuilder
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
merchantAccount String?
getter/setter pair
recurring RecurringBuilder
getter/setter pair
reference String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedRecurringDetailReference String?
getter/setter pair
shopperEmail String?
getter/setter pair
shopperInteraction PayoutRequestShopperInteractionEnum?
getter/setter pair
shopperName NameBuilder
getter/setter pair
shopperReference String?
getter/setter pair
telephoneNumber String?
getter/setter pair

Methods

build() PayoutRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(PayoutRequest other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(PayoutRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited