issuerUrl property
The URL to direct the shopper to. > In case of SecurePlus, do not redirect a shopper to this URL.
Implementation
@BuiltValueField(wireName: r'issuerUrl')
String? get issuerUrl;
The URL to direct the shopper to. > In case of SecurePlus, do not redirect a shopper to this URL.
@BuiltValueField(wireName: r'issuerUrl')
String? get issuerUrl;