ResponseAdditionalData3DSecure class abstract

ResponseAdditionalData3DSecure

Properties:

  • cardHolderInfo - Information provided by the issuer to the cardholder. If this field is present, you need to display this information to the cardholder.
  • cavv - The Cardholder Authentication Verification Value (CAVV) for the 3D Secure authentication session, as a Base64-encoded 20-byte array.
  • cavvAlgorithm - The CAVV algorithm used.
  • scaExemptionRequested - Shows the exemption type that Adyen requested for the payment. Possible values: * lowValue * secureCorporate * trustedBeneficiary * transactionRiskAnalysis
  • threeds2PeriodCardEnrolled - Indicates whether a card is enrolled for 3D Secure 2.
Annotations
  • @BuiltValue.new()

Properties

cardHolderInfo → String?
Information provided by the issuer to the cardholder. If this field is present, you need to display this information to the cardholder.
no setter
cavv → String?
The Cardholder Authentication Verification Value (CAVV) for the 3D Secure authentication session, as a Base64-encoded 20-byte array.
no setter
cavvAlgorithm → String?
The CAVV algorithm used.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaExemptionRequested → String?
Shows the exemption type that Adyen requested for the payment. Possible values: * lowValue * secureCorporate * trustedBeneficiary * transactionRiskAnalysis
no setter
threeds2PeriodCardEnrolled → bool?
Indicates whether a card is enrolled for 3D Secure 2.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ResponseAdditionalData3DSecureBuilder)) → ResponseAdditionalData3DSecure
Rebuilds the instance.
inherited
toBuilder() → ResponseAdditionalData3DSecureBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ResponseAdditionalData3DSecure>
no setter