cardHolderInfo property
Information provided by the issuer to the cardholder. If this field is present, you need to display this information to the cardholder.
Implementation
@BuiltValueField(wireName: r'cardHolderInfo')
String? get cardHolderInfo;
Information provided by the issuer to the cardholder. If this field is present, you need to display this information to the cardholder.
@BuiltValueField(wireName: r'cardHolderInfo')
String? get cardHolderInfo;