ResponseAdditionalDataBillingAddressBuilder class

Properties

billingAddressPeriodCity ↔ String?
getter/setter pair
billingAddressPeriodCountry ↔ String?
getter/setter pair
billingAddressPeriodHouseNumberOrName ↔ String?
getter/setter pair
billingAddressPeriodPostalCode ↔ String?
getter/setter pair
billingAddressPeriodStateOrProvince ↔ String?
getter/setter pair
billingAddressPeriodStreet ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → ResponseAdditionalDataBillingAddress
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(ResponseAdditionalDataBillingAddress other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(ResponseAdditionalDataBillingAddressBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited