ResponseAdditionalDataCard class abstract

ResponseAdditionalDataCard

Properties:

  • cardBin - The first six digits of the card number. This is the Bank Identification Number (BIN) for card numbers with a six-digit BIN. Example: 521234
  • cardHolderName - The cardholder name passed in the payment request.
  • cardIssuingBank - The bank or the financial institution granting lines of credit through card association branded payment cards. This information can be included when available.
  • cardIssuingCountry - The country where the card was issued. Example: US
  • cardIssuingCurrency - The currency in which the card is issued, if this information is available. Provided as the currency code or currency number from the ISO-4217 standard. Example: USD
  • cardPaymentMethod - The card payment method used for the transaction. Example: amex
  • cardProductId - The Card Product ID represents the type of card following card scheme product definitions and can be returned for Adyen Acquiring service level payments. Possible values Visa: * A - Visa Traditional * B - Visa Traditional Rewards * C - Visa Signature * D - Visa Signature Preferred * F - Visa Classic Possible values Mastercard: * MCC - Mastercard Card * MCE - Mastercard Electronic Card * MCF - Mastercard Corporate Fleet Card * MCG - Gold Mastercard Card * MCH - Mastercard Premium Charge * MCI - Mastercard Select Debit
  • cardSummary - The last four digits of a card number. > Returned only in case of a card payment.
  • issuerBin - The first eight digits of the card number. Only returned if the card number is 16 digits or more. This is the Bank Identification Number (BIN) for card numbers with an eight-digit BIN. Example: 52123423
Annotations
  • @BuiltValue.new()

Constructors

ResponseAdditionalDataCard([void updates(ResponseAdditionalDataCardBuilder b)])
factory

Properties

cardBin → String?
The first six digits of the card number. This is the Bank Identification Number (BIN) for card numbers with a six-digit BIN. Example: 521234
no setter
cardHolderName → String?
The cardholder name passed in the payment request.
no setter
cardIssuingBank → String?
The bank or the financial institution granting lines of credit through card association branded payment cards. This information can be included when available.
no setter
cardIssuingCountry → String?
The country where the card was issued. Example: US
no setter
cardIssuingCurrency → String?
The currency in which the card is issued, if this information is available. Provided as the currency code or currency number from the ISO-4217 standard. Example: USD
no setter
cardPaymentMethod → String?
The card payment method used for the transaction. Example: amex
no setter
cardProductId → ResponseAdditionalDataCardCardProductIdEnum?
The Card Product ID represents the type of card following card scheme product definitions and can be returned for Adyen Acquiring service level payments. Possible values Visa: * A - Visa Traditional * B - Visa Traditional Rewards * C - Visa Signature * D - Visa Signature Preferred * F - Visa Classic Possible values Mastercard: * MCC - Mastercard Card * MCE - Mastercard Electronic Card * MCF - Mastercard Corporate Fleet Card * MCG - Gold Mastercard Card * MCH - Mastercard Premium Charge * MCI - Mastercard Select Debit
no setter
cardSummary → String?
The last four digits of a card number. > Returned only in case of a card payment.
no setter
hashCode → int
The hash code for this object.
no setterinherited
issuerBin → String?
The first eight digits of the card number. Only returned if the card number is 16 digits or more. This is the Bank Identification Number (BIN) for card numbers with an eight-digit BIN. Example: 52123423
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ResponseAdditionalDataCardBuilder)) → ResponseAdditionalDataCard
Rebuilds the instance.
inherited
toBuilder() → ResponseAdditionalDataCardBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ResponseAdditionalDataCard>
no setter