ResponseAdditionalDataCardBuilder class

Properties

cardBin ↔ String?
getter/setter pair
cardHolderName ↔ String?
getter/setter pair
cardIssuingBank ↔ String?
getter/setter pair
cardIssuingCountry ↔ String?
getter/setter pair
cardIssuingCurrency ↔ String?
getter/setter pair
cardPaymentMethod ↔ String?
getter/setter pair
cardProductId ↔ ResponseAdditionalDataCardCardProductIdEnum?
getter/setter pair
cardSummary ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
issuerBin ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → ResponseAdditionalDataCard
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(ResponseAdditionalDataCard other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(ResponseAdditionalDataCardBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited