ResponseAdditionalDataDomesticError class abstract

ResponseAdditionalDataDomesticError

Properties:

  • domesticRefusalReasonRaw - The reason the transaction was declined, given by the local issuer. Currently available for merchants in Japan.
  • domesticShopperAdvice - The action the shopper should take, in a local language. Currently available in Japanese, for merchants in Japan.
Annotations
  • @BuiltValue.new()

Properties

domesticRefusalReasonRaw → String?
The reason the transaction was declined, given by the local issuer. Currently available for merchants in Japan.
no setter
domesticShopperAdvice → String?
The action the shopper should take, in a local language. Currently available in Japanese, for merchants in Japan.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ResponseAdditionalDataDomesticErrorBuilder)) → ResponseAdditionalDataDomesticError
Rebuilds the instance.
inherited
toBuilder() → ResponseAdditionalDataDomesticErrorBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ResponseAdditionalDataDomesticError>
no setter