ResponseAdditionalDataInstallments class abstract

ResponseAdditionalDataInstallments

Properties:

Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
installmentPaymentDataPeriodInstallmentType → String?
Type of installment. The value of installmentType should be IssuerFinanced.
no setter
installmentPaymentDataPeriodOptionLeftSquareBracketItemNrRightSquareBracketPeriodAnnualPercentageRate → String?
Annual interest rate.
no setter
installmentPaymentDataPeriodOptionLeftSquareBracketItemNrRightSquareBracketPeriodFirstInstallmentAmount → String?
First Installment Amount in minor units.
no setter
installmentPaymentDataPeriodOptionLeftSquareBracketItemNrRightSquareBracketPeriodInstallmentFee → String?
Installment fee amount in minor units.
no setter
installmentPaymentDataPeriodOptionLeftSquareBracketItemNrRightSquareBracketPeriodInterestRate → String?
Interest rate for the installment period.
no setter
installmentPaymentDataPeriodOptionLeftSquareBracketItemNrRightSquareBracketPeriodMaximumNumberOfInstallments → String?
Maximum number of installments possible for this payment.
no setter
installmentPaymentDataPeriodOptionLeftSquareBracketItemNrRightSquareBracketPeriodMinimumNumberOfInstallments → String?
Minimum number of installments possible for this payment.
no setter
installmentPaymentDataPeriodOptionLeftSquareBracketItemNrRightSquareBracketPeriodNumberOfInstallments → String?
Total number of installments possible for this payment.
no setter
installmentPaymentDataPeriodOptionLeftSquareBracketItemNrRightSquareBracketPeriodSubsequentInstallmentAmount → String?
Subsequent Installment Amount in minor units.
no setter
installmentPaymentDataPeriodOptionLeftSquareBracketItemNrRightSquareBracketPeriodTotalAmountDue → String?
Total amount in minor units.
no setter
installmentPaymentDataPeriodPaymentOptions → String?
Possible values: * PayInInstallmentsOnly * PayInFullOnly * PayInFullOrInstallments
no setter
installmentsPeriodValue → String?
The number of installments that the payment amount should be charged with. Example: 5 > Only relevant for card payments in countries that support installments.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ResponseAdditionalDataInstallmentsBuilder)) → ResponseAdditionalDataInstallments
Rebuilds the instance.
inherited
toBuilder() → ResponseAdditionalDataInstallmentsBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ResponseAdditionalDataInstallments>
no setter