ResponseAdditionalDataNetworkTokens class abstract

ResponseAdditionalDataNetworkTokens

Properties:

Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
networkTokenPeriodAvailable → String?
Indicates whether a network token is available for the specified card.
no setter
networkTokenPeriodBin → String?
The Bank Identification Number of a tokenized card, which is the first six digits of a card number.
no setter
networkTokenPeriodTokenSummary → String?
The last four digits of a network token.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ResponseAdditionalDataNetworkTokensBuilder)) → ResponseAdditionalDataNetworkTokens
Rebuilds the instance.
inherited
toBuilder() → ResponseAdditionalDataNetworkTokensBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ResponseAdditionalDataNetworkTokens>
no setter