ResponseAdditionalDataSepa class abstract

ResponseAdditionalDataSepa

Properties:

  • sepadirectdebitPeriodDateOfSignature - The transaction signature date. Format: yyyy-MM-dd
  • sepadirectdebitPeriodMandateId - Its value corresponds to the pspReference value of the transaction.
  • sepadirectdebitPeriodSepadirectdebitPeriodDueDate - The date that the the shopper's bank account is charged.
  • sepadirectdebitPeriodSequenceType - This field can take one of the following values: * OneOff: (OOFF) Direct debit instruction to initiate exactly one direct debit transaction. * First: (FRST) Initial/first collection in a series of direct debit instructions. * Recurring: (RCUR) Direct debit instruction to carry out regular direct debit transactions initiated by the creditor. * Final: (FNAL) Last/final collection in a series of direct debit instructions. Example: OOFF
Annotations
  • @BuiltValue.new()

Constructors

ResponseAdditionalDataSepa([void updates(ResponseAdditionalDataSepaBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sepadirectdebitPeriodDateOfSignature → String?
The transaction signature date. Format: yyyy-MM-dd
no setter
sepadirectdebitPeriodMandateId → String?
Its value corresponds to the pspReference value of the transaction.
no setter
sepadirectdebitPeriodSepadirectdebitPeriodDueDate → String?
The date that the the shopper's bank account is charged.
no setter
sepadirectdebitPeriodSequenceType → String?
This field can take one of the following values: * OneOff: (OOFF) Direct debit instruction to initiate exactly one direct debit transaction. * First: (FRST) Initial/first collection in a series of direct debit instructions. * Recurring: (RCUR) Direct debit instruction to carry out regular direct debit transactions initiated by the creditor. * Final: (FNAL) Last/final collection in a series of direct debit instructions. Example: OOFF
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ResponseAdditionalDataSepaBuilder)) → ResponseAdditionalDataSepa
Rebuilds the instance.
inherited
toBuilder() → ResponseAdditionalDataSepaBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ResponseAdditionalDataSepa>
no setter