selectedBrand property
The name of the brand to make a payout to. For Paysafecard it must be set to paysafecard.
Implementation
@BuiltValueField(wireName: r'selectedBrand')
String? get selectedBrand;
The name of the brand to make a payout to. For Paysafecard it must be set to paysafecard.
@BuiltValueField(wireName: r'selectedBrand')
String? get selectedBrand;