StoreDetailResponse class abstract

StoreDetailResponse

Properties:

  • additionalData - This field contains additional data, which may be returned in a particular response.
  • pspReference - A new reference to uniquely identify this request.
  • recurringDetailReference - The token which you can use later on for submitting the payout.
  • resultCode - The result code of the transaction. Success indicates that the details were stored successfully.
Annotations
  • @BuiltValue.new()

Constructors

StoreDetailResponse([void updates(StoreDetailResponseBuilder b)])
factory

Properties

additionalData → BuiltMap<String, String>?
This field contains additional data, which may be returned in a particular response.
no setter
hashCode int
The hash code for this object.
no setterinherited
pspReference String
A new reference to uniquely identify this request.
no setter
recurringDetailReference String
The token which you can use later on for submitting the payout.
no setter
resultCode String
The result code of the transaction. Success indicates that the details were stored successfully.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(StoreDetailResponseBuilder)) StoreDetailResponse
Rebuilds the instance.
inherited
toBuilder() StoreDetailResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<StoreDetailResponse>
no setter