amount property
A container object for the payable amount information of the transaction.
Implementation
@BuiltValueField(wireName: r'amount')
Amount get amount;
A container object for the payable amount information of the transaction.
@BuiltValueField(wireName: r'amount')
Amount get amount;