dateOfBirth property
The date of birth. Format: ISO-8601; example: YYYY-MM-DD For Paysafecard it must be the same as used when registering the Paysafecard account. > This field is mandatory for natural persons. > This field is required to update the existing dateOfBirth that is associated with this recurring contract.
Implementation
@BuiltValueField(wireName: r'dateOfBirth')
Date? get dateOfBirth;