entityType property

  1. @BuiltValueField.new(wireName: r'entityType')
SubmitRequestEntityTypeEnum? get entityType

The type of the entity the payout is processed for. Allowed values: * NaturalPerson * Company > This field is required to update the existing entityType that is associated with this recurring contract.

Implementation

@BuiltValueField(wireName: r'entityType')
SubmitRequestEntityTypeEnum? get entityType;