company constant

  1. @BuiltValueEnumConst.new(wireName: r'Company')
SubmitRequestEntityTypeEnum const company

The type of the entity the payout is processed for. Allowed values: * NaturalPerson * Company > This field is required to update the existing entityType that is associated with this recurring contract.

Implementation

@BuiltValueEnumConst(wireName: r'Company')
static const SubmitRequestEntityTypeEnum company = _$submitRequestEntityTypeEnum_company;