unknownDefaultOpenApi constant
- @BuiltValueEnumConst.new(wireName: r'unknown_default_open_api', fallback: true)
The type of the entity the payout is processed for. Allowed values: * NaturalPerson * Company > This field is required to update the existing entityType that is associated with this recurring contract.
Implementation
@BuiltValueEnumConst(wireName: r'unknown_default_open_api', fallback: true)
static const SubmitRequestEntityTypeEnum unknownDefaultOpenApi = _$submitRequestEntityTypeEnum_unknownDefaultOpenApi;