resultCode property
The response: * In case of success, it is payout-submit-received. * In case of an error, an informational message is returned.
Implementation
@BuiltValueField(wireName: r'resultCode')
String get resultCode;
The response: * In case of success, it is payout-submit-received. * In case of an error, an informational message is returned.
@BuiltValueField(wireName: r'resultCode')
String get resultCode;