AccountEvent class abstract

AccountEvent

Properties:

  • event - The event. >Permitted values: InactivateAccount, RefundNotPaidOutTransfers. For more information, refer to Verification checks.
  • executionDate - The date on which the event will take place.
  • reason - The reason why this event has been created.
Annotations
  • @BuiltValue.new()

Constructors

AccountEvent([void updates(AccountEventBuilder b)])
factory

Properties

event → AccountEventEventEnum?
The event. >Permitted values: InactivateAccount, RefundNotPaidOutTransfers. For more information, refer to Verification checks.
no setter
executionDate → DateTime?
The date on which the event will take place.
no setter
hashCode → int
The hash code for this object.
no setterinherited
reason → String?
The reason why this event has been created.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AccountEventBuilder)) → AccountEvent
Rebuilds the instance.
inherited
toBuilder() → AccountEventBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AccountEvent>
no setter