AccountHolderStatusStatusEnum class
- Inheritance
-
- Object
- EnumClass
- AccountHolderStatusStatusEnum
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
active
→ const AccountHolderStatusStatusEnum
-
The status of the account holder. >Permitted values:
Active, Inactive, Suspended, Closed.
-
closed
→ const AccountHolderStatusStatusEnum
-
The status of the account holder. >Permitted values:
Active, Inactive, Suspended, Closed.
-
inactive
→ const AccountHolderStatusStatusEnum
-
The status of the account holder. >Permitted values:
Active, Inactive, Suspended, Closed.
-
suspended
→ const AccountHolderStatusStatusEnum
-
The status of the account holder. >Permitted values:
Active, Inactive, Suspended, Closed.
-
unknownDefaultOpenApi
→ const AccountHolderStatusStatusEnum
-
The status of the account holder. >Permitted values:
Active, Inactive, Suspended, Closed.