AccountPayoutSpeedEnum class
- Inheritance
-
- Object
- EnumClass
- AccountPayoutSpeedEnum
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
AccountPayoutSpeedEnum> -
no setter
-
values
→ BuiltSet<
AccountPayoutSpeedEnum> -
no setter
Static Methods
-
valueOf(
String name) → AccountPayoutSpeedEnum
Constants
- INSTANT → const AccountPayoutSpeedEnum
-
Speed with which payouts for this account are processed. Permitted values:
STANDARD,SAME_DAY. - SAME_DAY → const AccountPayoutSpeedEnum
-
Speed with which payouts for this account are processed. Permitted values:
STANDARD,SAME_DAY. - STANDARD → const AccountPayoutSpeedEnum
-
Speed with which payouts for this account are processed. Permitted values:
STANDARD,SAME_DAY. - unknownDefaultOpenApi → const AccountPayoutSpeedEnum
-
Speed with which payouts for this account are processed. Permitted values:
STANDARD,SAME_DAY.