AccountProcessingStateBuilder class

Properties

disabled ↔ bool?
getter/setter pair
disableReason ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
processedFrom ↔ AmountBuilder
getter/setter pair
processedTo ↔ AmountBuilder
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tierNumber ↔ int?
getter/setter pair

Methods

build() → AccountProcessingState
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(AccountProcessingState other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(AccountProcessingStateBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited