bankCity property

  1. @BuiltValueField.new(wireName: r'bankCity')
String? get bankCity

The city in which the bank branch is located. >Refer to Required information for details on field requirements.

Implementation

@BuiltValueField(wireName: r'bankCity')
String? get bankCity;