CloseAccountRequest class abstract

CloseAccountRequest

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CloseAccountRequest([void updates(CloseAccountRequestBuilder b)])
factory

Properties

accountCode → String
The code of account to be closed.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CloseAccountRequestBuilder)) → CloseAccountRequest
Rebuilds the instance.
inherited
toBuilder() → CloseAccountRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CloseAccountRequest>
no setter