CloseAccountResponse class abstract

CloseAccountResponse

Properties:

  • accountCode - The account code of the account that is closed.
  • invalidFields - Contains field validation errors that would prevent requests from being processed.
  • pspReference - The reference of a request. Can be used to uniquely identify the request.
  • resultCode - The result code.
  • status - The new status of the account. >Permitted values: Active, Inactive, Suspended, Closed.
Annotations
  • @BuiltValue.new()

Constructors

CloseAccountResponse([void updates(CloseAccountResponseBuilder b)])
factory

Properties

accountCode → String?
The account code of the account that is closed.
no setter
hashCode → int
The hash code for this object.
no setterinherited
invalidFields → BuiltList<ErrorFieldType>?
Contains field validation errors that would prevent requests from being processed.
no setter
pspReference → String?
The reference of a request. Can be used to uniquely identify the request.
no setter
resultCode → String?
The result code.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → CloseAccountResponseStatusEnum?
The new status of the account. >Permitted values: Active, Inactive, Suspended, Closed.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CloseAccountResponseBuilder)) → CloseAccountResponse
Rebuilds the instance.
inherited
toBuilder() → CloseAccountResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CloseAccountResponse>
no setter