CloseStoresRequest class abstract

CloseStoresRequest

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CloseStoresRequest([void updates(CloseStoresRequestBuilder b)])
factory

Properties

accountHolderCode String
The code of the account holder.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stores → BuiltList<String>
List of stores to be closed.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CloseStoresRequestBuilder)) CloseStoresRequest
Rebuilds the instance.
inherited
toBuilder() CloseStoresRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CloseStoresRequest>
no setter