CreateAccountHolderRequest class abstract

CreateAccountHolderRequest

Properties:

  • accountHolderCode - Your unique identifier for the prospective account holder. The length must be between three (3) and fifty (50) characters long. Only letters, digits, and hyphens (-) are allowed.
  • accountHolderDetails - The details of the prospective account holder.
  • createDefaultAccount - If set to true, an account with the default options is automatically created for the account holder. By default, this field is set to true.
  • description - A description of the prospective account holder, maximum 256 characters. You can use alphanumeric characters (A-Z, a-z, 0-9), white spaces, and underscores _.
  • legalEntity - The legal entity type of the account holder. This determines the information that should be provided in the request. Possible values: Business, Individual, or NonProfit. * If set to Business or NonProfit, then accountHolderDetails.businessDetails must be provided, with at least one entry in the accountHolderDetails.businessDetails.shareholders list. * If set to Individual, then accountHolderDetails.individualDetails must be provided.
  • primaryCurrency - The three-character ISO currency code, with which the prospective account holder primarily deals.
  • processingTier - The starting processing tier for the prospective account holder.
  • verificationProfile - The identifier of the profile that applies to this entity.
Annotations
  • @BuiltValue.new()

Constructors

CreateAccountHolderRequest([void updates(CreateAccountHolderRequestBuilder b)])
factory

Properties

accountHolderCode → String
Your unique identifier for the prospective account holder. The length must be between three (3) and fifty (50) characters long. Only letters, digits, and hyphens (-) are allowed.
no setter
accountHolderDetails → AccountHolderDetails
The details of the prospective account holder.
no setter
createDefaultAccount → bool?
If set to true, an account with the default options is automatically created for the account holder. By default, this field is set to true.
no setter
description → String?
A description of the prospective account holder, maximum 256 characters. You can use alphanumeric characters (A-Z, a-z, 0-9), white spaces, and underscores _.
no setter
hashCode → int
The hash code for this object.
no setterinherited
legalEntity → CreateAccountHolderRequestLegalEntityEnum
The legal entity type of the account holder. This determines the information that should be provided in the request. Possible values: Business, Individual, or NonProfit. * If set to Business or NonProfit, then accountHolderDetails.businessDetails must be provided, with at least one entry in the accountHolderDetails.businessDetails.shareholders list. * If set to Individual, then accountHolderDetails.individualDetails must be provided.
no setter
primaryCurrency → String?
The three-character ISO currency code, with which the prospective account holder primarily deals.
no setter
processingTier → int?
The starting processing tier for the prospective account holder.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verificationProfile → String?
The identifier of the profile that applies to this entity.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CreateAccountHolderRequestBuilder)) → CreateAccountHolderRequest
Rebuilds the instance.
inherited
toBuilder() → CreateAccountHolderRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreateAccountHolderRequest>
no setter