CreateAccountHolderRequestLegalEntityEnum class

Inheritance
  • Object
  • EnumClass
  • CreateAccountHolderRequestLegalEntityEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreateAccountHolderRequestLegalEntityEnum>
no setter
values → BuiltSet<CreateAccountHolderRequestLegalEntityEnum>
no setter

Constants

business → const CreateAccountHolderRequestLegalEntityEnum
The legal entity type of the account holder. This determines the information that should be provided in the request. Possible values: Business, Individual, or NonProfit. * If set to Business or NonProfit, then accountHolderDetails.businessDetails must be provided, with at least one entry in the accountHolderDetails.businessDetails.shareholders list. * If set to Individual, then accountHolderDetails.individualDetails must be provided.
individual → const CreateAccountHolderRequestLegalEntityEnum
The legal entity type of the account holder. This determines the information that should be provided in the request. Possible values: Business, Individual, or NonProfit. * If set to Business or NonProfit, then accountHolderDetails.businessDetails must be provided, with at least one entry in the accountHolderDetails.businessDetails.shareholders list. * If set to Individual, then accountHolderDetails.individualDetails must be provided.
nonProfit → const CreateAccountHolderRequestLegalEntityEnum
The legal entity type of the account holder. This determines the information that should be provided in the request. Possible values: Business, Individual, or NonProfit. * If set to Business or NonProfit, then accountHolderDetails.businessDetails must be provided, with at least one entry in the accountHolderDetails.businessDetails.shareholders list. * If set to Individual, then accountHolderDetails.individualDetails must be provided.
partnership → const CreateAccountHolderRequestLegalEntityEnum
The legal entity type of the account holder. This determines the information that should be provided in the request. Possible values: Business, Individual, or NonProfit. * If set to Business or NonProfit, then accountHolderDetails.businessDetails must be provided, with at least one entry in the accountHolderDetails.businessDetails.shareholders list. * If set to Individual, then accountHolderDetails.individualDetails must be provided.
publicCompany → const CreateAccountHolderRequestLegalEntityEnum
The legal entity type of the account holder. This determines the information that should be provided in the request. Possible values: Business, Individual, or NonProfit. * If set to Business or NonProfit, then accountHolderDetails.businessDetails must be provided, with at least one entry in the accountHolderDetails.businessDetails.shareholders list. * If set to Individual, then accountHolderDetails.individualDetails must be provided.
unknownDefaultOpenApi → const CreateAccountHolderRequestLegalEntityEnum
The legal entity type of the account holder. This determines the information that should be provided in the request. Possible values: Business, Individual, or NonProfit. * If set to Business or NonProfit, then accountHolderDetails.businessDetails must be provided, with at least one entry in the accountHolderDetails.businessDetails.shareholders list. * If set to Individual, then accountHolderDetails.individualDetails must be provided.