CreateAccountResponse class abstract

CreateAccountResponse

Properties:

  • accountCode - The code of the new account.
  • accountHolderCode - The code of the account holder.
  • bankAccountUUID - The bankAccountUUID of the bank account held by the account holder to couple the account with. Scheduled payouts in currencies matching the currency of this bank account will be sent to this bank account. Payouts in different currencies will be sent to a matching bank account of the account holder.
  • description - The description of the account.
  • invalidFields - A list of fields that caused the /createAccount request to fail.
  • metadata - A set of key and value pairs containing metadata.
  • payoutMethodCode - The payout method code held by the account holder to couple the account with. Scheduled card payouts will be sent using this payout method code.
  • payoutSchedule - The details of the payout schedule added to the account.
  • payoutSpeed - Speed with which payouts for this account are processed. Permitted values: STANDARD, SAME_DAY.
  • pspReference - The reference of a request. Can be used to uniquely identify the request.
  • resultCode - The result code.
  • status - The status of the account. >Permitted values: Active.
Annotations
  • @BuiltValue.new()

Constructors

CreateAccountResponse([void updates(CreateAccountResponseBuilder b)])
factory

Properties

accountCode → String?
The code of the new account.
no setter
accountHolderCode → String?
The code of the account holder.
no setter
bankAccountUUID → String?
The bankAccountUUID of the bank account held by the account holder to couple the account with. Scheduled payouts in currencies matching the currency of this bank account will be sent to this bank account. Payouts in different currencies will be sent to a matching bank account of the account holder.
no setter
description → String?
The description of the account.
no setter
hashCode → int
The hash code for this object.
no setterinherited
invalidFields → BuiltList<ErrorFieldType>?
A list of fields that caused the /createAccount request to fail.
no setter
metadata → BuiltMap<String, String>?
A set of key and value pairs containing metadata.
no setter
payoutMethodCode → String?
The payout method code held by the account holder to couple the account with. Scheduled card payouts will be sent using this payout method code.
no setter
payoutSchedule → PayoutScheduleResponse?
The details of the payout schedule added to the account.
no setter
payoutSpeed → CreateAccountResponsePayoutSpeedEnum?
Speed with which payouts for this account are processed. Permitted values: STANDARD, SAME_DAY.
no setter
pspReference → String?
The reference of a request. Can be used to uniquely identify the request.
no setter
resultCode → String?
The result code.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → CreateAccountResponseStatusEnum?
The status of the account. >Permitted values: Active.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CreateAccountResponseBuilder)) → CreateAccountResponse
Rebuilds the instance.
inherited
toBuilder() → CreateAccountResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreateAccountResponse>
no setter