DeleteBankAccountRequest class abstract

DeleteBankAccountRequest

Properties:

Annotations
  • @BuiltValue.new()

Constructors

DeleteBankAccountRequest([void updates(DeleteBankAccountRequestBuilder b)])
factory

Properties

accountHolderCode String
The code of the Account Holder from which to delete the Bank Account(s).
no setter
bankAccountUUIDs → BuiltList<String>
The code(s) of the Bank Accounts to be deleted.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DeleteBankAccountRequestBuilder)) DeleteBankAccountRequest
Rebuilds the instance.
inherited
toBuilder() DeleteBankAccountRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DeleteBankAccountRequest>
no setter