DeletePayoutMethodRequest class abstract

DeletePayoutMethodRequest

Properties:

Annotations
  • @BuiltValue.new()

Constructors

DeletePayoutMethodRequest([void updates(DeletePayoutMethodRequestBuilder b)])
factory

Properties

accountHolderCode → String
The code of the account holder, from which to delete the payout methods.
no setter
hashCode → int
The hash code for this object.
no setterinherited
payoutMethodCodes → BuiltList<String>
The codes of the payout methods to be deleted.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DeletePayoutMethodRequestBuilder)) → DeletePayoutMethodRequest
Rebuilds the instance.
inherited
toBuilder() → DeletePayoutMethodRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DeletePayoutMethodRequest>
no setter