DeleteShareholderRequest class abstract

DeleteShareholderRequest

Properties:

Annotations
  • @BuiltValue.new()

Constructors

DeleteShareholderRequest([void updates(DeleteShareholderRequestBuilder b)])
factory

Properties

accountHolderCode String
The code of the Account Holder from which to delete the Shareholders.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareholderCodes → BuiltList<String>
The code(s) of the Shareholders to be deleted.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DeleteShareholderRequestBuilder)) DeleteShareholderRequest
Rebuilds the instance.
inherited
toBuilder() DeleteShareholderRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DeleteShareholderRequest>
no setter