accountHolderCode property
The code of the Account Holder from which to delete the Shareholders.
Implementation
@BuiltValueField(wireName: r'accountHolderCode')
String get accountHolderCode;
The code of the Account Holder from which to delete the Shareholders.
@BuiltValueField(wireName: r'accountHolderCode')
String get accountHolderCode;