DocumentDetail class abstract

DocumentDetail

Properties:

  • accountHolderCode - The code of account holder, to which the document applies.
  • bankAccountUUID - The Adyen-generated bankAccountUUID to which the document must be linked. Refer to Bank account check for details on when a document should be submitted. >Required if the documentType is BANK_STATEMENT, where a document is being submitted in order to verify a bank account.
  • description - Description of the document.
  • documentType - The type of the document. Refer to Verification checks for details on when each document type should be submitted and for the accepted file formats. Permitted values: * BANK_STATEMENT: A file containing a bank statement or other document proving ownership of a specific bank account. * COMPANY_REGISTRATION_SCREENING (Supported from v5 and later): A file containing a company registration document. * CONSTITUTIONAL_DOCUMENT: A file containing information about the account holder's legal arrangement. * PASSPORT: A file containing the identity page(s) of a passport. * ID_CARD_FRONT: A file containing only the front of the ID card. In order for a document to be usable, both the ID_CARD_FRONT and ID_CARD_BACK must be submitted. * ID_CARD_BACK: A file containing only the back of the ID card. In order for a document to be usable, both the ID_CARD_FRONT and ID_CARD_BACK must be submitted. * DRIVING_LICENCE_FRONT: A file containing only the front of the driving licence. In order for a document to be usable, both the DRIVING_LICENCE_FRONT and DRIVING_LICENCE_BACK must be submitted. * DRIVING_LICENCE_BACK: A file containing only the back of the driving licence. In order for a document to be usable, both the DRIVING_LICENCE_FRONT and DRIVING_LICENCE_FRONT must be submitted.
  • filename - Filename of the document.
  • legalArrangementCode - The Adyen-generated legalArrangementCode to which the document must be linked.
  • legalArrangementEntityCode - The Adyen-generated legalArrangementEntityCode to which the document must be linked.
  • shareholderCode - The Adyen-generated shareholderCode to which the document must be linked. Refer to Verification checks for details on when a document should be submitted. >Required if the account holder has a legalEntity of type Business and the documentType is either PASSPORT, ID_CARD_FRONT, ID_CARD_BACK, DRIVING_LICENCE_FRONT, or DRIVING_LICENCE_BACK.
  • signatoryCode - The Adyen-generated signatoryCode to which the document must be linked.
Annotations
  • @BuiltValue.new()

Constructors

DocumentDetail([void updates(DocumentDetailBuilder b)])
factory

Properties

accountHolderCode → String?
The code of account holder, to which the document applies.
no setter
bankAccountUUID → String?
The Adyen-generated bankAccountUUID to which the document must be linked. Refer to Bank account check for details on when a document should be submitted. >Required if the documentType is BANK_STATEMENT, where a document is being submitted in order to verify a bank account.
no setter
description → String?
Description of the document.
no setter
documentType → DocumentDetailDocumentTypeEnum
The type of the document. Refer to Verification checks for details on when each document type should be submitted and for the accepted file formats. Permitted values: * BANK_STATEMENT: A file containing a bank statement or other document proving ownership of a specific bank account. * COMPANY_REGISTRATION_SCREENING (Supported from v5 and later): A file containing a company registration document. * CONSTITUTIONAL_DOCUMENT: A file containing information about the account holder's legal arrangement. * PASSPORT: A file containing the identity page(s) of a passport. * ID_CARD_FRONT: A file containing only the front of the ID card. In order for a document to be usable, both the ID_CARD_FRONT and ID_CARD_BACK must be submitted. * ID_CARD_BACK: A file containing only the back of the ID card. In order for a document to be usable, both the ID_CARD_FRONT and ID_CARD_BACK must be submitted. * DRIVING_LICENCE_FRONT: A file containing only the front of the driving licence. In order for a document to be usable, both the DRIVING_LICENCE_FRONT and DRIVING_LICENCE_BACK must be submitted. * DRIVING_LICENCE_BACK: A file containing only the back of the driving licence. In order for a document to be usable, both the DRIVING_LICENCE_FRONT and DRIVING_LICENCE_FRONT must be submitted.
no setter
filename → String?
Filename of the document.
no setter
hashCode → int
The hash code for this object.
no setterinherited
legalArrangementCode → String?
The Adyen-generated legalArrangementCode to which the document must be linked.
no setter
legalArrangementEntityCode → String?
The Adyen-generated legalArrangementEntityCode to which the document must be linked.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareholderCode → String?
The Adyen-generated shareholderCode to which the document must be linked. Refer to Verification checks for details on when a document should be submitted. >Required if the account holder has a legalEntity of type Business and the documentType is either PASSPORT, ID_CARD_FRONT, ID_CARD_BACK, DRIVING_LICENCE_FRONT, or DRIVING_LICENCE_BACK.
no setter
signatoryCode → String?
The Adyen-generated signatoryCode to which the document must be linked.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DocumentDetailBuilder)) → DocumentDetail
Rebuilds the instance.
inherited
toBuilder() → DocumentDetailBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DocumentDetail>
no setter