accountCode property
The code of the account of which to retrieve the details. > Required if no accountHolderCode is provided.
Implementation
@BuiltValueField(wireName: r'accountCode')
String? get accountCode;
The code of the account of which to retrieve the details. > Required if no accountHolderCode is provided.
@BuiltValueField(wireName: r'accountCode')
String? get accountCode;