GetAccountHolderResponse class abstract

GetAccountHolderResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

GetAccountHolderResponse([void updates(GetAccountHolderResponseBuilder b)])
factory

Properties

accountHolderCode String?
The code of the account holder.
no setter
accountHolderDetails AccountHolderDetails?
Details of the account holder.
no setter
accountHolderStatus AccountHolderStatus?
The status of the account holder.
no setter
accounts → BuiltList<Account>?
A list of the accounts under the account holder.
no setter
description String?
The description of the account holder.
no setter
hashCode int
The hash code for this object.
no setterinherited
invalidFields → BuiltList<ErrorFieldType>?
Contains field validation errors that would prevent requests from being processed.
no setter
legalEntity GetAccountHolderResponseLegalEntityEnum?
The legal entity of the account holder.
no setter
migrationData MigrationData?
Details of the account holder migrated to the balance platform.
no setter
primaryCurrency String?
The three-character ISO currency code, with which the prospective account holder primarily deals.
no setter
pspReference String?
The reference of a request. Can be used to uniquely identify the request.
no setter
resultCode String?
The result code.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemUpToDateTime DateTime?
The time that shows how up to date is the information in the response.
no setter
verification KYCVerificationResult?
The details of KYC Verification of the account holder.
no setter
verificationProfile String?
The identifier of the profile that applies to this entity.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GetAccountHolderResponseBuilder)) GetAccountHolderResponse
Rebuilds the instance.
inherited
toBuilder() GetAccountHolderResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GetAccountHolderResponse>
no setter