systemUpToDateTime property
The time that shows how up to date is the information in the response.
Implementation
@BuiltValueField(wireName: r'systemUpToDateTime')
DateTime? get systemUpToDateTime;
The time that shows how up to date is the information in the response.
@BuiltValueField(wireName: r'systemUpToDateTime')
DateTime? get systemUpToDateTime;