GetTaxFormRequest class abstract

GetTaxFormRequest

Properties:

  • accountHolderCode - The account holder code you provided when you created the account holder.
  • formType - Type of the requested tax form. For example, 1099-K.
  • year - Applicable tax year in the YYYY format.
Annotations
  • @BuiltValue.new()

Constructors

GetTaxFormRequest([void updates(GetTaxFormRequestBuilder b)])
factory

Properties

accountHolderCode → String
The account holder code you provided when you created the account holder.
no setter
formType → String
Type of the requested tax form. For example, 1099-K.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
year → int
Applicable tax year in the YYYY format.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GetTaxFormRequestBuilder)) → GetTaxFormRequest
Rebuilds the instance.
inherited
toBuilder() → GetTaxFormRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GetTaxFormRequest>
no setter