GetUploadedDocumentsRequest class abstract

GetUploadedDocumentsRequest

Properties:

  • accountHolderCode - The code of the Account Holder for which to retrieve the documents.
  • bankAccountUUID - The code of the Bank Account for which to retrieve the documents.
  • shareholderCode - The code of the Shareholder for which to retrieve the documents.
Annotations
  • @BuiltValue.new()

Constructors

GetUploadedDocumentsRequest([void updates(GetUploadedDocumentsRequestBuilder b)])
factory

Properties

accountHolderCode → String
The code of the Account Holder for which to retrieve the documents.
no setter
bankAccountUUID → String?
The code of the Bank Account for which to retrieve the documents.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareholderCode → String?
The code of the Shareholder for which to retrieve the documents.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GetUploadedDocumentsRequestBuilder)) → GetUploadedDocumentsRequest
Rebuilds the instance.
inherited
toBuilder() → GetUploadedDocumentsRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GetUploadedDocumentsRequest>
no setter