IndividualDetails class abstract

IndividualDetails

Properties:

  • name_ - The name of the individual. >Make sure your account holder registers using the name shown on their Photo ID. Maximum length: 80 characters Cannot contain numbers. /n Cannot be empty.
  • personalData - Personal information of the individual.
Annotations
  • @BuiltValue.new()

Constructors

IndividualDetails([void updates(IndividualDetailsBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name_ ViasName?
The name of the individual. >Make sure your account holder registers using the name shown on their Photo ID. Maximum length: 80 characters Cannot contain numbers. /n Cannot be empty.
no setter
personalData ViasPersonalData?
Personal information of the individual.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(IndividualDetailsBuilder)) IndividualDetails
Rebuilds the instance.
inherited
toBuilder() IndividualDetailsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<IndividualDetails>
no setter