MigratedShareholders class abstract

MigratedShareholders

Properties:

  • legalEntityCode - The unique identifier of the legal entity of that shareholder in the balance platform.
  • shareholderCode - The unique identifier of the account of the migrated shareholder in the classic integration.
Annotations
  • @BuiltValue.new()

Constructors

MigratedShareholders([void updates(MigratedShareholdersBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
legalEntityCode String?
The unique identifier of the legal entity of that shareholder in the balance platform.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareholderCode String?
The unique identifier of the account of the migrated shareholder in the classic integration.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(MigratedShareholdersBuilder)) MigratedShareholders
Rebuilds the instance.
inherited
toBuilder() MigratedShareholdersBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<MigratedShareholders>
no setter