legalEntityCode property
The unique identifier of the legal entity of that shareholder in the balance platform.
Implementation
@BuiltValueField(wireName: r'legalEntityCode')
String? get legalEntityCode;
The unique identifier of the legal entity of that shareholder in the balance platform.
@BuiltValueField(wireName: r'legalEntityCode')
String? get legalEntityCode;