shareholderCode property
The unique identifier of the account of the migrated shareholder in the classic integration.
Implementation
@BuiltValueField(wireName: r'shareholderCode')
String? get shareholderCode;
The unique identifier of the account of the migrated shareholder in the classic integration.
@BuiltValueField(wireName: r'shareholderCode')
String? get shareholderCode;