MigratedStores class abstract

MigratedStores

Properties:

  • businessLineId - The unique identifier of the business line associated with the migrated account holder in the balance platform.
  • storeCode - The unique identifier of the store associated with the migrated account holder in the classic integration.
  • storeId - The unique identifier of the store associated with the migrated account holder in the balance platform.
  • storeReference - Your reference for the store in the classic integration. The Customer Area uses this value for the store description.
Annotations
  • @BuiltValue.new()

Constructors

MigratedStores([void updates(MigratedStoresBuilder b)])
factory

Properties

businessLineId String?
The unique identifier of the business line associated with the migrated account holder in the balance platform.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeCode String?
The unique identifier of the store associated with the migrated account holder in the classic integration.
no setter
storeId String?
The unique identifier of the store associated with the migrated account holder in the balance platform.
no setter
storeReference String?
Your reference for the store in the classic integration. The Customer Area uses this value for the store description.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(MigratedStoresBuilder)) MigratedStores
Rebuilds the instance.
inherited
toBuilder() MigratedStoresBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<MigratedStores>
no setter