storeCode property
The unique identifier of the store associated with the migrated account holder in the classic integration.
Implementation
@BuiltValueField(wireName: r'storeCode')
String? get storeCode;
The unique identifier of the store associated with the migrated account holder in the classic integration.
@BuiltValueField(wireName: r'storeCode')
String? get storeCode;