storeId property
The unique identifier of the store associated with the migrated account holder in the balance platform.
Implementation
@BuiltValueField(wireName: r'storeId')
String? get storeId;
The unique identifier of the store associated with the migrated account holder in the balance platform.
@BuiltValueField(wireName: r'storeId')
String? get storeId;