MigrationData class abstract

MigrationData

Properties:

  • accountHolderId - The unique identifier of the account holder in the balance platform.
  • balancePlatform - The unique identifier of the balance platfrom to which the account holder was migrated.
  • migrated - Set to true if the account holder has been migrated.
  • migratedAccounts - Contains the mapping of virtual account codes (classic integration) to the balance account codes (balance platform) associated with the migrated account holder.
  • migratedShareholders - Contains the mapping of shareholders associated with the migrated legal entities.
  • migratedStores - Contains the mapping of business lines and stores associated with the migrated account holder.
  • migrationDate - The date when account holder was migrated.
Annotations
  • @BuiltValue.new()

Constructors

MigrationData([void updates(MigrationDataBuilder b)])
factory

Properties

accountHolderId → String?
The unique identifier of the account holder in the balance platform.
no setter
balancePlatform → String?
The unique identifier of the balance platfrom to which the account holder was migrated.
no setter
hashCode → int
The hash code for this object.
no setterinherited
migrated → bool?
Set to true if the account holder has been migrated.
no setter
migratedAccounts → BuiltList<MigratedAccounts>?
Contains the mapping of virtual account codes (classic integration) to the balance account codes (balance platform) associated with the migrated account holder.
no setter
migratedShareholders → BuiltList<MigratedShareholders>?
Contains the mapping of shareholders associated with the migrated legal entities.
no setter
migratedStores → BuiltList<MigratedStores>?
Contains the mapping of business lines and stores associated with the migrated account holder.
no setter
migrationDate → DateTime?
The date when account holder was migrated.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(MigrationDataBuilder)) → MigrationData
Rebuilds the instance.
inherited
toBuilder() → MigrationDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<MigrationData>
no setter