migratedStores property
Contains the mapping of business lines and stores associated with the migrated account holder.
Implementation
@BuiltValueField(wireName: r'migratedStores')
BuiltList<MigratedStores>? get migratedStores;
Contains the mapping of business lines and stores associated with the migrated account holder.
@BuiltValueField(wireName: r'migratedStores')
BuiltList<MigratedStores>? get migratedStores;