MigrationDataBuilder class

Constructors

MigrationDataBuilder()

Properties

accountHolderId ↔ String?
getter/setter pair
balancePlatform ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
migrated ↔ bool?
getter/setter pair
migratedAccounts ↔ ListBuilder<MigratedAccounts>
getter/setter pair
migratedShareholders ↔ ListBuilder<MigratedShareholders>
getter/setter pair
migratedStores ↔ ListBuilder<MigratedStores>
getter/setter pair
migrationDate ↔ DateTime?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → MigrationData
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(MigrationData other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(MigrationDataBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited