PayoutMethod class abstract

PayoutMethod

Properties:

Annotations
  • @BuiltValue.new()

Constructors

PayoutMethod([void updates(PayoutMethodBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
merchantAccount → String
The merchantAccount you used in the /payments request when you saved the account holder's card details.
no setter
payoutMethodCode → String?
Adyen-generated unique alphanumeric identifier (UUID) for the payout method, returned in the response when you create a payout method. Required when updating an existing payout method in an /updateAccountHolder request.
no setter
payoutMethodReference → String?
Your reference for the payout method.
no setter
recurringDetailReference → String
The recurringDetailReference returned in the /payments response when you saved the account holder's card details.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperReference → String
The shopperReference you sent in the /payments request when you saved the account holder's card details.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PayoutMethodBuilder)) → PayoutMethod
Rebuilds the instance.
inherited
toBuilder() → PayoutMethodBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PayoutMethod>
no setter