PerformVerificationRequest class abstract

PerformVerificationRequest

Properties:

  • accountHolderCode - The code of the account holder to verify.
  • accountStateType - The state required for the account holder. > Permitted values: Processing, Payout.
  • tier - The tier required for the account holder.
Annotations
  • @BuiltValue.new()

Constructors

PerformVerificationRequest([void updates(PerformVerificationRequestBuilder b)])
factory

Properties

accountHolderCode → String
The code of the account holder to verify.
no setter
accountStateType → PerformVerificationRequestAccountStateTypeEnum
The state required for the account holder. > Permitted values: Processing, Payout.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tier → int
The tier required for the account holder.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PerformVerificationRequestBuilder)) → PerformVerificationRequest
Rebuilds the instance.
inherited
toBuilder() → PerformVerificationRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PerformVerificationRequest>
no setter