StoreDetailBuilder class

Constructors

StoreDetailBuilder()

Properties

address ViasAddressBuilder
getter/setter pair
fullPhoneNumber String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
getter/setter pair
merchantAccount String?
getter/setter pair
merchantCategoryCode String?
getter/setter pair
merchantHouseNumber String?
getter/setter pair
phoneNumber ViasPhoneNumberBuilder
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shopperInteraction StoreDetailShopperInteractionEnum?
getter/setter pair
splitConfigurationUUID String?
getter/setter pair
status StoreDetailStatusEnum?
getter/setter pair
store String?
getter/setter pair
storeName String?
getter/setter pair
storeReference String?
getter/setter pair
virtualAccount String?
getter/setter pair
webAddress String?
getter/setter pair

Methods

build() StoreDetail
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(StoreDetail other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(StoreDetailBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited