UltimateParentCompanyBusinessDetails class abstract

UltimateParentCompanyBusinessDetails

Properties:

Annotations
  • @BuiltValue.new()

Properties

hashCode int
The hash code for this object.
no setterinherited
legalBusinessName String?
The legal name of the company.
no setter
registrationNumber String?
The registration number of the company.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stockExchange String?
Market Identifier Code (MIC).
no setter
stockNumber String?
International Securities Identification Number (ISIN).
no setter
stockTicker String?
Stock Ticker symbol.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UltimateParentCompanyBusinessDetailsBuilder)) UltimateParentCompanyBusinessDetails
Rebuilds the instance.
inherited
toBuilder() UltimateParentCompanyBusinessDetailsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UltimateParentCompanyBusinessDetails>
no setter