UnSuspendAccountHolderResponse class abstract
UnSuspendAccountHolderResponse
Properties:
- accountHolderStatus - The new status of the Account Holder.
- invalidFields - Contains field validation errors that would prevent requests from being processed.
- pspReference - The reference of a request. Can be used to uniquely identify the request.
- resultCode - The result code.
- Annotations
-
- @BuiltValue.new()
Constructors
- UnSuspendAccountHolderResponse([void updates(UnSuspendAccountHolderResponseBuilder b)])
-
factory
Properties
- accountHolderStatus → AccountHolderStatus?
-
The new status of the Account Holder.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
invalidFields
→ BuiltList<
ErrorFieldType> ? -
Contains field validation errors that would prevent requests from being processed.
no setter
- pspReference → String?
-
The reference of a request. Can be used to uniquely identify the request.
no setter
- resultCode → String?
-
The result code.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(UnSuspendAccountHolderResponseBuilder)) → UnSuspendAccountHolderResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → UnSuspendAccountHolderResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
UnSuspendAccountHolderResponse> -
no setter