UpdateAccountHolderResponse class abstract

UpdateAccountHolderResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

UpdateAccountHolderResponse([void updates(UpdateAccountHolderResponseBuilder b)])
factory

Properties

accountHolderCode String?
The code of the account holder.
no setter
accountHolderDetails AccountHolderDetails?
Details of the account holder.
no setter
accountHolderStatus AccountHolderStatus?
The new status of the account holder.
no setter
description String?
The description of the account holder.
no setter
hashCode int
The hash code for this object.
no setterinherited
invalidFields → BuiltList<ErrorFieldType>?
in case the account holder has not been updated, contains account holder fields, that did not pass the validation.
no setter
legalEntity UpdateAccountHolderResponseLegalEntityEnum?
The legal entity of the account holder.
no setter
primaryCurrency String?
The three-character ISO currency code, with which the prospective account holder primarily deals.
no setter
pspReference String?
The reference of a request. Can be used to uniquely identify the request.
no setter
resultCode String?
The result code.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verification KYCVerificationResult?
The details of KYC Verification of the account holder.
no setter
verificationProfile String?
The identifier of the profile that applies to this entity.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UpdateAccountHolderResponseBuilder)) UpdateAccountHolderResponse
Rebuilds the instance.
inherited
toBuilder() UpdateAccountHolderResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UpdateAccountHolderResponse>
no setter