UpdateAccountHolderStateRequest class abstract

UpdateAccountHolderStateRequest

Properties:

  • accountHolderCode - The code of the Account Holder on which to update the state.
  • disable - If true, disable the requested state. If false, enable the requested state.
  • reason - The reason that the state is being updated. >Required if the state is being disabled.
  • stateType - The state to be updated. >Permitted values are: Processing, Payout
Annotations
  • @BuiltValue.new()

Properties

accountHolderCode → String
The code of the Account Holder on which to update the state.
no setter
disable → bool
If true, disable the requested state. If false, enable the requested state.
no setter
hashCode → int
The hash code for this object.
no setterinherited
reason → String?
The reason that the state is being updated. >Required if the state is being disabled.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateType → UpdateAccountHolderStateRequestStateTypeEnum
The state to be updated. >Permitted values are: Processing, Payout
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UpdateAccountHolderStateRequestBuilder)) → UpdateAccountHolderStateRequest
Rebuilds the instance.
inherited
toBuilder() → UpdateAccountHolderStateRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UpdateAccountHolderStateRequest>
no setter