UpdateAccountResponseBuilder class

Properties

accountCode ↔ String?
getter/setter pair
bankAccountUUID ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invalidFields ↔ ListBuilder<ErrorFieldType>
getter/setter pair
metadata ↔ MapBuilder<String, String>
getter/setter pair
payoutMethodCode ↔ String?
getter/setter pair
payoutSchedule ↔ PayoutScheduleResponseBuilder
getter/setter pair
payoutSpeed ↔ UpdateAccountResponsePayoutSpeedEnum?
getter/setter pair
pspReference ↔ String?
getter/setter pair
resultCode ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → UpdateAccountResponse
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(UpdateAccountResponse other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(UpdateAccountResponseBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited