UploadDocumentRequest class abstract

UploadDocumentRequest

Properties:

Annotations
  • @BuiltValue.new()

Constructors

UploadDocumentRequest([void updates(UploadDocumentRequestBuilder b)])
factory

Properties

documentContent → String
The content of the document, in Base64-encoded string format. To learn about document requirements, refer to Verification checks.
no setter
documentDetail → DocumentDetail
Details of the document being submitted.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UploadDocumentRequestBuilder)) → UploadDocumentRequest
Rebuilds the instance.
inherited
toBuilder() → UploadDocumentRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UploadDocumentRequest>
no setter