ViasName class abstract

ViasName

Properties:

  • firstName - The first name.
  • gender - The gender. >The following values are permitted: MALE, FEMALE, UNKNOWN.
  • infix - The name's infix, if applicable. >A maximum length of twenty (20) characters is imposed.
  • lastName - The last name.
Annotations
  • @BuiltValue.new()

Constructors

ViasName([void updates(ViasNameBuilder b)])
factory

Properties

firstName String?
The first name.
no setter
gender ViasNameGenderEnum?
The gender. >The following values are permitted: MALE, FEMALE, UNKNOWN.
no setter
hashCode int
The hash code for this object.
no setterinherited
infix String?
The name's infix, if applicable. >A maximum length of twenty (20) characters is imposed.
no setter
lastName String?
The last name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ViasNameBuilder)) ViasName
Rebuilds the instance.
inherited
toBuilder() ViasNameBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ViasName>
no setter