ViasPhoneNumber class abstract

ViasPhoneNumber

Properties:

  • phoneCountryCode - The two-character country code of the phone number. >The permitted country codes are defined in ISO-3166-1 alpha-2 (e.g. 'NL').
  • phoneNumber - The phone number. >The inclusion of the phone number country code is not necessary.
  • phoneType - The type of the phone number. >The following values are permitted: Landline, Mobile, SIP, Fax.
Annotations
  • @BuiltValue.new()

Constructors

ViasPhoneNumber([void updates(ViasPhoneNumberBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
phoneCountryCode String?
The two-character country code of the phone number. >The permitted country codes are defined in ISO-3166-1 alpha-2 (e.g. 'NL').
no setter
phoneNumber String?
The phone number. >The inclusion of the phone number country code is not necessary.
no setter
phoneType ViasPhoneNumberPhoneTypeEnum?
The type of the phone number. >The following values are permitted: Landline, Mobile, SIP, Fax.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ViasPhoneNumberBuilder)) ViasPhoneNumber
Rebuilds the instance.
inherited
toBuilder() ViasPhoneNumberBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ViasPhoneNumber>
no setter