AccountHolderBalanceResponse class abstract
AccountHolderBalanceResponse
Properties:
- balancePerAccount - A list of each account and their balances.
- invalidFields - Contains field validation errors that would prevent requests from being processed.
- pspReference - The reference of a request. Can be used to uniquely identify the request.
- resultCode - The result code.
- totalBalance - The total balance of the account holder.
- Annotations
-
- @BuiltValue.new()
Constructors
- AccountHolderBalanceResponse([void updates(AccountHolderBalanceResponseBuilder b)])
-
factory
Properties
-
balancePerAccount
→ BuiltList<
AccountDetailBalance> ? -
A list of each account and their balances.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
invalidFields
→ BuiltList<
ErrorFieldType> ? -
Contains field validation errors that would prevent requests from being processed.
no setter
- pspReference → String?
-
The reference of a request. Can be used to uniquely identify the request.
no setter
- resultCode → String?
-
The result code.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalBalance → DetailBalance?
-
The total balance of the account holder.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(AccountHolderBalanceResponseBuilder)) → AccountHolderBalanceResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → AccountHolderBalanceResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
AccountHolderBalanceResponse> -
no setter