DebitAccountHolderRequestBuilder class

Properties

accountHolderCode String?
getter/setter pair
amount AmountBuilder
getter/setter pair
bankAccountUUID String?
getter/setter pair
description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
merchantAccount String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splits ↔ ListBuilder<Split>
getter/setter pair

Methods

build() DebitAccountHolderRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(DebitAccountHolderRequest other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(DebitAccountHolderRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited