bankAccountDetail property
The details of the bank account to where a payout was made.
Implementation
@BuiltValueField(wireName: r'bankAccountDetail')
BankAccountDetail? get bankAccountDetail;
The details of the bank account to where a payout was made.
@BuiltValueField(wireName: r'bankAccountDetail')
BankAccountDetail? get bankAccountDetail;