collectInformation property

  1. @BuiltValueField.new(wireName: r'collectInformation')
CollectInformation? get collectInformation

Contains indicators whether the page should only collect information for specific KYC checks. By default, the page collects information for all KYC checks that apply to the legal entity type.

Implementation

@BuiltValueField(wireName: r'collectInformation')
CollectInformation? get collectInformation;