editMode property
Indicates if editing checks is allowed even if all the checks have passed.
Implementation
@BuiltValueField(wireName: r'editMode')
bool? get editMode;
Indicates if editing checks is allowed even if all the checks have passed.
@BuiltValueField(wireName: r'editMode')
bool? get editMode;