platformName property
The platform name which will show up in the welcome page.
Implementation
@BuiltValueField(wireName: r'platformName')
String? get platformName;
The platform name which will show up in the welcome page.
@BuiltValueField(wireName: r'platformName')
String? get platformName;