showPages property
Contains indicators whether specific pages must be shown to the account holder.
Implementation
@BuiltValueField(wireName: r'showPages')
ShowPages? get showPages;
Contains indicators whether specific pages must be shown to the account holder.
@BuiltValueField(wireName: r'showPages')
ShowPages? get showPages;