GetPciUrlRequest class abstract

GetPciUrlRequest

Properties:

  • accountHolderCode - The account holder code you provided when you created the account holder.
  • returnUrl - The URL where the account holder will be redirected back to after they fill out the questionnaire, or if their session times out. Maximum length of 500 characters.
Annotations
  • @BuiltValue.new()

Constructors

GetPciUrlRequest([void updates(GetPciUrlRequestBuilder b)])
factory

Properties

accountHolderCode String
The account holder code you provided when you created the account holder.
no setter
hashCode int
The hash code for this object.
no setterinherited
returnUrl String?
The URL where the account holder will be redirected back to after they fill out the questionnaire, or if their session times out. Maximum length of 500 characters.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GetPciUrlRequestBuilder)) GetPciUrlRequest
Rebuilds the instance.
inherited
toBuilder() GetPciUrlRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GetPciUrlRequest>
no setter