ShowPages class abstract

ShowPages

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ShowPages([void updates(ShowPagesBuilder b)])
factory

Properties

bankDetailsSummaryPage → bool?
Indicates whether the page with bank account details must be shown. Defaults to true.
no setter
bankVerificationPage → bool?
Indicates whether the bank check instant verification' details must be shown. Defaults to true.
no setter
businessDetailsSummaryPage → bool?
Indicates whether the page with the company's or organization's details must be shown. Defaults to true.
no setter
checksOverviewPage → bool?
Indicates whether the checks overview page must be shown. Defaults to false.
no setter
hashCode → int
The hash code for this object.
no setterinherited
individualDetailsSummaryPage → bool?
Indicates whether the page with the individual's details must be shown. Defaults to true.
no setter
legalArrangementsDetailsSummaryPage → bool?
Indicates whether the page with the legal arrangements' details must be shown. Defaults to true.
no setter
manualBankAccountPage → bool?
Indicates whether the page to manually add bank account' details must be shown. Defaults to true.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareholderDetailsSummaryPage → bool?
Indicates whether the page with the shareholders' details must be shown. Defaults to true.
no setter
welcomePage → bool?
Indicates whether the welcome page must be shown. Defaults to false.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ShowPagesBuilder)) → ShowPages
Rebuilds the instance.
inherited
toBuilder() → ShowPagesBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ShowPages>
no setter