DeleteNotificationConfigurationRequest class abstract

DeleteNotificationConfigurationRequest

Properties:

  • notificationIds - A list of IDs of the notification subscription configurations to be deleted.
Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
notificationIds → BuiltList<int>
A list of IDs of the notification subscription configurations to be deleted.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DeleteNotificationConfigurationRequestBuilder)) → DeleteNotificationConfigurationRequest
Rebuilds the instance.
inherited
toBuilder() → DeleteNotificationConfigurationRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DeleteNotificationConfigurationRequest>
no setter