ExchangeMessage class abstract

ExchangeMessage

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ExchangeMessage([void updates(ExchangeMessageBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageCode → String?
no setter
messageDescription → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ExchangeMessageBuilder)) → ExchangeMessage
Rebuilds the instance.
inherited
toBuilder() → ExchangeMessageBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ExchangeMessage>
no setter