NotificationConfigurationDetailsBuilder class

Properties

active ↔ bool?
getter/setter pair
apiVersion ↔ int?
getter/setter pair
description ↔ String?
getter/setter pair
eventConfigs ↔ ListBuilder<NotificationEventConfiguration>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hmacSignatureKey ↔ String?
getter/setter pair
notificationId ↔ int?
getter/setter pair
notifyPassword ↔ String?
getter/setter pair
notifyURL ↔ String?
getter/setter pair
notifyUsername ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sslProtocol ↔ NotificationConfigurationDetailsSslProtocolEnum?
getter/setter pair

Methods

build() → NotificationConfigurationDetails
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(NotificationConfigurationDetails other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(NotificationConfigurationDetailsBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited