UpdateNotificationConfigurationRequest class abstract

UpdateNotificationConfigurationRequest

Properties:

Annotations
  • @BuiltValue.new()

Properties

configurationDetails → NotificationConfigurationDetails
Details of the notification subscription configuration to be updated.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UpdateNotificationConfigurationRequestBuilder)) → UpdateNotificationConfigurationRequest
Rebuilds the instance.
inherited
toBuilder() → UpdateNotificationConfigurationRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UpdateNotificationConfigurationRequest>
no setter