Address class abstract

Address

Properties:

  • city - The name of the city. Maximum length: 3000 characters.
  • country - The two-character ISO-3166-1 alpha-2 country code. For example, US. > If you don't know the country or are not collecting the country from the shopper, provide country as ZZ.
  • houseNumberOrName - The number or name of the house. Maximum length: 3000 characters.
  • postalCode - A maximum of five digits for an address in the US, or a maximum of ten characters for an address in all other countries.
  • stateOrProvince - The two-character ISO 3166-2 state or province code. For example, CA in the US or ON in Canada. > Required for the US and Canada.
  • street - The name of the street. Maximum length: 3000 characters. > The house number should not be included in this field; it should be separately provided via houseNumberOrName.
Annotations
  • @BuiltValue.new()

Constructors

Address([void updates(AddressBuilder b)])
factory

Properties

city → String
The name of the city. Maximum length: 3000 characters.
no setter
country → String
The two-character ISO-3166-1 alpha-2 country code. For example, US. > If you don't know the country or are not collecting the country from the shopper, provide country as ZZ.
no setter
hashCode → int
The hash code for this object.
no setterinherited
houseNumberOrName → String
The number or name of the house. Maximum length: 3000 characters.
no setter
postalCode → String
A maximum of five digits for an address in the US, or a maximum of ten characters for an address in all other countries.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateOrProvince → String?
The two-character ISO 3166-2 state or province code. For example, CA in the US or ON in Canada. > Required for the US and Canada.
no setter
street → String
The name of the street. Maximum length: 3000 characters. > The house number should not be included in this field; it should be separately provided via houseNumberOrName.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AddressBuilder)) → Address
Rebuilds the instance.
inherited
toBuilder() → AddressBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Address>
no setter