BankAccount class abstract

BankAccount

Properties:

  • bankAccountNumber - The bank account number (without separators).
  • bankCity - The bank city.
  • bankLocationId - The location id of the bank. The field value is nil in most cases.
  • bankName - The name of the bank.
  • bic - The Business Identifier Code (BIC) is the SWIFT address assigned to a bank. The field value is nil in most cases.
  • countryCode - Country code where the bank is located. A valid value is an ISO two-character country code (e.g. 'NL').
  • iban - The International Bank Account Number (IBAN).
  • ownerName - The name of the bank account holder. If you submit a name with non-Latin characters, we automatically replace some of them with corresponding Latin characters to meet the FATF recommendations. For example: * χ12 is converted to ch12. * üA is converted to euA. * Peter Møller is converted to Peter Mller, because banks don't accept 'ø'. After replacement, the ownerName must have at least three alphanumeric characters (A-Z, a-z, 0-9), and at least one of them must be a valid Latin character (A-Z, a-z). For example: * John17 - allowed. * J17 - allowed. * 171 - not allowed. * John-7 - allowed. > If provided details don't match the required format, the response returns the error message: 203 'Invalid bank account holder name'.
  • taxId - The bank account holder's tax ID.
Annotations
  • @BuiltValue.new()

Constructors

BankAccount([void updates(BankAccountBuilder b)])
factory

Properties

bankAccountNumber → String?
The bank account number (without separators).
no setter
bankCity → String?
The bank city.
no setter
bankLocationId → String?
The location id of the bank. The field value is nil in most cases.
no setter
bankName → String?
The name of the bank.
no setter
bic → String?
The Business Identifier Code (BIC) is the SWIFT address assigned to a bank. The field value is nil in most cases.
no setter
countryCode → String?
Country code where the bank is located. A valid value is an ISO two-character country code (e.g. 'NL').
no setter
hashCode → int
The hash code for this object.
no setterinherited
iban → String?
The International Bank Account Number (IBAN).
no setter
ownerName → String?
The name of the bank account holder. If you submit a name with non-Latin characters, we automatically replace some of them with corresponding Latin characters to meet the FATF recommendations. For example: * χ12 is converted to ch12. * üA is converted to euA. * Peter Møller is converted to Peter Mller, because banks don't accept 'ø'. After replacement, the ownerName must have at least three alphanumeric characters (A-Z, a-z, 0-9), and at least one of them must be a valid Latin character (A-Z, a-z). For example: * John17 - allowed. * J17 - allowed. * 171 - not allowed. * John-7 - allowed. > If provided details don't match the required format, the response returns the error message: 203 'Invalid bank account holder name'.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxId → String?
The bank account holder's tax ID.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BankAccountBuilder)) → BankAccount
Rebuilds the instance.
inherited
toBuilder() → BankAccountBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BankAccount>
no setter