BankAccountBuilder class

Constructors

BankAccountBuilder()

Properties

bankAccountNumber ↔ String?
getter/setter pair
bankCity ↔ String?
getter/setter pair
bankLocationId ↔ String?
getter/setter pair
bankName ↔ String?
getter/setter pair
bic ↔ String?
getter/setter pair
countryCode ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iban ↔ String?
getter/setter pair
ownerName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxId ↔ String?
getter/setter pair

Methods

build() → BankAccount
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(BankAccount other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(BankAccountBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited