CreatePermitRequest class abstract

CreatePermitRequest

Properties:

  • merchantAccount - The merchant account identifier, with which you want to process the transaction.
  • permits - The permits to create for this recurring contract.
  • recurringDetailReference - The recurring contract the new permits will use.
  • shopperReference - The shopper's reference to uniquely identify this shopper (e.g. user ID or account ID).
Annotations
  • @BuiltValue.new()

Constructors

CreatePermitRequest([void updates(CreatePermitRequestBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
merchantAccount → String
The merchant account identifier, with which you want to process the transaction.
no setter
permits → BuiltList<Permit>
The permits to create for this recurring contract.
no setter
recurringDetailReference → String
The recurring contract the new permits will use.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperReference → String
The shopper's reference to uniquely identify this shopper (e.g. user ID or account ID).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CreatePermitRequestBuilder)) → CreatePermitRequest
Rebuilds the instance.
inherited
toBuilder() → CreatePermitRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreatePermitRequest>
no setter