CreatePermitResult class abstract

CreatePermitResult

Properties:

  • permitResultList - List of new permits.
  • pspReference - A unique reference associated with the request. This value is globally unique; quote it when communicating with us about this request.
Annotations
  • @BuiltValue.new()

Constructors

CreatePermitResult([void updates(CreatePermitResultBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
permitResultList → BuiltList<PermitResult>?
List of new permits.
no setter
pspReference → String?
A unique reference associated with the request. This value is globally unique; quote it when communicating with us about this request.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CreatePermitResultBuilder)) → CreatePermitResult
Rebuilds the instance.
inherited
toBuilder() → CreatePermitResultBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreatePermitResult>
no setter