DisablePermitRequest class abstract

DisablePermitRequest

Properties:

  • merchantAccount - The merchant account identifier, with which you want to process the transaction.
  • token - The permit token to disable.
Annotations
  • @BuiltValue.new()

Constructors

DisablePermitRequest([void updates(DisablePermitRequestBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
merchantAccount → String
The merchant account identifier, with which you want to process the transaction.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
The permit token to disable.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DisablePermitRequestBuilder)) → DisablePermitRequest
Rebuilds the instance.
inherited
toBuilder() → DisablePermitRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DisablePermitRequest>
no setter