DisablePermitResult class abstract

DisablePermitResult

Properties:

  • pspReference - A unique reference associated with the request. This value is globally unique; quote it when communicating with us about this request.
  • status - Status of the disable request.
Annotations
  • @BuiltValue.new()

Constructors

DisablePermitResult([void updates(DisablePermitResultBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pspReference → String?
A unique reference associated with the request. This value is globally unique; quote it when communicating with us about this request.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
Status of the disable request.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DisablePermitResultBuilder)) → DisablePermitResult
Rebuilds the instance.
inherited
toBuilder() → DisablePermitResultBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DisablePermitResult>
no setter