NotifyShopperRequest class abstract

NotifyShopperRequest

Properties:

  • amount - The amount of the upcoming payment.
  • billingDate - Date on which the subscription amount will be debited from the shopper. In YYYY-MM-DD format
  • billingSequenceNumber - Sequence of the debit. Depends on Frequency and Billing Attempts Rule.
  • displayedReference - Reference of Pre-debit notification that is displayed to the shopper. Optional field. Maps to reference if missing
  • merchantAccount - The merchant account identifier with which you want to process the transaction.
  • recurringDetailReference - This is the recurringDetailReference returned in the response when you created the token.
  • reference - Pre-debit notification reference sent by the merchant. This is a mandatory field
  • shopperReference - The ID that uniquely identifies the shopper. This shopperReference must be the same as the shopperReference used in the initial payment.
  • storedPaymentMethodId - This is the recurringDetailReference returned in the response when you created the token.
Annotations
  • @BuiltValue.new()

Constructors

NotifyShopperRequest([void updates(NotifyShopperRequestBuilder b)])
factory

Properties

amount → Amount
The amount of the upcoming payment.
no setter
billingDate → String?
Date on which the subscription amount will be debited from the shopper. In YYYY-MM-DD format
no setter
billingSequenceNumber → String?
Sequence of the debit. Depends on Frequency and Billing Attempts Rule.
no setter
displayedReference → String?
Reference of Pre-debit notification that is displayed to the shopper. Optional field. Maps to reference if missing
no setter
hashCode → int
The hash code for this object.
no setterinherited
merchantAccount → String
The merchant account identifier with which you want to process the transaction.
no setter
recurringDetailReference → String?
This is the recurringDetailReference returned in the response when you created the token.
no setter
reference → String
Pre-debit notification reference sent by the merchant. This is a mandatory field
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperReference → String
The ID that uniquely identifies the shopper. This shopperReference must be the same as the shopperReference used in the initial payment.
no setter
storedPaymentMethodId → String?
This is the recurringDetailReference returned in the response when you created the token.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NotifyShopperRequestBuilder)) → NotifyShopperRequest
Rebuilds the instance.
inherited
toBuilder() → NotifyShopperRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NotifyShopperRequest>
no setter