billingDate property
Date on which the subscription amount will be debited from the shopper. In YYYY-MM-DD format
Implementation
@BuiltValueField(wireName: r'billingDate')
String? get billingDate;
Date on which the subscription amount will be debited from the shopper. In YYYY-MM-DD format
@BuiltValueField(wireName: r'billingDate')
String? get billingDate;