recurringDetailReference property
This is the recurringDetailReference returned in the response when you created the token.
Implementation
@BuiltValueField(wireName: r'recurringDetailReference')
String? get recurringDetailReference;
This is the recurringDetailReference returned in the response when you created the token.
@BuiltValueField(wireName: r'recurringDetailReference')
String? get recurringDetailReference;