NotifyShopperRequestBuilder class

Properties

amount ↔ AmountBuilder
getter/setter pair
billingDate ↔ String?
getter/setter pair
billingSequenceNumber ↔ String?
getter/setter pair
displayedReference ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merchantAccount ↔ String?
getter/setter pair
recurringDetailReference ↔ String?
getter/setter pair
reference ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperReference ↔ String?
getter/setter pair
storedPaymentMethodId ↔ String?
getter/setter pair

Methods

build() → NotifyShopperRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(NotifyShopperRequest other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(NotifyShopperRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited