NotifyShopperResult class abstract

NotifyShopperResult

Properties:

  • displayedReference - Reference of Pre-debit notification that is displayed to the shopper
  • message - A simple description of the resultCode.
  • pspReference - The unique reference that is associated with the request.
  • reference - Reference of Pre-debit notification sent in my the merchant
  • resultCode - The code indicating the status of notification.
  • shopperNotificationReference - The unique reference for the request sent downstream.
  • storedPaymentMethodId - This is the recurringDetailReference returned in the response when token was created
Annotations
  • @BuiltValue.new()

Constructors

NotifyShopperResult([void updates(NotifyShopperResultBuilder b)])
factory

Properties

displayedReference → String?
Reference of Pre-debit notification that is displayed to the shopper
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?
A simple description of the resultCode.
no setter
pspReference → String?
The unique reference that is associated with the request.
no setter
reference → String?
Reference of Pre-debit notification sent in my the merchant
no setter
resultCode → String?
The code indicating the status of notification.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperNotificationReference → String?
The unique reference for the request sent downstream.
no setter
storedPaymentMethodId → String?
This is the recurringDetailReference returned in the response when token was created
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NotifyShopperResultBuilder)) → NotifyShopperResult
Rebuilds the instance.
inherited
toBuilder() → NotifyShopperResultBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NotifyShopperResult>
no setter