NotifyShopperResultBuilder class

Properties

displayedReference ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pair
pspReference ↔ String?
getter/setter pair
reference ↔ String?
getter/setter pair
resultCode ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperNotificationReference ↔ String?
getter/setter pair
storedPaymentMethodId ↔ String?
getter/setter pair

Methods

build() → NotifyShopperResult
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(NotifyShopperResult other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(NotifyShopperResultBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited