Permit class abstract

Permit

Properties:

  • partnerId - Partner ID (when using the permit-per-partner token sharing model).
  • profileReference - The profile to apply to this permit (when using the shared permits model).
  • restriction - Permit level restriction overrides.
  • resultKey - The key to link permit requests to permit results.
  • validTillDate - The expiry date for this permit.
Annotations
  • @BuiltValue.new()

Constructors

Permit([void updates(PermitBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
partnerId → String?
Partner ID (when using the permit-per-partner token sharing model).
no setter
profileReference → String?
The profile to apply to this permit (when using the shared permits model).
no setter
restriction → PermitRestriction?
Permit level restriction overrides.
no setter
resultKey → String?
The key to link permit requests to permit results.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validTillDate → DateTime?
The expiry date for this permit.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PermitBuilder)) → Permit
Rebuilds the instance.
inherited
toBuilder() → PermitBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Permit>
no setter