PermitRestriction class abstract

PermitRestriction

Properties:

  • maxAmount - The total sum amount of one or more payments made using this permit may not exceed this amount if set.
  • singleTransactionLimit - The amount of any single payment using this permit may not exceed this amount if set.
  • singleUse - Only a single payment can be made using this permit if set to true, otherwise multiple payments are allowed.
Annotations
  • @BuiltValue.new()

Constructors

PermitRestriction([void updates(PermitRestrictionBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxAmount → Amount?
The total sum amount of one or more payments made using this permit may not exceed this amount if set.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleTransactionLimit → Amount?
The amount of any single payment using this permit may not exceed this amount if set.
no setter
singleUse → bool?
Only a single payment can be made using this permit if set to true, otherwise multiple payments are allowed.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PermitRestrictionBuilder)) → PermitRestriction
Rebuilds the instance.
inherited
toBuilder() → PermitRestrictionBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PermitRestriction>
no setter