PermitResult class abstract

PermitResult

Properties:

  • resultKey - The key to link permit requests to permit results.
  • token - The permit token which is used to make payments by the partner company.
Annotations
  • @BuiltValue.new()

Constructors

PermitResult([void updates(PermitResultBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
resultKey → String?
The key to link permit requests to permit results.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String?
The permit token which is used to make payments by the partner company.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PermitResultBuilder)) → PermitResult
Rebuilds the instance.
inherited
toBuilder() → PermitResultBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PermitResult>
no setter