Recurring class abstract

Recurring

Properties:

  • contract - The type of recurring contract to be used. Possible values: * ONECLICK – Payment details can be used to initiate a one-click payment, where the shopper enters the card security code (CVC/CVV). * RECURRING – Payment details can be used without the card security code to initiate card-not-present transactions. * ONECLICK,RECURRING – Payment details can be used regardless of whether the shopper is on your site or not. * PAYOUT – Payment details can be used to make a payout. * EXTERNAL - Use this when you store payment details and send the raw card number or network token directly in your API request.
  • recurringDetailName - A descriptive name for this detail.
  • recurringExpiry - Date after which no further authorisations shall be performed. Only for 3D Secure 2.
  • recurringFrequency - Minimum number of days between authorisations. Only for 3D Secure 2.
  • tokenService - The name of the token service.
Annotations
  • @BuiltValue.new()

Constructors

Recurring([void updates(RecurringBuilder b)])
factory

Properties

contract → RecurringContractEnum?
The type of recurring contract to be used. Possible values: * ONECLICK – Payment details can be used to initiate a one-click payment, where the shopper enters the card security code (CVC/CVV). * RECURRING – Payment details can be used without the card security code to initiate card-not-present transactions. * ONECLICK,RECURRING – Payment details can be used regardless of whether the shopper is on your site or not. * PAYOUT – Payment details can be used to make a payout. * EXTERNAL - Use this when you store payment details and send the raw card number or network token directly in your API request.
no setter
hashCode → int
The hash code for this object.
no setterinherited
recurringDetailName → String?
A descriptive name for this detail.
no setter
recurringExpiry → DateTime?
Date after which no further authorisations shall be performed. Only for 3D Secure 2.
no setter
recurringFrequency → String?
Minimum number of days between authorisations. Only for 3D Secure 2.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenService → RecurringTokenServiceEnum?
The name of the token service.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RecurringBuilder)) → Recurring
Rebuilds the instance.
inherited
toBuilder() → RecurringBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Recurring>
no setter