RecurringDetail class abstract

RecurringDetail

Properties:

  • additionalData - This field contains additional data, which may be returned in a particular response. The additionalData object consists of entries, each of which includes the key and value.
  • alias - The alias of the credit card number. Applies only to recurring contracts storing credit card details
  • aliasType - The alias type of the credit card number. Applies only to recurring contracts storing credit card details.
  • bank - A container for bank account data.
  • billingAddress - The billing address.
  • card - A container for card data.
  • contractTypes - Types of recurring contracts.
  • creationDate - The date when the recurring details were created.
  • firstPspReference - The pspReference of the first recurring payment that created the recurring detail.
  • name_ - An optional descriptive name for this recurring detail.
  • networkTxReference - Returned in the response if you are not tokenizing with Adyen and are using the Merchant-initiated transactions (MIT) framework from Mastercard or Visa. This contains either the Mastercard Trace ID or the Visa Transaction ID.
  • paymentMethodVariant - The type or sub-brand of a payment method used, e.g. Visa Debit, Visa Corporate, etc. For more information, refer to PaymentMethodVariant.
  • recurringDetailReference - The reference that uniquely identifies the recurring detail.
  • shopperName - The name of the shopper.
  • socialSecurityNumber - A shopper's social security number (only in countries where it is legal to collect).
  • tokenDetails
  • variant - The payment method, such as “mc", "visa", "ideal", "paypal".
Annotations
  • @BuiltValue.new()

Constructors

RecurringDetail([void updates(RecurringDetailBuilder b)])
factory

Properties

additionalData → BuiltMap<String, String>?
This field contains additional data, which may be returned in a particular response. The additionalData object consists of entries, each of which includes the key and value.
no setter
alias → String?
The alias of the credit card number. Applies only to recurring contracts storing credit card details
no setter
aliasType → String?
The alias type of the credit card number. Applies only to recurring contracts storing credit card details.
no setter
bank → BankAccount?
A container for bank account data.
no setter
billingAddress → Address?
The billing address.
no setter
card → Card?
A container for card data.
no setter
contractTypes → BuiltList<String>?
Types of recurring contracts.
no setter
creationDate → DateTime?
The date when the recurring details were created.
no setter
firstPspReference → String?
The pspReference of the first recurring payment that created the recurring detail.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name_ → String?
An optional descriptive name for this recurring detail.
no setter
networkTxReference → String?
Returned in the response if you are not tokenizing with Adyen and are using the Merchant-initiated transactions (MIT) framework from Mastercard or Visa. This contains either the Mastercard Trace ID or the Visa Transaction ID.
no setter
paymentMethodVariant → String?
The type or sub-brand of a payment method used, e.g. Visa Debit, Visa Corporate, etc. For more information, refer to PaymentMethodVariant.
no setter
recurringDetailReference → String
The reference that uniquely identifies the recurring detail.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperName → Name?
The name of the shopper.
no setter
socialSecurityNumber → String?
A shopper's social security number (only in countries where it is legal to collect).
no setter
tokenDetails → TokenDetails?
no setter
variant → String
The payment method, such as “mc", "visa", "ideal", "paypal".
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RecurringDetailBuilder)) → RecurringDetail
Rebuilds the instance.
inherited
toBuilder() → RecurringDetailBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RecurringDetail>
no setter