RecurringDetailsResult class abstract

RecurringDetailsResult

Properties:

  • creationDate - The date when the recurring details were created.
  • details - Payment details stored for recurring payments.
  • lastKnownShopperEmail - The most recent email for this shopper (if available).
  • shopperReference - The reference you use to uniquely identify the shopper (e.g. user ID or account ID).
Annotations
  • @BuiltValue.new()

Constructors

RecurringDetailsResult([void updates(RecurringDetailsResultBuilder b)])
factory

Properties

creationDate → DateTime?
The date when the recurring details were created.
no setter
details → BuiltList<RecurringDetailWrapper>?
Payment details stored for recurring payments.
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastKnownShopperEmail → String?
The most recent email for this shopper (if available).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperReference → String?
The reference you use to uniquely identify the shopper (e.g. user ID or account ID).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RecurringDetailsResultBuilder)) → RecurringDetailsResult
Rebuilds the instance.
inherited
toBuilder() → RecurringDetailsResultBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RecurringDetailsResult>
no setter