ScheduleAccountUpdaterRequest class abstract

ScheduleAccountUpdaterRequest

Properties:

  • additionalData - This field contains additional data, which may be required for a particular request.
  • card - Credit card data. Optional if shopperReference and selectedRecurringDetailReference are provided.
  • merchantAccount - Account of the merchant.
  • reference - A reference that merchants can apply for the call.
  • selectedRecurringDetailReference - The selected detail recurring reference. Optional if card is provided.
  • shopperReference - The reference of the shopper that owns the recurring contract. Optional if card is provided.
Annotations
  • @BuiltValue.new()

Properties

additionalData → BuiltMap<String, String>?
This field contains additional data, which may be required for a particular request.
no setter
card → Card?
Credit card data. Optional if shopperReference and selectedRecurringDetailReference are provided.
no setter
hashCode → int
The hash code for this object.
no setterinherited
merchantAccount → String
Account of the merchant.
no setter
reference → String
A reference that merchants can apply for the call.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedRecurringDetailReference → String?
The selected detail recurring reference. Optional if card is provided.
no setter
shopperReference → String?
The reference of the shopper that owns the recurring contract. Optional if card is provided.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ScheduleAccountUpdaterRequestBuilder)) → ScheduleAccountUpdaterRequest
Rebuilds the instance.
inherited
toBuilder() → ScheduleAccountUpdaterRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ScheduleAccountUpdaterRequest>
no setter