ServiceError class abstract

ServiceError

Properties:

  • additionalData - Contains additional information about the payment. Some data fields are included only if you select them first. Go to Customer Area > Developers > Additional data.
  • errorCode - The error code mapped to the error message.
  • errorType - The category of the error.
  • message - A short explanation of the issue.
  • pspReference - The PSP reference of the payment.
  • status - The HTTP response status.
Annotations
  • @BuiltValue.new()

Constructors

ServiceError([void updates(ServiceErrorBuilder b)])
factory

Properties

additionalData → BuiltMap<String, String>?
Contains additional information about the payment. Some data fields are included only if you select them first. Go to Customer Area > Developers > Additional data.
no setter
errorCode → String?
The error code mapped to the error message.
no setter
errorType → String?
The category of the error.
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?
A short explanation of the issue.
no setter
pspReference → String?
The PSP reference of the payment.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int?
The HTTP response status.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ServiceErrorBuilder)) → ServiceError
Rebuilds the instance.
inherited
toBuilder() → ServiceErrorBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ServiceError>
no setter