TokenDetails class abstract

TokenDetails

Properties:

Annotations
  • @BuiltValue.new()

Constructors

TokenDetails([void updates(TokenDetailsBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenData → BuiltMap<String, String>?
no setter
tokenDataType → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TokenDetailsBuilder)) → TokenDetails
Rebuilds the instance.
inherited
toBuilder() → TokenDetailsBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TokenDetails>
no setter