AuthenticationSessionRequest class abstract

AuthenticationSessionRequest

Properties:

  • allowOrigin - The URL where the component will appear. In your live environment, you must protect the URL with an SSL certificate and ensure that it starts with https://.
  • policy - An object that contains a description of the allowed resources and roles for the requested session.
  • product - The type of component. For Onboarding components, set this to onboarding. For Platform Experience components, set this to platform.
Annotations
  • @BuiltValue.new()

Constructors

AuthenticationSessionRequest([void updates(AuthenticationSessionRequestBuilder b)])
factory

Properties

allowOrigin → String
The URL where the component will appear. In your live environment, you must protect the URL with an SSL certificate and ensure that it starts with https://.
no setter
hashCode → int
The hash code for this object.
no setterinherited
policy → Policy
An object that contains a description of the allowed resources and roles for the requested session.
no setter
product → ProductType
The type of component. For Onboarding components, set this to onboarding. For Platform Experience components, set this to platform.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AuthenticationSessionRequestBuilder)) → AuthenticationSessionRequest
Rebuilds the instance.
inherited
toBuilder() → AuthenticationSessionRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AuthenticationSessionRequest>
no setter