DefaultErrorResponseEntity class abstract

Standardized error response following RFC-7807 format

Properties:

  • detail - A human-readable explanation specific to this occurrence of the problem.
  • errorCode - Unique business error code.
  • instance - A URI that identifies the specific occurrence of the problem if applicable.
  • invalidFields - Array of fields with validation errors when applicable.
  • requestId - The unique reference for the request.
  • status - The HTTP status code.
  • title - A short, human-readable summary of the problem type.
  • type - A URI that identifies the validation error type. It points to human-readable documentation for the problem type.
Annotations
  • @BuiltValue.new()

Constructors

DefaultErrorResponseEntity([void updates(DefaultErrorResponseEntityBuilder b)])
factory

Properties

detail → String?
A human-readable explanation specific to this occurrence of the problem.
no setter
errorCode → String?
Unique business error code.
no setter
hashCode → int
The hash code for this object.
no setterinherited
instance → String?
A URI that identifies the specific occurrence of the problem if applicable.
no setter
invalidFields → BuiltList<InvalidField>?
Array of fields with validation errors when applicable.
no setter
requestId → String?
The unique reference for the request.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int?
The HTTP status code.
no setter
title → String?
A short, human-readable summary of the problem type.
no setter
type → String?
A URI that identifies the validation error type. It points to human-readable documentation for the problem type.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DefaultErrorResponseEntityBuilder)) → DefaultErrorResponseEntity
Rebuilds the instance.
inherited
toBuilder() → DefaultErrorResponseEntityBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DefaultErrorResponseEntity>
no setter