InvalidField class abstract

InvalidField

Properties:

  • name_ - The field that has an invalid value.
  • value - The invalid value.
  • message - Description of the validation error.
Annotations
  • @BuiltValue.new()

Constructors

InvalidField([void updates(InvalidFieldBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Description of the validation error.
no setter
name_ → String
The field that has an invalid value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The invalid value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(InvalidFieldBuilder)) → InvalidField
Rebuilds the instance.
inherited
toBuilder() → InvalidFieldBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<InvalidField>
no setter