legalEntityId property

  1. @BuiltValueField.new(wireName: r'legalEntityId')
String get legalEntityId

The unique identifier of the resource connected to the component. For Onboarding components, this is the legal entity that has a contractual relationship with your platform and owns the transfer instrument. For sole proprietorships, this is the legal entity of the individual owner.

Implementation

@BuiltValueField(wireName: r'legalEntityId')
String get legalEntityId;