PaymentInstrumentResourceBuilder class

Implemented types
Available extensions

Properties

discriminatorValue → String?

Available on ResourceBuilder, provided by the ResourceBuilderDiscriminatorExt extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
paymentInstrumentId ↔ String?
covariantgetter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ResourceType?
covariantgetter/setter pairoverride

Methods

build() → PaymentInstrumentResource
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant PaymentInstrumentResource other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(PaymentInstrumentResourceBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited