ResourceBuilder class abstract mixin

Implementers
Available extensions

Constructors

ResourceBuilder()

Properties

discriminatorValue → String?

Available on ResourceBuilder, provided by the ResourceBuilderDiscriminatorExt extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ResourceType?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(Resource other) → void
toString() → String
A string representation of this object.
inherited
update(void updates(ResourceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited