AbortRequest class abstract

Body of the Abort Request message. It conveys Information requested for identification of the message request carrying the transaction to abort. A message to display on the CustomerError Device could be sent by the Sale System (DisplayOutput).

Properties:

  • messageReference - Identification of a previous POI transaction.
  • abortReason - Reason of aborting a transaction.
  • displayOutput - Information to display and the way to process the display. To display an abort message to the Customer.
Annotations
  • @BuiltValue.new()

Constructors

AbortRequest([void updates(AbortRequestBuilder b)])
factory

Properties

abortReason → String
Reason of aborting a transaction.
no setter
displayOutput → DisplayOutput?
Information to display and the way to process the display. To display an abort message to the Customer.
no setter
hashCode → int
The hash code for this object.
no setterinherited
messageReference → MessageReference
Identification of a previous POI transaction.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AbortRequestBuilder)) → AbortRequest
Rebuilds the instance.
inherited
toBuilder() → AbortRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AbortRequest>
no setter