AmountsResp class abstract

AmountsResp

Properties:

  • currency - Currency of a monetary amount.
  • authorizedAmount - Amount requested by the Sale for the payment.
  • totalRebatesAmount - Sum of rebates in amount (total amount or line item amount) for all the loyalty programs.
  • totalFeesAmount - Total amount of financial fees.
  • cashBackAmount - The cash-back part of the amount requested by the Sale for the payment.
  • tipAmount - Amount paid for a tip. Allow the printing of the tip on the receipt, and to qualify the tip part of the amount.
Annotations
  • @BuiltValue.new()

Constructors

AmountsResp([void updates(AmountsRespBuilder b)])
factory

Properties

authorizedAmount → num
Amount requested by the Sale for the payment.
no setter
cashBackAmount → num?
The cash-back part of the amount requested by the Sale for the payment.
no setter
currency → String?
Currency of a monetary amount.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tipAmount → num?
Amount paid for a tip. Allow the printing of the tip on the receipt, and to qualify the tip part of the amount.
no setter
totalFeesAmount → num?
Total amount of financial fees.
no setter
totalRebatesAmount → num?
Sum of rebates in amount (total amount or line item amount) for all the loyalty programs.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AmountsRespBuilder)) → AmountsResp
Rebuilds the instance.
inherited
toBuilder() → AmountsRespBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AmountsResp>
no setter