BalanceInquiryRequest class abstract

It conveys Information related to the account for which a Balance Inquiry is requested. Content of the Balance Inquiry Request message.

Properties:

Annotations
  • @BuiltValue.new()

Constructors

BalanceInquiryRequest([void updates(BalanceInquiryRequestBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
loyaltyAccountReq → LoyaltyAccountReq?
Data related to a requested Loyalty program or account.
no setter
paymentAccountReq → PaymentAccountReq?
Data related to the account pointed by the payment card.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BalanceInquiryRequestBuilder)) → BalanceInquiryRequest
Rebuilds the instance.
inherited
toBuilder() → BalanceInquiryRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BalanceInquiryRequest>
no setter