CardAcquisitionRequest class abstract

It conveys Information related to the payment and loyalty cards to read and analyse. This message pair is usually followed by a message pair (e.g. payment or loyalty) which refers to this Card Acquisition message pair. Content of the Card Acquisition Request message.

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CardAcquisitionRequest([void updates(CardAcquisitionRequestBuilder b)])
factory

Properties

cardAcquisitionTransaction → CardAcquisitionTransaction
Data related to the payment and loyalty card acquisition.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleData → SaleData
Data related to the Sale System.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CardAcquisitionRequestBuilder)) → CardAcquisitionRequest
Rebuilds the instance.
inherited
toBuilder() → CardAcquisitionRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CardAcquisitionRequest>
no setter