CardAcquisitionTransactionBuilder class

Properties

allowedLoyaltyBrand ↔ ListBuilder<String>
getter/setter pair
allowedPaymentBrand ↔ ListBuilder<String>
getter/setter pair
cashBackFlag ↔ bool?
getter/setter pair
customerLanguage ↔ String?
getter/setter pair
forceCustomerSelectionFlag ↔ bool?
getter/setter pair
forceEntryMode ↔ ListBuilder<CardAcquisitionTransactionForceEntryModeEnum>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loyaltyHandling ↔ LoyaltyHandling?
getter/setter pair
paymentType ↔ PaymentType?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalAmount ↔ num?
getter/setter pair

Methods

build() → CardAcquisitionTransaction
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CardAcquisitionTransaction other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CardAcquisitionTransactionBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited