CardHolderPIN class abstract

CardHolderPIN

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CardHolderPIN([void updates(CardHolderPINBuilder b)])
factory

Properties

additionalInput → String?
no setter
encrPINBlock → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
pINFormat → PINFormat
Possible values: * ISO0 * ISO1 * ISO2 * ISO3
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CardHolderPINBuilder)) → CardHolderPIN
Rebuilds the instance.
inherited
toBuilder() → CardHolderPINBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CardHolderPIN>
no setter