CardReaderAPDURequest class abstract

It contains the APDU request to send to the chip of the card, and a possible invitation message to display on the CashierInterface or the CustomerInterface. Content of the Card Reader APDU Request message.

Properties:

  • aPDUClass - Class field of the APDU command (CLA). APDU request for Card Reader device request. For specific card like synchronous card, a private value should be used in accordance to ISO 7816- 4 (private range D0-FE).
  • aPDUInstruction - Instruction field of the APDU command (INS).
  • aPDUPar1 - Parameter 1 field of the APDU command (P1).
  • aPDUPar2 - Parameter 2 field of the APDU command(P2).
  • aPDUData - Data field of the APDU command (Lc + Data).
  • aPDUExpectedLength - Expected length of the data field of the APDU response to the command (Le).
Annotations
  • @BuiltValue.new()

Constructors

CardReaderAPDURequest([void updates(CardReaderAPDURequestBuilder b)])
factory

Properties

aPDUClass → String
Class field of the APDU command (CLA). APDU request for Card Reader device request. For specific card like synchronous card, a private value should be used in accordance to ISO 7816- 4 (private range D0-FE).
no setter
aPDUData → String?
Data field of the APDU command (Lc + Data).
no setter
aPDUExpectedLength → String?
Expected length of the data field of the APDU response to the command (Le).
no setter
aPDUInstruction → String
Instruction field of the APDU command (INS).
no setter
aPDUPar1 → String
Parameter 1 field of the APDU command (P1).
no setter
aPDUPar2 → String
Parameter 2 field of the APDU command(P2).
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CardReaderAPDURequestBuilder)) → CardReaderAPDURequest
Rebuilds the instance.
inherited
toBuilder() → CardReaderAPDURequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CardReaderAPDURequest>
no setter