CardReaderAPDURequestBuilder class

Properties

aPDUClass ↔ String?
getter/setter pair
aPDUData ↔ String?
getter/setter pair
aPDUExpectedLength ↔ String?
getter/setter pair
aPDUInstruction ↔ String?
getter/setter pair
aPDUPar1 ↔ String?
getter/setter pair
aPDUPar2 ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → CardReaderAPDURequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CardReaderAPDURequest other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CardReaderAPDURequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited