CheckDataBuilder class

Constructors

CheckDataBuilder()

Properties

accountNumber ↔ String?
getter/setter pair
bankID ↔ String?
getter/setter pair
checkCardNumber ↔ String?
getter/setter pair
checkNumber ↔ String?
getter/setter pair
country ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackData ↔ TrackDataBuilder
getter/setter pair
typeCode ↔ TypeCode?
getter/setter pair

Methods

build() → CheckData
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CheckData other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CheckDataBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited