ConvertedAmount class abstract

ConvertedAmount

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ConvertedAmount([void updates(ConvertedAmountBuilder b)])
factory

Properties

amountValue → num
Value of an amount.
no setter
currency → String
Currency of a monetary amount.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ConvertedAmountBuilder)) → ConvertedAmount
Rebuilds the instance.
inherited
toBuilder() → ConvertedAmountBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ConvertedAmount>
no setter