CurrencyConversion class abstract

Information related to a currency conversion. A currency conversion occurred in the payment, and the merchant needs to know information related to this conversion (e.g. to print on the sale receipt).

Properties:

  • customerApprovedFlag - Notify if the customer has approved something. Indicates if the customer has accepted a currency conversion.
  • convertedAmount - Amount after a currency conversion.
  • rate - Rate of currency conversion.
  • markup - Markup of a currency conversion amount as a percentage.
  • commission - Commission for a currency conversion.
  • declaration - Declaration to present to the customer or the cashier for validation. If a declaration has to be presented to the customer.
Annotations
  • @BuiltValue.new()

Constructors

CurrencyConversion([void updates(CurrencyConversionBuilder b)])
factory

Properties

commission → num?
Commission for a currency conversion.
no setter
convertedAmount → ConvertedAmount
Amount after a currency conversion.
no setter
customerApprovedFlag → bool?
Notify if the customer has approved something. Indicates if the customer has accepted a currency conversion.
no setter
declaration → String?
Declaration to present to the customer or the cashier for validation. If a declaration has to be presented to the customer.
no setter
hashCode → int
The hash code for this object.
no setterinherited
markup → String?
Markup of a currency conversion amount as a percentage.
no setter
rate → String?
Rate of currency conversion.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CurrencyConversionBuilder)) → CurrencyConversion
Rebuilds the instance.
inherited
toBuilder() → CurrencyConversionBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CurrencyConversion>
no setter