customerApprovedFlag property
Notify if the customer has approved something. Indicates if the customer has accepted a currency conversion.
Implementation
@BuiltValueField(wireName: r'CustomerApprovedFlag')
bool? get customerApprovedFlag;
Notify if the customer has approved something. Indicates if the customer has accepted a currency conversion.
@BuiltValueField(wireName: r'CustomerApprovedFlag')
bool? get customerApprovedFlag;