CurrencyConversionBuilder class

Constructors

CurrencyConversionBuilder()

Properties

commission ↔ num?
getter/setter pair
convertedAmount ↔ ConvertedAmountBuilder
getter/setter pair
customerApprovedFlag ↔ bool?
getter/setter pair
declaration ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
markup ↔ String?
getter/setter pair
rate ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → CurrencyConversion
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CurrencyConversion other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CurrencyConversionBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited