DisplayOutputBuilder class

Constructors

DisplayOutputBuilder()

Properties

device ↔ Device?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
infoQualify ↔ InfoQualify?
getter/setter pair
getter/setter pair
minimumDisplayTime ↔ int?
getter/setter pair
outputContent ↔ OutputContentBuilder
getter/setter pair
outputSignature ↔ String?
getter/setter pair
responseRequiredFlag ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → DisplayOutput
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(DisplayOutput other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(DisplayOutputBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited