DisplayResponse class abstract

It conveys the result of the display, parallel to the message request, except if response not required and absent. Content of the Display Response message.

Properties:

  • outputResult - Information related to the result the output (display, print, input). One per DisplayOutput item of the request, and in the same order.
Annotations
  • @BuiltValue.new()

Constructors

DisplayResponse([void updates(DisplayResponseBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
outputResult → BuiltList<OutputResult>
Information related to the result the output (display, print, input). One per DisplayOutput item of the request, and in the same order.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DisplayResponseBuilder)) → DisplayResponse
Rebuilds the instance.
inherited
toBuilder() → DisplayResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DisplayResponse>
no setter