EnableServiceRequestBuilder class

Properties

displayOutput ↔ DisplayOutputBuilder
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
servicesEnabled ↔ ListBuilder<EnableServiceRequestServicesEnabledEnum>
getter/setter pair
transactionAction ↔ TransactionAction?
getter/setter pair

Methods

build() → EnableServiceRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(EnableServiceRequest other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(EnableServiceRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited