EnableServiceResponse class abstract

It conveys the result of the Enable Service processing. Content of the Enable Service Response message.

Properties:

  • response - Result of a message request processing.
Annotations
  • @BuiltValue.new()

Constructors

EnableServiceResponse([void updates(EnableServiceResponseBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
response → Response
Result of a message request processing.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(EnableServiceResponseBuilder)) → EnableServiceResponse
Rebuilds the instance.
inherited
toBuilder() → EnableServiceResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<EnableServiceResponse>
no setter