EventNotification class abstract

Content of the EventNotification message. It conveys Information related to the event, and possible action (maintenance, message to display).

Properties:

  • timeStamp - Date and time of a transaction for the Sale System, the POI System or the Acquirer.
  • eventToNotify - Event the POI notifies to the Sale System. Possible values: * Abort * BeginMaintenance * CardInserted * CardRemoved * Completed * CustomerLanguage * EndMaintenance * Initialised * KeyPressed * OutOfOrder * Reject * SaleAdmin * SaleWakeUp * ScanBarcodeResult * SecurityAlarm * Shutdown * StopAssistance * UseAnotherCardForPreauth
  • eventDetails - Information about the event the POI notifies to the Sale System. If present, the Sale logs it for further examination.
  • rejectedMessage - Message request rejected by the receiver. Mandatory if EventToNotify is Reject, absent in other cases.
  • maintenanceRequiredFlag - Indicates if the occurred event requires maintenance call or action.
  • displayOutput - Information to display and the way to process the display. To display an event message.
Annotations
  • @BuiltValue.new()

Constructors

EventNotification([void updates(EventNotificationBuilder b)])
factory

Properties

displayOutput → BuiltList<DisplayOutput>?
Information to display and the way to process the display. To display an event message.
no setter
eventDetails → String?
Information about the event the POI notifies to the Sale System. If present, the Sale logs it for further examination.
no setter
eventToNotify → EventToNotify
Event the POI notifies to the Sale System. Possible values: * Abort * BeginMaintenance * CardInserted * CardRemoved * Completed * CustomerLanguage * EndMaintenance * Initialised * KeyPressed * OutOfOrder * Reject * SaleAdmin * SaleWakeUp * ScanBarcodeResult * SecurityAlarm * Shutdown * StopAssistance * UseAnotherCardForPreauth
no setter
hashCode → int
The hash code for this object.
no setterinherited
maintenanceRequiredFlag → bool?
Indicates if the occurred event requires maintenance call or action.
no setter
rejectedMessage → String?
Message request rejected by the receiver. Mandatory if EventToNotify is Reject, absent in other cases.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeStamp → DateTime
Date and time of a transaction for the Sale System, the POI System or the Acquirer.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(EventNotificationBuilder)) → EventNotification
Rebuilds the instance.
inherited
toBuilder() → EventNotificationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<EventNotification>
no setter