EventNotificationBuilder class

Constructors

EventNotificationBuilder()

Properties

displayOutput ↔ ListBuilder<DisplayOutput>
getter/setter pair
eventDetails ↔ String?
getter/setter pair
eventToNotify ↔ EventToNotify?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maintenanceRequiredFlag ↔ bool?
getter/setter pair
rejectedMessage ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeStamp ↔ DateTime?
getter/setter pair

Methods

build() → EventNotification
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(EventNotification other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(EventNotificationBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited