GeographicCoordinates class abstract

GeographicCoordinates

Properties:

  • latitude - Angular distance of a location on the earth south or north of the equator.
  • longitude - Angular measurement of the distance of a location on the earth east or west of the Greenwich observatory.
Annotations
  • @BuiltValue.new()

Constructors

GeographicCoordinates([void updates(GeographicCoordinatesBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
latitude → String
Angular distance of a location on the earth south or north of the equator.
no setter
longitude → String
Angular measurement of the distance of a location on the earth east or west of the Greenwich observatory.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GeographicCoordinatesBuilder)) → GeographicCoordinates
Rebuilds the instance.
inherited
toBuilder() → GeographicCoordinatesBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GeographicCoordinates>
no setter