Geolocation class abstract

Geolocation

Properties:

Annotations
  • @BuiltValue.new()

Constructors

Geolocation([void updates(GeolocationBuilder b)])
factory

Properties

geographicCoordinates → GeographicCoordinates?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uTMCoordinates → UTMCoordinates?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GeolocationBuilder)) → Geolocation
Rebuilds the instance.
inherited
toBuilder() → GeolocationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Geolocation>
no setter