GetTotalsResponse class abstract

Content of the Reconciliation Response message. It conveys Information related to the Reconciliation transaction processed by the POI System.

Properties:

  • response - Result of a message request processing.
  • pOIReconciliationID - Identification of the reconciliation period between Sale and POI.
  • transactionTotals - Result of the Sale to POI Reconciliation processing. If Response.Result is Success.
Annotations
  • @BuiltValue.new()

Constructors

GetTotalsResponse([void updates(GetTotalsResponseBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pOIReconciliationID → int
Identification of the reconciliation period between Sale and POI.
no setter
response → Response
Result of a message request processing.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionTotals → BuiltList<TransactionTotals>?
Result of the Sale to POI Reconciliation processing. If Response.Result is Success.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GetTotalsResponseBuilder)) → GetTotalsResponse
Rebuilds the instance.
inherited
toBuilder() → GetTotalsResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GetTotalsResponse>
no setter