HostStatus class abstract

Indicate the reachability of the host by the POI Terminal. State of a Host.

Properties:

Annotations
  • @BuiltValue.new()

Constructors

HostStatus([void updates(HostStatusBuilder b)])
factory

Properties

acquirerID → int
Identification of the Acquirer.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isReachableFlag → bool?
Indicate if a Host is reachable.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(HostStatusBuilder)) → HostStatus
Rebuilds the instance.
inherited
toBuilder() → HostStatusBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<HostStatus>
no setter