HostStatusBuilder class

Constructors

HostStatusBuilder()

Properties

acquirerID ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isReachableFlag ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → HostStatus
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(HostStatus other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(HostStatusBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited