Input class abstract

Input

Properties:

  • inputCommand - Type of requested input. Can be: GetConfirmation, TextString, DigitString, DecimalString or GetMenuEntry. Possible values: * DecimalString * DigitString * GetAnyKey * GetConfirmation * GetFunctionKey * GetMenuEntry * Password * SiteManager * TextString
  • confirmedFlag - Indicates te response of the user from the GetConfirmation input command.
  • functionKey - The number of the function key which is typed by the Customer on the POI or the Cashier on the Sale Terminal.
  • textInput - The text typed by the Customer on the POI or by the Cashier on the Sale Terminal.
  • digitInput - The digits typed by the Customer on the POI or by the Cashier on the Sale Terminal.
  • password - The text password typed by the Customer on the POI or by the Cashier on the Sale Terminal.
  • menuEntryNumber - The index of the menu item (from 1 to n) which is selected by the Cashier on the Sale Terminal. The value -1 indicates that the immediate upper level of the menu is requested. The value 0 indicates that the root of the menu is requested.
Annotations
  • @BuiltValue.new()

Constructors

Input([void updates(InputBuilder b)])
factory

Properties

confirmedFlag → bool?
Indicates te response of the user from the GetConfirmation input command.
no setter
digitInput → int?
The digits typed by the Customer on the POI or by the Cashier on the Sale Terminal.
no setter
functionKey → int?
The number of the function key which is typed by the Customer on the POI or the Cashier on the Sale Terminal.
no setter
hashCode → int
The hash code for this object.
no setterinherited
inputCommand → InputCommand
Type of requested input. Can be: GetConfirmation, TextString, DigitString, DecimalString or GetMenuEntry. Possible values: * DecimalString * DigitString * GetAnyKey * GetConfirmation * GetFunctionKey * GetMenuEntry * Password * SiteManager * TextString
no setter
The index of the menu item (from 1 to n) which is selected by the Cashier on the Sale Terminal. The value -1 indicates that the immediate upper level of the menu is requested. The value 0 indicates that the root of the menu is requested.
no setter
password → String?
The text password typed by the Customer on the POI or by the Cashier on the Sale Terminal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textInput → String?
The text typed by the Customer on the POI or by the Cashier on the Sale Terminal.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(InputBuilder)) → Input
Rebuilds the instance.
inherited
toBuilder() → InputBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Input>
no setter