InputBuilder class

Constructors

InputBuilder()

Properties

confirmedFlag ↔ bool?
getter/setter pair
digitInput ↔ int?
getter/setter pair
functionKey ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputCommand ↔ InputCommand?
getter/setter pair
getter/setter pair
password ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textInput ↔ String?
getter/setter pair

Methods

build() → Input
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(Input other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(InputBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited