disableCancelFlag property
Indicates if the Cancel function key has to be deactivated (value True).
Implementation
@BuiltValueField(wireName: r'DisableCancelFlag')
bool? get disableCancelFlag;
Indicates if the Cancel function key has to be deactivated (value True).
@BuiltValueField(wireName: r'DisableCancelFlag')
bool? get disableCancelFlag;