globalCorrectionFlag property

  1. @BuiltValueField.new(wireName: r'GlobalCorrectionFlag')
bool? get globalCorrectionFlag

Indicates, when the user presses the Correct function key in an input entry, if all the entered characters are removed (value True) or only the last entered character if any (value False).

Implementation

@BuiltValueField(wireName: r'GlobalCorrectionFlag')
bool? get globalCorrectionFlag;