maskCharactersFlag property

  1. @BuiltValueField.new(wireName: r'MaskCharactersFlag')
bool? get maskCharactersFlag

Indicates to mask the characters entered by the user (i.e. replacing in the display of the input, the entered character by a standard character as *).

Implementation

@BuiltValueField(wireName: r'MaskCharactersFlag')
bool? get maskCharactersFlag;