InputResult class abstract

InputResult

Properties:

  • device - Logical device located on a Sale Terminal or a POI Terminal, in terms of class of information to output (display, print or store), or input (keyboard) for the Cashier or the Customer. Possible values: * CashierDisplay * CashierInput * CustomerDisplay * CustomerInput
  • infoQualify - Qualification of the information to send to an output logical device, to display or print to the Cashier or the Customer. Possible values: * CustomerAssistance * Display * Document * Error * Input * POIReplication * Receipt * Sound * Status * Voucher
  • response
  • input - Data entered by the user, related to the input command.
Annotations
  • @BuiltValue.new()

Constructors

InputResult([void updates(InputResultBuilder b)])
factory

Properties

device → Device
Logical device located on a Sale Terminal or a POI Terminal, in terms of class of information to output (display, print or store), or input (keyboard) for the Cashier or the Customer. Possible values: * CashierDisplay * CashierInput * CustomerDisplay * CustomerInput
no setter
hashCode → int
The hash code for this object.
no setterinherited
infoQualify → InfoQualify
Qualification of the information to send to an output logical device, to display or print to the Cashier or the Customer. Possible values: * CustomerAssistance * Display * Document * Error * Input * POIReplication * Receipt * Sound * Status * Voucher
no setter
input → Input?
Data entered by the user, related to the input command.
no setter
response → Response
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(InputResultBuilder)) → InputResult
Rebuilds the instance.
inherited
toBuilder() → InputResultBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<InputResult>
no setter