InputResultBuilder class

Constructors

InputResultBuilder()

Properties

device ↔ Device?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
infoQualify ↔ InfoQualify?
getter/setter pair
input ↔ InputBuilder
getter/setter pair
response ↔ ResponseBuilder
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → InputResult
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(InputResult other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(InputResultBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited