InputUpdate class abstract

Definition: Content of the Input Update message. : It conveys update of the display of an Input request in progress.

Properties:

Annotations
  • @BuiltValue.new()

Constructors

InputUpdate([void updates(InputUpdateBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxDecimalLength → int?
no setter
maxLength → int?
no setter
no setter
messageReference → MessageReference
no setter
minLength → int?
no setter
outputContent → OutputContent
no setter
outputSignature → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(InputUpdateBuilder)) → InputUpdate
Rebuilds the instance.
inherited
toBuilder() → InputUpdateBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<InputUpdate>
no setter