InputUpdateBuilder class

Constructors

InputUpdateBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxDecimalLength ↔ int?
getter/setter pair
maxLength ↔ int?
getter/setter pair
getter/setter pair
messageReference ↔ MessageReferenceBuilder
getter/setter pair
minLength ↔ int?
getter/setter pair
outputContent ↔ OutputContentBuilder
getter/setter pair
outputSignature ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → InputUpdate
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(InputUpdate other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(InputUpdateBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited