Instalment class abstract

Instalment

Properties:

  • instalmentType - Type of instalment transaction. For requesting an instalment payment transaction. Possible values: * DeferredInstalments * EqualInstalments * InequalInstalments
  • sequenceNumber - Sequence number of the instalment. For an instalment payment transaction, number of the payment, from 1 to TotalNbOfPayments.
  • planID - Identification of an instalment plan.
  • period - Period of time with defined unit of time. A period between 2 payment instalments.
  • periodUnit - Type of instalment transaction. Possible values: * Annual * Daily * Monthly * Weekly
  • firstPaymentDate - First date of a payment. For instalment, the date of the first payments, if not immediate.
  • totalNbOfPayments - Total number of payments. For instalment, the number of payments, including the first one.
  • cumulativeAmount - Sum of a collection of amounts. Total amount of the payment instalments.
  • firstAmount - First amount of the payment instalments.
  • charges - Charges related to a transaction. Charge related to the payment instalments.
Annotations
  • @BuiltValue.new()

Constructors

Instalment([void updates(InstalmentBuilder b)])
factory

Properties

charges → num?
Charges related to a transaction. Charge related to the payment instalments.
no setter
cumulativeAmount → num?
Sum of a collection of amounts. Total amount of the payment instalments.
no setter
firstAmount → num?
First amount of the payment instalments.
no setter
firstPaymentDate → Date?
First date of a payment. For instalment, the date of the first payments, if not immediate.
no setter
hashCode → int
The hash code for this object.
no setterinherited
instalmentType → InstalmentType?
Type of instalment transaction. For requesting an instalment payment transaction. Possible values: * DeferredInstalments * EqualInstalments * InequalInstalments
no setter
period → int?
Period of time with defined unit of time. A period between 2 payment instalments.
no setter
periodUnit → PeriodUnit?
Type of instalment transaction. Possible values: * Annual * Daily * Monthly * Weekly
no setter
planID → String?
Identification of an instalment plan.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber → int?
Sequence number of the instalment. For an instalment payment transaction, number of the payment, from 1 to TotalNbOfPayments.
no setter
totalNbOfPayments → int?
Total number of payments. For instalment, the number of payments, including the first one.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(InstalmentBuilder)) → Instalment
Rebuilds the instance.
inherited
toBuilder() → InstalmentBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Instalment>
no setter