LoginResponse class abstract

It conveys Information related to the Login to process. Content of the Login Response message.

Properties:

  • response - Result of a message request processing.
  • pOISystemData - Information related to the POI System. Returned if the response result is Success.
  • tokenRequestStatus - If token is managed by the POI, the status of the token request.
Annotations
  • @BuiltValue.new()

Constructors

LoginResponse([void updates(LoginResponseBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pOISystemData → POISystemData?
Information related to the POI System. Returned if the response result is Success.
no setter
response → Response
Result of a message request processing.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenRequestStatus → bool?
If token is managed by the POI, the status of the token request.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(LoginResponseBuilder)) → LoginResponse
Rebuilds the instance.
inherited
toBuilder() → LoginResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<LoginResponse>
no setter