LoyaltyResult class abstract

Data related to the result of a processed loyalty transaction. In the Message Response, the result of each loyalty brand transaction.

Properties:

  • loyaltyAccount - Data related to a loyalty account processed in the transaction.
  • currentBalance - Balance of an account. If known (provided by the card or an external host).
  • loyaltyAcquirerData - Data related to the loyalty Acquirer during a loyalty transaction. If content not empty.
Annotations
  • @BuiltValue.new()

Constructors

LoyaltyResult([void updates(LoyaltyResultBuilder b)])
factory

Properties

currentBalance → num?
Balance of an account. If known (provided by the card or an external host).
no setter
hashCode → int
The hash code for this object.
no setterinherited
loyaltyAccount → LoyaltyAccount
Data related to a loyalty account processed in the transaction.
no setter
loyaltyAcquirerData → LoyaltyAcquirerData?
Data related to the loyalty Acquirer during a loyalty transaction. If content not empty.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(LoyaltyResultBuilder)) → LoyaltyResult
Rebuilds the instance.
inherited
toBuilder() → LoyaltyResultBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<LoyaltyResult>
no setter