MenuEntryBuilder class

Constructors

Properties

defaultSelectedFlag ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
outputFormat ↔ OutputFormat?
getter/setter pair
outputText ↔ ListBuilder<OutputText>
getter/setter pair
outputXHTML ↔ String?
getter/setter pair
predefinedContent ↔ PredefinedContentBuilder
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → MenuEntry
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(MenuEntry other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(MenuEntryBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited