MessageReferenceBuilder class

Constructors

MessageReferenceBuilder()

Properties

deviceID ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messageCategory ↔ MessageCategory?
getter/setter pair
POIID ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleID ↔ String?
getter/setter pair
serviceID ↔ String?
getter/setter pair

Methods

build() → MessageReference
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(MessageReference other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(MessageReferenceBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited