MobileData class abstract

Mobile phone is used as a payment instrument for the transaction. Information related to the mobile for the payment transaction.

Properties:

  • mobileCountryCode - Identifies the country of a mobile phone operator. If data available.
  • mobileNetworkCode - Identifies the mobile phone operator inside a country. If data available.
  • maskedMSISDN - Masked Mobile Subscriber Integrated Service Digital Network. If data available.
  • geolocation - Geographic location specified by geographic or UTM coordinates. If data available.
  • protectedMobileData - Sensitive information related to the mobile phone, protected by CMS. SensitiveMobileData.
  • sensitiveMobileData - Sensitive information related to the mobile phone. If unprotected mobile data.
Annotations
  • @BuiltValue.new()

Constructors

MobileData([void updates(MobileDataBuilder b)])
factory

Properties

geolocation → Geolocation?
Geographic location specified by geographic or UTM coordinates. If data available.
no setter
hashCode → int
The hash code for this object.
no setterinherited
maskedMSISDN → int?
Masked Mobile Subscriber Integrated Service Digital Network. If data available.
no setter
mobileCountryCode → int?
Identifies the country of a mobile phone operator. If data available.
no setter
mobileNetworkCode → int?
Identifies the mobile phone operator inside a country. If data available.
no setter
protectedMobileData → String?
Sensitive information related to the mobile phone, protected by CMS. SensitiveMobileData.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensitiveMobileData → SensitiveMobileData?
Sensitive information related to the mobile phone. If unprotected mobile data.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(MobileDataBuilder)) → MobileData
Rebuilds the instance.
inherited
toBuilder() → MobileDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<MobileData>
no setter