MobileDataBuilder class

Constructors

MobileDataBuilder()

Properties

geolocation ↔ GeolocationBuilder
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maskedMSISDN ↔ int?
getter/setter pair
mobileCountryCode ↔ int?
getter/setter pair
mobileNetworkCode ↔ int?
getter/setter pair
protectedMobileData ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensitiveMobileData ↔ SensitiveMobileDataBuilder
getter/setter pair

Methods

build() → MobileData
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(MobileData other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(MobileDataBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited