OriginalPOITransaction class abstract

Identification of a previous POI transaction. In the Payment Request message, it allows using the card of a previous CardAcquisition or Payment request.

Properties:

  • saleID - Identification of a Sale System for the NEXO SaletoPOI protocol.
  • POIID - Identification of a payment terminal for the NEXO SaletoPOI protocol. If original transaction is coming from another POI.
  • pOITransactionID - Unique identification of a POI transaction for a POI. Absent if SaleReferenceID is sufficient to identify the transaction.
  • reuseCardDataFlag - Indicates if the card data has to be retrieved from a previous transaction.
  • approvalCode - Code assigned to a transaction approval by the Acquirer. If referral.
  • acquirerID - Identification of the Acquirer. Restrict to the Acquirer if present.
  • amountValue - Value of an amount.
  • hostTransactionID - Identification of the transaction by the host in charge of the stored value transaction. If POITransactionID not present.
Annotations
  • @BuiltValue.new()

Constructors

OriginalPOITransaction([void updates(OriginalPOITransactionBuilder b)])
factory

Properties

acquirerID → int?
Identification of the Acquirer. Restrict to the Acquirer if present.
no setter
amountValue → num?
Value of an amount.
no setter
approvalCode → String?
Code assigned to a transaction approval by the Acquirer. If referral.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hostTransactionID → TransactionIDType?
Identification of the transaction by the host in charge of the stored value transaction. If POITransactionID not present.
no setter
POIID → String?
Identification of a payment terminal for the NEXO SaletoPOI protocol. If original transaction is coming from another POI.
no setter
pOITransactionID → TransactionIDType?
Unique identification of a POI transaction for a POI. Absent if SaleReferenceID is sufficient to identify the transaction.
no setter
reuseCardDataFlag → bool?
Indicates if the card data has to be retrieved from a previous transaction.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleID → String?
Identification of a Sale System for the NEXO SaletoPOI protocol.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(OriginalPOITransactionBuilder)) → OriginalPOITransaction
Rebuilds the instance.
inherited
toBuilder() → OriginalPOITransactionBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<OriginalPOITransaction>
no setter