OriginalPOITransactionBuilder class

Properties

acquirerID int?
getter/setter pair
amountValue num?
getter/setter pair
approvalCode String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hostTransactionID TransactionIDTypeBuilder
getter/setter pair
POIID String?
getter/setter pair
pOITransactionID TransactionIDTypeBuilder
getter/setter pair
reuseCardDataFlag bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saleID String?
getter/setter pair

Methods

build() OriginalPOITransaction
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(OriginalPOITransaction other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(OriginalPOITransactionBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited