OutputBarcode class abstract

OutputBarcode

Properties:

  • barcodeValue - Value with a Barcode coding. The barcode value to display or print.
Annotations
  • @BuiltValue.new()

Constructors

OutputBarcode([void updates(OutputBarcodeBuilder b)])
factory

Properties

barcodeValue → String
Value with a Barcode coding. The barcode value to display or print.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(OutputBarcodeBuilder)) → OutputBarcode
Rebuilds the instance.
inherited
toBuilder() → OutputBarcodeBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<OutputBarcode>
no setter