OutputContent class abstract

Content to display or print. This is a sequence of elements if they have different formats.

Properties:

  • outputFormat - Format of the content to display or print. Possible values: * BarCode * MessageRef * Text * XHTML
  • predefinedContent - Reference of a predefined message to display or print. Mandatory, if OutputFormat is MessageRef, not allowed otherwise.
  • outputText - Content of text message to display or print. Mandatory, if OutputFormat is Text, not allowed otherwise. One instance of OutputText per shared format.
  • outputXHTML - XHTML document body containing the message to display or print. Mandatory if OutputFormat is XHTML, not allowed otherwise.
  • outputBarcode - Barcode content to display or print. Mandatory if OutputFormat is Barcode, not allowed otherwise.
Annotations
  • @BuiltValue.new()

Constructors

OutputContent([void updates(OutputContentBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
outputBarcode → OutputBarcode?
Barcode content to display or print. Mandatory if OutputFormat is Barcode, not allowed otherwise.
no setter
outputFormat → OutputFormat
Format of the content to display or print. Possible values: * BarCode * MessageRef * Text * XHTML
no setter
outputText → BuiltList<OutputText>?
Content of text message to display or print. Mandatory, if OutputFormat is Text, not allowed otherwise. One instance of OutputText per shared format.
no setter
outputXHTML → String?
XHTML document body containing the message to display or print. Mandatory if OutputFormat is XHTML, not allowed otherwise.
no setter
predefinedContent → PredefinedContent?
Reference of a predefined message to display or print. Mandatory, if OutputFormat is MessageRef, not allowed otherwise.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(OutputContentBuilder)) → OutputContent
Rebuilds the instance.
inherited
toBuilder() → OutputContentBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<OutputContent>
no setter