OutputTextBuilder class

Constructors

OutputTextBuilder()

Properties

alignment ↔ Alignment?
getter/setter pair
characterHeight ↔ CharacterHeight?
getter/setter pair
characterSet ↔ int?
getter/setter pair
characterStyle ↔ CharacterStyle?
getter/setter pair
characterWidth ↔ CharacterWidth?
getter/setter pair
endOfLineFlag ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startColumn ↔ int?
getter/setter pair
startRow ↔ int?
getter/setter pair
text ↔ String?
getter/setter pair

Methods

build() → OutputText
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(OutputText other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(OutputTextBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited