POIData class abstract

Data related to the POI System. In the Message Response, identification of the POI transaction.

Properties:

  • pOITransactionID - Unique identification of a POI transaction for a POI.
  • pOIReconciliationID - Identification of the reconciliation period between Sale and POI. If Result is Success.
Annotations
  • @BuiltValue.new()

Constructors

POIData([void updates(POIDataBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pOIReconciliationID → int?
Identification of the reconciliation period between Sale and POI. If Result is Success.
no setter
pOITransactionID → TransactionIDType
Unique identification of a POI transaction for a POI.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(POIDataBuilder)) → POIData
Rebuilds the instance.
inherited
toBuilder() → POIDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<POIData>
no setter