POIStatus class abstract

Indicate the availability of the POI Terminal components. The data element is absent if the component is not part of the POI Terminal. State of a POI Terminal.

Properties:

  • globalStatus - Global status of a POI Server or POI Terminal. Possible values: * Busy * Maintenance * OK * Unreachable
  • securityOKFlag - Indicates if the security module of the POI is working and usable. If security module present.
  • pEDOKFlag - Indicates if the PED is working and usable. If PED present.
  • cardReaderOKFlag - Indicates if the card readers are working and usable. If card reader device present.
  • printerStatus - Possible values: * NoPaper * OK * OutOfOrder * PaperJam * PaperLow
  • communicationOKFlag - Indicates if the communication infrastructure is working and usable. If communication infrastructure present.
  • fraudPreventionFlag - Indicates a suspicion of fraud by the POI System. Could be set to True by the POI system to notify to the Sale system and the Cashier that a suspicion of fraud had been detected on the POI as an unexpected reboot of the POI.
Annotations
  • @BuiltValue.new()

Constructors

POIStatus([void updates(POIStatusBuilder b)])
factory

Properties

cardReaderOKFlag → bool?
Indicates if the card readers are working and usable. If card reader device present.
no setter
communicationOKFlag → bool?
Indicates if the communication infrastructure is working and usable. If communication infrastructure present.
no setter
fraudPreventionFlag → bool?
Indicates a suspicion of fraud by the POI System. Could be set to True by the POI system to notify to the Sale system and the Cashier that a suspicion of fraud had been detected on the POI as an unexpected reboot of the POI.
no setter
globalStatus → GlobalStatus
Global status of a POI Server or POI Terminal. Possible values: * Busy * Maintenance * OK * Unreachable
no setter
hashCode → int
The hash code for this object.
no setterinherited
pEDOKFlag → bool?
Indicates if the PED is working and usable. If PED present.
no setter
printerStatus → PrinterStatus?
Possible values: * NoPaper * OK * OutOfOrder * PaperJam * PaperLow
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityOKFlag → bool?
Indicates if the security module of the POI is working and usable. If security module present.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(POIStatusBuilder)) → POIStatus
Rebuilds the instance.
inherited
toBuilder() → POIStatusBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<POIStatus>
no setter