POISystemData class abstract

POISystemData

Properties:

Annotations
  • @BuiltValue.new()

Constructors

POISystemData([void updates(POISystemDataBuilder b)])
factory

Properties

dateTime → DateTime
Date and Time. In the response, the POI System gives its date and time to the Sale System.
no setter
hashCode → int
The hash code for this object.
no setterinherited
pOISoftware → POISoftware
no setter
pOIStatus → POIStatus?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(POISystemDataBuilder)) → POISystemData
Rebuilds the instance.
inherited
toBuilder() → POISystemDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<POISystemData>
no setter