PaymentAccountStatus class abstract

PaymentAccountStatus

Properties:

Annotations
  • @BuiltValue.new()

Constructors

PaymentAccountStatus([void updates(PaymentAccountStatusBuilder b)])
factory

Properties

currency → String?
Currency of a monetary amount.
no setter
currentBalance → num?
Balance of an account after processing of the transaction.
no setter
hashCode → int
The hash code for this object.
no setterinherited
paymentAcquirerData → PaymentAcquirerData?
no setter
paymentInstrumentData → PaymentInstrumentData?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaymentAccountStatusBuilder)) → PaymentAccountStatus
Rebuilds the instance.
inherited
toBuilder() → PaymentAccountStatusBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentAccountStatus>
no setter