PaymentAcquirerData class abstract

Data related to the response from the payment Acquirer.

Properties:

  • acquirerID - Identification of the Acquirer. Identification of the Acquirer when the POI System is multi-acquirer.
  • merchantID - Identification of the Merchant for the Acquirer.
  • acquirerPOIID - Identification of the POI for the payment Acquirer.
  • acquirerTransactionID - Identification of the Transaction for the Acquirer. If provided by the Acquirer.
  • approvalCode - Code assigned to a transaction approval by the Acquirer. If available.
  • hostReconciliationID - Identifier of a reconciliation period with a payment or loyalty host. Allows the assignment of a transaction to the Acquirer reconciliation (or batch).
Annotations
  • @BuiltValue.new()

Constructors

PaymentAcquirerData([void updates(PaymentAcquirerDataBuilder b)])
factory

Properties

acquirerID → int?
Identification of the Acquirer. Identification of the Acquirer when the POI System is multi-acquirer.
no setter
acquirerPOIID → String
Identification of the POI for the payment Acquirer.
no setter
acquirerTransactionID → TransactionIDType?
Identification of the Transaction for the Acquirer. If provided by the Acquirer.
no setter
approvalCode → String?
Code assigned to a transaction approval by the Acquirer. If available.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hostReconciliationID → String?
Identifier of a reconciliation period with a payment or loyalty host. Allows the assignment of a transaction to the Acquirer reconciliation (or batch).
no setter
merchantID → String
Identification of the Merchant for the Acquirer.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaymentAcquirerDataBuilder)) → PaymentAcquirerData
Rebuilds the instance.
inherited
toBuilder() → PaymentAcquirerDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentAcquirerData>
no setter