PaymentData class abstract

PaymentData

Properties:

  • paymentType - Type of payment transaction. Elements requested by the Sale System that are related to the payment only. Possible values: * CashAdvance * CashDeposit * Completion * FirstReservation * Instalment * IssuerInstalment * Normal * OneTimeReservation * PaidOut * Recurring * Refund * UpdateReservation
  • splitPaymentFlag - Indicates if the payment of the Sale transaction is split. Allows the POI to decline payment means that cannot accept split payment.
  • requestedValidityDate - Requested validity date for the reservation. Allows a specific period for the reservation according to the need of the Merchant for the first reservation and the reservation updates as well.
  • cardAcquisitionReference
  • instalment - Information related an instalment transaction. To request an instalment to the issuer, or to make individual instalments of a payment transaction.
  • paymentInstrumentData
Annotations
  • @BuiltValue.new()

Constructors

PaymentData([void updates(PaymentDataBuilder b)])
factory

Properties

cardAcquisitionReference → TransactionIDType?
no setter
hashCode → int
The hash code for this object.
no setterinherited
instalment → Instalment?
Information related an instalment transaction. To request an instalment to the issuer, or to make individual instalments of a payment transaction.
no setter
paymentInstrumentData → PaymentInstrumentData?
no setter
paymentType → PaymentType?
Type of payment transaction. Elements requested by the Sale System that are related to the payment only. Possible values: * CashAdvance * CashDeposit * Completion * FirstReservation * Instalment * IssuerInstalment * Normal * OneTimeReservation * PaidOut * Recurring * Refund * UpdateReservation
no setter
requestedValidityDate → Date?
Requested validity date for the reservation. Allows a specific period for the reservation according to the need of the Merchant for the first reservation and the reservation updates as well.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splitPaymentFlag → bool?
Indicates if the payment of the Sale transaction is split. Allows the POI to decline payment means that cannot accept split payment.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaymentDataBuilder)) → PaymentData
Rebuilds the instance.
inherited
toBuilder() → PaymentDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentData>
no setter