PaymentDataBuilder class

Constructors

PaymentDataBuilder()

Properties

cardAcquisitionReference ↔ TransactionIDTypeBuilder
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instalment ↔ InstalmentBuilder
getter/setter pair
paymentInstrumentData ↔ PaymentInstrumentDataBuilder
getter/setter pair
paymentType ↔ PaymentType?
getter/setter pair
requestedValidityDate ↔ Date?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splitPaymentFlag ↔ bool?
getter/setter pair

Methods

build() → PaymentData
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(PaymentData other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(PaymentDataBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited