PaymentInstrumentData class abstract

Data related to the instrument of payment for the transaction. Sent in the result of the payment transaction. For a card, it could also be sent in the CardAcquisition response, to be processed by the Sale System.

Properties:

  • paymentInstrumentType - Type of payment instrument. Possible values: * Card * Cash * Check * Mobile * StoredValue
  • protectedCardData - Sensitive information related to the payment card, protected by CMS. SensitiveCardData protected by CMS EnvelopedData.
  • cardData - Information related to the payment card used for the transaction. If PaymentInstrumentType is Card.
  • checkData - Information related to the paper check used for the transaction. If PaymentInstrumentType is Check.
  • mobileData - Information related to the mobile for the payment transaction. If PaymentInstrumentType is Mobile.
  • storedValueAccountID
Annotations
  • @BuiltValue.new()

Constructors

PaymentInstrumentData([void updates(PaymentInstrumentDataBuilder b)])
factory

Properties

cardData → CardData?
Information related to the payment card used for the transaction. If PaymentInstrumentType is Card.
no setter
checkData → CheckData?
Information related to the paper check used for the transaction. If PaymentInstrumentType is Check.
no setter
hashCode → int
The hash code for this object.
no setterinherited
mobileData → MobileData?
Information related to the mobile for the payment transaction. If PaymentInstrumentType is Mobile.
no setter
paymentInstrumentType → PaymentInstrumentType
Type of payment instrument. Possible values: * Card * Cash * Check * Mobile * StoredValue
no setter
protectedCardData → String?
Sensitive information related to the payment card, protected by CMS. SensitiveCardData protected by CMS EnvelopedData.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storedValueAccountID → StoredValueAccountID?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaymentInstrumentDataBuilder)) → PaymentInstrumentData
Rebuilds the instance.
inherited
toBuilder() → PaymentInstrumentDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentInstrumentData>
no setter