PaymentRequest class abstract

Request sent to terminal to initiate payment. It conveys Information related to the Payment transaction to process. Content of the PaymentRequest message.

Properties:

  • saleData - Data related to the Sale System.
  • paymentTransaction - Data related to the payment and loyalty transaction.
  • paymentData - Data related to the payment transaction. If one data element is present.
  • loyaltyData - Data related to a Loyalty program or account. Loyalty cards used with the payment transaction and read by the Sale System.
Annotations
  • @BuiltValue.new()

Constructors

PaymentRequest([void updates(PaymentRequestBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
loyaltyData → BuiltList<LoyaltyData>?
Data related to a Loyalty program or account. Loyalty cards used with the payment transaction and read by the Sale System.
no setter
paymentData → PaymentData?
Data related to the payment transaction. If one data element is present.
no setter
paymentTransaction → PaymentTransaction
Data related to the payment and loyalty transaction.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleData → SaleData
Data related to the Sale System.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaymentRequestBuilder)) → PaymentRequest
Rebuilds the instance.
inherited
toBuilder() → PaymentRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentRequest>
no setter