loyaltyResult property
Data related to the result of a processed loyalty transaction. Loyalty cards used with the payment transaction.
Implementation
@BuiltValueField(wireName: r'LoyaltyResult')
BuiltList<LoyaltyResult>? get loyaltyResult;
Data related to the result of a processed loyalty transaction. Loyalty cards used with the payment transaction.
@BuiltValueField(wireName: r'LoyaltyResult')
BuiltList<LoyaltyResult>? get loyaltyResult;