PaymentTotals class abstract

Totals of the payment transaction during the reconciliation period.

Properties:

  • transactionType - Type of transaction for which totals are grouped. Debit, Credit, ReverseDebit, ReverseCredit, OneTimeReservation, CompletedDeffered, FirstReservation, UpdateReservation, CompletedReservation, CashAdvance. Possible values: * Award * CashAdvance * CompletedDeffered * CompletedReservation * Credit * Debit * Declined * Failed * FirstReservation * IssuerInstalment * OneTimeReservation * Rebate * Redemption * ReverseAward * ReverseCredit * ReverseDebit * ReverseRebate * ReverseRedemption * UpdateReservation
  • transactionCount - Number of processed transaction during the period.
  • transactionAmount - Sum of amount of processed transaction during the period.
Annotations
  • @BuiltValue.new()

Constructors

PaymentTotals([void updates(PaymentTotalsBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionAmount num
Sum of amount of processed transaction during the period.
no setter
transactionCount int
Number of processed transaction during the period.
no setter
transactionType TransactionType
Type of transaction for which totals are grouped. Debit, Credit, ReverseDebit, ReverseCredit, OneTimeReservation, CompletedDeffered, FirstReservation, UpdateReservation, CompletedReservation, CashAdvance. Possible values: * Award * CashAdvance * CompletedDeffered * CompletedReservation * Credit * Debit * Declined * Failed * FirstReservation * IssuerInstalment * OneTimeReservation * Rebate * Redemption * ReverseAward * ReverseCredit * ReverseDebit * ReverseRebate * ReverseRedemption * UpdateReservation
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaymentTotalsBuilder)) PaymentTotals
Rebuilds the instance.
inherited
toBuilder() PaymentTotalsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentTotals>
no setter