transactionAmount property
Sum of amount of processed transaction during the period.
Implementation
@BuiltValueField(wireName: r'TransactionAmount')
num get transactionAmount;
Sum of amount of processed transaction during the period.
@BuiltValueField(wireName: r'TransactionAmount')
num get transactionAmount;