PaymentTransaction class abstract

PaymentTransaction

Properties:

Annotations
  • @BuiltValue.new()

Constructors

PaymentTransaction([void updates(PaymentTransactionBuilder b)])
factory

Properties

amountsReq → AmountsReq
Various amounts related to the payment request from the Sale System.
no setter
hashCode → int
The hash code for this object.
no setterinherited
originalPOITransaction → OriginalPOITransaction?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionConditions → TransactionConditions?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaymentTransactionBuilder)) → PaymentTransaction
Rebuilds the instance.
inherited
toBuilder() → PaymentTransactionBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentTransaction>
no setter