PerformedTransaction class abstract

Annotations
  • @BuiltValue.new()

Constructors

PerformedTransaction([void updates(PerformedTransactionBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
loyaltyResult → BuiltList<LoyaltyResult>?
no setter
paymentResult → PaymentResult?
no setter
pOIData → POIData?
no setter
response → Response
no setter
reversedAmount → num?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleData → SaleData?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PerformedTransactionBuilder)) → PerformedTransaction
Rebuilds the instance.
inherited
toBuilder() → PerformedTransactionBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PerformedTransaction>
no setter