Point class abstract

Point

Properties:

  • X - The hexadecimal value of the coordinates of a point on the abscissa.
  • Y - The hexadecimal value of the coordinates of a point on the ordinate.
Annotations
  • @BuiltValue.new()

Constructors

Point([void updates(PointBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
X → String
The hexadecimal value of the coordinates of a point on the abscissa.
no setter
Y → String
The hexadecimal value of the coordinates of a point on the ordinate.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PointBuilder)) → Point
Rebuilds the instance.
inherited
toBuilder() → PointBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Point>
no setter