ReconciliationRequest class abstract

Content of the Reconciliation Request message. It conveys Information related to the Reconciliation requested by the Sale System.

Properties:

  • reconciliationType - Type of Reconciliation requested by the Sale to the POI. Possible values: * AcquirerReconciliation * AcquirerSynchronisation * PreviousReconciliation * SaleReconciliation
  • acquirerID - Identification of the Acquirer. Could be present only if ReconciliationType is AcquirerReconciliation or AcquirerSynchronisation.
  • pOIReconciliationID - Identification of the reconciliation period between Sale and POI. Absent if ReconciliationType is not PreviousReconciliation.
Annotations
  • @BuiltValue.new()

Constructors

ReconciliationRequest([void updates(ReconciliationRequestBuilder b)])
factory

Properties

acquirerID → BuiltList<int>?
Identification of the Acquirer. Could be present only if ReconciliationType is AcquirerReconciliation or AcquirerSynchronisation.
no setter
hashCode → int
The hash code for this object.
no setterinherited
pOIReconciliationID → int?
Identification of the reconciliation period between Sale and POI. Absent if ReconciliationType is not PreviousReconciliation.
no setter
reconciliationType → ReconciliationType
Type of Reconciliation requested by the Sale to the POI. Possible values: * AcquirerReconciliation * AcquirerSynchronisation * PreviousReconciliation * SaleReconciliation
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReconciliationRequestBuilder)) → ReconciliationRequest
Rebuilds the instance.
inherited
toBuilder() → ReconciliationRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReconciliationRequest>
no setter