ReconciliationResponse class abstract

It conveys Information related to the Reconciliation transaction processed by the POI System. Content of the Reconciliation Response message.

Properties:

  • response - Result of a message request processing.
  • reconciliationType - Type of Reconciliation requested by the Sale to the POI. Possible values: * AcquirerReconciliation * AcquirerSynchronisation * PreviousReconciliation * SaleReconciliation
  • pOIReconciliationID - Identification of the reconciliation period between Sale and POI. Absent if ReconciliationType is AcquirerReconciliation.
  • transactionTotals - Result of the Sale to POI Reconciliation processing. If Response.Result is Success.
Annotations
  • @BuiltValue.new()

Constructors

ReconciliationResponse([void updates(ReconciliationResponseBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pOIReconciliationID → int?
Identification of the reconciliation period between Sale and POI. Absent if ReconciliationType is AcquirerReconciliation.
no setter
reconciliationType → ReconciliationType
Type of Reconciliation requested by the Sale to the POI. Possible values: * AcquirerReconciliation * AcquirerSynchronisation * PreviousReconciliation * SaleReconciliation
no setter
response → Response
Result of a message request processing.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionTotals → BuiltList<TransactionTotals>?
Result of the Sale to POI Reconciliation processing. If Response.Result is Success.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReconciliationResponseBuilder)) → ReconciliationResponse
Rebuilds the instance.
inherited
toBuilder() → ReconciliationResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReconciliationResponse>
no setter