RepeatedMessageResponse class abstract

RepeatedMessageResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

RepeatedMessageResponse([void updates(RepeatedMessageResponseBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageHeader → MessageHeader
no setter
repeatedResponseMessageBody → RepeatedResponseMessageBody
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RepeatedMessageResponseBuilder)) → RepeatedMessageResponse
Rebuilds the instance.
inherited
toBuilder() → RepeatedMessageResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RepeatedMessageResponse>
no setter