RepeatedResponseMessageBody class abstract

Annotations
  • @BuiltValue.new()

Constructors

RepeatedResponseMessageBody([void updates(RepeatedResponseMessageBodyBuilder b)])
factory

Properties

cardAcquisitionResponse → CardAcquisitionResponse?
no setter
cardReaderAPDUResponse → CardReaderAPDUResponse?
no setter
hashCode → int
The hash code for this object.
no setterinherited
loyaltyResponse → LoyaltyResponse?
no setter
paymentResponse → PaymentResponse?
no setter
reversalResponse → ReversalResponse?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storedValueResponse → StoredValueResponse?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RepeatedResponseMessageBodyBuilder)) → RepeatedResponseMessageBody
Rebuilds the instance.
inherited
toBuilder() → RepeatedResponseMessageBodyBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RepeatedResponseMessageBody>
no setter