ReversalReason class

Inheritance
  • Object
  • EnumClass
  • ReversalReason

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReversalReason>
no setter
values → BuiltSet<ReversalReason>
no setter

Static Methods

valueOf(String name) → ReversalReason

Constants

custCancel → const ReversalReason
Reason of the payment or loyalty reversal. Possible values: * CustCancel * Malfunction * MerchantCancel * Unable2Compl
malfunction → const ReversalReason
Reason of the payment or loyalty reversal. Possible values: * CustCancel * Malfunction * MerchantCancel * Unable2Compl
merchantCancel → const ReversalReason
Reason of the payment or loyalty reversal. Possible values: * CustCancel * Malfunction * MerchantCancel * Unable2Compl
unable2Compl → const ReversalReason
Reason of the payment or loyalty reversal. Possible values: * CustCancel * Malfunction * MerchantCancel * Unable2Compl
unknownDefaultOpenApi → const ReversalReason
Reason of the payment or loyalty reversal. Possible values: * CustCancel * Malfunction * MerchantCancel * Unable2Compl