ReversalRequest class abstract

It conveys Information related to the reversal of a previous payment or a loyalty transaction. Content of the Reversal Request message.

Properties:

  • saleData
  • originalPOITransaction - Identification of a previous POI transaction.
  • reversedAmount - Amount of the payment or loyalty to reverse. ReversedAmount is implicitly equal to the AuthorizedAmount if absent.
  • reversalReason - Reason of the payment or loyalty reversal. Possible values: * CustCancel * Malfunction * MerchantCancel * Unable2Compl
Annotations
  • @BuiltValue.new()

Constructors

ReversalRequest([void updates(ReversalRequestBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
originalPOITransaction → OriginalPOITransaction
Identification of a previous POI transaction.
no setter
reversalReason → ReversalReason
Reason of the payment or loyalty reversal. Possible values: * CustCancel * Malfunction * MerchantCancel * Unable2Compl
no setter
reversedAmount → num?
Amount of the payment or loyalty to reverse. ReversedAmount is implicitly equal to the AuthorizedAmount if absent.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleData → SaleData?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReversalRequestBuilder)) → ReversalRequest
Rebuilds the instance.
inherited
toBuilder() → ReversalRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReversalRequest>
no setter