SaleData class abstract

Data associated with the Sale System, with a particular value during the processing of the payment by the POI, including the cards acquisition.

Properties:

  • operatorID - Identification of the Cashier or Operator.
  • operatorLanguage - Language of the Cashier or Operator. If different from the Login.
  • shiftNumber - Shift number. If different from the Login, see Login SaleData.
  • saleTransactionID - Identification of a Sale transaction.
  • saleReferenceID - Identification of a Sale global transaction for a sequence of related POI transactions. If payment reservation.
  • saleTerminalData - Information related to the software and hardware features of the Sale Terminal. If content is not empty.
  • tokenRequestedType - Type of token replacing the PAN of a payment card to identify the payment mean of the customer. It allows, for a merchant, to use a token for a transaction only or for a longer period. Possible values: * Customer * Transaction
  • customerOrderID - Additional and optional identification of a customer order.
  • customerOrderReq - List of customer order open, closed or both to be sent in the response messages. Possible values: * Both * Closed * Open
  • saleToPOIData - Sale information intended for the POI. Stored with the transaction.
  • saleToAcquirerData - Sale information intended for the Acquirer. Send to the Acquirer if present.
  • saleToIssuerData - Sale information intended for the Issuer. Send to the Acquirer if present.
Annotations
  • @BuiltValue.new()

Constructors

SaleData([void updates(SaleDataBuilder b)])
factory

Properties

customerOrderID → String?
Additional and optional identification of a customer order.
no setter
customerOrderReq → BuiltList<SaleDataCustomerOrderReqEnum>?
List of customer order open, closed or both to be sent in the response messages. Possible values: * Both * Closed * Open
no setter
hashCode → int
The hash code for this object.
no setterinherited
operatorID → String?
Identification of the Cashier or Operator.
no setter
operatorLanguage → String?
Language of the Cashier or Operator. If different from the Login.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleReferenceID → String?
Identification of a Sale global transaction for a sequence of related POI transactions. If payment reservation.
no setter
saleTerminalData → SaleTerminalData?
Information related to the software and hardware features of the Sale Terminal. If content is not empty.
no setter
saleToAcquirerData → String?
Sale information intended for the Acquirer. Send to the Acquirer if present.
no setter
saleToIssuerData → SaleToIssuerData?
Sale information intended for the Issuer. Send to the Acquirer if present.
no setter
saleToPOIData → String?
Sale information intended for the POI. Stored with the transaction.
no setter
saleTransactionID → TransactionIDType
Identification of a Sale transaction.
no setter
shiftNumber → String?
Shift number. If different from the Login, see Login SaleData.
no setter
tokenRequestedType → TokenRequestedType?
Type of token replacing the PAN of a payment card to identify the payment mean of the customer. It allows, for a merchant, to use a token for a transaction only or for a longer period. Possible values: * Customer * Transaction
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SaleDataBuilder)) → SaleData
Rebuilds the instance.
inherited
toBuilder() → SaleDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SaleData>
no setter