SaleSoftware class abstract

Information related to the software of the Sale System which manages the NEXO Sale to POI protocol.

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SaleSoftware([void updates(SaleSoftwareBuilder b)])
factory

Properties

applicationName → String
Name of the software product.
no setter
certificationCode → String
Certification code of the software which manages the Sale to POI protocol.
no setter
hashCode → int
The hash code for this object.
no setterinherited
manufacturerID → String
Identification of the Manufacturer.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softwareVersion → String
Version of the software product.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SaleSoftwareBuilder)) → SaleSoftware
Rebuilds the instance.
inherited
toBuilder() → SaleSoftwareBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SaleSoftware>
no setter