SaleToIssuerData class abstract

Sale information intended for the Issuer. The POI System receives this information and sends it to the Acquirer for the Issuer without any change.

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SaleToIssuerData([void updates(SaleToIssuerDataBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statementReference → String?
Label to print on the bank statement.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SaleToIssuerDataBuilder)) → SaleToIssuerData
Rebuilds the instance.
inherited
toBuilder() → SaleToIssuerDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SaleToIssuerData>
no setter