SecurityTrailer class abstract

It contains information related to the security of the message. SecurityTrailer as used by Adyen.

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SecurityTrailer([void updates(SecurityTrailerBuilder b)])
factory

Properties

adyenCryptoVersion → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
hmac → String
no setter
keyIdentifier → String
no setter
keyVersion → int
no setter
nonce → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SecurityTrailerBuilder)) → SecurityTrailer
Rebuilds the instance.
inherited
toBuilder() → SecurityTrailerBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SecurityTrailer>
no setter