SecurityTrailerBuilder class

Constructors

SecurityTrailerBuilder()

Properties

adyenCryptoVersion ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hmac ↔ String?
getter/setter pair
keyIdentifier ↔ String?
getter/setter pair
keyVersion ↔ int?
getter/setter pair
nonce ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → SecurityTrailer
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(SecurityTrailer other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(SecurityTrailerBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited