SensitiveCardDataBuilder class

Constructors

SensitiveCardDataBuilder()

Properties

cardSeqNumb ↔ int?
getter/setter pair
expiryDate ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
PAN ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackData ↔ ListBuilder<TrackData>
getter/setter pair

Methods

build() → SensitiveCardData
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(SensitiveCardData other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(SensitiveCardDataBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited