SoundContent class abstract

SoundContent

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SoundContent([void updates(SoundContentBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
language → String?
no setter
referenceID → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
soundFormat → SoundFormat
Possible values: * MessageRef * SoundRef * Text
no setter
text → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SoundContentBuilder)) → SoundContent
Rebuilds the instance.
inherited
toBuilder() → SoundContentBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SoundContent>
no setter