StoredValueAccountIDBuilder class

Properties

entryMode ↔ ListBuilder<StoredValueAccountIDEntryModeEnum>
getter/setter pair
expiryDate ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identificationType ↔ IdentificationType?
getter/setter pair
ownerName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storedValueAccountType ↔ StoredValueAccountType?
getter/setter pair
storedValueID ↔ String?
getter/setter pair
storedValueProvider ↔ String?
getter/setter pair

Methods

build() → StoredValueAccountID
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(StoredValueAccountID other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(StoredValueAccountIDBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited