StoredValueDataBuilder class

Constructors

StoredValueDataBuilder()

Properties

currency ↔ String?
getter/setter pair
eanUpc ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemAmount ↔ num?
getter/setter pair
originalPOITransaction ↔ OriginalPOITransactionBuilder
getter/setter pair
productCode ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storedValueAccountID ↔ StoredValueAccountIDBuilder
getter/setter pair
storedValueProvider ↔ String?
getter/setter pair
storedValueTransactionType ↔ StoredValueTransactionType?
getter/setter pair

Methods

build() → StoredValueData
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(StoredValueData other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(StoredValueDataBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited