StoredValueRequestBuilder class

Constructors

StoredValueRequestBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleData ↔ SaleDataBuilder
getter/setter pair
storedValueData ↔ ListBuilder<StoredValueData>
getter/setter pair

Methods

build() → StoredValueRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(StoredValueRequest other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(StoredValueRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited