StoredValueResult class abstract

For each stored value card loaded or reloaded, in the StoredValue response message. Result of loading/reloading a stored value card.

Properties:

  • storedValueTransactionType - Identification of operation to proceed on the stored value account or the stored value card. Copy. Possible values: * Activate * Duplicate * Load * Reserve * Reverse * Unload
  • productCode - Product code of item purchased with the transaction. Copy.
  • eanUpc - Standard product code of item purchased with the transaction. Copy.
  • itemAmount - Total amount of the item line.
  • currency - Currency of a monetary amount. Copy.
  • storedValueAccountStatus - Data related to the result of the stored value card transaction.
  • hostTransactionID - Identification of the transaction by the host in charge of the stored value transaction. If provided by the Host.
Annotations
  • @BuiltValue.new()

Constructors

StoredValueResult([void updates(StoredValueResultBuilder b)])
factory

Properties

currency → String?
Currency of a monetary amount. Copy.
no setter
eanUpc → int?
Standard product code of item purchased with the transaction. Copy.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hostTransactionID → TransactionIDType?
Identification of the transaction by the host in charge of the stored value transaction. If provided by the Host.
no setter
itemAmount → num?
Total amount of the item line.
no setter
productCode → int?
Product code of item purchased with the transaction. Copy.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storedValueAccountStatus → StoredValueAccountStatus?
Data related to the result of the stored value card transaction.
no setter
storedValueTransactionType → StoredValueTransactionType
Identification of operation to proceed on the stored value account or the stored value card. Copy. Possible values: * Activate * Duplicate * Load * Reserve * Reverse * Unload
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(StoredValueResultBuilder)) → StoredValueResult
Rebuilds the instance.
inherited
toBuilder() → StoredValueResultBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<StoredValueResult>
no setter