TotalFilter class abstract

TotalFilter

Properties:

  • POIID - Identification of a POI System or a POI Terminal for the Sale to POI protocol.
  • saleID - Identification of a Sale System or a Sale Terminal for the Sale to POI protocol.
  • operatorID - Identification of the Cashier or Operator.
  • shiftNumber - Shift number.
  • totalsGroupID - Sent if totals in the response have to be computed only for this particular value of TotalsGroupID.
Annotations
  • @BuiltValue.new()

Constructors

TotalFilter([void updates(TotalFilterBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
operatorID → String?
Identification of the Cashier or Operator.
no setter
POIID → String?
Identification of a POI System or a POI Terminal for the Sale to POI protocol.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleID → String?
Identification of a Sale System or a Sale Terminal for the Sale to POI protocol.
no setter
shiftNumber → String?
Shift number.
no setter
totalsGroupID → String?
Sent if totals in the response have to be computed only for this particular value of TotalsGroupID.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TotalFilterBuilder)) → TotalFilter
Rebuilds the instance.
inherited
toBuilder() → TotalFilterBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TotalFilter>
no setter