TransactionConditions class abstract

Conditions on which the transaction must be processed.

Properties:

  • allowedPaymentBrand - Payment brands accepted for this transaction. Card payment brands allowed by the Sale System for the payment transaction. Restrict brand if data sent.
  • acquirerID - Identification of the Acquirer. Restrict to these Acquirer if present.
  • debitPreferredFlag - The preferred type of payment is a debit transaction rather than a credit transaction.
  • allowedLoyaltyBrand - Loyalty brands or programs allowed by the Sale System for the loyalty transaction. Restrict brand if data sent.
  • loyaltyHandling - Type of Loyalty processing requested by the Sale System. Possible values: * Allowed * Forbidden * Processed * Proposed * Required
  • customerLanguage - The language used on the terminal screen or in text printed by the terminal. Typical use case is setting the language on unattended terminals. Format: two-character ISO 639:2023 format.
  • forceOnlineFlag - Indicates if the Cashier requires POI forces online access to the Acquirer. Go online if data sent.
  • forceEntryMode - Payment instrument entry mode requested by the Sale System. Restrict entry mode if sent. Possible values: * CheckReader * Contactless * File * ICC * Keyed * MagStripe * Manual * RFID * Scanned * SynchronousICC * Tapped
  • merchantCategoryCode - The code which identifies the category of the transaction (MCC). The payment implies a specific MCC.
Annotations
  • @BuiltValue.new()

Constructors

TransactionConditions([void updates(TransactionConditionsBuilder b)])
factory

Properties

acquirerID → BuiltList<int>?
Identification of the Acquirer. Restrict to these Acquirer if present.
no setter
allowedLoyaltyBrand → BuiltList<String>?
Loyalty brands or programs allowed by the Sale System for the loyalty transaction. Restrict brand if data sent.
no setter
allowedPaymentBrand → BuiltList<String>?
Payment brands accepted for this transaction. Card payment brands allowed by the Sale System for the payment transaction. Restrict brand if data sent.
no setter
customerLanguage → String?
The language used on the terminal screen or in text printed by the terminal. Typical use case is setting the language on unattended terminals. Format: two-character ISO 639:2023 format.
no setter
debitPreferredFlag → bool?
The preferred type of payment is a debit transaction rather than a credit transaction.
no setter
forceEntryMode → BuiltList<TransactionConditionsForceEntryModeEnum>?
Payment instrument entry mode requested by the Sale System. Restrict entry mode if sent. Possible values: * CheckReader * Contactless * File * ICC * Keyed * MagStripe * Manual * RFID * Scanned * SynchronousICC * Tapped
no setter
forceOnlineFlag → bool?
Indicates if the Cashier requires POI forces online access to the Acquirer. Go online if data sent.
no setter
hashCode → int
The hash code for this object.
no setterinherited
loyaltyHandling → LoyaltyHandling?
Type of Loyalty processing requested by the Sale System. Possible values: * Allowed * Forbidden * Processed * Proposed * Required
no setter
merchantCategoryCode → String?
The code which identifies the category of the transaction (MCC). The payment implies a specific MCC.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TransactionConditionsBuilder)) → TransactionConditions
Rebuilds the instance.
inherited
toBuilder() → TransactionConditionsBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TransactionConditions>
no setter