TransactionStatusRequestBuilder class

Properties

documentQualifier ↔ ListBuilder<DocumentQualifier>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messageReference ↔ MessageReferenceBuilder
getter/setter pair
receiptReprintFlag ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → TransactionStatusRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(TransactionStatusRequest other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(TransactionStatusRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited