TransactionStatusResponseBuilder class

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageReference ↔ MessageReferenceBuilder
getter/setter pair
repeatedMessageResponse ↔ RepeatedMessageResponseBuilder
getter/setter pair
response ↔ ResponseBuilder
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → TransactionStatusResponse
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(TransactionStatusResponse other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(TransactionStatusResponseBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited