cardBrand property
Type of payment or loyalty card. If configured to present totals per card brand, and Response.Result is Success.
Implementation
@BuiltValueField(wireName: r'CardBrand')
String? get cardBrand;
Type of payment or loyalty card. If configured to present totals per card brand, and Response.Result is Success.
@BuiltValueField(wireName: r'CardBrand')
String? get cardBrand;