saleID property
Identification of a Sale System or a Sale Terminal for the Sale to POI protocol. Sent if requested in the message request.
Implementation
@BuiltValueField(wireName: r'SaleID')
String? get saleID;
Identification of a Sale System or a Sale Terminal for the Sale to POI protocol. Sent if requested in the message request.
@BuiltValueField(wireName: r'SaleID')
String? get saleID;