totalsGroupID property
Identification of a group of transaction on a POI Terminal, having the same Sale features. Sent if requested in the message request.
Implementation
@BuiltValueField(wireName: r'TotalsGroupID')
String? get totalsGroupID;
Identification of a group of transaction on a POI Terminal, having the same Sale features. Sent if requested in the message request.
@BuiltValueField(wireName: r'TotalsGroupID')
String? get totalsGroupID;