TransactionTotalsBuilder class

Constructors

TransactionTotalsBuilder()

Properties

acquirerID ↔ int?
getter/setter pair
cardBrand ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostReconciliationID ↔ String?
getter/setter pair
operatorID ↔ String?
getter/setter pair
paymentCurrency ↔ String?
getter/setter pair
paymentInstrumentType ↔ PaymentInstrumentType?
getter/setter pair
paymentTotals ↔ ListBuilder<PaymentTotals>
getter/setter pair
POIID ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleID ↔ String?
getter/setter pair
shiftNumber ↔ String?
getter/setter pair
totalsGroupID ↔ String?
getter/setter pair

Methods

build() → TransactionTotals
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(TransactionTotals other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(TransactionTotalsBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited