TypeCode class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TypeCode>
no setter
values → BuiltSet<TypeCode>
no setter

Static Methods

valueOf(String name) → TypeCode

Constants

company → const TypeCode
personal → const TypeCode
unknownDefaultOpenApi → const TypeCode