companyAccount property
Your company account. To return terminals to the company inventory, specify only this parameter and the terminals.
Implementation
@BuiltValueField(wireName: r'companyAccount')
String get companyAccount;
Your company account. To return terminals to the company inventory, specify only this parameter and the terminals.
@BuiltValueField(wireName: r'companyAccount')
String get companyAccount;