merchantAccount property

  1. @BuiltValueField.new(wireName: r'merchantAccount')
String? get merchantAccount

Name of the merchant account. Specify this parameter to assign terminals to this merchant account or to a store under this merchant account.

Implementation

@BuiltValueField(wireName: r'merchantAccount')
String? get merchantAccount;