merchantInventory property

  1. @BuiltValueField.new(wireName: r'merchantInventory')
bool? get merchantInventory

Boolean that indicates if you are assigning the terminals to the merchant inventory. Do not use when assigning terminals to a store. Required when assigning the terminal to a merchant account. - Set this to true to assign the terminals to the merchant inventory. This also means that the terminals cannot be boarded. - Set this to false to assign the terminals to the merchant account as in-store terminals. This makes the terminals ready to be boarded and to process payments through the specified merchant account.

Implementation

@BuiltValueField(wireName: r'merchantInventory')
bool? get merchantInventory;