GetTerminalDetailsResponse class abstract

GetTerminalDetailsResponse

Properties:

  • bluetoothIp - The Bluetooth IP address of the terminal.
  • bluetoothMac - The Bluetooth MAC address of the terminal.
  • companyAccount - The company account that the terminal is associated with. If this is the only account level shown in the response, the terminal is assigned to the inventory of the company account.
  • country - The country where the terminal is used.
  • deviceModel - The model name of the terminal.
  • dhcpEnabled - Indicates whether assigning IP addresses through a DHCP server is enabled on the terminal.
  • displayLabel - The label shown on the status bar of the display. This label (if any) is specified in your Customer Area.
  • ethernetIp - The terminal's IP address in your Ethernet network.
  • ethernetMac - The terminal's MAC address in your Ethernet network.
  • firmwareVersion - The software release currently in use on the terminal.
  • iccid - The integrated circuit card identifier (ICCID) of the SIM card in the terminal.
  • lastActivityDateTime - Date and time of the last activity on the terminal. Not included when the last activity was more than 14 days ago.
  • lastTransactionDateTime - Date and time of the last transaction on the terminal. Not included when the last transaction was more than 14 days ago.
  • linkNegotiation - The Ethernet link negotiation that the terminal uses: - auto: Auto-negotiation - 100full: 100 Mbps full duplex
  • merchantAccount - The merchant account that the terminal is associated with. If the response doesn't contain a store the terminal is assigned to this merchant account.
  • merchantInventory - Boolean that indicates if the terminal is assigned to the merchant inventory. This is returned when the terminal is assigned to a merchant account. - If true, this indicates that the terminal is in the merchant inventory. This also means that the terminal cannot be boarded. - If false, this indicates that the terminal is assigned to the merchant account as an in-store terminal. This means that the terminal is ready to be boarded, or is already boarded.
  • permanentTerminalId - The permanent terminal ID.
  • serialNumber - The serial number of the terminal.
  • simStatus - On a terminal that supports 3G or 4G connectivity, indicates the status of the SIM card in the terminal: ACTIVE or INVENTORY.
  • store - The store code of the store that the terminal is assigned to.
  • storeDetails - The store that the terminal is assigned to.
  • terminal - The unique terminal ID.
  • terminalStatus - The status of the terminal: - OnlineToday, OnlineLast1Day, OnlineLast2Days etcetera to OnlineLast7Days: Indicates when in the past week the terminal was last online. - SwitchedOff: Indicates it was more than a week ago that the terminal was last online. - ReAssignToInventoryPending, ReAssignToStorePending, ReAssignToMerchantInventoryPending: Indicates the terminal is scheduled to be reassigned.
  • wifiIp - The terminal's IP address in your Wi-Fi network.
  • wifiMac - The terminal's MAC address in your Wi-Fi network.
Annotations
  • @BuiltValue.new()

Constructors

GetTerminalDetailsResponse([void updates(GetTerminalDetailsResponseBuilder b)])
factory

Properties

bluetoothIp String?
The Bluetooth IP address of the terminal.
no setter
bluetoothMac String?
The Bluetooth MAC address of the terminal.
no setter
companyAccount String
The company account that the terminal is associated with. If this is the only account level shown in the response, the terminal is assigned to the inventory of the company account.
no setter
country String?
The country where the terminal is used.
no setter
deviceModel String?
The model name of the terminal.
no setter
dhcpEnabled bool?
Indicates whether assigning IP addresses through a DHCP server is enabled on the terminal.
no setter
displayLabel String?
The label shown on the status bar of the display. This label (if any) is specified in your Customer Area.
no setter
ethernetIp String?
The terminal's IP address in your Ethernet network.
no setter
ethernetMac String?
The terminal's MAC address in your Ethernet network.
no setter
firmwareVersion String?
The software release currently in use on the terminal.
no setter
hashCode int
The hash code for this object.
no setterinherited
iccid String?
The integrated circuit card identifier (ICCID) of the SIM card in the terminal.
no setter
lastActivityDateTime DateTime?
Date and time of the last activity on the terminal. Not included when the last activity was more than 14 days ago.
no setter
lastTransactionDateTime DateTime?
Date and time of the last transaction on the terminal. Not included when the last transaction was more than 14 days ago.
no setter
linkNegotiation String?
The Ethernet link negotiation that the terminal uses: - auto: Auto-negotiation - 100full: 100 Mbps full duplex
no setter
merchantAccount String?
The merchant account that the terminal is associated with. If the response doesn't contain a store the terminal is assigned to this merchant account.
no setter
merchantInventory bool?
Boolean that indicates if the terminal is assigned to the merchant inventory. This is returned when the terminal is assigned to a merchant account. - If true, this indicates that the terminal is in the merchant inventory. This also means that the terminal cannot be boarded. - If false, this indicates that the terminal is assigned to the merchant account as an in-store terminal. This means that the terminal is ready to be boarded, or is already boarded.
no setter
permanentTerminalId String?
The permanent terminal ID.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
The serial number of the terminal.
no setter
simStatus String?
On a terminal that supports 3G or 4G connectivity, indicates the status of the SIM card in the terminal: ACTIVE or INVENTORY.
no setter
store String?
The store code of the store that the terminal is assigned to.
no setter
storeDetails Store?
The store that the terminal is assigned to.
no setter
terminal String
The unique terminal ID.
no setter
terminalStatus GetTerminalDetailsResponseTerminalStatusEnum?
The status of the terminal: - OnlineToday, OnlineLast1Day, OnlineLast2Days etcetera to OnlineLast7Days: Indicates when in the past week the terminal was last online. - SwitchedOff: Indicates it was more than a week ago that the terminal was last online. - ReAssignToInventoryPending, ReAssignToStorePending, ReAssignToMerchantInventoryPending: Indicates the terminal is scheduled to be reassigned.
no setter
wifiIp String?
The terminal's IP address in your Wi-Fi network.
no setter
wifiMac String?
The terminal's MAC address in your Wi-Fi network.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GetTerminalDetailsResponseBuilder)) GetTerminalDetailsResponse
Rebuilds the instance.
inherited
toBuilder() GetTerminalDetailsResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GetTerminalDetailsResponse>
no setter