companyAccount property
The company account that the terminal is associated with. If this is the only account level shown in the response, the terminal is assigned to the inventory of the company account.
Implementation
@BuiltValueField(wireName: r'companyAccount')
String get companyAccount;