displayLabel property
The label shown on the status bar of the display. This label (if any) is specified in your Customer Area.
Implementation
@BuiltValueField(wireName: r'displayLabel')
String? get displayLabel;
The label shown on the status bar of the display. This label (if any) is specified in your Customer Area.
@BuiltValueField(wireName: r'displayLabel')
String? get displayLabel;