companyAccount property
Your company account. If you only specify this parameter, the response includes all terminals at all account levels.
Implementation
@BuiltValueField(wireName: r'companyAccount')
String get companyAccount;
Your company account. If you only specify this parameter, the response includes all terminals at all account levels.
@BuiltValueField(wireName: r'companyAccount')
String get companyAccount;