EventNotification class

Event notification details for terminal events.

Implemented types

Constructors

EventNotification({String? eventToNotify, String? eventDetails, String? rejectedMessage, String? timeStamp, Map<String, dynamic>? additionalAttributes})
Creates a new event notification.
EventNotification.fromJson(Map<String, dynamic> json)
Creates an EventNotification from JSON.
factory

Properties

additionalAttributes → Map<String, dynamic>
Additional attributes not covered by standard fields.
final
eventDetails → String?
Additional event details.
final
eventToNotify → String?
Type of event being notified.
final
hashCode → int
The hash code for this object.
no setterinherited
rejectedMessage → String?
Rejected message if event was rejected.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeStamp → String?
Event timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSerializable() → Map<String, dynamic>
Converts this object to a serializable map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited