MessageHeader class

Header containing routing and metadata for terminal messages.

Implemented types

Constructors

MessageHeader({required MessageCategoryType messageCategory, required MessageClassType messageClass, required MessageType messageType, required String poiId, required String protocolVersion, required String saleId, required String serviceId, String? deviceId})
Creates a new message header.
MessageHeader.fromJson(Map<String, dynamic> json)
Creates a MessageHeader from JSON.
factory

Properties

deviceId ↔ String?
Optional device identifier.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messageCategory ↔ MessageCategoryType
Category of the message (payment, reversal, event).
getter/setter pair
messageClass ↔ MessageClassType
Class of the message (service, event).
getter/setter pair
messageType ↔ MessageType
Type of message (request, response, notification).
getter/setter pair
poiId ↔ String
Point of Interaction ID (terminal identifier).
getter/setter pair
protocolVersion ↔ String
Nexo protocol version.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleId ↔ String
Sale system identifier.
getter/setter pair
serviceId ↔ String
Service ID for message correlation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSerializable() → Map<String, dynamic>
Converts this object to a serializable map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited