ObjectSerializer class

Utility class for serializing objects to JSON-compatible format.

Constructors

ObjectSerializer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

serialize(dynamic data, String type) → dynamic
Serializes data to a JSON-compatible format.