POIData class

Point of Interaction transaction data.

Constructors

POIData({POITransactionID? poiTransactionID, String? poiReconciliationId})
Creates a new POI data object.
POIData.fromJson(Map<String, dynamic> json)
Creates a POIData from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
poiReconciliationId String?
POI reconciliation identifier.
final
poiTransactionID POITransactionID?
POI transaction identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited