POITransactionID class
POI transaction identifier.
Constructors
- POITransactionID({String? timeStamp, String? transactionID})
- Creates a new POI transaction ID.
-
POITransactionID.fromJson(Map<
String, dynamic> json) -
Creates a POITransactionID from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeStamp → String?
-
Transaction timestamp.
final
- transactionID → String?
-
Transaction ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toSerializable(
) → Map< String, dynamic> - Converts this object to a serializable map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited