PaymentRequest class
Payment request payload.
- Implemented types
Constructors
- PaymentRequest({required PaymentTransaction paymentTransaction, required SaleData saleData})
- Creates a new payment request.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- paymentTransaction → PaymentTransaction
-
Payment transaction details including amounts.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saleData → SaleData
-
Sale transaction context data.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toSerializable(
) → Map< String, dynamic> -
Converts this object to a serializable map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited