PaymentResponse class

Payment response data.

Constructors

PaymentResponse({POIData? poiData})
Creates a new payment response.
PaymentResponse.fromJson(Map<String, dynamic> json)
Creates a PaymentResponse from JSON.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
poiData → POIData?
Point of Interaction response data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited