PaymentTransaction class
Payment transaction details.
- Implemented types
Constructors
- PaymentTransaction({required AmountsReq amountsReq})
- Creates a new payment transaction.
Properties
- amountsReq → AmountsReq
-
Requested payment amounts and currency.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toSerializable(
) → Map< String, dynamic> -
Converts this object to a serializable map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited