ResponseResult class

Result of a reversal operation.

Constructors

ResponseResult({String? result})
Creates a new response result.
ResponseResult.fromJson(Map<String, dynamic> json)
Creates a ResponseResult from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
result String?
Result status string.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited