SaleData class

Sale transaction context data.

Implemented types

Constructors

SaleData({required SaleTransactionID saleTransactionId, dynamic saleToAcquirerData})
Creates a new sale data object.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saleToAcquirerData ↔ dynamic
Additional acquirer-specific data.
getter/setter pair
saleTransactionId SaleTransactionID
Unique transaction identifier.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSerializable() Map<String, dynamic>
Converts this object to a serializable map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited