SaleToPOIResponse class

Main SaleToPOI response message from terminal.

Constructors

SaleToPOIResponse({MessageHeader? messageHeader, PaymentResponse? paymentResponse, ReversalResponse? reversalResponse})
Creates a new SaleToPOI response.
SaleToPOIResponse.fromJson(Map<String, dynamic> json)
Creates a SaleToPOIResponse from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
messageHeader MessageHeader?
Message metadata and routing information.
final
paymentResponse PaymentResponse?
Payment transaction response.
final
reversalResponse ReversalResponse?
Reversal response.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited