TerminalApiRequest class
Request wrapper for terminal API calls.
- Implemented types
Constructors
- TerminalApiRequest({required SaleToPOIRequest saleToPOIRequest})
- Creates a new terminal API request.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saleToPOIRequest → SaleToPOIRequest
-
The actual SaleToPOI request payload.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toSerializable(
) → Map< String, dynamic> -
Converts this object to a serializable map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited