TerminalApiResponse class
Response wrapper for terminal API calls.
Constructors
- TerminalApiResponse({SaleToPOIResponse? saleToPOIResponse, SaleToPOIRequest? saleToPOIRequest})
- Creates a new terminal API response.
-
TerminalApiResponse.fromJson(Map<
String, dynamic> json) -
Creates a TerminalApiResponse from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saleToPOIRequest → SaleToPOIRequest?
-
Request payload (echoed back in some cases).
final
- saleToPOIResponse → SaleToPOIResponse?
-
Response payload from terminal.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited