CancelTransfersRequest class abstract

CancelTransfersRequest

Properties:

  • transferIds - Contains the unique identifiers of the transfers that you want to cancel.
Annotations
  • @BuiltValue.new()

Constructors

CancelTransfersRequest([void updates(CancelTransfersRequestBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transferIds → BuiltList<String>?
Contains the unique identifiers of the transfers that you want to cancel.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CancelTransfersRequestBuilder)) CancelTransfersRequest
Rebuilds the instance.
inherited
toBuilder() CancelTransfersRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CancelTransfersRequest>
no setter