amount property
An object containing the amount of the grant, in minor units.
Implementation
@BuiltValueField(wireName: r'amount')
Amount? get amount;
An object containing the amount of the grant, in minor units.
@BuiltValueField(wireName: r'amount')
Amount? get amount;