balances property
An object containing the details of the existing grant.
Implementation
@BuiltValueField(wireName: r'balances')
CapitalBalance get balances;
An object containing the details of the existing grant.
@BuiltValueField(wireName: r'balances')
CapitalBalance get balances;