balanceAccountId property
The identifier of the balance account that belongs to the receiving account holder.
Implementation
@BuiltValueField(wireName: r'balanceAccountId')
String? get balanceAccountId;
The identifier of the balance account that belongs to the receiving account holder.
@BuiltValueField(wireName: r'balanceAccountId')
String? get balanceAccountId;