CounterpartyInfoV3 class abstract

CounterpartyInfoV3

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CounterpartyInfoV3([void updates(CounterpartyInfoV3Builder b)])
factory

Properties

balanceAccountId String?
The unique identifier of the counterparty balance account.
no setter
bankAccount BankAccountV3?
Contains information about the counterparty bank account.
no setter
card Card?
Contains information about the counterparty card.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transferInstrumentId String?
The unique identifier of the counterparty transfer instrument.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CounterpartyInfoV3Builder)) CounterpartyInfoV3
Rebuilds the instance.
inherited
toBuilder() CounterpartyInfoV3Builder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CounterpartyInfoV3>
no setter