FundingInstrumentSourceOfFundsEnum class

Inheritance
  • Object
  • EnumClass
  • FundingInstrumentSourceOfFundsEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<FundingInstrumentSourceOfFundsEnum>
no setter
values → BuiltSet<FundingInstrumentSourceOfFundsEnum>
no setter

Constants

DEBIT → const FundingInstrumentSourceOfFundsEnum
Indicates where the funds used for the transfer originated. Possible values are: - DEBIT for card-to-card transfers. - DEPOSIT_ACCOUNT for wallet-to-card transfers.
DEPOSIT_ACCOUNT → const FundingInstrumentSourceOfFundsEnum
Indicates where the funds used for the transfer originated. Possible values are: - DEBIT for card-to-card transfers. - DEPOSIT_ACCOUNT for wallet-to-card transfers.
unknownDefaultOpenApi → const FundingInstrumentSourceOfFundsEnum
Indicates where the funds used for the transfer originated. Possible values are: - DEBIT for card-to-card transfers. - DEPOSIT_ACCOUNT for wallet-to-card transfers.