scaOnApproval property

  1. @BuiltValueField.new(wireName: r'scaOnApproval')
bool? get scaOnApproval

Specifies whether you will initiate Strong Customer Authentication (SCA) in thePOST /transfers/approve request. Only applies to transfers made with an Adyen business account.

Implementation

@BuiltValueField(wireName: r'scaOnApproval')
bool? get scaOnApproval;