fundingInstrument property
Details of the card or token used to fund the pay-in transaction.
Implementation
@BuiltValueField(wireName: r'fundingInstrument')
FundingInstrument? get fundingInstrument;
Details of the card or token used to fund the pay-in transaction.
@BuiltValueField(wireName: r'fundingInstrument')
FundingInstrument? get fundingInstrument;