AuthenticationInfo class abstract

AuthenticationInfo

Properties:

  • acsTransId - Universally unique transaction identifier assigned by the Access Control Server (ACS) to identify a single transaction.
  • challenge - Information about Strong Customer Authentication (SCA). Returned when type is challenge.
  • challengeIndicator - Specifies a preference for receiving a challenge. Possible values: * 01: No preference * 02: No challenge requested * 03: Challenge requested (preference) * 04: Challenge requested (mandate) * 05: No challenge requested (transactional risk analysis is already performed) * 07: No challenge requested (SCA is already performed) * 08: No challenge requested (trusted beneficiaries exemption of no challenge required) * 09: Challenge requested (trusted beneficiaries prompt requested if challenge required) * 80: No challenge requested (secure corporate payment with Mastercard) * 82: No challenge requested (secure corporate payment with Visa)
  • createdAt - Date and time in UTC of the cardholder authentication. ISO 8601 format: YYYY-MM-DDThh:mm:ss+TZD, for example, 2020-12-18T10:15:30+01:00.
  • deviceChannel - Indicates the type of channel interface being used to initiate the transaction. Possible values: * app * browser * 3DSRequestorInitiated (initiated by a merchant when the cardholder is not available)
  • dsTransID - Universally unique transaction identifier assigned by the DS (card scheme) to identify a single transaction.
  • exemptionIndicator - Indicates the exemption type that was applied to the authentication by the issuer, if exemption applied. Possible values: * lowValue * secureCorporate * trustedBeneficiary * transactionRiskAnalysis * acquirerExemption * noExemptionApplied * visaDAFExemption
  • inPSD2Scope - Indicates if the purchase was in the PSD2 scope.
  • messageCategory - Identifies the category of the message for a specific use case. Possible values: * payment * nonPayment
  • messageVersion - The messageVersion value as defined in the 3D Secure 2 specification.
  • riskScore - Risk score calculated from the transaction rules.
  • threeDSServerTransID - The threeDSServerTransID value as defined in the 3D Secure 2 specification.
  • transStatus - The transStatus value as defined in the 3D Secure 2 specification. Possible values: * Y: Authentication / Account verification successful. * N: Not Authenticated / Account not verified. Transaction denied. * U: Authentication / Account verification could not be performed. * I: Informational Only / 3D Secure Requestor challenge preference acknowledged. * R: Authentication / Account verification rejected by the Issuer.
  • transStatusReason - Provides information on why the transStatus field has the specified value. For possible values, refer to our docs.
  • type - The type of authentication performed. Possible values: * frictionless * challenge
Annotations
  • @BuiltValue.new()

Constructors

AuthenticationInfo([void updates(AuthenticationInfoBuilder b)])
factory

Properties

acsTransId → String
Universally unique transaction identifier assigned by the Access Control Server (ACS) to identify a single transaction.
no setter
challenge → ChallengeInfo?
Information about Strong Customer Authentication (SCA). Returned when type is challenge.
no setter
challengeIndicator → AuthenticationInfoChallengeIndicatorEnum
Specifies a preference for receiving a challenge. Possible values: * 01: No preference * 02: No challenge requested * 03: Challenge requested (preference) * 04: Challenge requested (mandate) * 05: No challenge requested (transactional risk analysis is already performed) * 07: No challenge requested (SCA is already performed) * 08: No challenge requested (trusted beneficiaries exemption of no challenge required) * 09: Challenge requested (trusted beneficiaries prompt requested if challenge required) * 80: No challenge requested (secure corporate payment with Mastercard) * 82: No challenge requested (secure corporate payment with Visa)
no setter
createdAt → DateTime
Date and time in UTC of the cardholder authentication. ISO 8601 format: YYYY-MM-DDThh:mm:ss+TZD, for example, 2020-12-18T10:15:30+01:00.
no setter
deviceChannel → AuthenticationInfoDeviceChannelEnum
Indicates the type of channel interface being used to initiate the transaction. Possible values: * app * browser * 3DSRequestorInitiated (initiated by a merchant when the cardholder is not available)
no setter
dsTransID → String
Universally unique transaction identifier assigned by the DS (card scheme) to identify a single transaction.
no setter
exemptionIndicator → AuthenticationInfoExemptionIndicatorEnum?
Indicates the exemption type that was applied to the authentication by the issuer, if exemption applied. Possible values: * lowValue * secureCorporate * trustedBeneficiary * transactionRiskAnalysis * acquirerExemption * noExemptionApplied * visaDAFExemption
no setter
hashCode → int
The hash code for this object.
no setterinherited
inPSD2Scope → bool
Indicates if the purchase was in the PSD2 scope.
no setter
messageCategory → AuthenticationInfoMessageCategoryEnum
Identifies the category of the message for a specific use case. Possible values: * payment * nonPayment
no setter
messageVersion → String
The messageVersion value as defined in the 3D Secure 2 specification.
no setter
riskScore → int?
Risk score calculated from the transaction rules.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threeDSServerTransID → String
The threeDSServerTransID value as defined in the 3D Secure 2 specification.
no setter
transStatus → AuthenticationInfoTransStatusEnum
The transStatus value as defined in the 3D Secure 2 specification. Possible values: * Y: Authentication / Account verification successful. * N: Not Authenticated / Account not verified. Transaction denied. * U: Authentication / Account verification could not be performed. * I: Informational Only / 3D Secure Requestor challenge preference acknowledged. * R: Authentication / Account verification rejected by the Issuer.
no setter
transStatusReason → AuthenticationInfoTransStatusReasonEnum?
Provides information on why the transStatus field has the specified value. For possible values, refer to our docs.
no setter
type → AuthenticationInfoTypeEnum
The type of authentication performed. Possible values: * frictionless * challenge
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AuthenticationInfoBuilder)) → AuthenticationInfo
Rebuilds the instance.
inherited
toBuilder() → AuthenticationInfoBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AuthenticationInfo>
no setter