AuthenticationInfoBuilder class

Constructors

AuthenticationInfoBuilder()

Properties

acsTransId ↔ String?
getter/setter pair
challenge ↔ ChallengeInfoBuilder
getter/setter pair
challengeIndicator ↔ AuthenticationInfoChallengeIndicatorEnum?
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
deviceChannel ↔ AuthenticationInfoDeviceChannelEnum?
getter/setter pair
dsTransID ↔ String?
getter/setter pair
exemptionIndicator ↔ AuthenticationInfoExemptionIndicatorEnum?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inPSD2Scope ↔ bool?
getter/setter pair
messageCategory ↔ AuthenticationInfoMessageCategoryEnum?
getter/setter pair
messageVersion ↔ String?
getter/setter pair
riskScore ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threeDSServerTransID ↔ String?
getter/setter pair
transStatus ↔ AuthenticationInfoTransStatusEnum?
getter/setter pair
transStatusReason ↔ AuthenticationInfoTransStatusReasonEnum?
getter/setter pair
type ↔ AuthenticationInfoTypeEnum?
getter/setter pair

Methods

build() → AuthenticationInfo
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(AuthenticationInfo other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(AuthenticationInfoBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited