threeDSRequestorInitiated constant

  1. @BuiltValueEnumConst.new(wireName: r'ThreeDSRequestorInitiated')
AuthenticationInfoDeviceChannelEnum const threeDSRequestorInitiated

Indicates the type of channel interface being used to initiate the transaction. Possible values: * app * browser * 3DSRequestorInitiated (initiated by a merchant when the cardholder is not available)

Implementation

@BuiltValueEnumConst(wireName: r'ThreeDSRequestorInitiated')
static const AuthenticationInfoDeviceChannelEnum threeDSRequestorInitiated = _$authenticationInfoDeviceChannelEnum_threeDSRequestorInitiated;