paymentInstrumentId property
The unique identifier of the payment instrument that was used for the authentication.
Implementation
@BuiltValueField(wireName: r'paymentInstrumentId')
String get paymentInstrumentId;
The unique identifier of the payment instrument that was used for the authentication.
@BuiltValueField(wireName: r'paymentInstrumentId')
String get paymentInstrumentId;