AuthenticationNotificationDataBuilder class

Properties

authentication ↔ AuthenticationInfoBuilder
getter/setter pair
balancePlatform ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
paymentInstrumentId ↔ String?
getter/setter pair
purchase ↔ PurchaseInfoBuilder
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ AuthenticationNotificationDataStatusEnum?
getter/setter pair

Methods

build() → AuthenticationNotificationData
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(AuthenticationNotificationData other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(AuthenticationNotificationDataBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited