replace method

  1. @override
void replace(
  1. AuthenticationNotificationData other
)
override

Replaces the value in the builder with a new one.

The implementation of this method will be generated for you by the built_value generator.

Implementation

@override
void replace(AuthenticationNotificationData other) {
  _$v = other as _$AuthenticationNotificationData;
}