AuthenticationNotificationRequestBuilder class

Properties

data ↔ AuthenticationNotificationDataBuilder
getter/setter pair
environment ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ DateTime?
getter/setter pair
type ↔ AuthenticationNotificationRequestTypeEnum?
getter/setter pair

Methods

build() → AuthenticationNotificationRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(AuthenticationNotificationRequest other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(AuthenticationNotificationRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited