ChallengeInfo class abstract

ChallengeInfo

Properties:

  • challengeCancel - Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. Possible values: * 00: Data element is absent or value has been sent back with the key challengeCancel. * 01: Cardholder selected Cancel. * 02: 3DS Requestor cancelled Authentication. * 03: Transaction abandoned. * 04: Transaction timed out at ACS — other timeouts. * 05: Transaction timed out at ACS — first CReq not received by ACS. * 06: Transaction error. * 07: Unknown. * 08: Transaction time out at SDK.
  • flow - The flow used in the challenge. Possible values: * PWD_OTP_PHONE_FL: one-time password (OTP) flow via SMS * PWD_OTP_EMAIL_FL: one-time password (OTP) flow via email * OOB_TRIGGER_FL: out-of-band (OOB) flow
  • lastInteraction - The last time of interaction with the challenge.
  • phoneNumber - The last four digits of the phone number used in the challenge.
  • resends - The number of times the one-time password (OTP) was resent during the challenge.
  • retries - The number of retries used in the challenge.
Annotations
  • @BuiltValue.new()

Constructors

ChallengeInfo([void updates(ChallengeInfoBuilder b)])
factory

Properties

challengeCancel → ChallengeInfoChallengeCancelEnum?
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. Possible values: * 00: Data element is absent or value has been sent back with the key challengeCancel. * 01: Cardholder selected Cancel. * 02: 3DS Requestor cancelled Authentication. * 03: Transaction abandoned. * 04: Transaction timed out at ACS — other timeouts. * 05: Transaction timed out at ACS — first CReq not received by ACS. * 06: Transaction error. * 07: Unknown. * 08: Transaction time out at SDK.
no setter
flow → ChallengeInfoFlowEnum
The flow used in the challenge. Possible values: * PWD_OTP_PHONE_FL: one-time password (OTP) flow via SMS * PWD_OTP_EMAIL_FL: one-time password (OTP) flow via email * OOB_TRIGGER_FL: out-of-band (OOB) flow
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastInteraction → DateTime
The last time of interaction with the challenge.
no setter
phoneNumber → String?
The last four digits of the phone number used in the challenge.
no setter
resends → int?
The number of times the one-time password (OTP) was resent during the challenge.
no setter
retries → int?
The number of retries used in the challenge.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ChallengeInfoBuilder)) → ChallengeInfo
Rebuilds the instance.
inherited
toBuilder() → ChallengeInfoBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ChallengeInfo>
no setter