Date class

A gregorian calendar date generated by OpenAPI generator to differentiate between DateTime and Date formats.

Implemented types

Constructors

Date(int year, int month, int day)

Properties

day → int
First day is 1.
final
hashCode → int
The hash code for this object.
no setteroverride
month → int
January is 1.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
year → int
final

Methods

compareTo(Date other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDateTime({bool utc = false}) → DateTime
Convert to a DateTime.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

now({bool utc = false}) → Date
The current date