Purchase class abstract

Purchase

Properties:

Annotations
  • @BuiltValue.new()

Constructors

Purchase([void updates(PurchaseBuilder b)])
factory

Properties

date → DateTime
The time of the purchase.
no setter
hashCode → int
The hash code for this object.
no setterinherited
merchantName → String
The name of the merchant.
no setter
originalAmount → Amount
The amount of the purchase in the original currency.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PurchaseBuilder)) → Purchase
Rebuilds the instance.
inherited
toBuilder() → PurchaseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Purchase>
no setter