PurchaseBuilder class

Constructors

PurchaseBuilder()

Properties

date ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merchantName ↔ String?
getter/setter pair
originalAmount ↔ AmountBuilder
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → Purchase
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(Purchase other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(PurchaseBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited