PurchaseInfo class abstract

PurchaseInfo

Properties:

  • date - The date of the purchase.
  • merchantName - The name of the business that the cardholder purchased from.
  • originalAmount - The amount of the purchase.
Annotations
  • @BuiltValue.new()

Constructors

PurchaseInfo([void updates(PurchaseInfoBuilder b)])
factory

Properties

date → String
The date of the purchase.
no setter
hashCode → int
The hash code for this object.
no setterinherited
merchantName → String
The name of the business that the cardholder purchased from.
no setter
originalAmount → Amount
The amount of the purchase.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PurchaseInfoBuilder)) → PurchaseInfo
Rebuilds the instance.
inherited
toBuilder() → PurchaseInfoBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PurchaseInfo>
no setter