merchantName property
The name of the business that the cardholder purchased from.
Implementation
@BuiltValueField(wireName: r'merchantName')
String get merchantName;
The name of the business that the cardholder purchased from.
@BuiltValueField(wireName: r'merchantName')
String get merchantName;