RelayedAuthenticationRequest class abstract

RelayedAuthenticationRequest

Properties:

  • environment - The environment from which the webhook originated. Possible values: test, live.
  • id - The unique identifier of the challenge.
  • paymentInstrumentId - The unique identifier of the payment instrument used for the purchase.
  • purchase - The details of the purchase.
  • threeDSRequestorAppURL - URL for auto-switching to the threeDS Requestor App. If not present, the threeDS Requestor App doesn't support auto-switching.
  • timestamp - When the event was queued.
  • type - Type of notification.
Annotations
  • @BuiltValue.new()

Constructors

RelayedAuthenticationRequest([void updates(RelayedAuthenticationRequestBuilder b)])
factory

Properties

environment → String
The environment from which the webhook originated. Possible values: test, live.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier of the challenge.
no setter
paymentInstrumentId → String
The unique identifier of the payment instrument used for the purchase.
no setter
purchase → Purchase
The details of the purchase.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threeDSRequestorAppURL → String?
URL for auto-switching to the threeDS Requestor App. If not present, the threeDS Requestor App doesn't support auto-switching.
no setter
timestamp → DateTime?
When the event was queued.
no setter
type → RelayedAuthenticationRequestTypeEnum
Type of notification.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RelayedAuthenticationRequestBuilder)) → RelayedAuthenticationRequest
Rebuilds the instance.
inherited
toBuilder() → RelayedAuthenticationRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RelayedAuthenticationRequest>
no setter