RelayedAuthenticationRequestBuilder class

Properties

environment ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
paymentInstrumentId ↔ String?
getter/setter pair
purchase ↔ PurchaseBuilder
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threeDSRequestorAppURL ↔ String?
getter/setter pair
timestamp ↔ DateTime?
getter/setter pair
type ↔ RelayedAuthenticationRequestTypeEnum?
getter/setter pair

Methods

build() → RelayedAuthenticationRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(RelayedAuthenticationRequest other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(RelayedAuthenticationRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited