BalanceNotificationData class abstract

BalanceNotificationData

Properties:

  • balanceAccountId - The unique identifier of the balance account.
  • balancePlatform - The unique identifier of the balance platform.
  • balances - The list balance types.
  • creationDate - The date and time when the event was triggered, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
  • currency - The three-character ISO currency code.
  • id - The ID of the resource.
  • settingIds - The unique identifier of the balance webhook setting.
Annotations
  • @BuiltValue.new()

Constructors

BalanceNotificationData([void updates(BalanceNotificationDataBuilder b)])
factory

Properties

balanceAccountId → String
The unique identifier of the balance account.
no setter
balancePlatform → String?
The unique identifier of the balance platform.
no setter
balances → Balances
The list balance types.
no setter
creationDate → DateTime?
The date and time when the event was triggered, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
no setter
currency → String
The three-character ISO currency code.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the resource.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settingIds → BuiltList<String>
The unique identifier of the balance webhook setting.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BalanceNotificationDataBuilder)) → BalanceNotificationData
Rebuilds the instance.
inherited
toBuilder() → BalanceNotificationDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BalanceNotificationData>
no setter