Balances class abstract

Balances

Properties:

  • available - The balance that is available for use.
  • balance - The sum of transactions that have already been settled.
  • pending - The sum of transactions that will be settled in the future.
  • reserved - The balance currently held in reserve.
Annotations
  • @BuiltValue.new()

Constructors

Balances([void updates(BalancesBuilder b)])
factory

Properties

available → int?
The balance that is available for use.
no setter
balance → int?
The sum of transactions that have already been settled.
no setter
hashCode → int
The hash code for this object.
no setterinherited
pending → int?
The sum of transactions that will be settled in the future.
no setter
reserved → int?
The balance currently held in reserve.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BalancesBuilder)) → Balances
Rebuilds the instance.
inherited
toBuilder() → BalancesBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Balances>
no setter