ReleaseBlockedBalanceNotificationData class abstract

ReleaseBlockedBalanceNotificationData

Properties:

  • accountHolder - Contains information about the account holder associated with the balanceAccount.
  • amount - The amount released.
  • balanceAccount - Contains information about the associated balance account.
  • balancePlatform - The unique identifier of the balance platform.
  • batchReference - The reference of the batch that was released.
  • blockedBalanceAfter - The new blocked balance after the funds were released.
  • blockedBalanceBefore - The blocked balance before the funds were released.
  • creationDate - The date and time when the event was triggered, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
  • id - The ID of the resource.
  • valueDate - The date and time when the amount was released, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
Annotations
  • @BuiltValue.new()

Properties

accountHolder → ResourceReference
Contains information about the account holder associated with the balanceAccount.
no setter
amount → Amount
The amount released.
no setter
balanceAccount → ResourceReference
Contains information about the associated balance account.
no setter
balancePlatform → String?
The unique identifier of the balance platform.
no setter
batchReference → String?
The reference of the batch that was released.
no setter
blockedBalanceAfter → Amount?
The new blocked balance after the funds were released.
no setter
blockedBalanceBefore → Amount?
The blocked balance before the funds were released.
no setter
creationDate → DateTime?
The date and time when the event was triggered, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the resource.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueDate → DateTime?
The date and time when the amount was released, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReleaseBlockedBalanceNotificationDataBuilder)) → ReleaseBlockedBalanceNotificationData
Rebuilds the instance.
inherited
toBuilder() → ReleaseBlockedBalanceNotificationDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReleaseBlockedBalanceNotificationData>
no setter