ReleasedBlockedBalanceNotificationRequest class abstract

ReleasedBlockedBalanceNotificationRequest

Properties:

  • data - Contains event details.
  • environment - The environment from which the webhook originated. Possible values: test, live.
  • timestamp - When the event was queued.
  • type - Type of webhook.
Annotations
  • @BuiltValue.new()

Properties

data → ReleaseBlockedBalanceNotificationData
Contains event details.
no setter
environment → String
The environment from which the webhook originated. Possible values: test, live.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime?
When the event was queued.
no setter
type → ReleasedBlockedBalanceNotificationRequestTypeEnum
Type of webhook.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReleasedBlockedBalanceNotificationRequestBuilder)) → ReleasedBlockedBalanceNotificationRequest
Rebuilds the instance.
inherited
toBuilder() → ReleasedBlockedBalanceNotificationRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReleasedBlockedBalanceNotificationRequest>
no setter