AccountHolderNotificationData class abstract

AccountHolderNotificationData

Properties:

  • accountHolder - Contains information about the account holder resource that triggered the event.
  • balancePlatform - The unique identifier of the balance platform.
Annotations
  • @BuiltValue.new()

Properties

accountHolder → AccountHolder?
Contains information about the account holder resource that triggered the event.
no setter
balancePlatform → String?
The unique identifier of the balance platform.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AccountHolderNotificationDataBuilder)) → AccountHolderNotificationData
Rebuilds the instance.
inherited
toBuilder() → AccountHolderNotificationDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AccountHolderNotificationData>
no setter