accountHolder property
Contains information about the account holder resource that triggered the event.
Implementation
@BuiltValueField(wireName: r'accountHolder')
AccountHolder? get accountHolder;
Contains information about the account holder resource that triggered the event.
@BuiltValueField(wireName: r'accountHolder')
AccountHolder? get accountHolder;