Amount class abstract

Amount

Properties:

Annotations
  • @BuiltValue.new()

Constructors

Amount([void updates(AmountBuilder b)])
factory

Properties

currency → String
The three-character ISO currency code of the amount.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The numeric value of the amount, in minor units.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AmountBuilder)) → Amount
Rebuilds the instance.
inherited
toBuilder() → AmountBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Amount>
no setter