Balance class abstract

Balance

Properties:

  • available - The balance available for use.
  • balance - The sum of the transactions that have already been settled.
  • currency - The three-character ISO currency code of the balance.
  • pending - The sum of the transactions that will be settled in the future.
  • reserved - The balance currently held in reserve.
Annotations
  • @BuiltValue.new()

Constructors

Balance([void updates(BalanceBuilder b)])
factory

Properties

available → int
The balance available for use.
no setter
balance → int
The sum of the transactions that have already been settled.
no setter
currency → String
The three-character ISO currency code of the balance.
no setter
hashCode → int
The hash code for this object.
no setterinherited
pending → int?
The sum of the transactions that will be settled in the future.
no setter
reserved → int
The balance currently held in reserve.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BalanceBuilder)) → Balance
Rebuilds the instance.
inherited
toBuilder() → BalanceBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Balance>
no setter