BalanceAccountBuilder class

Constructors

BalanceAccountBuilder()

Properties

accountHolderId ↔ String?
getter/setter pair
balances ↔ ListBuilder<Balance>
getter/setter pair
defaultCurrencyCode ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
metadata ↔ MapBuilder<String, String>
getter/setter pair
migratedAccountCode ↔ String?
getter/setter pair
platformPaymentConfiguration ↔ PlatformPaymentConfigurationBuilder
getter/setter pair
reference ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ BalanceAccountStatusEnum?
getter/setter pair
timeZone ↔ String?
getter/setter pair

Methods

build() → BalanceAccount
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(BalanceAccount other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(BalanceAccountBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited