BankAccountDetails class abstract

BankAccountDetails

Properties:

  • accountNumber - The bank account number, without separators or whitespace.
  • accountType - The bank account type. Possible values: checking or savings. Defaults to checking.
  • branchNumber - The bank account branch number, without separators or whitespace
  • formFactor - Business accounts with a formFactor value of physical are business accounts issued under the central bank of that country. The default value is physical for NL, US, and UK business accounts. Adyen creates a local IBAN for business accounts when the formFactor value is set to virtual. The local IBANs that are supported are for DE and FR, which reference a physical NL account, with funds being routed through the central bank of NL.
  • iban - The international bank account number as defined in the ISO-13616 standard.
  • routingNumber - The routing number, without separators or whitespace.
  • sortCode - The sort code, without separators or whitespace.
  • type - iban or usLocal or ukLocal
Annotations
  • @BuiltValue.new()

Constructors

BankAccountDetails([void updates(BankAccountDetailsBuilder b)])
factory

Properties

accountNumber → String?
The bank account number, without separators or whitespace.
no setter
accountType → String?
The bank account type. Possible values: checking or savings. Defaults to checking.
no setter
branchNumber → String?
The bank account branch number, without separators or whitespace
no setter
formFactor → String?
Business accounts with a formFactor value of physical are business accounts issued under the central bank of that country. The default value is physical for NL, US, and UK business accounts. Adyen creates a local IBAN for business accounts when the formFactor value is set to virtual. The local IBANs that are supported are for DE and FR, which reference a physical NL account, with funds being routed through the central bank of NL.
no setter
hashCode → int
The hash code for this object.
no setterinherited
iban → String?
The international bank account number as defined in the ISO-13616 standard.
no setter
routingNumber → String?
The routing number, without separators or whitespace.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortCode → String?
The sort code, without separators or whitespace.
no setter
type → String
iban or usLocal or ukLocal
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BankAccountDetailsBuilder)) → BankAccountDetails
Rebuilds the instance.
inherited
toBuilder() → BankAccountDetailsBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BankAccountDetails>
no setter