BankScoreSignalTriggeredData class abstract

BankScoreSignalTriggeredData

Properties:

  • accountHolder - Contains information about the account holder.
  • accountHolderStatus - The status of the account holder.
  • automatedActions - The automated action(s) taken as a result of the score signals that were triggered.
  • balancePlatform - The unique identifier of the balance platform.
  • creationDate - The date and time when the event was triggered, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
  • id - The ID of the resource.
  • riskScore - The score of the identity resulting from the signal(s) that were triggered.
  • scoreSignalsTriggered - The name(s) of the score signals that were triggered.
  • signalSourceTypes - The type(s) of the score signals that were triggered.
Annotations
  • @BuiltValue.new()

Constructors

BankScoreSignalTriggeredData([void updates(BankScoreSignalTriggeredDataBuilder b)])
factory

Properties

accountHolder → ResourceReference?
Contains information about the account holder.
no setter
accountHolderStatus → String?
The status of the account holder.
no setter
automatedActions → BuiltList<String>?
The automated action(s) taken as a result of the score signals that were triggered.
no setter
balancePlatform → String?
The unique identifier of the balance platform.
no setter
creationDate → DateTime?
The date and time when the event was triggered, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the resource.
no setter
riskScore → int?
The score of the identity resulting from the signal(s) that were triggered.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scoreSignalsTriggered → BuiltList<String>?
The name(s) of the score signals that were triggered.
no setter
signalSourceTypes → BuiltList<String>?
The type(s) of the score signals that were triggered.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BankScoreSignalTriggeredDataBuilder)) → BankScoreSignalTriggeredData
Rebuilds the instance.
inherited
toBuilder() → BankScoreSignalTriggeredDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BankScoreSignalTriggeredData>
no setter