BulkAddress class abstract

BulkAddress

Properties:

  • city - The name of the city.
  • company - The name of the company.
  • country - The two-character ISO-3166-1 alpha-2 country code. For example, US.
  • email - The email address.
  • houseNumberOrName - The house number or name.
  • line1 - The name of the street and the number of the building. For example: Simon Carmiggeltstraat 6-50.
  • line2 - Additional information about the delivery address. For example, an apartment number.
  • line3 - Additional information about the delivery address.
  • mobile - The full telephone number.
  • name_ - The recipient’s name (person or contact), for example ‘John Doe’.
  • postalCode - The postal code. Maximum length: * 5 digits for addresses in the US. * 10 characters for all other countries.
  • stateOrProvince - The two-letter ISO 3166-2 state or province code. Maximum length: 2 characters for addresses in the US.
  • street - The streetname of the house.
Annotations
  • @BuiltValue.new()

Constructors

BulkAddress([void updates(BulkAddressBuilder b)])
factory

Properties

city → String?
The name of the city.
no setter
company → String?
The name of the company.
no setter
country → String
The two-character ISO-3166-1 alpha-2 country code. For example, US.
no setter
email → String?
The email address.
no setter
hashCode → int
The hash code for this object.
no setterinherited
houseNumberOrName → String?
The house number or name.
no setter
line1 → String?
The name of the street and the number of the building. For example: Simon Carmiggeltstraat 6-50.
no setter
line2 → String?
Additional information about the delivery address. For example, an apartment number.
no setter
line3 → String?
Additional information about the delivery address.
no setter
mobile → String?
The full telephone number.
no setter
name_ → String?
The recipient’s name (person or contact), for example ‘John Doe’.
no setter
postalCode → String?
The postal code. Maximum length: * 5 digits for addresses in the US. * 10 characters for all other countries.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateOrProvince → String?
The two-letter ISO 3166-2 state or province code. Maximum length: 2 characters for addresses in the US.
no setter
street → String?
The streetname of the house.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BulkAddressBuilder)) → BulkAddress
Rebuilds the instance.
inherited
toBuilder() → BulkAddressBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BulkAddress>
no setter