CapabilityProblemEntity class abstract

CapabilityProblemEntity

Properties:

  • documents - List of document IDs to which the verification errors related to the capabilities correspond to.
  • id - The ID of the entity.
  • owner - Contains details about the owner of the entity that has an error.
  • type - Type of entity. Possible values: LegalEntity, BankAccount, Document.
Annotations
  • @BuiltValue.new()

Constructors

CapabilityProblemEntity([void updates(CapabilityProblemEntityBuilder b)])
factory

Properties

documents → BuiltList<String>?
List of document IDs to which the verification errors related to the capabilities correspond to.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the entity.
no setter
owner → CapabilityProblemEntityRecursive?
Contains details about the owner of the entity that has an error.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CapabilityProblemEntityTypeEnum?
Type of entity. Possible values: LegalEntity, BankAccount, Document.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CapabilityProblemEntityBuilder)) → CapabilityProblemEntity
Rebuilds the instance.
inherited
toBuilder() → CapabilityProblemEntityBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CapabilityProblemEntity>
no setter