CardConfigurationBuilder class

Constructors

CardConfigurationBuilder()

Properties

activation ↔ String?
getter/setter pair
activationUrl ↔ String?
getter/setter pair
bulkAddress ↔ BulkAddressBuilder
getter/setter pair
cardImageId ↔ String?
getter/setter pair
carrier ↔ String?
getter/setter pair
carrierImageId ↔ String?
getter/setter pair
configurationProfileId ↔ String?
getter/setter pair
currency ↔ String?
getter/setter pair
envelope ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
insert ↔ String?
getter/setter pair
language ↔ String?
getter/setter pair
logoImageId ↔ String?
getter/setter pair
pinMailer ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipmentMethod ↔ String?
getter/setter pair

Methods

build() → CardConfiguration
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CardConfiguration other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CardConfigurationBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited