CardOrderItem class abstract

CardOrderItem

Properties:

  • balancePlatform - The unique identifier of the balance platform.
  • card - The status of the card delivery. Possible values: created, rejected, processing, produced, shipped, delivered, notApplicable, unknown.
  • cardOrderItemId - The unique identifier of the card order item.
  • creationDate - The date and time when the event was triggered, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
  • id - The ID of the resource.
  • paymentInstrumentId - The unique identifier of the payment instrument related to the card order item.
  • pin - Contains information about the status of the PIN delivery.
  • shippingMethod - The shipping method used to deliver the card or the PIN.
Annotations
  • @BuiltValue.new()

Constructors

CardOrderItem([void updates(CardOrderItemBuilder b)])
factory

Properties

balancePlatform → String?
The unique identifier of the balance platform.
no setter
card → CardOrderItemDeliveryStatus?
The status of the card delivery. Possible values: created, rejected, processing, produced, shipped, delivered, notApplicable, unknown.
no setter
cardOrderItemId → String?
The unique identifier of the card order item.
no setter
creationDate → DateTime?
The date and time when the event was triggered, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the resource.
no setter
paymentInstrumentId → String?
The unique identifier of the payment instrument related to the card order item.
no setter
pin → CardOrderItemDeliveryStatus?
Contains information about the status of the PIN delivery.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingMethod → String?
The shipping method used to deliver the card or the PIN.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CardOrderItemBuilder)) → CardOrderItem
Rebuilds the instance.
inherited
toBuilder() → CardOrderItemBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CardOrderItem>
no setter