CardOrderItemBuilder class

Constructors

CardOrderItemBuilder()

Properties

balancePlatform ↔ String?
getter/setter pair
card ↔ CardOrderItemDeliveryStatusBuilder
getter/setter pair
cardOrderItemId ↔ String?
getter/setter pair
creationDate ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
paymentInstrumentId ↔ String?
getter/setter pair
pin ↔ CardOrderItemDeliveryStatusBuilder
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingMethod ↔ String?
getter/setter pair

Methods

build() → CardOrderItem
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CardOrderItem other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CardOrderItemBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited