CardOrderItemDeliveryStatus class abstract

CardOrderItemDeliveryStatus

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CardOrderItemDeliveryStatus([void updates(CardOrderItemDeliveryStatusBuilder b)])
factory

Properties

errorMessage → String?
An error message.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → CardOrderItemDeliveryStatusStatusEnum?
The status of the PIN delivery.
no setter
trackingNumber → String?
The tracking number of the PIN delivery.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CardOrderItemDeliveryStatusBuilder)) → CardOrderItemDeliveryStatus
Rebuilds the instance.
inherited
toBuilder() → CardOrderItemDeliveryStatusBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CardOrderItemDeliveryStatus>
no setter