ContactDetails class abstract

ContactDetails

Properties:

  • address - The address of the account holder.
  • email - The email address of the account holder.
  • phone - The phone number of the account holder.
  • webAddress - The URL of the account holder's website.
Annotations
  • @Deprecated('ContactDetails has been deprecated')
  • @BuiltValue.new()

Constructors

ContactDetails([void updates(ContactDetailsBuilder b)])
factory

Properties

address → Address
The address of the account holder.
no setter
email → String
The email address of the account holder.
no setter
hashCode → int
The hash code for this object.
no setterinherited
phone → Phone
The phone number of the account holder.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webAddress → String?
The URL of the account holder's website.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ContactDetailsBuilder)) → ContactDetails
Rebuilds the instance.
inherited
toBuilder() → ContactDetailsBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ContactDetails>
no setter