DeliveryAddress class abstract

DeliveryAddress

Properties:

  • city - The name of the city.
  • country - The two-character ISO-3166-1 alpha-2 country code. For example, US. >If you don't know the country or are not collecting the country from the shopper, provide country as ZZ.
  • line1 - The name of the street. Do not include the number of the building. For example, if the address is Simon Carmiggeltstraat 6-50, provide Simon Carmiggeltstraat.
  • line2 - The number of the building. For example, if the address is Simon Carmiggeltstraat 6-50, provide 6-50.
  • line3 - Additional information about the delivery address.
  • postalCode - The postal code. Maximum length: * 5 digits for an address in the US. * 10 characters for an address in all other countries.
  • stateOrProvince - The state or province code, maximum 3 characters. For example, CA for California in the US or ON for Ontario in Canada. > Required for the US and Canada.
Annotations
  • @BuiltValue.new()

Constructors

DeliveryAddress([void updates(DeliveryAddressBuilder b)])
factory

Properties

city → String?
The name of the city.
no setter
country → String
The two-character ISO-3166-1 alpha-2 country code. For example, US. >If you don't know the country or are not collecting the country from the shopper, provide country as ZZ.
no setter
hashCode → int
The hash code for this object.
no setterinherited
line1 → String?
The name of the street. Do not include the number of the building. For example, if the address is Simon Carmiggeltstraat 6-50, provide Simon Carmiggeltstraat.
no setter
line2 → String?
The number of the building. For example, if the address is Simon Carmiggeltstraat 6-50, provide 6-50.
no setter
line3 → String?
Additional information about the delivery address.
no setter
postalCode → String?
The postal code. Maximum length: * 5 digits for an address in the US. * 10 characters for an address in all other countries.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateOrProvince → String?
The state or province code, maximum 3 characters. For example, CA for California in the US or ON for Ontario in Canada. > Required for the US and Canada.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DeliveryAddressBuilder)) → DeliveryAddress
Rebuilds the instance.
inherited
toBuilder() → DeliveryAddressBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DeliveryAddress>
no setter