Device class abstract

Device

Properties:

  • deviceId - The unique identifier of the device used for provisioning the network token.
  • formFactor - The type of the device used for provisioning the network token. For example, phone, mobile_phone, watch, mobilephone_or_tablet, etc
  • osName - The operating system of the device used for provisioning the network token.
Annotations
  • @BuiltValue.new()

Constructors

Device([void updates(DeviceBuilder b)])
factory

Properties

deviceId → String?
The unique identifier of the device used for provisioning the network token.
no setter
formFactor → String?
The type of the device used for provisioning the network token. For example, phone, mobile_phone, watch, mobilephone_or_tablet, etc
no setter
hashCode → int
The hash code for this object.
no setterinherited
osName → String?
The operating system of the device used for provisioning the network token.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DeviceBuilder)) → Device
Rebuilds the instance.
inherited
toBuilder() → DeviceBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Device>
no setter