Expiry class abstract

Expiry

Properties:

  • month - The month in which the card will expire.
  • year - The year in which the card will expire.
Annotations
  • @BuiltValue.new()

Constructors

Expiry([void updates(ExpiryBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
month → String?
The month in which the card will expire.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
year → String?
The year in which the card will expire.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ExpiryBuilder)) → Expiry
Rebuilds the instance.
inherited
toBuilder() → ExpiryBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Expiry>
no setter