NetworkTokenNotificationDataV2 class abstract

NetworkTokenNotificationDataV2

Properties:

  • authentication - Contains information about the authentication process triggered during token provisioning.
  • authenticationApplied - Specifies whether the authentication process was triggered during token provisioning.
  • balancePlatform - The unique identifier of the balance platform.
  • decision - The decision about the network token provisioning. Possible values: approved, declined, requiresAuthentication.
  • id - The unique identifier of the network token.
  • paymentInstrumentId - The unique identifier of the payment instrument to which the network token is associated.
  • schemeRiskScore - The confidence score of scheme, indicating the degree of risk associated with a token. A high score indicates a high level of risk. A low score indicates a low level of risk. Possible values for visa : 00 to 99, a value of 00 signifies no score was provided by visa
  • status - The status of the network token.
  • tokenLastFour - The last four digits of the network token. Use this value to help your user to identify their network token.
  • tokenRequestor - Contains information about the entity or organization that is requesting the network token.
  • transactionRulesResult - Contains the results of the evaluation of the transaction rules that apply to network token creation.
  • type - The type of network token. Possible values: wallet, cof.
  • validationFacts - The rules used to validate the request for provisioning the network token.
  • wallet - Contains information about the wallet for which the network token is provisioned. Returned only when type is wallet.
Annotations
  • @BuiltValue.new()

Properties

authentication → TokenAuthentication?
Contains information about the authentication process triggered during token provisioning.
no setter
authenticationApplied → bool?
Specifies whether the authentication process was triggered during token provisioning.
no setter
balancePlatform → String?
The unique identifier of the balance platform.
no setter
decision → String?
The decision about the network token provisioning. Possible values: approved, declined, requiresAuthentication.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the network token.
no setter
paymentInstrumentId → String?
The unique identifier of the payment instrument to which the network token is associated.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemeRiskScore → String?
The confidence score of scheme, indicating the degree of risk associated with a token. A high score indicates a high level of risk. A low score indicates a low level of risk. Possible values for visa : 00 to 99, a value of 00 signifies no score was provided by visa
no setter
status → String?
The status of the network token.
no setter
tokenLastFour → String?
The last four digits of the network token. Use this value to help your user to identify their network token.
no setter
tokenRequestor → NetworkTokenRequestor?
Contains information about the entity or organization that is requesting the network token.
no setter
transactionRulesResult → NetworkTokenTransactionRulesResult?
Contains the results of the evaluation of the transaction rules that apply to network token creation.
no setter
type → String?
The type of network token. Possible values: wallet, cof.
no setter
validationFacts → BuiltList<ValidationFacts>?
The rules used to validate the request for provisioning the network token.
no setter
wallet → Wallet?
Contains information about the wallet for which the network token is provisioned. Returned only when type is wallet.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NetworkTokenNotificationDataV2Builder)) → NetworkTokenNotificationDataV2
Rebuilds the instance.
inherited
toBuilder() → NetworkTokenNotificationDataV2Builder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NetworkTokenNotificationDataV2>
no setter