NetworkTokenRiskRuleData class abstract

NetworkTokenRiskRuleData

Properties:

  • description - The description of the transaction rule.
  • id - The unique identifier of the transaction rule.
  • outcomeType - The outcome type of the transaction rule.
  • reference - The reference for the transaction rule.
  • score - The transaction score determined by the rule.
Annotations
  • @BuiltValue.new()

Constructors

NetworkTokenRiskRuleData([void updates(NetworkTokenRiskRuleDataBuilder b)])
factory

Properties

description → String?
The description of the transaction rule.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the transaction rule.
no setter
outcomeType → String?
The outcome type of the transaction rule.
no setter
reference → String?
The reference for the transaction rule.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → int?
The transaction score determined by the rule.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NetworkTokenRiskRuleDataBuilder)) → NetworkTokenRiskRuleData
Rebuilds the instance.
inherited
toBuilder() → NetworkTokenRiskRuleDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NetworkTokenRiskRuleData>
no setter