NetworkTokenTransactionRulesResult class abstract

NetworkTokenTransactionRulesResult

Properties:

  • advice - The advice given by the Risk analysis.
  • allHardBlockRulesPassed - Indicates whether the transaction passed all rules with outcomeType hardBlock.
  • score - The score of the Risk analysis.
  • triggeredTransactionRules - Contains a list of all triggered transaction rules and the corresponding data.
Annotations
  • @BuiltValue.new()

Properties

advice → String?
The advice given by the Risk analysis.
no setter
allHardBlockRulesPassed → bool?
Indicates whether the transaction passed all rules with outcomeType hardBlock.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → int?
The score of the Risk analysis.
no setter
triggeredTransactionRules → BuiltList<NetworkTokenTriggeredRiskRule>?
Contains a list of all triggered transaction rules and the corresponding data.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NetworkTokenTransactionRulesResultBuilder)) → NetworkTokenTransactionRulesResult
Rebuilds the instance.
inherited
toBuilder() → NetworkTokenTransactionRulesResultBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NetworkTokenTransactionRulesResult>
no setter