NetworkTokenTriggeredRiskRule class abstract

NetworkTokenTriggeredRiskRule

Properties:

  • reason - Explains why the transaction rule failed.
  • transactionRule - Contains information about the transaction rule.
  • transactionRuleSource - Contains information about the resource to which the transaction rule applies.
Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → String?
Explains why the transaction rule failed.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionRule → NetworkTokenRiskRuleData?
Contains information about the transaction rule.
no setter
transactionRuleSource → NetworkTokenRiskRuleSource?
Contains information about the resource to which the transaction rule applies.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NetworkTokenTriggeredRiskRuleBuilder)) → NetworkTokenTriggeredRiskRule
Rebuilds the instance.
inherited
toBuilder() → NetworkTokenTriggeredRiskRuleBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NetworkTokenTriggeredRiskRule>
no setter