NetworkTokenTriggeredRiskRuleBuilder class

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionRule ↔ NetworkTokenRiskRuleDataBuilder
getter/setter pair
transactionRuleSource ↔ NetworkTokenRiskRuleSourceBuilder
getter/setter pair

Methods

build() → NetworkTokenTriggeredRiskRule
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(NetworkTokenTriggeredRiskRule other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(NetworkTokenTriggeredRiskRuleBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited