PaymentInstrumentNotificationData class abstract

PaymentInstrumentNotificationData

Properties:

  • balancePlatform - The unique identifier of the balance platform.
  • paymentInstrument - Contains information about the payment instrument resource that triggered the event.
Annotations
  • @BuiltValue.new()

Properties

balancePlatform → String?
The unique identifier of the balance platform.
no setter
hashCode → int
The hash code for this object.
no setterinherited
paymentInstrument → PaymentInstrument?
Contains information about the payment instrument resource that triggered the event.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PaymentInstrumentNotificationDataBuilder)) → PaymentInstrumentNotificationData
Rebuilds the instance.
inherited
toBuilder() → PaymentInstrumentNotificationDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PaymentInstrumentNotificationData>
no setter