PhoneNumber class abstract

PhoneNumber

Properties:

  • phoneCountryCode - The two-character ISO-3166-1 alpha-2 country code of the phone number. For example, US or NL.
  • phoneNumber - The phone number. The inclusion of the phone number country code is not necessary.
  • phoneType - The type of the phone number. Possible values: Landline, Mobile, SIP, Fax.
Annotations
  • @BuiltValue.new()

Constructors

PhoneNumber([void updates(PhoneNumberBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
phoneCountryCode → String?
The two-character ISO-3166-1 alpha-2 country code of the phone number. For example, US or NL.
no setter
phoneNumber → String?
The phone number. The inclusion of the phone number country code is not necessary.
no setter
phoneType → PhoneNumberPhoneTypeEnum?
The type of the phone number. Possible values: Landline, Mobile, SIP, Fax.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PhoneNumberBuilder)) → PhoneNumber
Rebuilds the instance.
inherited
toBuilder() → PhoneNumberBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PhoneNumber>
no setter