Resource class abstract

Resource

Properties:

  • balancePlatform - The unique identifier of the balance platform.
  • creationDate - The date and time when the event was triggered, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
  • id - The ID of the resource.
Annotations
  • @BuiltValue.new()

Constructors

Resource([void updates(ResourceBuilder b)])
factory

Properties

balancePlatform → String?
The unique identifier of the balance platform.
no setter
creationDate → DateTime?
The date and time when the event was triggered, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the resource.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ResourceBuilder)) → Resource
Rebuilds the instance.
inherited
toBuilder() → ResourceBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Resource>
no setter