ResourceReference class abstract

ResourceReference

Properties:

  • description - The description of the resource.
  • id - The unique identifier of the resource.
  • reference - The reference for the resource.
Annotations
  • @BuiltValue.new()

Constructors

ResourceReference([void updates(ResourceReferenceBuilder b)])
factory

Properties

description → String?
The description of the resource.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the resource.
no setter
reference → String?
The reference for the resource.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ResourceReferenceBuilder)) → ResourceReference
Rebuilds the instance.
inherited
toBuilder() → ResourceReferenceBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ResourceReference>
no setter