SweepConfigurationNotificationData class abstract

SweepConfigurationNotificationData

Properties:

  • accountId - The unique identifier of the balance account for which the sweep was configured.
  • balancePlatform - The unique identifier of the balance platform.
  • sweep - Contains information about the sweep resource that triggered the event.
Annotations
  • @BuiltValue.new()

Properties

accountId → String?
The unique identifier of the balance account for which the sweep was configured.
no setter
balancePlatform → String?
The unique identifier of the balance platform.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sweep → SweepConfigurationV2?
Contains information about the sweep resource that triggered the event.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SweepConfigurationNotificationDataBuilder)) → SweepConfigurationNotificationData
Rebuilds the instance.
inherited
toBuilder() → SweepConfigurationNotificationDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SweepConfigurationNotificationData>
no setter