ValidationFacts class abstract

ValidationFacts

Properties:

  • reasons - The reason for the result of the validations. This field is only sent for validationFacts.type walletValidation, when validationFacts.result is invalid.
  • result - The evaluation result of the validation facts. Possible values: valid, invalid, notValidated, notApplicable.
  • type - The type of the validation fact.
Annotations
  • @BuiltValue.new()

Constructors

ValidationFacts([void updates(ValidationFactsBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
reasons → BuiltList<String>?
The reason for the result of the validations. This field is only sent for validationFacts.type walletValidation, when validationFacts.result is invalid.
no setter
result → ValidationFactsResultEnum?
The evaluation result of the validation facts. Possible values: valid, invalid, notValidated, notApplicable.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
The type of the validation fact.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ValidationFactsBuilder)) → ValidationFacts
Rebuilds the instance.
inherited
toBuilder() → ValidationFactsBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ValidationFacts>
no setter