VerificationDeadline class abstract

VerificationDeadline

Properties:

  • capabilities - The names of the capabilities to be disallowed.
  • entityIds - The unique identifiers of the bank account(s) that the deadline applies to
  • expiresAt - The date that verification is due by before capabilities are disallowed.
Annotations
  • @BuiltValue.new()

Constructors

VerificationDeadline([void updates(VerificationDeadlineBuilder b)])
factory

Properties

capabilities → BuiltList<VerificationDeadlineCapabilitiesEnum>
The names of the capabilities to be disallowed.
no setter
entityIds → BuiltList<String>?
The unique identifiers of the bank account(s) that the deadline applies to
no setter
expiresAt → DateTime
The date that verification is due by before capabilities are disallowed.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(VerificationDeadlineBuilder)) → VerificationDeadline
Rebuilds the instance.
inherited
toBuilder() → VerificationDeadlineBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<VerificationDeadline>
no setter