VerificationError class abstract

VerificationError

Properties:

  • capabilities - Contains the capabilities that the verification error applies to.
  • code - The verification error code.
  • message - A description of the error.
  • remediatingActions - Contains the actions that you can take to resolve the verification error.
  • subErrors - Contains more granular information about the verification error.
  • type - The type of error. Possible values: * invalidInput * dataMissing * pendingStatus * dataReview
Annotations
  • @BuiltValue.new()

Constructors

VerificationError([void updates(VerificationErrorBuilder b)])
factory

Properties

capabilities → BuiltList<VerificationErrorCapabilitiesEnum>?
Contains the capabilities that the verification error applies to.
no setter
code → String?
The verification error code.
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?
A description of the error.
no setter
remediatingActions → BuiltList<RemediatingAction>?
Contains the actions that you can take to resolve the verification error.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subErrors → BuiltList<VerificationErrorRecursive>?
Contains more granular information about the verification error.
no setter
type → VerificationErrorTypeEnum?
The type of error. Possible values: * invalidInput * dataMissing * pendingStatus * dataReview
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(VerificationErrorBuilder)) → VerificationError
Rebuilds the instance.
inherited
toBuilder() → VerificationErrorBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<VerificationError>
no setter