AchNotificationOfChangeNotificationRequest class abstract

AchNotificationOfChangeNotificationRequest

Properties:

  • createdAt - Timestamp for when the webhook was created.
  • data - Contains details of the update.
  • environment - The environment from which the webhook originated. Possible values: test, live.
  • type - Type of notification.
  • version - The version of this webhook type.
Annotations
  • @BuiltValue.new()

Properties

createdAt → DateTime
Timestamp for when the webhook was created.
no setter
data → AchNotificationOfChangeNotificationRequestData?
Contains details of the update.
no setter
environment → String?
The environment from which the webhook originated. Possible values: test, live.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Type of notification.
no setter
version → String?
The version of this webhook type.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AchNotificationOfChangeNotificationRequestBuilder)) → AchNotificationOfChangeNotificationRequest
Rebuilds the instance.
inherited
toBuilder() → AchNotificationOfChangeNotificationRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AchNotificationOfChangeNotificationRequest>
no setter