AchNotificationOfChangeNotificationRequestBuilder class

Properties

createdAt ↔ DateTime?
getter/setter pair
data ↔ AchNotificationOfChangeNotificationRequestDataBuilder
getter/setter pair
environment ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
getter/setter pair
version ↔ String?
getter/setter pair

Methods

build() → AchNotificationOfChangeNotificationRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(AchNotificationOfChangeNotificationRequest other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(AchNotificationOfChangeNotificationRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited