AchNotificationOfChangeNotificationRequestData class abstract

AchNotificationOfChangeNotificationRequestData

Properties:

Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
notificationOfChange → AchNotificationOfChangeNotificationRequestDataNoc
The Notification of Change information.
no setter
pspReference → String
PSP Reference.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperReference → String
Shopper reference.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AchNotificationOfChangeNotificationRequestDataBuilder)) → AchNotificationOfChangeNotificationRequestData
Rebuilds the instance.
inherited
toBuilder() → AchNotificationOfChangeNotificationRequestDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AchNotificationOfChangeNotificationRequestData>
no setter