AchNotificationOfChangeNotificationRequestDataNocNewBankAccountTypeEnum class

Inheritance
  • Object
  • EnumClass
  • AchNotificationOfChangeNotificationRequestDataNocNewBankAccountTypeEnum

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

checking → const AchNotificationOfChangeNotificationRequestDataNocNewBankAccountTypeEnum
New bank account type. Possible values: * Savings * Checking
savings → const AchNotificationOfChangeNotificationRequestDataNocNewBankAccountTypeEnum
New bank account type. Possible values: * Savings * Checking
unknownDefaultOpenApi → const AchNotificationOfChangeNotificationRequestDataNocNewBankAccountTypeEnum
New bank account type. Possible values: * Savings * Checking