AuthorisationAdjustmentNotificationRequestItemRecursiveBuilder class

Properties

additionalData ↔ AuthorisationAdjustmentAdditionalDataBuilder
getter/setter pair
amount ↔ AmountBuilder
getter/setter pair
eventCode ↔ AuthorisationAdjustmentNotificationRequestItemRecursiveEventCodeEnum?
getter/setter pair
eventDate ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merchantAccountCode ↔ String?
getter/setter pair
merchantReference ↔ String?
getter/setter pair
originalReference ↔ String?
getter/setter pair
paymentMethod ↔ String?
getter/setter pair
pspReference ↔ String?
getter/setter pair
reason ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success ↔ String?
getter/setter pair

Methods

build() → AuthorisationAdjustmentNotificationRequestItemRecursive
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(AuthorisationAdjustmentNotificationRequestItemRecursive other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(AuthorisationAdjustmentNotificationRequestItemRecursiveBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited