AuthorisationNotificationAdditionalData class abstract

AuthorisationNotificationAdditionalData

Properties:

Annotations
  • @BuiltValue.new()

Properties

accountValidation → String?
no setter
acquirerAccountCode → String?
The acquirer account code.
no setter
acquirerCode → String?
The acquirer code.
no setter
acquirerReference → String?
The acquirer reference.
no setter
acquirerResponseCode → String?
no setter
acsRenderingTypePeriodAcsInterface → String?
no setter
acsRenderingTypePeriodAcsUiTemplate → String?
no setter
adjustAuthorisationData → String?
no setter
airlinePeriodLessThanNameGreaterThan → String?
Information related to airlines.
no setter
alias → String?
Alias for this card.
no setter
aliasType → String?
Alias type.
no setter
allow3DS2 → String?
no setter
antfinancialospPeriodTimestamp → String?
no setter
applicationinfoPeriodLessThanNameGreaterThan → String?
Shopper device application info in a dynamic format.
no setter
arn → String?
Acquirer Reference Number of the dispute.
no setter
authCode → String?
no setter
authDateTime → String?
no setter
authenticationType → String?
3DS authentication type
no setter
authorisationMid → String?
Authorisation MID of the acquirer.
no setter
authorisedAmountCurrency → String?
The currency authorised for a dynamic zero auth request.
no setter
authorisedAmountValue → String?
The amount authorised for a dynamic zero auth request.
no setter
avsResult → String?
Address Verification Service result.
no setter
avsResultRaw → String?
Address Verification Service result raw.
no setter
bankAccountNumber → String?
The bank account number.
no setter
bankAccountPeriodIban → String?
no setter
bankAccountPeriodOwnerName → String?
no setter
bankLocation → String?
The bank location.
no setter
bankLocationId → String?
The bank location ID.
no setter
bankName → String?
The bank name.
no setter
bankSummary → String?
no setter
bankVerificationResult → String?
The bank verification result.
no setter
bankVerificationResultRaw → String?
The bank verification result raw.
no setter
bic → String?
Business Identifier Code.
no setter
billingAddressPeriodCity → String?
no setter
billingAddressPeriodCountry → String?
no setter
billingAddressPeriodHouseNumberOrName → String?
no setter
billingAddressPeriodPostalCode → String?
no setter
billingAddressPeriodStateOrProvince → String?
no setter
billingAddressPeriodStreet → String?
no setter
binRangeId → String?
no setter
bookingDate → String?
no setter
browserCode → String?
Browser code.
no setter
captureDelayHours → String?
The amount of delay after authorisation.
no setter
captureMerchantReference → String?
The merchant reference of the capture.
no setter
capturePspReference → String?
The PSP reference of the capture.
no setter
cardBin → String?
Card Bank Identification number.
no setter
cardFunction → String?
no setter
cardIssuerCountryId → String?
no setter
cardIssuingBank → String?
Card issuing bank.
no setter
cardIssuingCountry → String?
Card issuing country.
no setter
cardIssuingCurrency → String?
Card issuing currency.
no setter
cardPaymentMethod → String?
Card payment method.
no setter
cardProductId → String?
The card product identifier for the card used in the transaction.
no setter
cardSchemeEnhancedDataLevel → String?
Card scheme enhanced data level.
no setter
cardSummary → String?
Card summary
no setter
cavv → String?
Secure Cardholder Authentication Verification Value.
no setter
cavvAlgorithm → String?
CAVV algorithm.
no setter
challengeCancel → String?
Information about the 3DS challenge being canceled.
no setter
checkoutSessionId → String?
no setter
coBrandedWith → String?
no setter
countryCode → String?
no setter
currentBalanceCurrency → String?
no setter
currentBalanceValue → String?
no setter
cvcResult → String?
Card Verification Code result.
no setter
cvcResultRaw → String?
Card Verification Code result raw.
no setter
deliveryAddressPeriodCity → String?
no setter
deliveryAddressPeriodCountry → String?
no setter
deliveryAddressPeriodHouseNumberOrName → String?
no setter
deliveryAddressPeriodPostalCode → String?
Delivery address: postal code.
no setter
deliveryAddressPeriodStateOrProvince → String?
no setter
deliveryAddressPeriodStreet → String?
no setter
deviceType → String?
Type of device the request was made from.
no setter
directdebitGBPeriodDateOfSignature → String?
Direct debit GB: date of signature.
no setter
directdebitGBPeriodMandateId → String?
Direct debit GB: mandate ID.
no setter
directdebitGBPeriodSequenceType → String?
Direct debit GB: sequence type.
no setter
directdebitGBPeriodServiceUserName → String?
Direct debit GB: service user name.
no setter
directdebitGBPeriodServiceUserNumber → String?
Direct debit GB: service user number.
no setter
domesticRefusalReasonRaw → String?
no setter
domesticShopperAdvice → String?
no setter
dsTransID → String?
no setter
eci → String?
3DS: Electronic Commerce Indicator.
no setter
expiryDate → String?
Expiry date of the card.
no setter
extraCostsCurrency → String?
Additional cost used in BIN or card verification.
no setter
extraCostsValue → String?
Related additional cost value.
no setter
extraCostsValueGratuity → String?
Gratuity related additional cost value.
no setter
extraCostsValueSurcharge → String?
Surcharge related additional cost value.
no setter
fraudCheckLessThanCheckIDGreaterThanLessThanNameGreaterThan → String?
Information on the fraud check in a dynamic format.
no setter
fraudManualReview → String?
Indicates if the risk check was done manually.
no setter
fraudOffset → String?
The fraud offset.
no setter
fraudResultType → String?
Result type of the fraud check.
no setter
fraudRiskLevel → AuthorisationNotificationAdditionalDataFraudRiskLevelEnum?
The risk level of the transaction as classified by the machine learning fraud risk rule. The risk level indicates the likelihood that a transaction will result in a fraudulent dispute. Possible values: * veryLow * low * medium * high * veryHigh
no setter
fundingSource → String?
Funding source.
no setter
fundsAvailability → String?
no setter
goPayPeriodGopayAccountId → String?
A GoPay shopper's wallet ID. Used by merchant for Risk and Fraud checks.
no setter
grossCurrency → String?
Chargeback gross currency.
no setter
grossValue → String?
Chargeback gross value.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hmacSignature → String?
no setter
iban → String?
International Bank Account Number.
no setter
iDealConsumerAccountNumber → String?
Only included for iDeal payments.
no setter
iDealConsumerBIC → String?
Only included for iDeal payments.
no setter
iDealConsumerCity → String?
Only included for iDeal payments.
no setter
iDealConsumerIBAN → String?
Only included for iDeal payments.
no setter
iDealConsumerIban → String?
Only included for iDeal payments.
no setter
iDealConsumerName → String?
Only included for iDeal payments.
no setter
iDealTransactionId → String?
Only included for iDeal payments.
no setter
inferredRefusalReason → String?
no setter
installmentsPeriodValue → String?
no setter
interactionCounter → String?
3DS interaction counter.
no setter
isCardCommercial → String?
Indicates if the card is used for business purposes only.
no setter
issuerBin → String?
no setter
issuerCommentsPeriodCardholderName → String?
Card holder name.
no setter
issuerConcentratorName → String?
no setter
issuerCountry → String?
Country of the card issuer.
no setter
latestCardPeriodBin → String?
no setter
latestCardPeriodExpiryDate → String?
no setter
latestCardPeriodSummary → String?
no setter
liabilityShift → String?
Risk liability shift.
no setter
mcBankNetReferenceNumber → String?
no setter
mcFinancialNetworkCode → String?
no setter
merchantAdviceCode → String?
no setter
merchantIntegrationPeriodType → String?
no setter
merchantIntegrationPeriodVersion → String?
no setter
merchantOrderReference → String?
no setter
merchantReference → String?
no setter
metadata → BuiltMap<String, String>?
A set of key-value pairs provided in the request, prefixed with 'metadata.'. For example, 'metadata.myField: myValue'
no setter
modifiedShopperReference → String?
no setter
networkTokenPeriodAvailable → String?
no setter
networkTokenPeriodBin → String?
no setter
networkTokenPeriodTokenSummary → String?
no setter
networkTxReference → String?
no setter
nfcPeriodExpire → String?
NFC related.
no setter
nfcPeriodIssue → String?
NFC related.
no setter
nfcPeriodPinPeriodProvided → String?
NFC related.
no setter
nfcPeriodUid → String?
NFC related.
no setter
oneyRawResponse → String?
no setter
opiPeriodTransToken → String?
The transaction token to be used in your Oracle Opera integration.
no setter
ownerCity → String?
Owner city.
no setter
ownerName → String?
Owner name.
no setter
paymentAccountReference → String?
no setter
paymentLinkId → String?
ID of the Checkout payment link.
no setter
paymentMethod → String?
no setter
paymentMethodVariant → String?
no setter
payoutEligible → String?
no setter
paypalAddressStatus → String?
Related to PayPal.
no setter
paypalBillingName → String?
Related to PayPal.
no setter
paypalEmail → String?
The buyer's PayPal account email address. Example: paypaltest@adyen.com
no setter
paypalErrorCode → String?
Related to PayPal.
no setter
paypalErrorDescription → String?
Related to PayPal.
no setter
paypalPairingId → String?
Related to PayPal.
no setter
paypalPayerId → String?
The buyer's PayPal ID. Example: LF5HCWWBRV2KL
no setter
paypalPayerResidenceCountry → String?
The buyer's country of residence. Example: NL
no setter
paypalPayerStatus → String?
The status of the buyer's PayPal account. Example: unverified
no setter
paypalPhone → String?
Related to PayPal.
no setter
paypalProtectionEligibility → String?
The eligibility for PayPal Seller Protection for this payment. Example: Ineligible
no setter
paypalRisk → String?
Related to PayPal.
no setter
payULatamTrazabilityCode → String?
Related to PayU in LATAM.
no setter
platform → String?
no setter
realtimeAccountUpdaterStatus → String?
Real time Account Update status.
no setter
receiptPeriodRetrievalReferenceNumber → String?
no setter
receiptPeriodSystemTraceAuditNumber → String?
no setter
recurringPeriodContractTypes → String?
no setter
recurringPeriodFirstPspReference → String?
no setter
recurringPeriodRecurringDetailReference → String?
The new tokenization.storedPaymentMethodId field replaces this field. The recurringDetailReference returned in the /payments response when you stored the shopper's payment details.
no setter
recurringPeriodShopperReference → String?
The new tokenization.shopperReferencefield replaces this field. The shopper reference you set when you made the request to store the shopper's payment details.
no setter
recurringProcessingModel → String?
The recurring processing model the request was flagged with.
no setter
redirectUrl → String?
no setter
referred → String?
If the payment is referred, this field is set to true. This field is unavailable if the payment is referred and is usually not returned with ecommerce transactions. Example: true
no setter
refusalReasonRaw → String?
Raw refusal reason received from the acquirer, where available. Example: AUTHORISED
no setter
retryPeriodRescueScheduled → String?
Indicates if an auto rescue for a payment is scheduled.
no setter
returnUrl → String?
no setter
riskdataPeriodLessThanNameGreaterThan → String?
Risk data in a dynamic format.
no setter
riskExperimentReference → String?
no setter
riskProfile → String?
Related to Risk.
no setter
riskProfileReference → String?
Related to Risk.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaExemptionRequested → String?
no setter
sepadirectdebitPeriodDateOfSignature → String?
no setter
sepadirectdebitPeriodMandateId → String?
no setter
sepadirectdebitPeriodSequenceType → String?
no setter
shopperCountry → String?
Country of the shopper.
no setter
shopperEmail → String?
Email of the shopper.
no setter
shopperInteraction → String?
The shopper interaction type of the payment request. Example: Ecommerce
no setter
shopperIP → String?
IP of the shopper.
no setter
shopperLocale → String?
The locale of the shopper.
no setter
shopperName → String?
no setter
shopperReference → String?
no setter
shopperSocialSecurityNumber → String?
The social security number of the shopper.
no setter
shopperStatement → String?
The text to be shown on the shopper's bank statement.
no setter
shopperTelephone → String?
The telephone number of the shopper.
no setter
store → String?
Identifier of the store processing the transaction.
no setter
swishPeriodPayerAlias → String?
A Swish shopper's telephone number.
no setter
tenderReference → String?
Tender reference. For point-of-sale integrations only.
no setter
terminalId → String?
Terminal ID. For point-of-sale integrations only.
no setter
threeDAuthenticated → String?
A Boolean value indicating whether 3DS authentication was completed on this payment. Example: true
no setter
threeDAuthenticatedResponse → String?
The raw 3DS authentication result from the card issuer. Example: N
no setter
threeDOffered → String?
A Boolean value indicating whether 3DS was offered for this payment. Example: true
no setter
threeDOfferedResponse → String?
The raw enrollment result from the 3DS directory services of the card schemes. Example: Y
no setter
threeDSVersion → String?
The 3D Secure 2 version.
no setter
tokenizationPeriodShopperReference → String?
The reference for the shopper that you sent when tokenizing the payment details.
no setter
tokenizationPeriodStoredPaymentMethodId → String?
The reference that uniquely identifies tokenized payment details.
no setter
tokenizationPeriodStorePeriodOperationType → AuthorisationNotificationAdditionalDataTokenizationPeriodStorePeriodOperationTypeEnum?
The operation performed on the token. Possible values: * created: the token has been created. * updated: the existing token has been updated. * alreadyExisting: the details have already been stored.
no setter
tokenTxVariant → String?
Payment method variant of the token/wallet payment method.
no setter
totalFraudScore → String?
Total fraud score from risk.
no setter
transactionId → String?
no setter
txScreeningPeriodAppliedRule → String?
no setter
txScreeningPeriodCheckSum → String?
no setter
txScreeningPeriodResolution → String?
no setter
untokenisedCardSummary → String?
Card summary without tokenization.
no setter
visaTransactionId → String?
no setter
xid → String?
The 3DS transaction ID of the 3DS session sent in notifications. The value is Base64-encoded and is returned for transactions with directoryResponse 'N' or 'Y'. Example: ODgxNDc2MDg2MDExODk5MAAAAAA=
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AuthorisationNotificationAdditionalDataBuilder)) → AuthorisationNotificationAdditionalData
Rebuilds the instance.
inherited
toBuilder() → AuthorisationNotificationAdditionalDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AuthorisationNotificationAdditionalData>
no setter