AuthorisationNotificationRequestItemWrapperBuilder class

Properties

hashCode → int
The hash code for this object.
no setterinherited
notificationRequestItem ↔ AuthorisationNotificationRequestItemBuilder
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → AuthorisationNotificationRequestItemWrapper
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(AuthorisationNotificationRequestItemWrapper other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(AuthorisationNotificationRequestItemWrapperBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited