AutoRescueAdditionalData class abstract

Annotations
  • @BuiltValue.new()

Constructors

AutoRescueAdditionalData([void updates(AutoRescueAdditionalDataBuilder b)])
factory

Properties

bookingDate → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hmacSignature → String?
no setter
merchantOrderReference → String?
no setter
paymentMethodVariant → String?
no setter
retryPeriodRescueReference → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AutoRescueAdditionalDataBuilder)) → AutoRescueAdditionalData
Rebuilds the instance.
inherited
toBuilder() → AutoRescueAdditionalDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AutoRescueAdditionalData>
no setter