CancelOrRefundAdditionalData class abstract

Annotations
  • @BuiltValue.new()

Constructors

CancelOrRefundAdditionalData([void updates(CancelOrRefundAdditionalDataBuilder b)])
factory

Properties

acquirerErrorCode → String?
no setter
acquirerErrorDescription → String?
no setter
acquirerReference → String?
no setter
acsRenderingTypePeriodAcsInterface → String?
no setter
acsRenderingTypePeriodAcsUiTemplate → String?
no setter
arn → String?
no setter
authCode → String?
no setter
authenticationType → String?
no setter
bookingDate → String?
no setter
checkoutSessionId → String?
no setter
coBrandedWith → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hmacSignature → String?
no setter
interactionCounter → String?
no setter
merchantOrderReference → String?
no setter
modificationPeriodAction → String?
no setter
originalMerchantReference → String?
no setter
paymentLinkId → String?
no setter
paymentMethodVariant → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperCountry → String?
no setter
store → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CancelOrRefundAdditionalDataBuilder)) → CancelOrRefundAdditionalData
Rebuilds the instance.
inherited
toBuilder() → CancelOrRefundAdditionalDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CancelOrRefundAdditionalData>
no setter