CancelOrRefundNotificationRequestItemWrapper class abstract

CancelOrRefundNotificationRequestItemWrapper

Properties:

Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
notificationRequestItem → CancelOrRefundNotificationRequestItem?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CancelOrRefundNotificationRequestItemWrapperBuilder)) → CancelOrRefundNotificationRequestItemWrapper
Rebuilds the instance.
inherited
toBuilder() → CancelOrRefundNotificationRequestItemWrapperBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CancelOrRefundNotificationRequestItemWrapper>
no setter