CancellationAdditionalData class abstract

CancellationAdditionalData

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CancellationAdditionalData([void updates(CancellationAdditionalDataBuilder b)])
factory

Properties

accountValidation → String?
no setter
acquirerAccountCode → String?
no setter
acquirerCode → String?
no setter
acquirerReference → String?
no setter
acsRenderingTypePeriodAcsInterface → String?
no setter
acsRenderingTypePeriodAcsUiTemplate → String?
no setter
alias → String?
no setter
aliasType → String?
no setter
arn → String?
no setter
authCode → String?
no setter
authenticationType → String?
no setter
authorisationMid → String?
no setter
avsResult → String?
no setter
avsResultRaw → String?
no setter
bankAccountNumber → String?
no setter
bankLocationId → String?
no setter
bankName → String?
no setter
bic → String?
no setter
billingAddressPeriodCity → String?
no setter
billingAddressPeriodCountry → String?
no setter
billingAddressPeriodHouseNumberOrName → String?
no setter
billingAddressPeriodPostalCode → String?
no setter
billingAddressPeriodStateOrProvince → String?
no setter
billingAddressPeriodStreet → String?
no setter
bookingDate → String?
no setter
cardBin → String?
no setter
cardHolderName → String?
no setter
cardIssuingBank → String?
no setter
cardIssuingCountry → String?
no setter
cardIssuingCurrency → String?
no setter
cardPaymentMethod → String?
no setter
cardSchemeEnhancedDataLevel → String?
no setter
cardSummary → String?
no setter
cavv → String?
no setter
cavvAlgorithm → String?
no setter
checkoutSessionId → String?
no setter
coBrandedWith → String?
no setter
countryCode → String?
no setter
cvcResult → String?
no setter
cvcResultRaw → String?
no setter
deliveryAddressPeriodCity → String?
no setter
deliveryAddressPeriodCountry → String?
no setter
deliveryAddressPeriodHouseNumberOrName → String?
no setter
deliveryAddressPeriodStateOrProvince → String?
no setter
deliveryAddressPeriodStreet → String?
no setter
eci → String?
no setter
expiryDate → String?
no setter
fraudCheckLessThanCheckIDGreaterThanLessThanNameGreaterThan → String?
Information on the fraud check in a dynamic format.
no setter
fraudManualReview → String?
Indicates if the risk check was done manually.
no setter
fraudOffset → String?
The fraud offset.
no setter
fraudResultType → String?
Result type of the fraud check.
no setter
fraudRiskLevel → CancellationAdditionalDataFraudRiskLevelEnum?
The risk level of the transaction as classified by the machine learning fraud risk rule. The risk level indicates the likelihood that a transaction will result in a fraudulent dispute. Possible values: * veryLow * low * medium * high * veryHigh
no setter
hashCode → int
The hash code for this object.
no setterinherited
hmacSignature → String?
no setter
interactionCounter → String?
no setter
merchantOrderReference → String?
no setter
paymentAccountReference → String?
no setter
paymentLinkId → String?
no setter
paymentMethodVariant → String?
no setter
riskdataPeriodLessThanNameGreaterThan → String?
Risk data in a dynamic format.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperCountry → String?
no setter
shopperSocialSecurityNumber → String?
no setter
store → String?
no setter
totalFraudScore → String?
Total fraud score from risk.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CancellationAdditionalDataBuilder)) → CancellationAdditionalData
Rebuilds the instance.
inherited
toBuilder() → CancellationAdditionalDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CancellationAdditionalData>
no setter