CancellationNotificationRequestItem class abstract

CancellationNotificationRequestItem

Properties:

  • additionalData - This object is a generic container that can hold extra fields.
  • amount - The payment amount. For HTTP POST notifications, currency and value are returned as URL parameters.
  • eventCode - The type of event the notification item is for.
  • eventDate - The time when the event was generated. Format: ISO 8601; yyyy-MM-DDThh:mm:ssTZD
  • merchantAccountCode - The merchant account identifier used in the transaction the notification item is for.
  • merchantReference - Your reference to uniquely identify the payment.
  • originalReference - For modifications, this field corresponds to the payment request assigned to the original payment.
  • paymentMethod - The payment method used in the transaction.
  • pspReference - Adyen's 16-character unique reference associated with the transaction or request. This value is globally unique. Use it when communicating with us about this request.
  • reason - If success = false, then this includes a short message with an explanation for the refusal.
  • success - Informs about the outcome of the event (eventCode) the notification is for. If true: the event was executed successfully. If false: the event was not executed successfully.
Annotations
  • @BuiltValue.new()

Properties

additionalData → CancellationAdditionalData?
This object is a generic container that can hold extra fields.
no setter
amount → Amount
The payment amount. For HTTP POST notifications, currency and value are returned as URL parameters.
no setter
eventCode → CancellationNotificationRequestItemEventCodeEnum
The type of event the notification item is for.
no setter
eventDate → DateTime
The time when the event was generated. Format: ISO 8601; yyyy-MM-DDThh:mm:ssTZD
no setter
hashCode → int
The hash code for this object.
no setterinherited
merchantAccountCode → String
The merchant account identifier used in the transaction the notification item is for.
no setter
merchantReference → String
Your reference to uniquely identify the payment.
no setter
originalReference → String?
For modifications, this field corresponds to the payment request assigned to the original payment.
no setter
paymentMethod → String?
The payment method used in the transaction.
no setter
pspReference → String
Adyen's 16-character unique reference associated with the transaction or request. This value is globally unique. Use it when communicating with us about this request.
no setter
reason → String?
If success = false, then this includes a short message with an explanation for the refusal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → String
Informs about the outcome of the event (eventCode) the notification is for. If true: the event was executed successfully. If false: the event was not executed successfully.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CancellationNotificationRequestItemBuilder)) → CancellationNotificationRequestItem
Rebuilds the instance.
inherited
toBuilder() → CancellationNotificationRequestItemBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CancellationNotificationRequestItem>
no setter