DirectDebitNoticeOfChangeNotificationRequest class abstract

DirectDebitNoticeOfChangeNotificationRequest

Properties:

  • createdAt - The timestamp indicating when the webhook was created.
  • data - Contains the details of the bank account update.
  • environment - The environment from which the webhook originated.
  • type - The type of notification.
  • version - The version of this webhook type.
Annotations
  • @BuiltValue.new()

Properties

createdAt → DateTime
The timestamp indicating when the webhook was created.
no setter
data → DirectDebitNotificationOfChangeNotificationRequestData?
Contains the details of the bank account update.
no setter
environment → DirectDebitNoticeOfChangeNotificationRequestEnvironmentEnum?
The environment from which the webhook originated.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DirectDebitNoticeOfChangeNotificationRequestTypeEnum
The type of notification.
no setter
version → String?
The version of this webhook type.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DirectDebitNoticeOfChangeNotificationRequestBuilder)) → DirectDebitNoticeOfChangeNotificationRequest
Rebuilds the instance.
inherited
toBuilder() → DirectDebitNoticeOfChangeNotificationRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DirectDebitNoticeOfChangeNotificationRequest>
no setter