DirectDebitNoticeOfChangeNotificationRequestBuilder class

Properties

createdAt ↔ DateTime?
getter/setter pair
data ↔ DirectDebitNotificationOfChangeNotificationRequestDataBuilder
getter/setter pair
environment ↔ DirectDebitNoticeOfChangeNotificationRequestEnvironmentEnum?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ DirectDebitNoticeOfChangeNotificationRequestTypeEnum?
getter/setter pair
version ↔ String?
getter/setter pair

Methods

build() → DirectDebitNoticeOfChangeNotificationRequest
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(DirectDebitNoticeOfChangeNotificationRequest other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(DirectDebitNoticeOfChangeNotificationRequestBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited