DirectDebitNoticeOfChangeNotificationRequestDataNoc class abstract

DirectDebitNoticeOfChangeNotificationRequestDataNoc

Properties:

  • newBankAccountNumber - The corrected bank account number provided by the receiving bank.
  • newBankAccountType - The corrected bank account type provided by the receiving bank. This field is specific to ACH Direct Debit transactions. Possible values: * Savings * Checking
  • newBankLocationId - The corrected bank location ID provided by the receiving bank. This field is specific to EFT PAD transactions.
  • newBranchCode - The corrected bank routing number provided by the receiving bank. This field is specific to ACH Direct Debit transactions.
  • reasonCode - A standard code from the ACH network that specifies the reason for a Notice of Change (e.g., an incorrect account number). This field is specific to ACH Direct Debit transactions. Possible values: * C01 : Incorrect bank account number. * C02 : Incorrect transit/routing number. * C03 : Incorrect transit/routing number and bank account number. * C04 : Bank account name change. * C05 : Incorrect payment code. * C06 : Incorrect bank account number and transit code. * C07 : Incorrect transit/routing number, bank account number and payment code. * C09 : Incorrect individual ID number. * C10 : Incorrect company name. * C11 : Incorrect company identification. * C12 : Incorrect company name and company ID.
Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
newBankAccountNumber → String?
The corrected bank account number provided by the receiving bank.
no setter
newBankAccountType → DirectDebitNoticeOfChangeNotificationRequestDataNocNewBankAccountTypeEnum?
The corrected bank account type provided by the receiving bank. This field is specific to ACH Direct Debit transactions. Possible values: * Savings * Checking
no setter
newBankLocationId → String?
The corrected bank location ID provided by the receiving bank. This field is specific to EFT PAD transactions.
no setter
newBranchCode → String?
The corrected bank routing number provided by the receiving bank. This field is specific to ACH Direct Debit transactions.
no setter
reasonCode → DirectDebitNoticeOfChangeNotificationRequestDataNocReasonCodeEnum?
A standard code from the ACH network that specifies the reason for a Notice of Change (e.g., an incorrect account number). This field is specific to ACH Direct Debit transactions. Possible values: * C01 : Incorrect bank account number. * C02 : Incorrect transit/routing number. * C03 : Incorrect transit/routing number and bank account number. * C04 : Bank account name change. * C05 : Incorrect payment code. * C06 : Incorrect bank account number and transit code. * C07 : Incorrect transit/routing number, bank account number and payment code. * C09 : Incorrect individual ID number. * C10 : Incorrect company name. * C11 : Incorrect company identification. * C12 : Incorrect company name and company ID.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DirectDebitNoticeOfChangeNotificationRequestDataNocBuilder)) → DirectDebitNoticeOfChangeNotificationRequestDataNoc
Rebuilds the instance.
inherited
toBuilder() → DirectDebitNoticeOfChangeNotificationRequestDataNocBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DirectDebitNoticeOfChangeNotificationRequestDataNoc>
no setter