DisputesNotificationAdditionalData class abstract

DisputesNotificationAdditionalData

Properties:

Annotations
  • @BuiltValue.new()

Properties

arn → String?
Acquirer Reference Number of the dispute.
no setter
autoDefended → String?
Indicates if the dispute was automatically defended.
no setter
captureMerchantReference → String?
The merchant reference of the capture.
no setter
capturePspReference → String?
The PSP reference of the capture.
no setter
chargebackReasonCode → String?
The reason code for the chargeback.
no setter
chargebackSchemeCode → String?
The card scheme for the chargeback.
no setter
defendable → String?
Indicates if you can defend the dispute.
no setter
defensePeriodEndsAt → String?
When the defense period ends. Format: ISO 8601 format with time zone offset: YYYY-MM-DDThh:mm:ss+TZD, for example, 2020-12-18T10:15:30+01:00.
no setter
disputeStatus → DisputesNotificationAdditionalDataDisputeStatusEnum?
More information about the stage the dispute is in. This parameter is not returned for disputed payments processed in Brazil.
no setter
grossCurrency → String?
Chargeback gross currency.
no setter
grossValue → String?
Chargeback gross value.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hmacSignature → String?
no setter
invoiceCreditorAccount → String?
no setter
modificationMerchantReferences → String?
no setter
nofReasonCode → String?
The reason code for the Notification of Fraud (NOF).
no setter
nofSchemeCode → String?
The card scheme for the Notification of Fraud (NOF).
no setter
paymentMethodVariant → String?
The Adyen sub-variant of the payment method used for the payment request.
no setter
rfiReasonCode → String?
The reason code for the Request for Information (RFI).
no setter
rfiSchemeCode → String?
The card scheme for the Request for Information (RFI).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperReference → String?
The ID that uniquely identifies the shopper. This is the same as the shopperReference used in the initial payment.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DisputesNotificationAdditionalDataBuilder)) → DisputesNotificationAdditionalData
Rebuilds the instance.
inherited
toBuilder() → DisputesNotificationAdditionalDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DisputesNotificationAdditionalData>
no setter