PayoutAdditionalData class abstract

Annotations
  • @BuiltValue.new()

Constructors

PayoutAdditionalData([void updates(PayoutAdditionalDataBuilder b)])
factory

Properties

authCode → String?
no setter
bookingDate → String?
no setter
cardBin → String?
no setter
cardHolderName → String?
no setter
cardSummary → String?
no setter
expiryDate → String?
no setter
fundingSource → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hmacSignature → String?
no setter
paymentMethodVariant → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PayoutAdditionalDataBuilder)) → PayoutAdditionalData
Rebuilds the instance.
inherited
toBuilder() → PayoutAdditionalDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PayoutAdditionalData>
no setter