RecurringContractNotificationAdditionalData class abstract

RecurringContractNotificationAdditionalData

Properties:

Annotations
  • @BuiltValue.new()

Properties

acquirerAccountCode → String?
The acquirer account code.
no setter
acquirerCode → String?
The acquirer code.
no setter
acquirerReference → String?
The acquirer reference.
no setter
acsRenderingTypePeriodAcsInterface → String?
ACS interface. Related to 3DS.
no setter
acsRenderingTypePeriodAcsUiTemplate → String?
ACS UI template.
no setter
alias → String?
Alias for this card.
no setter
aliasType → String?
Alias type.
no setter
arn → String?
Acquirer Reference Number of the dispute.
no setter
authCode → String?
Authcode of the scheme.
no setter
authenticationType → String?
3DS authentication type
no setter
authorisationMid → String?
Authorisation MID of the acquirer.
no setter
authorisedAmountCurrency → String?
The currency authorised for a dynamic zero auth request.
no setter
authorisedAmountValue → String?
The amount authorised for a dynamic zero auth request.
no setter
avsResult → String?
Address Verification Service result.
no setter
avsResultRaw → String?
Address Verification Service result raw.
no setter
bankAccountNumber → String?
The bank account number.
no setter
bankLocation → String?
The bank location.
no setter
bankLocationId → String?
The bank location ID.
no setter
bankName → String?
The bank name.
no setter
bankVerificationResult → String?
The bank verification result.
no setter
bankVerificationResultRaw → String?
The bank verification result raw.
no setter
bic → String?
Business Identifier Code.
no setter
billingAddressPeriodCity → String?
BillingAddress: county.
no setter
billingAddressPeriodHouseNumberOrName → String?
BillingAddress: house number or name.
no setter
billingAddressPeriodPostalCode → String?
BillingAddress: postal code.
no setter
billingAddressPeriodStateOrProvince → String?
BillingAddress: state or province
no setter
billingAddressPeriodStreet → String?
BillingAddress: street
no setter
browserCode → String?
Browser code.
no setter
captureDelayHours → String?
The amount of delay after authorisation.
no setter
captureMerchantReference → String?
The merchant reference of the capture.
no setter
capturePspReference → String?
The PSP reference of the capture.
no setter
cardBin → String?
Card Bank Identification number.
no setter
cardIssuingBank → String?
Card issuing bank.
no setter
cardIssuingCountry → String?
Card issuing country.
no setter
cardIssuingCurrency → String?
Card issuing currency.
no setter
cardPaymentMethod → String?
Card payment method.
no setter
cardSchemeEnhancedDataLevel → String?
Card scheme enhanced data level.
no setter
cardSummary → String?
Card summary
no setter
cavv → String?
Secure Cardholder Authentication Verification Value.
no setter
cavvAlgorithm → String?
CAVV algorithm.
no setter
challengeCancel → String?
Information about the 3DS challenge being canceled.
no setter
checkoutSessionId → String?
ID of the Checkout Session.
no setter
cvcResult → String?
Card Verification Code result.
no setter
cvcResultRaw → String?
Card Verification Code result raw.
no setter
deliveryAddressPeriodCity → String?
Delivery address: city.
no setter
deliveryAddressPeriodCountry → String?
Delivery address: country.
no setter
deliveryAddressPeriodHouseNumberOrName → String?
Delivery address: house number or name.
no setter
deliveryAddressPeriodPostalCode → String?
Delivery address: postal code.
no setter
deliveryAddressPeriodStateOrProvince → String?
Delivery address: state or province.
no setter
deliveryAddressPeriodStreet → String?
Delivery address: street.
no setter
deviceType → String?
Type of device the request was made from.
no setter
directdebitGBPeriodDateOfSignature → String?
Direct debit GB: date of signature.
no setter
directdebitGBPeriodMandateId → String?
Direct debit GB: mandate ID.
no setter
directdebitGBPeriodSequenceType → String?
Direct debit GB: sequence type.
no setter
directdebitGBPeriodServiceUserName → String?
Direct debit GB: service user name.
no setter
directdebitGBPeriodServiceUserNumber → String?
Direct debit GB: service user number.
no setter
eci → String?
3DS: Electronic Commerce Indicator.
no setter
expiryDate → String?
Expiry date of the card.
no setter
extraCostsCurrency → String?
Additional cost used in BIN or card verification.
no setter
extraCostsValue → String?
Related additional cost value.
no setter
extraCostsValueGratuity → String?
Gratuity related additional cost value.
no setter
extraCostsValueSurcharge → String?
Surcharge related additional cost value.
no setter
fraudCheckLessThanCheckIDGreaterThanLessThanNameGreaterThan → String?
Information on the fraud check in a dynamic format.
no setter
fraudManualReview → String?
Indicates if the risk check was done manually.
no setter
fraudOffset → String?
The fraud offset.
no setter
fraudResultType → String?
Result type of the fraud check.
no setter
fraudRiskLevel → RecurringContractNotificationAdditionalDataFraudRiskLevelEnum?
The risk level of the transaction as classified by the machine learning fraud risk rule. The risk level indicates the likelihood that a transaction will result in a fraudulent dispute. Possible values: * veryLow * low * medium * high * veryHigh
no setter
fundingSource → String?
Funding source.
no setter
goPayPeriodGopayAccountId → String?
A GoPay shopper's wallet ID. Used by merchant for Risk and Fraud checks.
no setter
grossCurrency → String?
Chargeback gross currency.
no setter
grossValue → String?
Chargeback gross value.
no setter
hashCode → int
The hash code for this object.
no setterinherited
iban → String?
International Bank Account Number.
no setter
installmentsPeriodValue → String?
The number of installments that the payment amount should be charged with. Example: 5 > Only relevant for card payments in countries that support installments.
no setter
interactionCounter → String?
3DS interaction counter.
no setter
issuerCommentsPeriodCardholderName → String?
Card holder name.
no setter
issuerCountry → String?
Country of the card issuer.
no setter
latestCardPeriodBin → String?
Recurring: Latest card BIN.
no setter
latestCardPeriodExpiryDate → String?
Recurring: Latest card expiry date.
no setter
latestCardPeriodSummary → String?
Recurring: Latest card summary.
no setter
liabilityShift → String?
Risk liability shift.
no setter
metadata → BuiltMap<String, String>?
A set of key-value pairs provided in the request, prefixed with 'metadata.'. For example, 'metadata.myField: myValue'
no setter
networkTokenPeriodAvailable → String?
Recurring related.
no setter
networkTokenPeriodBin → String?
Recurring related.
no setter
networkTokenPeriodTokenSummary → String?
Recurring related.
no setter
nfcPeriodExpire → String?
NFC related.
no setter
nfcPeriodIssue → String?
NFC related.
no setter
nfcPeriodPinPeriodProvided → String?
NFC related.
no setter
nfcPeriodUid → String?
NFC related.
no setter
opiPeriodTransToken → String?
Trans token related to Oracle Opera.
no setter
ownerCity → String?
Owner city.
no setter
ownerName → String?
Owner name.
no setter
paymentAccountReference → String?
Reference of the payment account.
no setter
paymentLinkId → String?
ID of the Checkout payment link.
no setter
payULatamTrazabilityCode → String?
Related to PayU in LATAM.
no setter
realtimeAccountUpdaterStatus → String?
Real time Account Update status.
no setter
recurringPeriodContractTypes → String?
Recurring contract types.
no setter
recurringPeriodFirstPspReference → String?
Recurring first PSP reference.
no setter
recurringPeriodRecurringDetailReference → String?
The token for stored payment details to make recurring payments.
no setter
referred → String?
If the payment is referred, this field is set to true. This field is unavailable if the payment is referred and is usually not returned with ecommerce transactions. Example: true
no setter
refusalReasonRaw → String?
Raw refusal reason received from the acquirer, where available. Example: AUTHORISED
no setter
retryPeriodRescueScheduled → String?
Indicates if an auto rescue for a payment is scheduled.
no setter
riskProfile → String?
Related to Risk.
no setter
riskProfileReference → String?
Related to Risk.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperCountry → String?
Country of the shopper.
no setter
shopperEmail → String?
Email of the shopper.
no setter
shopperInteraction → String?
The shopper interaction type of the payment request. Example: Ecommerce
no setter
shopperIP → String?
IP of the shopper.
no setter
shopperLocale → String?
The locale of the shopper.
no setter
shopperReference → String?
The ID that uniquely identifies the shopper. The shopperReference is the same as the shopperReference used in the initial payment.
no setter
shopperSocialSecurityNumber → String?
The social security number of the shopper.
no setter
shopperStatement → String?
The text to be shown on the shopper's bank statement.
no setter
shopperTelephone → String?
The telephone number of the shopper.
no setter
store → String?
Identifier of the store processing the transaction.
no setter
tenderReference → String?
Tender reference. For point-of-sale integrations only.
no setter
terminalId → String?
Terminal ID. For point-of-sale integrations only.
no setter
threeDAuthenticated → String?
A Boolean value indicating whether 3DS authentication was completed on this payment. Example: true
no setter
threeDAuthenticatedResponse → String?
The raw 3DS authentication result from the card issuer. Example: N
no setter
threeDOffered → String?
A Boolean value indicating whether 3DS was offered for this payment. Example: true
no setter
threeDOfferedResponse → String?
The raw enrollment result from the 3DS directory services of the card schemes. Example: Y
no setter
threeDSVersion → String?
The 3D Secure 2 version.
no setter
tokenTxVariant → String?
Payment method variant of the token/wallet payment method.
no setter
totalFraudScore → String?
Total fraud score from risk.
no setter
untokenisedCardSummary → String?
Card summary without tokenization.
no setter
xid → String?
The 3DS transaction ID of the 3DS session sent in notifications. The value is Base64-encoded and is returned for transactions with directoryResponse 'N' or 'Y'. Example: ODgxNDc2MDg2MDExODk5MAAAAAA=
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RecurringContractNotificationAdditionalDataBuilder)) → RecurringContractNotificationAdditionalData
Rebuilds the instance.
inherited
toBuilder() → RecurringContractNotificationAdditionalDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RecurringContractNotificationAdditionalData>
no setter