RecurringContractNotificationRequest class abstract

RecurringContractNotificationRequest

Properties:

  • live - Informs about the origin of the notification. The value is true when originating from the live environment, false for the test environment.
  • notificationItems - A container object for the details included in the notification.
Annotations
  • @BuiltValue.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
live → String?
Informs about the origin of the notification. The value is true when originating from the live environment, false for the test environment.
no setter
notificationItems → BuiltList<RecurringContractNotificationRequestItemWrapper>?
A container object for the details included in the notification.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RecurringContractNotificationRequestBuilder)) → RecurringContractNotificationRequest
Rebuilds the instance.
inherited
toBuilder() → RecurringContractNotificationRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RecurringContractNotificationRequest>
no setter