RefundFailedAdditionalData class abstract

Annotations
  • @BuiltValue.new()

Constructors

RefundFailedAdditionalData([void updates(RefundFailedAdditionalDataBuilder b)])
factory

Properties

acquirerErrorCode → String?
no setter
bookingDate → String?
no setter
coBrandedWith → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hmacSignature → String?
no setter
paymentMethodVariant → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperCountry → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RefundFailedAdditionalDataBuilder)) → RefundFailedAdditionalData
Rebuilds the instance.
inherited
toBuilder() → RefundFailedAdditionalDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RefundFailedAdditionalData>
no setter