RefundWithDataAdditionalData class abstract

Annotations
  • @BuiltValue.new()

Constructors

RefundWithDataAdditionalData([void updates(RefundWithDataAdditionalDataBuilder b)])
factory

Properties

acquirerAccountCode → String?
no setter
acquirerCode → String?
no setter
acquirerReference → String?
no setter
acsRenderingTypePeriodAcsInterface → String?
no setter
acsRenderingTypePeriodAcsUiTemplate → String?
no setter
alias → String?
no setter
aliasType → String?
no setter
arn → String?
no setter
authCode → String?
no setter
authenticationType → String?
no setter
authorisationMid → String?
no setter
avsResult → String?
no setter
bookingDate → String?
no setter
cardBin → String?
no setter
cardHolderName → String?
no setter
cardIssuingBank → String?
no setter
cardIssuingCountry → String?
no setter
cardIssuingCurrency → String?
no setter
cardPaymentMethod → String?
no setter
cardSummary → String?
no setter
cavv → String?
no setter
cavvAlgorithm → String?
no setter
checkoutSessionId → String?
no setter
coBrandedWith → String?
no setter
cvcResult → String?
no setter
eci → String?
no setter
expiryDate → String?
no setter
fundingSource → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hmacSignature → String?
no setter
interactionCounter → String?
no setter
isCardCommercial → String?
no setter
issuerCountry → String?
no setter
liabilityShift → String?
no setter
merchantOrderReference → String?
no setter
paymentAccountReference → String?
no setter
paymentLinkId → String?
no setter
paymentMethodVariant → String?
no setter
refusalReasonRaw → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopperCountry → String?
no setter
shopperInteraction → String?
no setter
shopperIP → String?
no setter
store → String?
no setter
tenderReference → String?
no setter
terminalId → String?
no setter
threeDAuthenticated → String?
no setter
threeDAuthenticatedResponse → String?
no setter
threeDOffered → String?
no setter
threeDOfferedResponse → String?
no setter
xid → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RefundWithDataAdditionalDataBuilder)) → RefundWithDataAdditionalData
Rebuilds the instance.
inherited
toBuilder() → RefundWithDataAdditionalDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RefundWithDataAdditionalData>
no setter