ReportAvailableNotificationRequestItemRecursive class abstract

ReportAvailableNotificationRequestItemRecursive

Properties:

  • additionalData - This object is a generic container that can hold extra fields.
  • amount - The payment amount. For HTTP POST notifications, currency and value are returned as URL parameters.
  • eventCode - The type of event the notification item is for.
  • eventDate - The time when the event was generated. Format: ISO 8601; yyyy-MM-DDThh:mm:ssTZD
  • merchantAccountCode - The merchant account identifier used in the transaction the notification item is for.
  • merchantReference - Your reference to uniquely identify the payment.
  • originalReference - For modifications, this field corresponds to the payment request assigned to the original payment.
  • paymentMethod - The payment method used in the transaction.
  • pspReference - Contains the file name of the report.
  • reason - Contains the download URL where you can obtain a copy of the report.
  • success - Always true.
Annotations
  • @BuiltValue.new()

Properties

additionalData → ReportAdditionalData?
This object is a generic container that can hold extra fields.
no setter
amount → Amount
The payment amount. For HTTP POST notifications, currency and value are returned as URL parameters.
no setter
eventCode → ReportAvailableNotificationRequestItemRecursiveEventCodeEnum
The type of event the notification item is for.
no setter
eventDate → DateTime
The time when the event was generated. Format: ISO 8601; yyyy-MM-DDThh:mm:ssTZD
no setter
hashCode → int
The hash code for this object.
no setterinherited
merchantAccountCode → String
The merchant account identifier used in the transaction the notification item is for.
no setter
merchantReference → String
Your reference to uniquely identify the payment.
no setter
originalReference → String?
For modifications, this field corresponds to the payment request assigned to the original payment.
no setter
paymentMethod → String?
The payment method used in the transaction.
no setter
pspReference → String
Contains the file name of the report.
no setter
reason → String
Contains the download URL where you can obtain a copy of the report.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → String
Always true.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReportAvailableNotificationRequestItemRecursiveBuilder)) → ReportAvailableNotificationRequestItemRecursive
Rebuilds the instance.
inherited
toBuilder() → ReportAvailableNotificationRequestItemRecursiveBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReportAvailableNotificationRequestItemRecursive>
no setter