content property
- @BuiltValueField.new(wireName: r'content')
Details of the liable account with funds under threshold.
Implementation
@BuiltValueField(wireName: r'content')
AccountFundsBelowThresholdNotificationContent? get content;
Details of the liable account with funds under threshold.
@BuiltValueField(wireName: r'content')
AccountFundsBelowThresholdNotificationContent? get content;