balanceDate property
The date of the funds were found to be below threshold.
Implementation
@BuiltValueField(wireName: r'balanceDate')
LocalDate? get balanceDate;
The date of the funds were found to be below threshold.
@BuiltValueField(wireName: r'balanceDate')
LocalDate? get balanceDate;