payoutMethods property
Array of tokenized card details associated with the account holder. For details about how you can use the tokens to pay out, refer to Pay out to cards.
Implementation
@BuiltValueField(wireName: r'payoutMethods')
BuiltList<PayoutMethod>? get payoutMethods;