storeDetails property
Array of stores associated with the account holder. Required when onboarding account holders that have an Adyen point of sale.
Implementation
@BuiltValueField(wireName: r'storeDetails')
BuiltList<StoreDetail>? get storeDetails;
Array of stores associated with the account holder. Required when onboarding account holders that have an Adyen point of sale.
@BuiltValueField(wireName: r'storeDetails')
BuiltList<StoreDetail>? get storeDetails;