accountCode property
The code of the account from which the payout was made.
Implementation
@BuiltValueField(wireName: r'accountCode')
String? get accountCode;
The code of the account from which the payout was made.
@BuiltValueField(wireName: r'accountCode')
String? get accountCode;