bankAccountDetail property
Details of the Bank Account to which the payout was made.
Implementation
@BuiltValueField(wireName: r'bankAccountDetail')
BankAccountDetail? get bankAccountDetail;
Details of the Bank Account to which the payout was made.
@BuiltValueField(wireName: r'bankAccountDetail')
BankAccountDetail? get bankAccountDetail;