payoutAccountCountry property
The country code of the bank from which the payout was initiated.
Implementation
@BuiltValueField(wireName: r'payoutAccountCountry')
String? get payoutAccountCountry;
The country code of the bank from which the payout was initiated.
@BuiltValueField(wireName: r'payoutAccountCountry')
String? get payoutAccountCountry;