payoutAccountNumber property
The account number of the bank from which the payout was initiated.
Implementation
@BuiltValueField(wireName: r'payoutAccountNumber')
String? get payoutAccountNumber;
The account number of the bank from which the payout was initiated.
@BuiltValueField(wireName: r'payoutAccountNumber')
String? get payoutAccountNumber;