payoutBalanceAccountId property
The balance account id to which payment was made
Implementation
@BuiltValueField(wireName: r'payoutBalanceAccountId')
String? get payoutBalanceAccountId;
The balance account id to which payment was made
@BuiltValueField(wireName: r'payoutBalanceAccountId')
String? get payoutBalanceAccountId;