payoutBankName property
The name of the bank the payout from which the payout was initiated.
Implementation
@BuiltValueField(wireName: r'payoutBankName')
String? get payoutBankName;
The name of the bank the payout from which the payout was initiated.
@BuiltValueField(wireName: r'payoutBankName')
String? get payoutBankName;