payoutBranchCode property
The branch code of the bank from which the payout was initiated.
Implementation
@BuiltValueField(wireName: r'payoutBranchCode')
String? get payoutBranchCode;
The branch code of the bank from which the payout was initiated.
@BuiltValueField(wireName: r'payoutBranchCode')
String? get payoutBranchCode;