AccountHolderPayoutNotificationContentPayoutSpeedEnum class

Inheritance
  • Object
  • EnumClass
  • AccountHolderPayoutNotificationContentPayoutSpeedEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

INSTANT → const AccountHolderPayoutNotificationContentPayoutSpeedEnum
Speed with which payouts for this account are processed. Permitted values: STANDARD, SAME_DAY.
SAME_DAY → const AccountHolderPayoutNotificationContentPayoutSpeedEnum
Speed with which payouts for this account are processed. Permitted values: STANDARD, SAME_DAY.
STANDARD → const AccountHolderPayoutNotificationContentPayoutSpeedEnum
Speed with which payouts for this account are processed. Permitted values: STANDARD, SAME_DAY.
unknownDefaultOpenApi → const AccountHolderPayoutNotificationContentPayoutSpeedEnum
Speed with which payouts for this account are processed. Permitted values: STANDARD, SAME_DAY.