AccountHolderStatus class abstract

AccountHolderStatus

Properties:

  • events - A list of events scheduled for the account holder.
  • payoutState - The payout state of the account holder.
  • processingState - The processing state of the account holder.
  • status - The status of the account holder. >Permitted values: Active, Inactive, Suspended, Closed.
  • statusReason - The reason why the status was assigned to the account holder.
Annotations
  • @BuiltValue.new()

Constructors

AccountHolderStatus([void updates(AccountHolderStatusBuilder b)])
factory

Properties

events → BuiltList<AccountEvent>?
A list of events scheduled for the account holder.
no setter
hashCode int
The hash code for this object.
no setterinherited
payoutState AccountPayoutState?
The payout state of the account holder.
no setter
processingState AccountProcessingState?
The processing state of the account holder.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AccountHolderStatusStatusEnum
The status of the account holder. >Permitted values: Active, Inactive, Suspended, Closed.
no setter
statusReason String?
The reason why the status was assigned to the account holder.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AccountHolderStatusBuilder)) AccountHolderStatus
Rebuilds the instance.
inherited
toBuilder() AccountHolderStatusBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AccountHolderStatus>
no setter