statusReason property
The reason why the status was assigned to the account holder.
Implementation
@BuiltValueField(wireName: r'statusReason')
String? get statusReason;
The reason why the status was assigned to the account holder.
@BuiltValueField(wireName: r'statusReason')
String? get statusReason;