AccountHolderStatusBuilder class

Properties

events ↔ ListBuilder<AccountEvent>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
payoutState AccountPayoutStateBuilder
getter/setter pair
processingState AccountProcessingStateBuilder
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AccountHolderStatusStatusEnum?
getter/setter pair
statusReason String?
getter/setter pair

Methods

build() AccountHolderStatus
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(AccountHolderStatus other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(AccountHolderStatusBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited