invalidFields property
In case the store status has not been updated, contains fields that did not pass the validation.
Implementation
@BuiltValueField(wireName: r'invalidFields')
BuiltList<ErrorFieldType>? get invalidFields;
In case the store status has not been updated, contains fields that did not pass the validation.
@BuiltValueField(wireName: r'invalidFields')
BuiltList<ErrorFieldType>? get invalidFields;