accountHolderCode property
The code of the account holder whom the event refers to.
Implementation
@BuiltValueField(wireName: r'accountHolderCode')
String? get accountHolderCode;
The code of the account holder whom the event refers to.
@BuiltValueField(wireName: r'accountHolderCode')
String? get accountHolderCode;