event property
- @BuiltValueField.new(wireName: r'event')
The event name that will be trigger if no action is taken.
Implementation
@BuiltValueField(wireName: r'event')
AccountHolderUpcomingDeadlineNotificationContentEventEnum? get event;
The event name that will be trigger if no action is taken.
@BuiltValueField(wireName: r'event')
AccountHolderUpcomingDeadlineNotificationContentEventEnum? get event;