AccountHolderUpcomingDeadlineNotificationContentEventEnum class

Inheritance
  • Object
  • EnumClass
  • AccountHolderUpcomingDeadlineNotificationContentEventEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accessPii → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
apiTierUpdate → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
closeAccount → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
closeStores → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
deleteBalanceAccounts → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
deleteBankAccounts → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
deleteLegalArrangements → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
deleteLiableBankAccount → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
deletePayoutMethods → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
deleteShareholders → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
deleteShareholdersNoKyc → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
deleteSignatories → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
deleteUnusedAccount → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
inactivateAccount → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
kYCDeadlineExtension → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
migrateAccountToBP → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
recalculateAccountStatusAndProcessingTier → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
refundNotPaidOutTransfers → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
resolveEvents → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
saveAccountHolder → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
saveKYCCheckStatus → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
suspendAccount → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
unknownDefaultOpenApi → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
unSuspendAccount → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
updateAccountHolderState → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.
verification → const AccountHolderUpcomingDeadlineNotificationContentEventEnum
The event name that will be trigger if no action is taken.