payoutMethodCode property
The unique code of the payout method that has been verified.
Implementation
@BuiltValueField(wireName: r'payoutMethodCode')
String? get payoutMethodCode;
The unique code of the payout method that has been verified.
@BuiltValueField(wireName: r'payoutMethodCode')
String? get payoutMethodCode;