signatoryCode property
The code of the signatory that has been verified.
Implementation
@BuiltValueField(wireName: r'signatoryCode')
String? get signatoryCode;
The code of the signatory that has been verified.
@BuiltValueField(wireName: r'signatoryCode')
String? get signatoryCode;