notAllowedReason property

  1. @BuiltValueField.new(wireName: r'notAllowedReason')
String? get notAllowedReason

The reason why payouts (to all of the account holder's accounts) have been disabled (by Adyen). If payouts have been disabled by Adyen, this field will explain why. If this field is blank, payouts have not been disabled by Adyen.

Implementation

@BuiltValueField(wireName: r'notAllowedReason')
String? get notAllowedReason;