ownerCity property
The city of residence of the bank account owner. >Refer to Required information for details on field requirements.
Implementation
@BuiltValueField(wireName: r'ownerCity')
String? get ownerCity;
The city of residence of the bank account owner. >Refer to Required information for details on field requirements.
@BuiltValueField(wireName: r'ownerCity')
String? get ownerCity;