ownerNationality property
The country code of the country of nationality of the bank account owner. >The permitted country codes are defined in ISO-3166-1 alpha-2 (e.g. 'NL'). >Refer to Required information for details on field requirements.
Implementation
@BuiltValueField(wireName: r'ownerNationality')
String? get ownerNationality;