transferDate property
The date on which the beneficiary was set up and funds transferred from benefactor to beneficiary.
Implementation
@BuiltValueField(wireName: r'transferDate')
DateTime? get transferDate;
The date on which the beneficiary was set up and funds transferred from benefactor to beneficiary.
@BuiltValueField(wireName: r'transferDate')
DateTime? get transferDate;