BusinessDetails class abstract

BusinessDetails

Properties:

  • doingBusinessAs - The registered name of the company (if it differs from the legal name of the company).
  • legalBusinessName - The legal name of the company.
  • listedUltimateParentCompany - Information about the parent public company. Required if the account holder is 100% owned by a publicly listed company.
  • registrationNumber - The registration number of the company.
  • shareholders - Array containing information about individuals associated with the account holder either through ownership or control. For details about how you can identify them, refer to our verification guide.
  • signatories - Signatories associated with the company. Each array entry should represent one signatory.
  • stockExchange - Market Identifier Code (MIC).
  • stockNumber - International Securities Identification Number (ISIN).
  • stockTicker - Stock Ticker symbol.
  • taxId - The tax ID of the company.
Annotations
  • @BuiltValue.new()

Constructors

BusinessDetails([void updates(BusinessDetailsBuilder b)])
factory

Properties

doingBusinessAs String?
The registered name of the company (if it differs from the legal name of the company).
no setter
hashCode int
The hash code for this object.
no setterinherited
legalBusinessName String?
The legal name of the company.
no setter
listedUltimateParentCompany → BuiltList<UltimateParentCompany>?
Information about the parent public company. Required if the account holder is 100% owned by a publicly listed company.
no setter
registrationNumber String?
The registration number of the company.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareholders → BuiltList<ShareholderContact>?
Array containing information about individuals associated with the account holder either through ownership or control. For details about how you can identify them, refer to our verification guide.
no setter
signatories → BuiltList<SignatoryContact>?
Signatories associated with the company. Each array entry should represent one signatory.
no setter
stockExchange String?
Market Identifier Code (MIC).
no setter
stockNumber String?
International Securities Identification Number (ISIN).
no setter
stockTicker String?
Stock Ticker symbol.
no setter
taxId String?
The tax ID of the company.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BusinessDetailsBuilder)) BusinessDetails
Rebuilds the instance.
inherited
toBuilder() BusinessDetailsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BusinessDetails>
no setter