doingBusinessAs property
The registered name of the company (if it differs from the legal name of the company).
Implementation
@BuiltValueField(wireName: r'doingBusinessAs')
String? get doingBusinessAs;
The registered name of the company (if it differs from the legal name of the company).
@BuiltValueField(wireName: r'doingBusinessAs')
String? get doingBusinessAs;