shareholders property
Array containing information about individuals associated with the account holder either through ownership or control. For details about how you can identify them, refer to our verification guide.
Implementation
@BuiltValueField(wireName: r'shareholders')
BuiltList<ShareholderContact>? get shareholders;