BusinessDetailsBuilder class

Constructors

BusinessDetailsBuilder()

Properties

doingBusinessAs String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
legalBusinessName String?
getter/setter pair
listedUltimateParentCompany ↔ ListBuilder<UltimateParentCompany>
getter/setter pair
registrationNumber String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareholders ↔ ListBuilder<ShareholderContact>
getter/setter pair
signatories ↔ ListBuilder<SignatoryContact>
getter/setter pair
stockExchange String?
getter/setter pair
stockNumber String?
getter/setter pair
stockTicker String?
getter/setter pair
taxId String?
getter/setter pair

Methods

build() BusinessDetails
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(BusinessDetails other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(BusinessDetailsBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited