legalEntity property
- @BuiltValueField.new(wireName: r'legalEntity')
The type of legal entity of the new account holder.
Implementation
@BuiltValueField(wireName: r'legalEntity')
CreateAccountHolderResponseLegalEntityEnum? get legalEntity;
The type of legal entity of the new account holder.
@BuiltValueField(wireName: r'legalEntity')
CreateAccountHolderResponseLegalEntityEnum? get legalEntity;