payoutSchedule property
The details of the payout schedule added to the account.
Implementation
@BuiltValueField(wireName: r'payoutSchedule')
PayoutScheduleResponse? get payoutSchedule;
The details of the payout schedule added to the account.
@BuiltValueField(wireName: r'payoutSchedule')
PayoutScheduleResponse? get payoutSchedule;