KYCCheckResult class abstract

KYCCheckResult

Properties:

  • checks - A list of the checks and their statuses.
Annotations
  • @BuiltValue.new()

Constructors

KYCCheckResult([void updates(KYCCheckResultBuilder b)])
factory

Properties

checks → BuiltList<KYCCheckStatusData>?
A list of the checks and their statuses.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(KYCCheckResultBuilder)) KYCCheckResult
Rebuilds the instance.
inherited
toBuilder() KYCCheckResultBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<KYCCheckResult>
no setter