KYCCheckStatusDataBuilder class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requiredFields
↔ ListBuilder<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ KYCCheckStatusDataStatusEnum?
-
getter/setter pair
- summary ↔ KYCCheckSummaryBuilder
-
getter/setter pair
- type ↔ KYCCheckStatusDataTypeEnum?
-
getter/setter pair
Methods
-
build(
) → KYCCheckStatusData -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
KYCCheckStatusData other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(KYCCheckStatusDataBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited