KYCLegalArrangementEntityCheckResult class abstract

KYCLegalArrangementEntityCheckResult

Properties:

Annotations
  • @BuiltValue.new()

Properties

checks → BuiltList<KYCCheckStatusData>?
A list of the checks and their statuses.
no setter
hashCode int
The hash code for this object.
no setterinherited
legalArrangementCode String?
The unique ID of the legal arrangement to which the entity belongs.
no setter
legalArrangementEntityCode String?
The unique ID of the legal arrangement entity to which the check applies.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(KYCLegalArrangementEntityCheckResultBuilder)) KYCLegalArrangementEntityCheckResult
Rebuilds the instance.
inherited
toBuilder() KYCLegalArrangementEntityCheckResultBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<KYCLegalArrangementEntityCheckResult>
no setter