shareholderCode property
The code of the shareholder to which the check applies.
Implementation
@BuiltValueField(wireName: r'shareholderCode')
String? get shareholderCode;
The code of the shareholder to which the check applies.
@BuiltValueField(wireName: r'shareholderCode')
String? get shareholderCode;