KYCUltimateParentCompanyCheckResult class abstract

KYCUltimateParentCompanyCheckResult

Properties:

Annotations
  • @BuiltValue.new()

Properties

checks → BuiltList<KYCCheckStatusData>?
A list of the checks and their statuses.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ultimateParentCompanyCode String?
The code of the Ultimate Parent Company to which the check applies.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(KYCUltimateParentCompanyCheckResultBuilder)) KYCUltimateParentCompanyCheckResult
Rebuilds the instance.
inherited
toBuilder() KYCUltimateParentCompanyCheckResultBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<KYCUltimateParentCompanyCheckResult>
no setter