ultimateParentCompanyCode property
The code of the Ultimate Parent Company to which the check applies.
Implementation
@BuiltValueField(wireName: r'ultimateParentCompanyCode')
String? get ultimateParentCompanyCode;
The code of the Ultimate Parent Company to which the check applies.
@BuiltValueField(wireName: r'ultimateParentCompanyCode')
String? get ultimateParentCompanyCode;