accountHolder property
The results of the checks on the account holder.
Implementation
@BuiltValueField(wireName: r'accountHolder')
KYCCheckResult? get accountHolder;
The results of the checks on the account holder.
@BuiltValueField(wireName: r'accountHolder')
KYCCheckResult? get accountHolder;