payoutMethods property
- @BuiltValueField.new(wireName: r'payoutMethods')
The results of the checks on the payout methods.
Implementation
@BuiltValueField(wireName: r'payoutMethods')
BuiltList<KYCPayoutMethodCheckResult>? get payoutMethods;
The results of the checks on the payout methods.
@BuiltValueField(wireName: r'payoutMethods')
BuiltList<KYCPayoutMethodCheckResult>? get payoutMethods;