KYCVerificationResultBuilder class
Constructors
Properties
- accountHolder ↔ KYCCheckResultBuilder
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
legalArrangements
↔ ListBuilder<
KYCLegalArrangementCheckResult> -
getter/setter pair
-
legalArrangementsEntities
↔ ListBuilder<
KYCLegalArrangementEntityCheckResult> -
getter/setter pair
-
payoutMethods
↔ ListBuilder<
KYCPayoutMethodCheckResult> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
getter/setter pair
-
signatories
↔ ListBuilder<
KYCSignatoryCheckResult> -
getter/setter pair
-
ultimateParentCompany
↔ ListBuilder<
KYCUltimateParentCompanyCheckResult> -
getter/setter pair
Methods
-
build(
) → KYCVerificationResult -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
KYCVerificationResult other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(KYCVerificationResultBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited