LegalArrangementDetail class abstract

LegalArrangementDetail

Properties:

  • address - The address of the legal arrangement.
  • legalArrangementCode - Adyen-generated unique alphanumeric identifier (UUID) for the entry, returned in the response when you create a legal arrangement. Use only when updating an account holder. If you include this field when creating an account holder, the request will fail.
  • legalArrangementEntities - An array containing information about other entities that are part of the legal arrangement.
  • legalArrangementReference - Your reference for the legal arrangement. Must be between 3 to 128 characters.
  • legalForm - The form of legal arrangement. Required if type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
  • name_ - The legal name of the legal arrangement. Minimum length: 3 characters.
  • registrationNumber - The registration number of the legal arrangement.
  • taxNumber - The tax identification number of the legal arrangement.
  • type - The type of legal arrangement. Possible values: - Association - Partnership - SoleProprietorship - Trust
Annotations
  • @BuiltValue.new()

Constructors

LegalArrangementDetail([void updates(LegalArrangementDetailBuilder b)])
factory

Properties

address ViasAddress
The address of the legal arrangement.
no setter
hashCode int
The hash code for this object.
no setterinherited
legalArrangementCode String?
Adyen-generated unique alphanumeric identifier (UUID) for the entry, returned in the response when you create a legal arrangement. Use only when updating an account holder. If you include this field when creating an account holder, the request will fail.
no setter
legalArrangementEntities → BuiltList<LegalArrangementEntityDetail>?
An array containing information about other entities that are part of the legal arrangement.
no setter
legalArrangementReference String?
Your reference for the legal arrangement. Must be between 3 to 128 characters.
no setter
legalForm LegalArrangementDetailLegalFormEnum?
The form of legal arrangement. Required if type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
no setter
name_ String
The legal name of the legal arrangement. Minimum length: 3 characters.
no setter
registrationNumber String?
The registration number of the legal arrangement.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taxNumber String?
The tax identification number of the legal arrangement.
no setter
type LegalArrangementDetailTypeEnum
The type of legal arrangement. Possible values: - Association - Partnership - SoleProprietorship - Trust
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(LegalArrangementDetailBuilder)) LegalArrangementDetail
Rebuilds the instance.
inherited
toBuilder() LegalArrangementDetailBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<LegalArrangementDetail>
no setter