PayoutScheduleResponseScheduleEnum class

Inheritance
  • Object
  • EnumClass
  • PayoutScheduleResponseScheduleEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PayoutScheduleResponseScheduleEnum>
no setter
values → BuiltSet<PayoutScheduleResponseScheduleEnum>
no setter

Constants

bIWEEKLYON1STAND15THATMIDNIGHT → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
DAILY → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
DAILY_AU → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
DAILY_EU → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
DAILY_SG → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
DAILY_US → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
HOLD → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
MONTHLY → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
unknownDefaultOpenApi → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
WEEKLY → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
WEEKLY_MON_TO_FRI_AU → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
WEEKLY_MON_TO_FRI_EU → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
WEEKLY_MON_TO_FRI_US → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
WEEKLY_ON_TUE_FRI_MIDNIGHT → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
WEEKLY_SUN_TO_THU_AU → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.
WEEKLY_SUN_TO_THU_US → const PayoutScheduleResponseScheduleEnum
The payout schedule for the account. Possible values: DEFAULT, DAILY, DAILY_US, DAILY_EU, DAILY_AU, DAILY_SG, WEEKLY, WEEKLY_ON_TUE_FRI_MIDNIGHT, BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT, MONTHLY, HOLD. > HOLD prevents scheduled payouts, but you can still initiate payouts manually.