issuerCountry property
The country where the document was issued, in the two-character ISO 3166-1 alpha-2 format. For example, NL.
Implementation
@BuiltValueField(wireName: r'issuerCountry')
String? get issuerCountry;
The country where the document was issued, in the two-character ISO 3166-1 alpha-2 format. For example, NL.
@BuiltValueField(wireName: r'issuerCountry')
String? get issuerCountry;