RefundResult class abstract
RefundResult
Properties:
- originalTransaction - The transaction that has been refunded.
- pspReference - The reference of the refund.
- response - The response indicating if the refund has been received for processing.
- Annotations
-
- @BuiltValue.new()
Constructors
- RefundResult([void updates(RefundResultBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- originalTransaction → Transaction?
-
The transaction that has been refunded.
no setter
- pspReference → String?
-
The reference of the refund.
no setter
- response → String?
-
The response indicating if the refund has been received for processing.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(RefundResultBuilder)) → RefundResult -
Rebuilds the instance.
inherited
-
toBuilder(
) → RefundResultBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
RefundResult> -
no setter