response property
The response indicating if the refund has been received for processing.
Implementation
@BuiltValueField(wireName: r'response')
String? get response;
The response indicating if the refund has been received for processing.
@BuiltValueField(wireName: r'response')
String? get response;