ScheduledRefundsNotificationContent class abstract

ScheduledRefundsNotificationContent

Properties:

Annotations
  • @BuiltValue.new()

Properties

accountCode String?
The code of the account.
no setter
accountHolderCode String?
The code of the Account Holder.
no setter
hashCode int
The hash code for this object.
no setterinherited
invalidFields → BuiltList<ErrorFieldType>?
Invalid fields list.
no setter
lastPayout Transaction?
The most recent payout (after which all transactions were scheduled to be refunded).
no setter
refundResults → BuiltList<RefundResult>?
A list of the refunds that have been scheduled and their results.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ScheduledRefundsNotificationContentBuilder)) ScheduledRefundsNotificationContent
Rebuilds the instance.
inherited
toBuilder() ScheduledRefundsNotificationContentBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ScheduledRefundsNotificationContent>
no setter