lastPayout property
The most recent payout (after which all transactions were scheduled to be refunded).
Implementation
@BuiltValueField(wireName: r'lastPayout')
Transaction? get lastPayout;
The most recent payout (after which all transactions were scheduled to be refunded).
@BuiltValueField(wireName: r'lastPayout')
Transaction? get lastPayout;