ShareholderContact class abstract

ShareholderContact

Properties:

  • address - The address of the person.
  • email - The e-mail address of the person.
  • fullPhoneNumber - The phone number of the person provided as a single string. It will be handled as a landline phone. Examples: "0031 6 11 22 33 44", "+316/1122-3344", "(0031) 611223344"
  • jobTitle - Job title of the person. Required when the shareholderType is Controller. Example values: Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, President, Vice President, Executive President, Managing Member, Partner, Treasurer, Director, or Other.
  • name_ - The name of the person.
  • personalData - Contains information about the person.
  • phoneNumber - The phone number of the person.
  • shareholderCode - The unique identifier (UUID) of the shareholder entry. >If, during an Account Holder create or update request, this field is left blank (but other fields provided), a new Shareholder will be created with a procedurally-generated UUID. >If, during an Account Holder create request, a UUID is provided, the creation of Account Holder will fail with a validation Error.. >If, during an Account Holder update request, a UUID that is not correlated with an existing Shareholder is provided, the update of the Shareholder will fail. >If, during an Account Holder update request, a UUID that is correlated with an existing Shareholder is provided, the existing Shareholder will be updated.
  • shareholderReference - Your reference for the shareholder entry.
  • shareholderType - Specifies how the person is associated with the account holder. Possible values: * Owner: Individuals who directly or indirectly own 25% or more of a company. * Controller: Individuals who are members of senior management staff responsible for managing a company or organization.
  • webAddress - The URL of the person's website.
Annotations
  • @BuiltValue.new()

Constructors

ShareholderContact([void updates(ShareholderContactBuilder b)])
factory

Properties

address ViasAddress?
The address of the person.
no setter
email String?
The e-mail address of the person.
no setter
fullPhoneNumber String?
The phone number of the person provided as a single string. It will be handled as a landline phone. Examples: "0031 6 11 22 33 44", "+316/1122-3344", "(0031) 611223344"
no setter
hashCode int
The hash code for this object.
no setterinherited
jobTitle String?
Job title of the person. Required when the shareholderType is Controller. Example values: Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, President, Vice President, Executive President, Managing Member, Partner, Treasurer, Director, or Other.
no setter
name_ ViasName?
The name of the person.
no setter
personalData ViasPersonalData?
Contains information about the person.
no setter
phoneNumber ViasPhoneNumber?
The phone number of the person.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareholderCode String?
The unique identifier (UUID) of the shareholder entry. >If, during an Account Holder create or update request, this field is left blank (but other fields provided), a new Shareholder will be created with a procedurally-generated UUID. >If, during an Account Holder create request, a UUID is provided, the creation of Account Holder will fail with a validation Error.. >If, during an Account Holder update request, a UUID that is not correlated with an existing Shareholder is provided, the update of the Shareholder will fail. >If, during an Account Holder update request, a UUID that is correlated with an existing Shareholder is provided, the existing Shareholder will be updated.
no setter
shareholderReference String?
Your reference for the shareholder entry.
no setter
shareholderType ShareholderContactShareholderTypeEnum?
Specifies how the person is associated with the account holder. Possible values: * Owner: Individuals who directly or indirectly own 25% or more of a company. * Controller: Individuals who are members of senior management staff responsible for managing a company or organization.
no setter
webAddress String?
The URL of the person's website.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ShareholderContactBuilder)) ShareholderContact
Rebuilds the instance.
inherited
toBuilder() ShareholderContactBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ShareholderContact>
no setter