shareholderCode property

  1. @BuiltValueField.new(wireName: r'shareholderCode')
String? get shareholderCode

The unique identifier (UUID) of the shareholder entry. >If, during an Account Holder create or update request, this field is left blank (but other fields provided), a new Shareholder will be created with a procedurally-generated UUID. >If, during an Account Holder create request, a UUID is provided, the creation of Account Holder will fail with a validation Error.. >If, during an Account Holder update request, a UUID that is not correlated with an existing Shareholder is provided, the update of the Shareholder will fail. >If, during an Account Holder update request, a UUID that is correlated with an existing Shareholder is provided, the existing Shareholder will be updated.

Implementation

@BuiltValueField(wireName: r'shareholderCode')
String? get shareholderCode;