StoreDetailShopperInteractionEnum class

Inheritance
  • Object
  • EnumClass
  • StoreDetailShopperInteractionEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<StoreDetailShopperInteractionEnum>
no setter
values → BuiltSet<StoreDetailShopperInteractionEnum>
no setter

Constants

ecommerce → const StoreDetailShopperInteractionEnum
The sales channel. Possible values: Ecommerce, POS.
POS → const StoreDetailShopperInteractionEnum
The sales channel. Possible values: Ecommerce, POS.
unknownDefaultOpenApi → const StoreDetailShopperInteractionEnum
The sales channel. Possible values: Ecommerce, POS.