invalidFields property

  1. @BuiltValueField.new(wireName: r'invalidFields')
BuiltList<ErrorFieldType>? get invalidFields

in case the account holder has not been updated, contains account holder fields, that did not pass the validation.

Implementation

@BuiltValueField(wireName: r'invalidFields')
BuiltList<ErrorFieldType>? get invalidFields;