UpdateAccountHolderResponseLegalEntityEnum class

Inheritance
  • Object
  • EnumClass
  • UpdateAccountHolderResponseLegalEntityEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UpdateAccountHolderResponseLegalEntityEnum>
no setter
values → BuiltSet<UpdateAccountHolderResponseLegalEntityEnum>
no setter

Constants

business → const UpdateAccountHolderResponseLegalEntityEnum
The legal entity of the account holder.
individual → const UpdateAccountHolderResponseLegalEntityEnum
The legal entity of the account holder.
nonProfit → const UpdateAccountHolderResponseLegalEntityEnum
The legal entity of the account holder.
partnership → const UpdateAccountHolderResponseLegalEntityEnum
The legal entity of the account holder.
publicCompany → const UpdateAccountHolderResponseLegalEntityEnum
The legal entity of the account holder.
unknownDefaultOpenApi → const UpdateAccountHolderResponseLegalEntityEnum
The legal entity of the account holder.