ViasAddress class abstract
ViasAddress
Properties:
- city - The name of the city. Required if the
houseNumberOrName,street,postalCode, orstateOrProvinceare provided. - country - The two-character country code of the address in ISO-3166-1 alpha-2 format. For example, NL.
- houseNumberOrName - The number or name of the house.
- postalCode - The postal code. Required if the
houseNumberOrName,street,city, orstateOrProvinceare provided. Maximum length: * 5 digits for addresses in the US. * 10 characters for all other countries. - stateOrProvince - The abbreviation of the state or province. Required if the
houseNumberOrName,street,city, orpostalCodeare provided. Maximum length: * 2 characters for addresses in the US or Canada. * 3 characters for all other countries. - street - The name of the street. Required if the
houseNumberOrName,city,postalCode, orstateOrProvinceare provided.
- Annotations
-
- @BuiltValue.new()
Constructors
- ViasAddress([void updates(ViasAddressBuilder b)])
-
factory
Properties
- city → String?
-
The name of the city. Required if the
houseNumberOrName,street,postalCode, orstateOrProvinceare provided.no setter - country → String
-
The two-character country code of the address in ISO-3166-1 alpha-2 format. For example, NL.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- houseNumberOrName → String?
-
The number or name of the house.
no setter
- postalCode → String?
-
The postal code. Required if the
houseNumberOrName,street,city, orstateOrProvinceare provided. Maximum length: * 5 digits for addresses in the US. * 10 characters for all other countries.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateOrProvince → String?
-
The abbreviation of the state or province. Required if the
houseNumberOrName,street,city, orpostalCodeare provided. Maximum length: * 2 characters for addresses in the US or Canada. * 3 characters for all other countries.no setter - street → String?
-
The name of the street. Required if the
houseNumberOrName,city,postalCode, orstateOrProvinceare provided.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ViasAddressBuilder)) → ViasAddress -
Rebuilds the instance.
inherited
-
toBuilder(
) → ViasAddressBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ViasAddress> -
no setter