ViasNameGenderEnum class

Inheritance
  • Object
  • EnumClass
  • ViasNameGenderEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ViasNameGenderEnum>
no setter
values → BuiltSet<ViasNameGenderEnum>
no setter

Static Methods

valueOf(String name) ViasNameGenderEnum

Constants

FEMALE → const ViasNameGenderEnum
The gender. >The following values are permitted: MALE, FEMALE, UNKNOWN.
MALE → const ViasNameGenderEnum
The gender. >The following values are permitted: MALE, FEMALE, UNKNOWN.
UNKNOWN → const ViasNameGenderEnum
The gender. >The following values are permitted: MALE, FEMALE, UNKNOWN.
unknownDefaultOpenApi → const ViasNameGenderEnum
The gender. >The following values are permitted: MALE, FEMALE, UNKNOWN.