ViasPersonalData class abstract
ViasPersonalData
Properties:
- dateOfBirth - The person's date of birth, in ISO-8601 YYYY-MM-DD format. For example, 2000-01-31.
- documentData - Array that contains information about the person's identification document. You can submit only one entry per document type.
- nationality - The nationality of the person represented by a two-character country code, in ISO 3166-1 alpha-2 format. For example, NL.
- Annotations
-
- @BuiltValue.new()
Constructors
- ViasPersonalData([void updates(ViasPersonalDataBuilder b)])
-
factory
Properties
- dateOfBirth → String?
-
The person's date of birth, in ISO-8601 YYYY-MM-DD format. For example, 2000-01-31.
no setter
-
documentData
→ BuiltList<
PersonalDocumentData> ? -
Array that contains information about the person's identification document. You can submit only one entry per document type.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- nationality → String?
-
The nationality of the person represented by a two-character country code, in ISO 3166-1 alpha-2 format. For example, NL.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ViasPersonalDataBuilder)) → ViasPersonalData -
Rebuilds the instance.
inherited
-
toBuilder(
) → ViasPersonalDataBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ViasPersonalData> -
no setter