nationality property
The nationality of the person represented by a two-character country code, in ISO 3166-1 alpha-2 format. For example, NL.
Implementation
@BuiltValueField(wireName: r'nationality')
String? get nationality;
The nationality of the person represented by a two-character country code, in ISO 3166-1 alpha-2 format. For example, NL.
@BuiltValueField(wireName: r'nationality')
String? get nationality;