ReportNotificationData class abstract

ReportNotificationData

Properties:

  • accountHolder - The account holder related to the report.
  • balanceAccount - The balance account related to the report.
  • balancePlatform - The unique identifier of the balance platform.
  • creationDate - The date and time when the event was triggered, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
  • downloadUrl - The URL at which you can download the report. To download, you must authenticate your GET request with your API credentials.
  • fileName - The filename of the report.
  • id - The ID of the resource.
  • reportType - The type of report. Possible values: - balanceplatform_accounting_interactive_report - balanceplatform_accounting_report - balanceplatform_balance_report - balanceplatform_fee_report - balanceplatform_payment_instrument_report - balanceplatform_payout_report - balanceplatform_statement_report
Annotations
  • @BuiltValue.new()

Constructors

ReportNotificationData([void updates(ReportNotificationDataBuilder b)])
factory

Properties

accountHolder → ResourceReference?
The account holder related to the report.
no setter
balanceAccount → ResourceReference?
The balance account related to the report.
no setter
balancePlatform → String?
The unique identifier of the balance platform.
no setter
creationDate → DateTime?
The date and time when the event was triggered, in ISO 8601 extended format. For example, 2025-03-19T10:15:30+01:00.
no setter
downloadUrl → String
The URL at which you can download the report. To download, you must authenticate your GET request with your API credentials.
no setter
fileName → String
The filename of the report.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the resource.
no setter
reportType → String
The type of report. Possible values: - balanceplatform_accounting_interactive_report - balanceplatform_accounting_report - balanceplatform_balance_report - balanceplatform_fee_report - balanceplatform_payment_instrument_report - balanceplatform_payout_report - balanceplatform_statement_report
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReportNotificationDataBuilder)) → ReportNotificationData
Rebuilds the instance.
inherited
toBuilder() → ReportNotificationDataBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReportNotificationData>
no setter