ReportNotificationDataBuilder class

Properties

accountHolder ↔ ResourceReferenceBuilder
getter/setter pair
balanceAccount ↔ ResourceReferenceBuilder
getter/setter pair
balancePlatform ↔ String?
getter/setter pair
creationDate ↔ DateTime?
getter/setter pair
downloadUrl ↔ String?
getter/setter pair
fileName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
reportType ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → ReportNotificationData
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(ReportNotificationData other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(ReportNotificationDataBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited