accountHolder property
Contains information about the account holder associated with the balanceAccount.
Implementation
@BuiltValueField(wireName: r'accountHolder')
ResourceReference get accountHolder;
Contains information about the account holder associated with the balanceAccount.
@BuiltValueField(wireName: r'accountHolder')
ResourceReference get accountHolder;