numberOfNights property
The total number of nights the room is booked for.
Implementation
@BuiltValueField(wireName: r'numberOfNights')
int? get numberOfNights;
The total number of nights the room is booked for.
@BuiltValueField(wireName: r'numberOfNights')
int? get numberOfNights;