balanceAccountId property
The unique identifier of the destination or source balance account. > If you are updating the counterparty from a transfer instrument to a balance account, set transferInstrumentId to null.
Implementation
@BuiltValueField(wireName: r'balanceAccountId')
String? get balanceAccountId;