TransactionRuleBuilder class

Constructors

TransactionRuleBuilder()

Properties

aggregationLevel String?
getter/setter pair
description String?
getter/setter pair
endDate String?
getter/setter pair
entityKey TransactionRuleEntityKeyBuilder
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
interval TransactionRuleIntervalBuilder
getter/setter pair
outcomeType TransactionRuleOutcomeTypeEnum?
getter/setter pair
reference String?
getter/setter pair
requestType TransactionRuleRequestTypeEnum?
getter/setter pair
ruleRestrictions TransactionRuleRestrictionsBuilder
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score int?
getter/setter pair
startDate String?
getter/setter pair
status TransactionRuleStatusEnum?
getter/setter pair
type TransactionRuleTypeEnum?
getter/setter pair

Methods

build() TransactionRule
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(TransactionRule other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(TransactionRuleBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited