n02 constant
Indicates if the Cardholder Name on the account is identical to the shipping Name used for this transaction. Allowed values: * 01 — Account Name identical to shipping Name * 02 — Account Name different to shipping Name
Implementation
@BuiltValueEnumConst(wireName: r'02')
static const AcctInfoShipNameIndicatorEnum n02 = _$acctInfoShipNameIndicatorEnum_n02;