DonationCampaignBuilder class
Constructors
Properties
- amounts ↔ AmountsBuilder
-
getter/setter pair
-
getter/setter pair
- campaignName ↔ String?
-
getter/setter pair
- causeName ↔ String?
-
getter/setter pair
- donation ↔ DonationBuilder
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pair
- logoUrl ↔ String?
-
getter/setter pair
- nonprofitDescription ↔ String?
-
getter/setter pair
- nonprofitName ↔ String?
-
getter/setter pair
- nonprofitUrl ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- termsAndConditionsUrl ↔ String?
-
getter/setter pair
Methods
-
build(
) → DonationCampaign -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
DonationCampaign other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(DonationCampaignBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited