EBankingFinlandDetails class abstract
EBankingFinlandDetails
Properties:
- checkoutAttemptId - The checkout attempt identifier.
- issuer - The Ebanking Finland issuer value of the shopper's selected bank.
- sdkData - Base64-encoded JSON object containing SDK related parameters required by the SDK
- type - ebanking_FI
- Annotations
-
- @BuiltValue.new()
Constructors
- EBankingFinlandDetails([void updates(EBankingFinlandDetailsBuilder b)])
-
factory
Properties
- checkoutAttemptId → String?
-
The checkout attempt identifier.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuer → String?
-
The Ebanking Finland issuer value of the shopper's selected bank.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkData → String?
-
Base64-encoded JSON object containing SDK related parameters required by the SDK
no setter
- type → EBankingFinlandDetailsTypeEnum
-
ebanking_FI
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(EBankingFinlandDetailsBuilder)) → EBankingFinlandDetails -
Rebuilds the instance.
inherited
-
toBuilder(
) → EBankingFinlandDetailsBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
EBankingFinlandDetails> -
no setter