EcontextVoucherDetails class abstract
EcontextVoucherDetails
Properties:
- checkoutAttemptId - The checkout attempt identifier.
- firstName - The shopper's first name.
- lastName - The shopper's last name.
- sdkData - Base64-encoded JSON object containing SDK related parameters required by the SDK
- shopperEmail - The shopper's email.
- telephoneNumber - The shopper's contact number. It must have an international number format, for example +31 20 779 1846. Formats like +31 (0)20 779 1846 or 0031 20 779 1846 are not accepted.
- type - econtextvoucher
- Annotations
-
- @BuiltValue.new()
Constructors
- EcontextVoucherDetails([void updates(EcontextVoucherDetailsBuilder b)])
-
factory
Properties
- checkoutAttemptId → String?
-
The checkout attempt identifier.
no setter
- firstName → String
-
The shopper's first name.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String
-
The shopper's last name.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkData → String?
-
Base64-encoded JSON object containing SDK related parameters required by the SDK
no setter
- shopperEmail → String
-
The shopper's email.
no setter
- telephoneNumber → String
-
The shopper's contact number. It must have an international number format, for example +31 20 779 1846. Formats like +31 (0)20 779 1846 or 0031 20 779 1846 are not accepted.
no setter
- type → EcontextVoucherDetailsTypeEnum
-
econtextvoucher
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(EcontextVoucherDetailsBuilder)) → EcontextVoucherDetails -
Rebuilds the instance.
inherited
-
toBuilder(
) → EcontextVoucherDetailsBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
EcontextVoucherDetails> -
no setter