departureAirportCode property
The IATA three-letter airport code of the departure airport. This field is required if the airline data includes leg details. * Encoding: ASCII * Example: Amsterdam = AMS * minLength: 3 characters * maxLength: 3 characters * Must not start with a space or be all spaces. * Must not be all zeros.
Implementation
@BuiltValueField(wireName: r'departureAirportCode')
String? get departureAirportCode;