PayUUpiDetails class abstract
PayUUpiDetails
Properties:
- checkoutAttemptId - The checkout attempt identifier.
- recurringDetailReference - This is the
recurringDetailReferencereturned in the response when you created the token. - sdkData - Base64-encoded JSON object containing SDK related parameters required by the SDK
- shopperNotificationReference - The
shopperNotificationReferencereturned in the response when you requested to notify the shopper. Used for recurring payment only. - storedPaymentMethodId - This is the
recurringDetailReferencereturned in the response when you created the token. - type - payu_IN_upi
- virtualPaymentAddress - The virtual payment address for UPI.
- Annotations
-
- @BuiltValue.new()
Constructors
- PayUUpiDetails([void updates(PayUUpiDetailsBuilder b)])
-
factory
Properties
- checkoutAttemptId → String?
-
The checkout attempt identifier.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- recurringDetailReference → String?
-
This is the
recurringDetailReferencereturned in the response when you created the token.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkData → String?
-
Base64-encoded JSON object containing SDK related parameters required by the SDK
no setter
- shopperNotificationReference → String?
-
The
shopperNotificationReferencereturned in the response when you requested to notify the shopper. Used for recurring payment only.no setter - storedPaymentMethodId → String?
-
This is the
recurringDetailReferencereturned in the response when you created the token.no setter - type → PayUUpiDetailsTypeEnum
-
payu_IN_upi
no setter
- virtualPaymentAddress → String?
-
The virtual payment address for UPI.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(PayUUpiDetailsBuilder)) → PayUUpiDetails -
Rebuilds the instance.
inherited
-
toBuilder(
) → PayUUpiDetailsBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
PayUUpiDetails> -
no setter