PaymentValidationsNameResultRawResponse class abstract
PaymentValidationsNameResultRawResponse
Properties:
- firstName - The raw first name validation result that Adyen received from the scheme. First name validation result is only returned for Visa.
- fullName - The raw full name validation result that Adyen received from the scheme. Full name is the only field that is validated for Mastercard
- lastName - The raw last name validation result that Adyen received from the scheme. Last name validation result is only returned for Visa.
- middleName - The raw middle name validation result that Adyen received from the scheme. Middle name validation result is only returned for Visa.
- status - The raw name validation status value that Adyen received from the scheme. Only returned for Visa.
- Annotations
-
- @BuiltValue.new()
Constructors
- PaymentValidationsNameResultRawResponse([void updates(PaymentValidationsNameResultRawResponseBuilder b)])
-
factory
Properties
- firstName → String?
-
The raw first name validation result that Adyen received from the scheme. First name validation result is only returned for Visa.
no setter
- fullName → String?
-
The raw full name validation result that Adyen received from the scheme. Full name is the only field that is validated for Mastercard
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String?
-
The raw last name validation result that Adyen received from the scheme. Last name validation result is only returned for Visa.
no setter
- middleName → String?
-
The raw middle name validation result that Adyen received from the scheme. Middle name validation result is only returned for Visa.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
The raw name validation status value that Adyen received from the scheme. Only returned for Visa.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(PaymentValidationsNameResultRawResponseBuilder)) → PaymentValidationsNameResultRawResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → PaymentValidationsNameResultRawResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
PaymentValidationsNameResultRawResponse> -
no setter