firstName property
The raw first name validation result that Adyen received from the scheme. First name validation result is only returned for Visa.
Implementation
@BuiltValueField(wireName: r'firstName')
String? get firstName;
The raw first name validation result that Adyen received from the scheme. First name validation result is only returned for Visa.
@BuiltValueField(wireName: r'firstName')
String? get firstName;