SamsungPayDetails class abstract
SamsungPayDetails
Properties:
- checkoutAttemptId - The checkout attempt identifier.
- fundingSource - The funding source that should be used when multiple sources are available. For Brazilian combo cards, by default the funding source is credit. To use debit, set this value to debit.
- recurringDetailReference - This is the
recurringDetailReferencereturned in the response when you created the token. - samsungPayToken - The payload you received from the Samsung Pay SDK response.
- sdkData - Base64-encoded JSON object containing SDK related parameters required by the SDK
- storedPaymentMethodId - This is the
recurringDetailReferencereturned in the response when you created the token. - type - samsungpay
- Annotations
-
- @BuiltValue.new()
Constructors
- SamsungPayDetails([void updates(SamsungPayDetailsBuilder b)])
-
factory
Properties
- checkoutAttemptId → String?
-
The checkout attempt identifier.
no setter
- fundingSource → SamsungPayDetailsFundingSourceEnum?
-
The funding source that should be used when multiple sources are available. For Brazilian combo cards, by default the funding source is credit. To use debit, set this value to debit.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- recurringDetailReference → String?
-
This is the
recurringDetailReferencereturned in the response when you created the token.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samsungPayToken → String
-
The payload you received from the Samsung Pay SDK response.
no setter
- sdkData → String?
-
Base64-encoded JSON object containing SDK related parameters required by the SDK
no setter
- storedPaymentMethodId → String?
-
This is the
recurringDetailReferencereturned in the response when you created the token.no setter - type → SamsungPayDetailsTypeEnum?
-
samsungpay
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(SamsungPayDetailsBuilder)) → SamsungPayDetails -
Rebuilds the instance.
inherited
-
toBuilder(
) → SamsungPayDetailsBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
SamsungPayDetails> -
no setter