DisputeServiceResult class abstract
DisputeServiceResult
Properties:
- errorMessage - The general error message.
- success - Indicates whether the request succeeded.
- Annotations
-
- @BuiltValue.new()
Constructors
- DisputeServiceResult([void updates(DisputeServiceResultBuilder b)])
-
factory
Properties
- errorMessage → String?
-
The general error message.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Indicates whether the request succeeded.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(DisputeServiceResultBuilder)) → DisputeServiceResult -
Rebuilds the instance.
inherited
-
toBuilder(
) → DisputeServiceResultBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
DisputeServiceResult> -
no setter