OnboardingLinkInfo class abstract
OnboardingLinkInfo
Properties:
- locale - The language that will be used for the page, specified by a combination of two letter ISO 639-1 language and ISO 3166-1 alpha-2 country codes. See possible valuesfor marketplaces or platforms. If not specified in the request or if the language is not supported, the page uses the browser language. If the browser language is not supported, the page uses en-US by default.
- redirectUrl - The URL where the user is redirected after they complete hosted onboarding.
- settings - Key-value pairs indicating the settings for the hosted onboarding page. The key represents a specific setting.
- themeId - The unique identifier of the hosted onboarding theme.
- Annotations
-
- @BuiltValue.new()
Constructors
- OnboardingLinkInfo([void updates(OnboardingLinkInfoBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale → String?
-
The language that will be used for the page, specified by a combination of two letter ISO 639-1 language and ISO 3166-1 alpha-2 country codes. See possible valuesfor marketplaces or platforms. If not specified in the request or if the language is not supported, the page uses the browser language. If the browser language is not supported, the page uses en-US by default.
no setter
- redirectUrl → String?
-
The URL where the user is redirected after they complete hosted onboarding.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → OnboardingLinkSettings?
-
Key-value pairs indicating the settings for the hosted onboarding page. The key represents a specific setting.
no setter
- themeId → String?
-
The unique identifier of the hosted onboarding theme.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(OnboardingLinkInfoBuilder)) → OnboardingLinkInfo -
Rebuilds the instance.
inherited
-
toBuilder(
) → OnboardingLinkInfoBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
OnboardingLinkInfo> -
no setter