OnboardingThemes class abstract
OnboardingThemes
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- OnboardingThemes([void updates(OnboardingThemesBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- next → String?
-
The next page. Only present if there is a next page.
no setter
- previous → String?
-
The previous page. Only present if there is a previous page.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
themes
→ BuiltList<
OnboardingTheme> -
List of onboarding themes.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(OnboardingThemesBuilder)) → OnboardingThemes -
Rebuilds the instance.
inherited
-
toBuilder(
) → OnboardingThemesBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
OnboardingThemes> -
no setter