doingBusinessAsAbsent property
Set this to true if the organization or legal arrangement does not have a Doing business as name.
Implementation
@BuiltValueField(wireName: r'doingBusinessAsAbsent')
bool? get doingBusinessAsAbsent;
Set this to true if the organization or legal arrangement does not have a Doing business as name.
@BuiltValueField(wireName: r'doingBusinessAsAbsent')
bool? get doingBusinessAsAbsent;