economicSector property
The sector of the economy the legal entity operates within, represented by a 2-4 digit code that may include a ".". Example: 45.11 You can locate economic sector codes for your area by referencing codes defined by the NACE (Nomenclature of Economic Activities) used in the European Union.
Implementation
@BuiltValueField(wireName: r'economicSector')
String? get economicSector;