KlarnaInfo class abstract
KlarnaInfo
Properties:
- autoCapture - Indicates the status of Automatic capture. Default value: false.
- disputeEmail - The email address for disputes.
- region - The region of operation. For example, NA, EU, CH, AU.
- supportEmail - The email address of merchant support.
- Annotations
-
- @BuiltValue.new()
Constructors
- KlarnaInfo([void updates(KlarnaInfoBuilder b)])
-
factory
Properties
- autoCapture → bool?
-
Indicates the status of Automatic capture. Default value: false.
no setter
- disputeEmail → String
-
The email address for disputes.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- region → KlarnaInfoRegionEnum
-
The region of operation. For example, NA, EU, CH, AU.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportEmail → String
-
The email address of merchant support.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(KlarnaInfoBuilder)) → KlarnaInfo -
Rebuilds the instance.
inherited
-
toBuilder(
) → KlarnaInfoBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
KlarnaInfo> -
no setter