primarySettlementCurrency property
The currency of the country where the legal entity of this merchant account is registered. Format: ISO currency code. For example, a legal entity based in the United States has USD as the primary settlement currency.
Implementation
@BuiltValueField(wireName: r'primarySettlementCurrency')
String? get primarySettlementCurrency;