enabled property
Enables sending event notifications either by pressing the Confirm key on terminals with a keypad or by tapping the event notification button on the terminal screen.
Implementation
@BuiltValueField(wireName: r'enabled')
bool? get enabled;