PayoutSettingsPriorityEnum class
- Inheritance
-
- Object
- EnumClass
- PayoutSettingsPriorityEnum
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
first
→ const PayoutSettingsPriorityEnum
-
Determines how long it takes for the funds to reach the bank account. Adyen pays out based on the payout frequency. Depending on the currencies and banks involved in transferring the money, it may take up to three days for the payout funds to arrive in the bank account. Possible values: * first: same day. * urgent: the next day. * normal: between 1 and 3 days.
-
normal
→ const PayoutSettingsPriorityEnum
-
Determines how long it takes for the funds to reach the bank account. Adyen pays out based on the payout frequency. Depending on the currencies and banks involved in transferring the money, it may take up to three days for the payout funds to arrive in the bank account. Possible values: * first: same day. * urgent: the next day. * normal: between 1 and 3 days.
-
unknownDefaultOpenApi
→ const PayoutSettingsPriorityEnum
-
Determines how long it takes for the funds to reach the bank account. Adyen pays out based on the payout frequency. Depending on the currencies and banks involved in transferring the money, it may take up to three days for the payout funds to arrive in the bank account. Possible values: * first: same day. * urgent: the next day. * normal: between 1 and 3 days.
-
urgent
→ const PayoutSettingsPriorityEnum
-
Determines how long it takes for the funds to reach the bank account. Adyen pays out based on the payout frequency. Depending on the currencies and banks involved in transferring the money, it may take up to three days for the payout funds to arrive in the bank account. Possible values: * first: same day. * urgent: the next day. * normal: between 1 and 3 days.