Profile class abstract
Profile
Properties:
- authType - The type of Wi-Fi network. Possible values: wpa-psk, wpa2-psk, wpa-eap, wpa2-eap.
- autoWifi - Indicates whether to automatically select the best authentication method available. Does not work on older terminal models.
- bssType - Use infra for infrastructure-based networks. This applies to most networks. Use adhoc only if the communication is p2p-based between base stations.
- channel - The channel number of the Wi-Fi network. The recommended setting is 0 for automatic channel selection.
- defaultProfile - Indicates whether this is your preferred wireless network. If true, the terminal will try connecting to this network first.
- domainSuffix - Specifies the server domain name for EAP-TLS and EAP-PEAP WiFi profiles on Android 11 and above.
- eap - For
authTypewpa-eap or wpa2-eap. Possible values: tls, peap, leap, fast - eapCaCert - For
authTypewpa-eap or wpa2-eap. The root certificate from the CA that signed the certificate of the RADIUS server that is part of your wireless network. - eapClientCert - For
eaptls. The certificate chain for the terminals. All terminals in the same network will use the same EAP client certificate. - eapClientKey - For
eaptls. The RSA private key for the client. Include the lines BEGIN RSA PRIVATE KEY and END RSA PRIVATE KEY. - eapClientPwd - For
eaptls. The password of the RSA key file, if that file is password-protected. - eapIdentity - For
authTypewpa-eap or wpa2-eap. The EAP-PEAP username from your MS-CHAP account. Must match the configuration of your RADIUS server. - eapIntermediateCert - For
eaptls. The EAP intermediate certificate. - eapPwd - For
eappeap. The EAP-PEAP password from your MS-CHAP account. Must match the configuration of your RADIUS server. - hiddenSsid - Indicates if the network doesn't broadcast its SSID. Mandatory for Android terminals, because these terminals rely on this setting to be able to connect to any network.
- name_ - Your name for the Wi-Fi profile.
- psk - For
authType**wpa-psk or wpa2-psk. The password to the wireless network. - ssid - The name of the wireless network.
- wsec - The type of encryption. Possible values: auto, ccmp (recommended), tkip
- Annotations
-
- @BuiltValue.new()
Constructors
- Profile([void updates(ProfileBuilder b)])
-
factory
Properties
- authType → String
-
The type of Wi-Fi network. Possible values: wpa-psk, wpa2-psk, wpa-eap, wpa2-eap.
no setter
- autoWifi → bool?
-
Indicates whether to automatically select the best authentication method available. Does not work on older terminal models.
no setter
- bssType → String
-
Use infra for infrastructure-based networks. This applies to most networks. Use adhoc only if the communication is p2p-based between base stations.
no setter
- channel → int?
-
The channel number of the Wi-Fi network. The recommended setting is 0 for automatic channel selection.
no setter
- defaultProfile → bool?
-
Indicates whether this is your preferred wireless network. If true, the terminal will try connecting to this network first.
no setter
- domainSuffix → String?
-
Specifies the server domain name for EAP-TLS and EAP-PEAP WiFi profiles on Android 11 and above.
no setter
- eap → String?
-
For
authTypewpa-eap or wpa2-eap. Possible values: tls, peap, leap, fastno setter - eapCaCert → File?
-
For
authTypewpa-eap or wpa2-eap. The root certificate from the CA that signed the certificate of the RADIUS server that is part of your wireless network.no setter - eapClientCert → File?
-
For
eaptls. The certificate chain for the terminals. All terminals in the same network will use the same EAP client certificate.no setter - eapClientKey → File?
-
For
eaptls. The RSA private key for the client. Include the lines BEGIN RSA PRIVATE KEY and END RSA PRIVATE KEY.no setter - eapClientPwd → String?
-
For
eaptls. The password of the RSA key file, if that file is password-protected.no setter - eapIdentity → String?
-
For
authTypewpa-eap or wpa2-eap. The EAP-PEAP username from your MS-CHAP account. Must match the configuration of your RADIUS server.no setter - eapIntermediateCert → File?
-
For
eaptls. The EAP intermediate certificate.no setter - eapPwd → String?
-
For
eappeap. The EAP-PEAP password from your MS-CHAP account. Must match the configuration of your RADIUS server.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
Indicates if the network doesn't broadcast its SSID. Mandatory for Android terminals, because these terminals rely on this setting to be able to connect to any network.
no setter
- name_ → String?
-
Your name for the Wi-Fi profile.
no setter
- psk → String?
-
For
authType**wpa-psk or wpa2-psk. The password to the wireless network.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ssid → String
-
The name of the wireless network.
no setter
- wsec → String
-
The type of encryption. Possible values: auto, ccmp (recommended), tkip
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ProfileBuilder)) → Profile -
Rebuilds the instance.
inherited
-
toBuilder(
) → ProfileBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
Profile> -
no setter