AcctInfoChAccChangeIndEnum class
- Inheritance
-
- Object
- EnumClass
- AcctInfoChAccChangeIndEnum
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
n01
→ const AcctInfoChAccChangeIndEnum
-
Length of time since the cardholder’s account information with the 3DS Requestor was last changed, including Billing or Shipping address, new payment account, or new user(s) added. Allowed values: * 01 — Changed during this transaction * 02 — Less than 30 days * 03 — 30–60 days * 04 — More than 60 days
-
n02
→ const AcctInfoChAccChangeIndEnum
-
Length of time since the cardholder’s account information with the 3DS Requestor was last changed, including Billing or Shipping address, new payment account, or new user(s) added. Allowed values: * 01 — Changed during this transaction * 02 — Less than 30 days * 03 — 30–60 days * 04 — More than 60 days
-
n03
→ const AcctInfoChAccChangeIndEnum
-
Length of time since the cardholder’s account information with the 3DS Requestor was last changed, including Billing or Shipping address, new payment account, or new user(s) added. Allowed values: * 01 — Changed during this transaction * 02 — Less than 30 days * 03 — 30–60 days * 04 — More than 60 days
-
n04
→ const AcctInfoChAccChangeIndEnum
-
Length of time since the cardholder’s account information with the 3DS Requestor was last changed, including Billing or Shipping address, new payment account, or new user(s) added. Allowed values: * 01 — Changed during this transaction * 02 — Less than 30 days * 03 — 30–60 days * 04 — More than 60 days
-
unknownDefaultOpenApi
→ const AcctInfoChAccChangeIndEnum
-
Length of time since the cardholder’s account information with the 3DS Requestor was last changed, including Billing or Shipping address, new payment account, or new user(s) added. Allowed values: * 01 — Changed during this transaction * 02 — Less than 30 days * 03 — 30–60 days * 04 — More than 60 days