carRentalPeriodReturnLocationId property
- @BuiltValueField.new(wireName: r'carRental.returnLocationId')
The agency code, phone number, or address abbreviation * Format: Alphanumeric * maxLength: 10 * Must not start with a space or be all spaces *Must not be all zeros.
Implementation
@BuiltValueField(wireName: r'carRental.returnLocationId')
String? get carRentalPeriodReturnLocationId;