ModifyRequest class abstract
ModifyRequest
Properties:
- additionalData - This field contains additional data, which may be required for a particular payout request.
- merchantAccount - The merchant account identifier, with which you want to process the transaction.
- originalReference - The PSP reference received in the
/submitThirdPartyresponse.
- Annotations
-
- @BuiltValue.new()
Constructors
- ModifyRequest([void updates(ModifyRequestBuilder b)])
-
factory
Properties
-
additionalData
→ BuiltMap<
String, String> ? -
This field contains additional data, which may be required for a particular payout request.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantAccount → String
-
The merchant account identifier, with which you want to process the transaction.
no setter
- originalReference → String
-
The PSP reference received in the
/submitThirdPartyresponse.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ModifyRequestBuilder)) → ModifyRequest -
Rebuilds the instance.
inherited
-
toBuilder(
) → ModifyRequestBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ModifyRequest> -
no setter