PayoutRequest class abstract
PayoutRequest
Properties:
- amount - The amount information for the transaction (in minor units). For BIN or card verification requests, set amount to 0 (zero).
- billingAddress - The address where to send the invoice. > The
billingAddressobject is required in the following scenarios. Include all of the fields within this object. >* For 3D Secure 2 transactions in all browser-based and mobile implementations. >* For cross-border payouts to and from Canada. - card - A container for card data. > Either
bankAccountorcardfield must be provided in a payment request. - fraudOffset - An integer value that is added to the normal fraud score. The value can be either positive or negative.
- fundSource - The person or entity funding the money.
- merchantAccount - The merchant account identifier, with which you want to process the transaction.
- recurring - The recurring settings for the payment. Use this property when you want to enable recurring payments.
- reference - The reference to uniquely identify a payment. This reference is used in all communication with you about the payment status. We recommend using a unique value per payment; however, it is not a requirement. If you need to provide multiple references for a transaction, separate them with hyphens ("-"). Maximum length: 80 characters.
- selectedRecurringDetailReference - The
recurringDetailReferenceyou want to use for this payment. The valueLATESTcan be used to select the most recently stored recurring detail. - shopperEmail - The shopper's email address. We recommend that you provide this data, as it is used in velocity fraud checks. > Required for Visa and JCB transactions that require 3D Secure 2 authentication if you did not include the
telephoneNumber. - shopperInteraction - Specifies the sales channel, through which the shopper gives their card details, and whether the shopper is a returning customer. For the web service API, Adyen assumes Ecommerce shopper interaction by default. This field has the following possible values: *
Ecommerce- Online transactions where the cardholder is present (online). For better authorisation rates, we recommend sending the card security code (CSC) along with the request. *ContAuth- Card on file and/or subscription transactions, where the cardholder is known to the merchant (returning customer). If the shopper is present (online), you can supply also the CSC to improve authorisation (one-click payment). *Moto- Mail-order and telephone-order transactions where the shopper is in contact with the merchant via email or telephone. *POS- Point-of-sale transactions where the shopper is physically present to make a payment using a secure payment terminal. - shopperName - The shopper's full name.
- shopperReference - Required for recurring payments. Your reference to uniquely identify this shopper, for example user ID or account ID. The value is case-sensitive and must be at least three characters. > Your reference must not include personally identifiable information (PII) such as name or email address.
- telephoneNumber - The shopper's telephone number. The phone number must include a plus sign (+) and a country code (1-3 digits), followed by the number (4-15 digits). If the value you provide does not follow the guidelines, we do not submit it for authentication. > Required for Visa and JCB transactions that require 3D Secure 2 authentication, if you did not include the
shopperEmail.
- Annotations
-
- @BuiltValue.new()
Constructors
- PayoutRequest([void updates(PayoutRequestBuilder b)])
-
factory
Properties
- amount → Amount
-
The amount information for the transaction (in minor units). For BIN or card verification requests, set amount to 0 (zero).
no setter
- billingAddress → Address?
-
The address where to send the invoice. > The
billingAddressobject is required in the following scenarios. Include all of the fields within this object. >* For 3D Secure 2 transactions in all browser-based and mobile implementations. >* For cross-border payouts to and from Canada.no setter - card → Card?
-
A container for card data. > Either
bankAccountorcardfield must be provided in a payment request.no setter - fraudOffset → int?
-
An integer value that is added to the normal fraud score. The value can be either positive or negative.
no setter
- fundSource → FundSource?
-
The person or entity funding the money.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantAccount → String
-
The merchant account identifier, with which you want to process the transaction.
no setter
- recurring → Recurring?
-
The recurring settings for the payment. Use this property when you want to enable recurring payments.
no setter
- reference → String
-
The reference to uniquely identify a payment. This reference is used in all communication with you about the payment status. We recommend using a unique value per payment; however, it is not a requirement. If you need to provide multiple references for a transaction, separate them with hyphens ("-"). Maximum length: 80 characters.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedRecurringDetailReference → String?
-
The
recurringDetailReferenceyou want to use for this payment. The valueLATESTcan be used to select the most recently stored recurring detail.no setter - shopperEmail → String?
-
The shopper's email address. We recommend that you provide this data, as it is used in velocity fraud checks. > Required for Visa and JCB transactions that require 3D Secure 2 authentication if you did not include the
telephoneNumber.no setter - shopperInteraction → PayoutRequestShopperInteractionEnum?
-
Specifies the sales channel, through which the shopper gives their card details, and whether the shopper is a returning customer. For the web service API, Adyen assumes Ecommerce shopper interaction by default. This field has the following possible values: *
Ecommerce- Online transactions where the cardholder is present (online). For better authorisation rates, we recommend sending the card security code (CSC) along with the request. *ContAuth- Card on file and/or subscription transactions, where the cardholder is known to the merchant (returning customer). If the shopper is present (online), you can supply also the CSC to improve authorisation (one-click payment). *Moto- Mail-order and telephone-order transactions where the shopper is in contact with the merchant via email or telephone. *POS- Point-of-sale transactions where the shopper is physically present to make a payment using a secure payment terminal.no setter - shopperName → Name?
-
The shopper's full name.
no setter
- shopperReference → String?
-
Required for recurring payments. Your reference to uniquely identify this shopper, for example user ID or account ID. The value is case-sensitive and must be at least three characters. > Your reference must not include personally identifiable information (PII) such as name or email address.
no setter
- telephoneNumber → String?
-
The shopper's telephone number. The phone number must include a plus sign (+) and a country code (1-3 digits), followed by the number (4-15 digits). If the value you provide does not follow the guidelines, we do not submit it for authentication. > Required for Visa and JCB transactions that require 3D Secure 2 authentication, if you did not include the
shopperEmail.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(PayoutRequestBuilder)) → PayoutRequest -
Rebuilds the instance.
inherited
-
toBuilder(
) → PayoutRequestBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
PayoutRequest> -
no setter