StoreDetailAndSubmitRequest class abstract

StoreDetailAndSubmitRequest

Properties:

  • additionalData - This field contains additional data, which may be required for a particular request.
  • amount - A container object for the payable amount information of the transaction.
  • bank - A container for bank account data. > This field is mandatory if card is not provided.
  • billingAddress - The billing address. > The billingAddress object is required for cross-border payouts to and from Canada. Include all of the fields within this object.
  • card - A container for card data. > This field is mandatory if bank is not provided.
  • dateOfBirth - The date of birth. Format: ISO-8601; example: YYYY-MM-DD For Paysafecard it must be the same as used when registering the Paysafecard account. > This field is mandatory for natural persons.
  • entityType - The type of the entity the payout is processed for.
  • fraudOffset - An integer value that is added to the normal fraud score. The value can be either positive or negative.
  • merchantAccount - The merchant account identifier, with which you want to process the transaction.
  • nationality - The shopper's nationality. A valid value is an ISO 2-character country code (e.g. 'NL').
  • recurring - A container for the type of recurring contract to be retrieved. The recurring.contract must be set to PAYOUT
  • reference - The merchant reference for this payment. This reference will be used in all communication to the merchant about the status of the payout. Although it is a good idea to make sure it is unique, this is not a requirement.
  • selectedBrand - The name of the brand to make a payout to. For Paysafecard it must be set to paysafecard.
  • shopperEmail - The shopper's email address.
  • shopperName - The shopper's name. When the entityType is Company, the shopperName.lastName must contain the company name.
  • shopperReference - The shopper's reference for the payment transaction.
  • shopperStatement - The description of this payout. This description is shown on the bank statement of the shopper (if this is supported by the chosen payment method).
  • socialSecurityNumber - The shopper's social security number.
  • telephoneNumber - The shopper's phone number.
Annotations
  • @BuiltValue.new()

Constructors

StoreDetailAndSubmitRequest([void updates(StoreDetailAndSubmitRequestBuilder b)])
factory

Properties

additionalData → BuiltMap<String, String>?
This field contains additional data, which may be required for a particular request.
no setter
amount Amount
A container object for the payable amount information of the transaction.
no setter
bank BankAccount?
A container for bank account data. > This field is mandatory if card is not provided.
no setter
billingAddress Address?
The billing address. > The billingAddress object is required for cross-border payouts to and from Canada. Include all of the fields within this object.
no setter
card Card?
A container for card data. > This field is mandatory if bank is not provided.
no setter
dateOfBirth Date
The date of birth. Format: ISO-8601; example: YYYY-MM-DD For Paysafecard it must be the same as used when registering the Paysafecard account. > This field is mandatory for natural persons.
no setter
entityType StoreDetailAndSubmitRequestEntityTypeEnum
The type of the entity the payout is processed for.
no setter
fraudOffset int?
An integer value that is added to the normal fraud score. The value can be either positive or negative.
no setter
hashCode int
The hash code for this object.
no setterinherited
merchantAccount String
The merchant account identifier, with which you want to process the transaction.
no setter
nationality String
The shopper's nationality. A valid value is an ISO 2-character country code (e.g. 'NL').
no setter
recurring Recurring
A container for the type of recurring contract to be retrieved. The recurring.contract must be set to PAYOUT
no setter
reference String
The merchant reference for this payment. This reference will be used in all communication to the merchant about the status of the payout. Although it is a good idea to make sure it is unique, this is not a requirement.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedBrand String?
The name of the brand to make a payout to. For Paysafecard it must be set to paysafecard.
no setter
shopperEmail String
The shopper's email address.
no setter
shopperName Name?
The shopper's name. When the entityType is Company, the shopperName.lastName must contain the company name.
no setter
shopperReference String
The shopper's reference for the payment transaction.
no setter
shopperStatement String?
The description of this payout. This description is shown on the bank statement of the shopper (if this is supported by the chosen payment method).
no setter
socialSecurityNumber String?
The shopper's social security number.
no setter
telephoneNumber String?
The shopper's phone number.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(StoreDetailAndSubmitRequestBuilder)) StoreDetailAndSubmitRequest
Rebuilds the instance.
inherited
toBuilder() StoreDetailAndSubmitRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<StoreDetailAndSubmitRequest>
no setter