StoreDetailRequest class abstract
StoreDetailRequest
Properties:
- additionalData - This field contains additional data, which may be required for a particular request.
- bank - A container for bank account data. > This field is mandatory if
cardis not provided. - billingAddress - The billing address. > The
billingAddressobject is required for cross-border payouts to and from Canada. Include all of the fields within this object. - card - A container for card data. > This field is mandatory if
bankis not provided. - dateOfBirth - The date of birth. Format: ISO-8601; example: YYYY-MM-DD For Paysafecard it must be the same as used when registering the Paysafecard account. > This field is mandatory for natural persons.
- entityType - The type of the entity the payout is processed for.
- fraudOffset - An integer value that is added to the normal fraud score. The value can be either positive or negative.
- merchantAccount - The merchant account identifier, with which you want to process the transaction.
- nationality - The shopper's nationality. A valid value is an ISO 2-character country code (e.g. 'NL').
- recurring - A container for the type of recurring contract to be retrieved. The recurring.contract must be set to
PAYOUT - selectedBrand - The name of the brand to make a payout to. For Paysafecard it must be set to
paysafecard. - shopperEmail - The shopper's email address.
- shopperName - The shopper's name. When the
entityTypeisCompany, theshopperName.lastNamemust contain the company name. - shopperReference - The shopper's reference for the payment transaction.
- socialSecurityNumber - The shopper's social security number.
- telephoneNumber - The shopper's phone number.
- Annotations
-
- @BuiltValue.new()
Constructors
- StoreDetailRequest([void updates(StoreDetailRequestBuilder b)])
-
factory
Properties
-
additionalData
→ BuiltMap<
String, String> ? -
This field contains additional data, which may be required for a particular request.
no setter
- bank → BankAccount?
-
A container for bank account data. > This field is mandatory if
cardis not provided.no setter - billingAddress → Address?
-
The billing address. > The
billingAddressobject is required for cross-border payouts to and from Canada. Include all of the fields within this object.no setter - card → Card?
-
A container for card data. > This field is mandatory if
bankis not provided.no setter - dateOfBirth → Date
-
The date of birth. Format: ISO-8601; example: YYYY-MM-DD For Paysafecard it must be the same as used when registering the Paysafecard account. > This field is mandatory for natural persons.
no setter
- entityType → StoreDetailRequestEntityTypeEnum
-
The type of the entity the payout is processed for.
no setter
- fraudOffset → int?
-
An integer value that is added to the normal fraud score. The value can be either positive or negative.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantAccount → String
-
The merchant account identifier, with which you want to process the transaction.
no setter
- nationality → String
-
The shopper's nationality. A valid value is an ISO 2-character country code (e.g. 'NL').
no setter
- recurring → Recurring
-
A container for the type of recurring contract to be retrieved. The recurring.contract must be set to
PAYOUTno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedBrand → String?
-
The name of the brand to make a payout to. For Paysafecard it must be set to
paysafecard.no setter - shopperEmail → String
-
The shopper's email address.
no setter
- shopperName → Name?
-
The shopper's name. When the
entityTypeisCompany, theshopperName.lastNamemust contain the company name.no setter - shopperReference → String
-
The shopper's reference for the payment transaction.
no setter
-
The shopper's social security number.
no setter
- telephoneNumber → String?
-
The shopper's phone number.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(StoreDetailRequestBuilder)) → StoreDetailRequest -
Rebuilds the instance.
inherited
-
toBuilder(
) → StoreDetailRequestBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
StoreDetailRequest> -
no setter