SubmitRequest class abstract

SubmitRequest

Properties:

  • additionalData - This field contains additional data, which may be required for a particular request.
  • amount - A container object for the payable amount information of the transaction.
  • dateOfBirth - The date of birth. Format: ISO-8601; example: YYYY-MM-DD For Paysafecard it must be the same as used when registering the Paysafecard account. > This field is mandatory for natural persons. > This field is required to update the existing dateOfBirth that is associated with this recurring contract.
  • entityType - The type of the entity the payout is processed for. Allowed values: * NaturalPerson * Company > This field is required to update the existing entityType that is associated with this recurring contract.
  • fraudOffset - An integer value that is added to the normal fraud score. The value can be either positive or negative.
  • merchantAccount - The merchant account identifier you want to process the transaction request with.
  • nationality - The shopper's nationality. A valid value is an ISO 2-character country code (e.g. 'NL'). > This field is required to update the existing nationality that is associated with this recurring contract.
  • recurring - A container for the type of recurring contract to be retrieved. The recurring.contract must be set to "PAYOUT".
  • reference - The merchant reference for this payout. This reference will be used in all communication to the merchant about the status of the payout. Although it is a good idea to make sure it is unique, this is not a requirement.
  • selectedRecurringDetailReference - This is the recurringDetailReference you want to use for this payout. You can use the value LATEST to select the most recently used recurring detail.
  • shopperEmail - The shopper's email address.
  • shopperName - The shopper's name. In case the entityType is Company, the shopperName.lastName must contain the company name. > This field is required to update the existing shopperName associated with a recurring contract.
  • shopperReference - The shopper's reference for the payout transaction.
  • shopperStatement - The description of this payout. This description is shown on the bank statement of the shopper (if this is supported by the chosen payment method).
  • socialSecurityNumber - The shopper's social security number.
Annotations
  • @BuiltValue.new()

Constructors

SubmitRequest([void updates(SubmitRequestBuilder b)])
factory

Properties

additionalData → BuiltMap<String, String>?
This field contains additional data, which may be required for a particular request.
no setter
amount Amount
A container object for the payable amount information of the transaction.
no setter
dateOfBirth Date?
The date of birth. Format: ISO-8601; example: YYYY-MM-DD For Paysafecard it must be the same as used when registering the Paysafecard account. > This field is mandatory for natural persons. > This field is required to update the existing dateOfBirth that is associated with this recurring contract.
no setter
entityType SubmitRequestEntityTypeEnum?
The type of the entity the payout is processed for. Allowed values: * NaturalPerson * Company > This field is required to update the existing entityType that is associated with this recurring contract.
no setter
fraudOffset int?
An integer value that is added to the normal fraud score. The value can be either positive or negative.
no setter
hashCode int
The hash code for this object.
no setterinherited
merchantAccount String
The merchant account identifier you want to process the transaction request with.
no setter
nationality String?
The shopper's nationality. A valid value is an ISO 2-character country code (e.g. 'NL'). > This field is required to update the existing nationality that is associated with this recurring contract.
no setter
recurring Recurring
A container for the type of recurring contract to be retrieved. The recurring.contract must be set to "PAYOUT".
no setter
reference String
The merchant reference for this payout. This reference will be used in all communication to the merchant about the status of the payout. Although it is a good idea to make sure it is unique, this is not a requirement.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedRecurringDetailReference String
This is the recurringDetailReference you want to use for this payout. You can use the value LATEST to select the most recently used recurring detail.
no setter
shopperEmail String
The shopper's email address.
no setter
shopperName Name?
The shopper's name. In case the entityType is Company, the shopperName.lastName must contain the company name. > This field is required to update the existing shopperName associated with a recurring contract.
no setter
shopperReference String
The shopper's reference for the payout transaction.
no setter
shopperStatement String?
The description of this payout. This description is shown on the bank statement of the shopper (if this is supported by the chosen payment method).
no setter
socialSecurityNumber String?
The shopper's social security number.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SubmitRequestBuilder)) SubmitRequest
Rebuilds the instance.
inherited
toBuilder() SubmitRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SubmitRequest>
no setter