reference property
The merchant reference for this payout. This reference will be used in all communication to the merchant about the status of the payout. Although it is a good idea to make sure it is unique, this is not a requirement.
Implementation
@BuiltValueField(wireName: r'reference')
String get reference;