shopperStatement property
The description of this payout. This description is shown on the bank statement of the shopper (if this is supported by the chosen payment method).
Implementation
@BuiltValueField(wireName: r'shopperStatement')
String? get shopperStatement;