SubmitResponse class abstract
SubmitResponse
Properties:
- additionalData - This field contains additional data, which may be returned in a particular response.
- pspReference - A new reference to uniquely identify this request.
- refusalReason - In case of refusal, an informational message for the reason.
- resultCode - The response: * In case of success, it is
payout-submit-received. * In case of an error, an informational message is returned.
- Annotations
-
- @BuiltValue.new()
Constructors
- SubmitResponse([void updates(SubmitResponseBuilder b)])
-
factory
Properties
-
additionalData
→ BuiltMap<
String, String> ? -
This field contains additional data, which may be returned in a particular response.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- pspReference → String
-
A new reference to uniquely identify this request.
no setter
- refusalReason → String?
-
In case of refusal, an informational message for the reason.
no setter
- resultCode → String
-
The response: * In case of success, it is
payout-submit-received. * In case of an error, an informational message is returned.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(SubmitResponseBuilder)) → SubmitResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → SubmitResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
SubmitResponse> -
no setter