GetAccountHolderRequest class abstract
GetAccountHolderRequest
Properties:
- accountCode - The code of the account of which to retrieve the details. > Required if no
accountHolderCodeis provided. - accountHolderCode - The code of the account holder of which to retrieve the details. > Required if no
accountCodeis provided. - showDetails - True if the request should return the account holder details
- Annotations
-
- @BuiltValue.new()
Constructors
- GetAccountHolderRequest([void updates(GetAccountHolderRequestBuilder b)])
-
factory
Properties
- accountCode → String?
-
The code of the account of which to retrieve the details. > Required if no
accountHolderCodeis provided.no setter - accountHolderCode → String?
-
The code of the account holder of which to retrieve the details. > Required if no
accountCodeis provided.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showDetails → bool?
-
True if the request should return the account holder details
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(GetAccountHolderRequestBuilder)) → GetAccountHolderRequest -
Rebuilds the instance.
inherited
-
toBuilder(
) → GetAccountHolderRequestBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
GetAccountHolderRequest> -
no setter