GetAccountHolderResponse class abstract
GetAccountHolderResponse
Properties:
- accountHolderCode - The code of the account holder.
- accountHolderDetails - Details of the account holder.
- accountHolderStatus - The status of the account holder.
- accounts - A list of the accounts under the account holder.
- description - The description of the account holder.
- invalidFields - Contains field validation errors that would prevent requests from being processed.
- legalEntity - The legal entity of the account holder.
- migrationData - Details of the account holder migrated to the balance platform.
- primaryCurrency - The three-character ISO currency code, with which the prospective account holder primarily deals.
- pspReference - The reference of a request. Can be used to uniquely identify the request.
- resultCode - The result code.
- systemUpToDateTime - The time that shows how up to date is the information in the response.
- verification - The details of KYC Verification of the account holder.
- verificationProfile - The identifier of the profile that applies to this entity.
- Annotations
-
- @BuiltValue.new()
Constructors
- GetAccountHolderResponse([void updates(GetAccountHolderResponseBuilder b)])
-
factory
Properties
- accountHolderCode → String?
-
The code of the account holder.
no setter
- accountHolderDetails → AccountHolderDetails?
-
Details of the account holder.
no setter
- accountHolderStatus → AccountHolderStatus?
-
The status of the account holder.
no setter
-
accounts
→ BuiltList<
Account> ? -
A list of the accounts under the account holder.
no setter
- description → String?
-
The description of the account holder.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
invalidFields
→ BuiltList<
ErrorFieldType> ? -
Contains field validation errors that would prevent requests from being processed.
no setter
- legalEntity → GetAccountHolderResponseLegalEntityEnum?
-
The legal entity of the account holder.
no setter
- migrationData → MigrationData?
-
Details of the account holder migrated to the balance platform.
no setter
- primaryCurrency → String?
-
The three-character ISO currency code, with which the prospective account holder primarily deals.
no setter
- pspReference → String?
-
The reference of a request. Can be used to uniquely identify the request.
no setter
- resultCode → String?
-
The result code.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemUpToDateTime → DateTime?
-
The time that shows how up to date is the information in the response.
no setter
- verification → KYCVerificationResult?
-
The details of KYC Verification of the account holder.
no setter
- verificationProfile → String?
-
The identifier of the profile that applies to this entity.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(GetAccountHolderResponseBuilder)) → GetAccountHolderResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → GetAccountHolderResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
GetAccountHolderResponse> -
no setter