storeReference property
Your reference for the store in the classic integration. The Customer Area uses this value for the store description.
Implementation
@BuiltValueField(wireName: r'storeReference')
String? get storeReference;
Your reference for the store in the classic integration. The Customer Area uses this value for the store description.
@BuiltValueField(wireName: r'storeReference')
String? get storeReference;