PayoutScheduleResponse class abstract
PayoutScheduleResponse
Properties:
- nextScheduledPayout - The date of the next scheduled payout.
- schedule - The payout schedule for the account. Possible values:
DEFAULT,DAILY,DAILY_US,DAILY_EU,DAILY_AU,DAILY_SG,WEEKLY,WEEKLY_ON_TUE_FRI_MIDNIGHT,BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT,MONTHLY,HOLD. >HOLDprevents scheduled payouts, but you can still initiate payouts manually.
- Annotations
-
- @BuiltValue.new()
Constructors
- PayoutScheduleResponse([void updates(PayoutScheduleResponseBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextScheduledPayout → DateTime?
-
The date of the next scheduled payout.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedule → PayoutScheduleResponseScheduleEnum?
-
The payout schedule for the account. Possible values:
DEFAULT,DAILY,DAILY_US,DAILY_EU,DAILY_AU,DAILY_SG,WEEKLY,WEEKLY_ON_TUE_FRI_MIDNIGHT,BIWEEKLY_ON_1ST_AND_15TH_AT_MIDNIGHT,MONTHLY,HOLD. >HOLDprevents scheduled payouts, but you can still initiate payouts manually.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(PayoutScheduleResponseBuilder)) → PayoutScheduleResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → PayoutScheduleResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
PayoutScheduleResponse> -
no setter