UpdatePayoutScheduleRequestActionEnum class
- Inheritance
-
- Object
- EnumClass
- UpdatePayoutScheduleRequestActionEnum
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
CLOSE
→ const UpdatePayoutScheduleRequestActionEnum
-
Direction on how to handle any payouts that have already been scheduled. Possible values: *
CLOSE: close the existing batch of payouts. * UPDATE: reschedule the existing batch to the new schedule. * NOTHING (default): allow the payout to proceed.
-
NOTHING
→ const UpdatePayoutScheduleRequestActionEnum
-
Direction on how to handle any payouts that have already been scheduled. Possible values: *
CLOSE: close the existing batch of payouts. * UPDATE: reschedule the existing batch to the new schedule. * NOTHING (default): allow the payout to proceed.
-
unknownDefaultOpenApi
→ const UpdatePayoutScheduleRequestActionEnum
-
Direction on how to handle any payouts that have already been scheduled. Possible values: *
CLOSE: close the existing batch of payouts. * UPDATE: reschedule the existing batch to the new schedule. * NOTHING (default): allow the payout to proceed.
-
UPDATE
→ const UpdatePayoutScheduleRequestActionEnum
-
Direction on how to handle any payouts that have already been scheduled. Possible values: *
CLOSE: close the existing batch of payouts. * UPDATE: reschedule the existing batch to the new schedule. * NOTHING (default): allow the payout to proceed.