DebitAccountHolderResponse class abstract
DebitAccountHolderResponse
Properties:
- accountHolderCode - The code of the account holder.
- bankAccountUUID - The Adyen-generated unique alphanumeric identifier (UUID) of the account holder's bank account.
- invalidFields - Contains field validation errors that would prevent requests from being processed.
- merchantReferences - List of the
referencevalues from thesplitarray in the request. - pspReference - The reference of a request. Can be used to uniquely identify the request.
- resultCode - The result code.
- Annotations
-
- @BuiltValue.new()
Constructors
- DebitAccountHolderResponse([void updates(DebitAccountHolderResponseBuilder b)])
-
factory
Properties
- accountHolderCode → String?
-
The code of the account holder.
no setter
- bankAccountUUID → String?
-
The Adyen-generated unique alphanumeric identifier (UUID) of the account holder's bank account.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
invalidFields
→ BuiltList<
ErrorFieldType> ? -
Contains field validation errors that would prevent requests from being processed.
no setter
-
merchantReferences
→ BuiltList<
String> ? -
List of the
referencevalues from thesplitarray in the request.no setter - pspReference → String?
-
The reference of a request. Can be used to uniquely identify the request.
no setter
- resultCode → String?
-
The result code.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(DebitAccountHolderResponseBuilder)) → DebitAccountHolderResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → DebitAccountHolderResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
DebitAccountHolderResponse> -
no setter