GetOnboardingUrlRequest class abstract
GetOnboardingUrlRequest
Properties:
- accountHolderCode - The account holder code you provided when you created the account holder.
- collectInformation - Contains indicators whether the page should only collect information for specific KYC checks. By default, the page collects information for all KYC checks that apply to the legal entity type.
- editMode - Indicates if editing checks is allowed even if all the checks have passed.
- mobileOAuthCallbackUrl - The URL to which the account holder is redirected after completing an OAuth authentication with a bank through Trustly/PayMyBank.
- platformName - The platform name which will show up in the welcome page.
- returnUrl - The URL where the account holder will be redirected back to after they complete the onboarding, or if their session times out. Maximum length of 500 characters. If you don't provide this, the account holder will be redirected back to the default return URL configured in your platform account.
- shopperLocale - The language to be used in the page, specified by a combination of a language and country code. For example, pt-BR. If not specified in the request or if the language is not supported, the page uses the browser language. If the browser language is not supported, the page uses en-US by default. For a list of supported languages, refer to Change the page language.
- showPages - Contains indicators whether specific pages must be shown to the account holder.
- Annotations
-
- @BuiltValue.new()
Constructors
- GetOnboardingUrlRequest([void updates(GetOnboardingUrlRequestBuilder b)])
-
factory
Properties
- accountHolderCode → String
-
The account holder code you provided when you created the account holder.
no setter
- collectInformation → CollectInformation?
-
Contains indicators whether the page should only collect information for specific KYC checks. By default, the page collects information for all KYC checks that apply to the legal entity type.
no setter
- editMode → bool?
-
Indicates if editing checks is allowed even if all the checks have passed.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- mobileOAuthCallbackUrl → String?
-
The URL to which the account holder is redirected after completing an OAuth authentication with a bank through Trustly/PayMyBank.
no setter
- platformName → String?
-
The platform name which will show up in the welcome page.
no setter
- returnUrl → String?
-
The URL where the account holder will be redirected back to after they complete the onboarding, or if their session times out. Maximum length of 500 characters. If you don't provide this, the account holder will be redirected back to the default return URL configured in your platform account.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shopperLocale → String?
-
The language to be used in the page, specified by a combination of a language and country code. For example, pt-BR. If not specified in the request or if the language is not supported, the page uses the browser language. If the browser language is not supported, the page uses en-US by default. For a list of supported languages, refer to Change the page language.
no setter
- showPages → ShowPages?
-
Contains indicators whether specific pages must be shown to the account holder.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(GetOnboardingUrlRequestBuilder)) → GetOnboardingUrlRequest -
Rebuilds the instance.
inherited
-
toBuilder(
) → GetOnboardingUrlRequestBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
GetOnboardingUrlRequest> -
no setter