GetPciUrlResponse class abstract
GetPciUrlResponse
Properties:
- invalidFields - Information about any invalid fields.
- pspReference - The reference of a request. Can be used to uniquely identify the request.
- redirectUrl - The URL to the PCI compliance questionnaire where you should redirect your account holder. This URL must be used within 30 seconds and can only be used once.
- resultCode - The result code.
- Annotations
-
- @BuiltValue.new()
Constructors
- GetPciUrlResponse([void updates(GetPciUrlResponseBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
invalidFields
→ BuiltList<
ErrorFieldType> ? -
Information about any invalid fields.
no setter
- pspReference → String?
-
The reference of a request. Can be used to uniquely identify the request.
no setter
- redirectUrl → String?
-
The URL to the PCI compliance questionnaire where you should redirect your account holder. This URL must be used within 30 seconds and can only be used once.
no setter
- resultCode → String?
-
The result code.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(GetPciUrlResponseBuilder)) → GetPciUrlResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → GetPciUrlResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
GetPciUrlResponse> -
no setter