DiagnosisResponse class abstract
It conveys the result of the requested diagnosis and a possible message to display on a logical device. Content of the Diagnosis Response message.
Properties:
- response - Result of a message request processing.
- pOIStatus - State of a POI Terminal. If
Response.Resultis Success. - hostStatus - State of a Host.
- Annotations
-
- @BuiltValue.new()
Constructors
- DiagnosisResponse([void updates(DiagnosisResponseBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hostStatus
→ BuiltList<
HostStatus> ? -
State of a Host.
no setter
- pOIStatus → POIStatus?
-
State of a POI Terminal. If
Response.Resultis Success.no setter - response → Response
-
Result of a message request processing.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(DiagnosisResponseBuilder)) → DiagnosisResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → DiagnosisResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
DiagnosisResponse> -
no setter