merchantOverrideFlag property
Indicates that the Merchant forced the result of the payment to successful. Allows the Sale System to be sure that the payment has been forced.
Implementation
@BuiltValueField(wireName: r'MerchantOverrideFlag')
bool? get merchantOverrideFlag;