onlineFlag property
Indicate that the payment transaction processing has required the approval of a host. Allows the Sale System to know if the payment was online or offline.
Implementation
@BuiltValueField(wireName: r'OnlineFlag')
bool? get onlineFlag;