merchantAccount property
The merchant account that the terminal is associated with. If the response doesn't contain a store the terminal is assigned to this merchant account.
Implementation
@BuiltValueField(wireName: r'merchantAccount')
String? get merchantAccount;