merchantInventory property
Boolean that indicates if the terminal is assigned to the merchant inventory. This is returned when the terminal is assigned to a merchant account. - If true, this indicates that the terminal is in the merchant inventory. This also means that the terminal cannot be boarded. - If false, this indicates that the terminal is assigned to the merchant account as an in-store terminal. This means that the terminal is ready to be boarded, or is already boarded.
Implementation
@BuiltValueField(wireName: r'merchantInventory')
bool? get merchantInventory;