AmountsReq class

Payment amounts specification.

Implemented types

Constructors

AmountsReq({required String currency, required num requestedAmount})
Creates a new amounts request.

Properties

currency String
Currency code (e.g., USD, EUR).
final
hashCode int
The hash code for this object.
no setterinherited
requestedAmount num
Requested payment amount.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSerializable() Map<String, dynamic>
Converts this object to a serializable map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited