MessageType enum

Message types for terminal communication.

Inheritance
Available extensions

Values

request → const MessageType

Request message.

const MessageType('Request')
response → const MessageType

Response message.

const MessageType('Response')
notification → const MessageType

Notification message.

const MessageType('Notification')
unknown → const MessageType

Unknown type.

const MessageType('Unknown')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
String value of the enum.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String? value) MessageType
Parses a message type from a string value.

Constants

values → const List<MessageType>
A constant List of the values in this enum, in order of their declaration.