NexoDerivedKey class

Derived cryptographic keys for Nexo encryption.

Constructors

NexoDerivedKey({required Uint8List cipherKey, required Uint8List hmacKey, required Uint8List iv})
Creates a new Nexo derived key.

Properties

cipherKey Uint8List
Cipher key for encryption/decryption.
final
hashCode int
The hash code for this object.
no setterinherited
hmacKey Uint8List
HMAC key for message authentication.
final
iv Uint8List
Initialization vector for encryption.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited