OriginalPOITransaction class
Reference to the original POI transaction being reversed.
- Implemented types
Constructors
- OriginalPOITransaction({required POITransactionID poiTransactionID})
- Creates a new original POI transaction reference.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- poiTransactionID → POITransactionID
-
Original POI transaction identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toSerializable(
) → Map< String, dynamic> -
Converts this object to a serializable map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited