ReversalRequest class
Request to reverse a previous transaction.
- Implemented types
Constructors
- ReversalRequest({required SaleData saleData, OriginalPOITransaction? originalPOITransaction, ReversalReasonType? reversalReason})
- Creates a new reversal request.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- originalPOITransaction → OriginalPOITransaction?
-
Original POI transaction being reversed.
final
- reversalReason → ReversalReasonType?
-
Reason for the reversal.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saleData → SaleData
-
Sale transaction context data.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toSerializable(
) → Map< String, dynamic> -
Converts this object to a serializable map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited