SaleToPOIRequest class

Main SaleToPOI request message for terminal communication.

Implemented types

Constructors

SaleToPOIRequest({required MessageHeader messageHeader, PaymentRequest? paymentRequest, ReversalRequest? reversalRequest, EventNotification? eventNotification})
Creates a new SaleToPOI request.
SaleToPOIRequest.fromJson(Map<String, dynamic> json)
Creates a SaleToPOIRequest from JSON.
factory

Properties

eventNotification EventNotification?
Event notification details (optional).
final
hashCode int
The hash code for this object.
no setterinherited
messageHeader MessageHeader
Message metadata and routing information.
final
paymentRequest PaymentRequest?
Payment transaction request (optional).
final
reversalRequest ReversalRequest?
Reversal/cancellation request (optional).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSerializable() Map<String, dynamic>
Converts this object to a serializable map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited