SaleToPOISecuredMessage class

Secured SaleToPOI message with encryption.

Implemented types

Constructors

SaleToPOISecuredMessage({required MessageHeader messageHeader, required String nexoBlob, required SecurityTrailer securityTrailer})
Creates a new secured SaleToPOI message.
SaleToPOISecuredMessage.fromJson(Map<String, dynamic> json)
Creates a SaleToPOISecuredMessage from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
messageHeader MessageHeader
Message metadata and routing information.
final
nexoBlob String
Encrypted payload blob.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityTrailer SecurityTrailer
Security trailer with HMAC signature.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSerializable() Map<String, dynamic>
Converts this object to a serializable map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited