SaleTransactionID class
Unique sale transaction identifier.
- Implemented types
Constructors
- SaleTransactionID({required String timeStamp, required String transactionId})
- Creates a new sale transaction ID.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeStamp → String
-
Transaction timestamp.
final
- transactionId → String
-
Unique transaction ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toSerializable(
) → Map< String, dynamic> -
Converts this object to a serializable map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited