SecurityKey class
Security key for encrypting/decrypting terminal messages.
Constructors
- SecurityKey({required int adyenCryptoVersion, required String keyIdentifier, required int keyVersion, required String passphrase})
- Creates a new security key.
Properties
- adyenCryptoVersion → int
-
Adyen crypto version identifier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyIdentifier → String
-
Key identifier for the terminal.
final
- keyVersion → int
-
Version of the key.
final
- passphrase → String
-
Passphrase for key derivation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited