SecurityTrailer class

Security trailer containing cryptographic signature information.

Implemented types

Constructors

SecurityTrailer({required int adyenCryptoVersion, required String hmac, required String keyIdentifier, required int keyVersion, required String nonce})
Creates a new security trailer.
SecurityTrailer.fromJson(Map<String, dynamic> json)
Creates a SecurityTrailer from JSON.
factory

Properties

adyenCryptoVersion int
Adyen crypto version identifier.
final
hashCode int
The hash code for this object.
no setterinherited
hmac String
HMAC signature for message authentication.
final
keyIdentifier String
Key identifier used for signing.
final
keyVersion int
Version of the key used for signing.
final
nonce String
Nonce used for cryptographic operations.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSerializable() Map<String, dynamic>
Converts this object to a serializable map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited