TerminalApiSecuredRequest class

Secured request wrapper for encrypted terminal API calls.

Implemented types

Constructors

TerminalApiSecuredRequest({required SaleToPOISecuredMessage saleToPOIRequest})
Creates a new secured terminal API request.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saleToPOIRequest SaleToPOISecuredMessage
Encrypted SaleToPOI request message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSerializable() Map<String, dynamic>
Converts this object to a serializable map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited