TerminalApiSecuredResponse class
Secured response wrapper for encrypted terminal API responses.
Constructors
- TerminalApiSecuredResponse({required SaleToPOISecuredMessage saleToPOIResponse})
- Creates a new secured terminal API response.
-
TerminalApiSecuredResponse.fromJson(Map<
String, dynamic> json) -
Creates a TerminalApiSecuredResponse from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saleToPOIResponse → SaleToPOISecuredMessage
-
Decrypted SaleToPOI response message.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited