CapitalGrant class abstract
CapitalGrant
Properties:
- amount - An object containing the amount of the grant, in minor units.
- balances - An object containing the details of the existing grant.
- counterparty - An object containing the details of the receiving party of the grant. Setting either an
accountHolderId,balanceAccountId, or both is required. - fee - An object containing the fee currency and value, in minor units.
- grantAccountId - The identifier of the grant account used for the grant.
- grantOfferId - The identifier of the grant offer that has been selected and from which the grant details will be used.
- id - The identifier of the grant reference.
- repayment - An object containing the details of the 30-day repayment threshold.
- status - The current status of the grant. Possible values: Pending, Active, Repaid, WrittenOff, Failed, Revoked.
- Annotations
-
- @BuiltValue.new()
Constructors
- CapitalGrant([void updates(CapitalGrantBuilder b)])
-
factory
Properties
- amount → Amount?
-
An object containing the amount of the grant, in minor units.
no setter
- balances → CapitalBalance
-
An object containing the details of the existing grant.
no setter
- counterparty → Counterparty?
-
An object containing the details of the receiving party of the grant. Setting either an
accountHolderId,balanceAccountId, or both is required.no setter - fee → Fee?
-
An object containing the fee currency and value, in minor units.
no setter
- grantAccountId → String
-
The identifier of the grant account used for the grant.
no setter
- grantOfferId → String
-
The identifier of the grant offer that has been selected and from which the grant details will be used.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The identifier of the grant reference.
no setter
- repayment → Repayment?
-
An object containing the details of the 30-day repayment threshold.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → CapitalGrantStatusEnum
-
The current status of the grant. Possible values: Pending, Active, Repaid, WrittenOff, Failed, Revoked.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(CapitalGrantBuilder)) → CapitalGrant -
Rebuilds the instance.
inherited
-
toBuilder(
) → CapitalGrantBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
CapitalGrant> -
no setter