CapitalGrantInfo class abstract
CapitalGrantInfo
Properties:
- counterparty - An object containing the details of the receiving party of the grant. Setting either an
accountHolderId,balanceAccountId, or both is required. - grantAccountId - The identifier of the grant account used for the grant.
- grantOfferId - The identifier of the grant offer that has been selected and from which the grant details will be used.
- Annotations
-
- @BuiltValue.new()
Constructors
- CapitalGrantInfo([void updates(CapitalGrantInfoBuilder b)])
-
factory
Properties
- counterparty → Counterparty?
-
An object containing the details of the receiving party of the grant. Setting either an
accountHolderId,balanceAccountId, or both is required.no setter - grantAccountId → String
-
The identifier of the grant account used for the grant.
no setter
- grantOfferId → String
-
The identifier of the grant offer that has been selected and from which the grant details will be used.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(CapitalGrantInfoBuilder)) → CapitalGrantInfo -
Rebuilds the instance.
inherited
-
toBuilder(
) → CapitalGrantInfoBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
CapitalGrantInfo> -
no setter