FundingInstrumentSourceOfFundsEnum class
- Inheritance
-
- Object
- EnumClass
- FundingInstrumentSourceOfFundsEnum
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
FundingInstrumentSourceOfFundsEnum> -
no setter
-
values
→ BuiltSet<
FundingInstrumentSourceOfFundsEnum> -
no setter
Static Methods
Constants
- DEBIT → const FundingInstrumentSourceOfFundsEnum
- Indicates where the funds used for the transfer originated. Possible values are: - DEBIT for card-to-card transfers. - DEPOSIT_ACCOUNT for wallet-to-card transfers.
- DEPOSIT_ACCOUNT → const FundingInstrumentSourceOfFundsEnum
- Indicates where the funds used for the transfer originated. Possible values are: - DEBIT for card-to-card transfers. - DEPOSIT_ACCOUNT for wallet-to-card transfers.
- unknownDefaultOpenApi → const FundingInstrumentSourceOfFundsEnum
- Indicates where the funds used for the transfer originated. Possible values are: - DEBIT for card-to-card transfers. - DEPOSIT_ACCOUNT for wallet-to-card transfers.