AuthenticationNotificationData class abstract
AuthenticationNotificationData
Properties:
- authentication - Contains information about the authentication.
- balancePlatform - The unique identifier of the balance platform.
- id - The unique identifier of the authentication.
- paymentInstrumentId - The unique identifier of the payment instrument that was used for the authentication.
- purchase - Contains information about the purchase.
- status - Outcome of the authentication. Allowed values: * authenticated * rejected * error
- Annotations
-
- @BuiltValue.new()
Constructors
- AuthenticationNotificationData([void updates(AuthenticationNotificationDataBuilder b)])
-
factory
Properties
- authentication → AuthenticationInfo
-
Contains information about the authentication.
no setter
- balancePlatform → String?
-
The unique identifier of the balance platform.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier of the authentication.
no setter
- paymentInstrumentId → String
-
The unique identifier of the payment instrument that was used for the authentication.
no setter
- purchase → PurchaseInfo
-
Contains information about the purchase.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AuthenticationNotificationDataStatusEnum
-
Outcome of the authentication. Allowed values: * authenticated * rejected * error
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(AuthenticationNotificationDataBuilder)) → AuthenticationNotificationData -
Rebuilds the instance.
inherited
-
toBuilder(
) → AuthenticationNotificationDataBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
AuthenticationNotificationData> -
no setter