ChallengeInfoChallengeCancelEnum class
- Inheritance
-
- Object
- EnumClass
- ChallengeInfoChallengeCancelEnum
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
n00
→ const ChallengeInfoChallengeCancelEnum
-
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. Possible values: * 00: Data element is absent or value has been sent back with the key
challengeCancel. * 01: Cardholder selected Cancel. * 02: 3DS Requestor cancelled Authentication. * 03: Transaction abandoned. * 04: Transaction timed out at ACS — other timeouts. * 05: Transaction timed out at ACS — first CReq not received by ACS. * 06: Transaction error. * 07: Unknown. * 08: Transaction time out at SDK.
-
n01
→ const ChallengeInfoChallengeCancelEnum
-
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. Possible values: * 00: Data element is absent or value has been sent back with the key
challengeCancel. * 01: Cardholder selected Cancel. * 02: 3DS Requestor cancelled Authentication. * 03: Transaction abandoned. * 04: Transaction timed out at ACS — other timeouts. * 05: Transaction timed out at ACS — first CReq not received by ACS. * 06: Transaction error. * 07: Unknown. * 08: Transaction time out at SDK.
-
n02
→ const ChallengeInfoChallengeCancelEnum
-
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. Possible values: * 00: Data element is absent or value has been sent back with the key
challengeCancel. * 01: Cardholder selected Cancel. * 02: 3DS Requestor cancelled Authentication. * 03: Transaction abandoned. * 04: Transaction timed out at ACS — other timeouts. * 05: Transaction timed out at ACS — first CReq not received by ACS. * 06: Transaction error. * 07: Unknown. * 08: Transaction time out at SDK.
-
n03
→ const ChallengeInfoChallengeCancelEnum
-
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. Possible values: * 00: Data element is absent or value has been sent back with the key
challengeCancel. * 01: Cardholder selected Cancel. * 02: 3DS Requestor cancelled Authentication. * 03: Transaction abandoned. * 04: Transaction timed out at ACS — other timeouts. * 05: Transaction timed out at ACS — first CReq not received by ACS. * 06: Transaction error. * 07: Unknown. * 08: Transaction time out at SDK.
-
n04
→ const ChallengeInfoChallengeCancelEnum
-
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. Possible values: * 00: Data element is absent or value has been sent back with the key
challengeCancel. * 01: Cardholder selected Cancel. * 02: 3DS Requestor cancelled Authentication. * 03: Transaction abandoned. * 04: Transaction timed out at ACS — other timeouts. * 05: Transaction timed out at ACS — first CReq not received by ACS. * 06: Transaction error. * 07: Unknown. * 08: Transaction time out at SDK.
-
n05
→ const ChallengeInfoChallengeCancelEnum
-
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. Possible values: * 00: Data element is absent or value has been sent back with the key
challengeCancel. * 01: Cardholder selected Cancel. * 02: 3DS Requestor cancelled Authentication. * 03: Transaction abandoned. * 04: Transaction timed out at ACS — other timeouts. * 05: Transaction timed out at ACS — first CReq not received by ACS. * 06: Transaction error. * 07: Unknown. * 08: Transaction time out at SDK.
-
n06
→ const ChallengeInfoChallengeCancelEnum
-
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. Possible values: * 00: Data element is absent or value has been sent back with the key
challengeCancel. * 01: Cardholder selected Cancel. * 02: 3DS Requestor cancelled Authentication. * 03: Transaction abandoned. * 04: Transaction timed out at ACS — other timeouts. * 05: Transaction timed out at ACS — first CReq not received by ACS. * 06: Transaction error. * 07: Unknown. * 08: Transaction time out at SDK.
-
n07
→ const ChallengeInfoChallengeCancelEnum
-
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. Possible values: * 00: Data element is absent or value has been sent back with the key
challengeCancel. * 01: Cardholder selected Cancel. * 02: 3DS Requestor cancelled Authentication. * 03: Transaction abandoned. * 04: Transaction timed out at ACS — other timeouts. * 05: Transaction timed out at ACS — first CReq not received by ACS. * 06: Transaction error. * 07: Unknown. * 08: Transaction time out at SDK.
-
n08
→ const ChallengeInfoChallengeCancelEnum
-
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. Possible values: * 00: Data element is absent or value has been sent back with the key
challengeCancel. * 01: Cardholder selected Cancel. * 02: 3DS Requestor cancelled Authentication. * 03: Transaction abandoned. * 04: Transaction timed out at ACS — other timeouts. * 05: Transaction timed out at ACS — first CReq not received by ACS. * 06: Transaction error. * 07: Unknown. * 08: Transaction time out at SDK.
-
unknownDefaultOpenApi
→ const ChallengeInfoChallengeCancelEnum
-
Indicator informing the Access Control Server (ACS) and the Directory Server (DS) that the authentication has been cancelled. Possible values: * 00: Data element is absent or value has been sent back with the key
challengeCancel. * 01: Cardholder selected Cancel. * 02: 3DS Requestor cancelled Authentication. * 03: Transaction abandoned. * 04: Transaction timed out at ACS — other timeouts. * 05: Transaction timed out at ACS — first CReq not received by ACS. * 06: Transaction error. * 07: Unknown. * 08: Transaction time out at SDK.