AccountHolderDetails class abstract
AccountHolderDetails
Properties:
- address - The address of the account holder.
- bankAccountDetails - Array of bank accounts associated with the account holder. For details about the required
bankAccountDetailfields, see Required information. - bankAggregatorDataReference - The opaque reference value returned by the Adyen API during bank account login.
- businessDetails - Details about the business or nonprofit account holder. Required when creating an account holder with
legalEntityBusiness or NonProfit. - email - The email address of the account holder.
- fullPhoneNumber - The phone number of the account holder provided as a single string. It will be handled as a landline phone. Examples: "0031 6 11 22 33 44", "+316/1122-3344", "(0031) 611223344"
- individualDetails - Details about the individual account holder. Required when creating an account holder with
legalEntityIndividual. - lastReviewDate - Date when you last reviewed the account holder's information, in ISO-8601 YYYY-MM-DD format. For example, 2020-01-31.
- legalArrangements - An array containing information about the account holder's legal arrangements.
- merchantCategoryCode - The Merchant Category Code of the account holder. > If not specified in the request, this will be derived from the platform account (which is configured by Adyen).
- metadata - A set of key and value pairs for general use by the account holder or merchant. The keys do not have specific names and may be used for storing miscellaneous data as desired. > The values being stored have a maximum length of eighty (80) characters and will be truncated if necessary. > Note that during an update of metadata, the omission of existing key-value pairs will result in the deletion of those key-value pairs.
- payoutMethods - Array of tokenized card details associated with the account holder. For details about how you can use the tokens to pay out, refer to Pay out to cards.
- phoneNumber - The phone number of the account holder. > Required if a
fullPhoneNumberis not provided. - principalBusinessAddress - The principal business address of the account holder.
- storeDetails - Array of stores associated with the account holder. Required when onboarding account holders that have an Adyen point of sale.
- webAddress - The URL of the website of the account holder.
- Annotations
-
- @BuiltValue.new()
Constructors
- AccountHolderDetails([void updates(AccountHolderDetailsBuilder b)])
-
factory
Properties
- address → ViasAddress
-
The address of the account holder.
no setter
-
bankAccountDetails
→ BuiltList<
BankAccountDetail> ? -
Array of bank accounts associated with the account holder. For details about the required
bankAccountDetailfields, see Required information.no setter - bankAggregatorDataReference → String?
-
The opaque reference value returned by the Adyen API during bank account login.
no setter
- businessDetails → BusinessDetails?
-
Details about the business or nonprofit account holder. Required when creating an account holder with
legalEntityBusiness or NonProfit.no setter - email → String?
-
The email address of the account holder.
no setter
- fullPhoneNumber → String?
-
The phone number of the account holder provided as a single string. It will be handled as a landline phone. Examples: "0031 6 11 22 33 44", "+316/1122-3344", "(0031) 611223344"
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- individualDetails → IndividualDetails?
-
Details about the individual account holder. Required when creating an account holder with
legalEntityIndividual.no setter - lastReviewDate → String?
-
Date when you last reviewed the account holder's information, in ISO-8601 YYYY-MM-DD format. For example, 2020-01-31.
no setter
-
legalArrangements
→ BuiltList<
LegalArrangementDetail> ? -
An array containing information about the account holder's legal arrangements.
no setter
- merchantCategoryCode → String?
-
The Merchant Category Code of the account holder. > If not specified in the request, this will be derived from the platform account (which is configured by Adyen).
no setter
-
metadata
→ BuiltMap<
String, String> ? -
A set of key and value pairs for general use by the account holder or merchant. The keys do not have specific names and may be used for storing miscellaneous data as desired. > The values being stored have a maximum length of eighty (80) characters and will be truncated if necessary. > Note that during an update of metadata, the omission of existing key-value pairs will result in the deletion of those key-value pairs.
no setter
-
payoutMethods
→ BuiltList<
PayoutMethod> ? -
Array of tokenized card details associated with the account holder. For details about how you can use the tokens to pay out, refer to Pay out to cards.
no setter
- phoneNumber → ViasPhoneNumber?
-
The phone number of the account holder. > Required if a
fullPhoneNumberis not provided.no setter - principalBusinessAddress → ViasAddress?
-
The principal business address of the account holder.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storeDetails
→ BuiltList<
StoreDetail> ? -
Array of stores associated with the account holder. Required when onboarding account holders that have an Adyen point of sale.
no setter
- webAddress → String?
-
The URL of the website of the account holder.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(AccountHolderDetailsBuilder)) → AccountHolderDetails -
Rebuilds the instance.
inherited
-
toBuilder(
) → AccountHolderDetailsBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
AccountHolderDetails> -
no setter