AccountHolderPayoutNotificationContent class abstract
AccountHolderPayoutNotificationContent
Properties:
- accountCode - The code of the account from which the payout was made.
- accountHolderCode - The code of the Account Holder to which the payout was made.
- amounts - The payout amounts (per currency).
- bankAccountDetail - Details of the Bank Account to which the payout was made.
- description - A description of the payout.
- estimatedArrivalDate - The estimated date of arrival.
- invalidFields - Invalid fields list.
- merchantReference - The merchant reference.
- originalPspReference - The PSP reference of the original payout.
- payoutAccountCountry - The country code of the bank from which the payout was initiated.
- payoutAccountNumber - The account number of the bank from which the payout was initiated.
- payoutBalanceAccountId - The balance account id to which payment was made
- payoutBankName - The name of the bank the payout from which the payout was initiated.
- payoutBranchCode - The branch code of the bank from which the payout was initiated.
- payoutReference - The unique payout identifier.
- payoutSpeed - Speed with which payouts for this account are processed. Permitted values:
STANDARD,SAME_DAY. - status - The payout status.
- Annotations
-
- @BuiltValue.new()
Constructors
- AccountHolderPayoutNotificationContent([void updates(AccountHolderPayoutNotificationContentBuilder b)])
-
factory
Properties
- accountCode → String?
-
The code of the account from which the payout was made.
no setter
- accountHolderCode → String?
-
The code of the Account Holder to which the payout was made.
no setter
-
amounts
→ BuiltList<
Amount> ? -
The payout amounts (per currency).
no setter
- bankAccountDetail → BankAccountDetail?
-
Details of the Bank Account to which the payout was made.
no setter
- description → String?
-
A description of the payout.
no setter
- estimatedArrivalDate → LocalDate?
-
The estimated date of arrival.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
invalidFields
→ BuiltList<
ErrorFieldType> ? -
Invalid fields list.
no setter
- merchantReference → String?
-
The merchant reference.
no setter
- originalPspReference → String?
-
The PSP reference of the original payout.
no setter
- payoutAccountCountry → String?
-
The country code of the bank from which the payout was initiated.
no setter
- payoutAccountNumber → String?
-
The account number of the bank from which the payout was initiated.
no setter
- payoutBalanceAccountId → String?
-
The balance account id to which payment was made
no setter
- payoutBankName → String?
-
The name of the bank the payout from which the payout was initiated.
no setter
- payoutBranchCode → String?
-
The branch code of the bank from which the payout was initiated.
no setter
- payoutReference → int?
-
The unique payout identifier.
no setter
- payoutSpeed → AccountHolderPayoutNotificationContentPayoutSpeedEnum?
-
Speed with which payouts for this account are processed. Permitted values:
STANDARD,SAME_DAY.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → OperationStatus?
-
The payout status.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(AccountHolderPayoutNotificationContentBuilder)) → AccountHolderPayoutNotificationContent -
Rebuilds the instance.
inherited
-
toBuilder(
) → AccountHolderPayoutNotificationContentBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
AccountHolderPayoutNotificationContent> -
no setter