AccountHolderPayoutNotificationContentBuilder class
Constructors
Properties
- accountCode ↔ String?
-
getter/setter pair
- accountHolderCode ↔ String?
-
getter/setter pair
-
amounts
↔ ListBuilder<
Amount> -
getter/setter pair
- bankAccountDetail ↔ BankAccountDetailBuilder
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
- estimatedArrivalDate ↔ LocalDateBuilder
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
invalidFields
↔ ListBuilder<
ErrorFieldType> -
getter/setter pair
- merchantReference ↔ String?
-
getter/setter pair
- originalPspReference ↔ String?
-
getter/setter pair
- payoutAccountCountry ↔ String?
-
getter/setter pair
- payoutAccountNumber ↔ String?
-
getter/setter pair
- payoutBalanceAccountId ↔ String?
-
getter/setter pair
- payoutBankName ↔ String?
-
getter/setter pair
- payoutBranchCode ↔ String?
-
getter/setter pair
- payoutReference ↔ int?
-
getter/setter pair
- payoutSpeed ↔ AccountHolderPayoutNotificationContentPayoutSpeedEnum?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ OperationStatusBuilder
-
getter/setter pair
Methods
-
build(
) → AccountHolderPayoutNotificationContent -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
AccountHolderPayoutNotificationContent other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(AccountHolderPayoutNotificationContentBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited