AccountHolderStatusChangeNotificationContent class abstract
AccountHolderStatusChangeNotificationContent
Properties:
- accountHolderCode - The code of the account holder.
- invalidFields - in case the account holder has not been updated, contains account holder fields, that did not pass the validation.
- newStatus - The new status of the account holder.
- oldStatus - The former status of the account holder.
- reason - The reason for the status change.
- Annotations
-
- @BuiltValue.new()
Constructors
- AccountHolderStatusChangeNotificationContent([void updates(AccountHolderStatusChangeNotificationContentBuilder b)])
-
factory
Properties
- accountHolderCode → String
-
The code of the account holder.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
invalidFields
→ BuiltList<
ErrorFieldType> ? -
in case the account holder has not been updated, contains account holder fields, that did not pass the validation.
no setter
- newStatus → AccountHolderStatus?
-
The new status of the account holder.
no setter
- oldStatus → AccountHolderStatus?
-
The former status of the account holder.
no setter
- reason → String?
-
The reason for the status change.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(AccountHolderStatusChangeNotificationContentBuilder)) → AccountHolderStatusChangeNotificationContent -
Rebuilds the instance.
inherited
-
toBuilder(
) → AccountHolderStatusChangeNotificationContentBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
AccountHolderStatusChangeNotificationContent> -
no setter