AccountHolderUpcomingDeadlineNotificationContent class abstract
AccountHolderUpcomingDeadlineNotificationContent
Properties:
- accountHolderCode - The code of the account holder whom the event refers to.
- event - The event name that will be trigger if no action is taken.
- executionDate - The execution date scheduled for the event.
- reason - The reason that leads to scheduling of the event.
- Annotations
-
- @BuiltValue.new()
Constructors
- AccountHolderUpcomingDeadlineNotificationContent([void updates(AccountHolderUpcomingDeadlineNotificationContentBuilder b)])
-
factory
Properties
- accountHolderCode → String?
-
The code of the account holder whom the event refers to.
no setter
- event → AccountHolderUpcomingDeadlineNotificationContentEventEnum?
-
The event name that will be trigger if no action is taken.
no setter
- executionDate → DateTime?
-
The execution date scheduled for the event.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → String?
-
The reason that leads to scheduling of the event.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(AccountHolderUpcomingDeadlineNotificationContentBuilder)) → AccountHolderUpcomingDeadlineNotificationContent -
Rebuilds the instance.
inherited
-
toBuilder(
) → AccountHolderUpcomingDeadlineNotificationContentBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
AccountHolderUpcomingDeadlineNotificationContent> -
no setter