bankName property
The name of the banking institution with which the bank account is held. >Refer to Required information for details on field requirements.
Implementation
@BuiltValueField(wireName: r'bankName')
String? get bankName;
The name of the banking institution with which the bank account is held. >Refer to Required information for details on field requirements.
@BuiltValueField(wireName: r'bankName')
String? get bankName;