KYCCheckSummary class abstract
KYCCheckSummary
Properties:
- kycCheckCode - The code of the check. For possible values, refer to Verification codes.
- kycCheckDescription - A description of the check.
- Annotations
-
- @BuiltValue.new()
Constructors
- KYCCheckSummary([void updates(KYCCheckSummaryBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kycCheckCode → int?
-
The code of the check. For possible values, refer to Verification codes.
no setter
- kycCheckDescription → String?
-
A description of the check.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(KYCCheckSummaryBuilder)) → KYCCheckSummary -
Rebuilds the instance.
inherited
-
toBuilder(
) → KYCCheckSummaryBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
KYCCheckSummary> -
no setter