KYCVerificationResult class abstract
KYCVerificationResult
Properties:
- accountHolder - The results of the checks on the account holder.
- legalArrangements - The results of the checks on the legal arrangements.
- legalArrangementsEntities - The results of the checks on the legal arrangement entities.
- payoutMethods - The results of the checks on the payout methods.
- shareholders - The results of the checks on the shareholders.
- signatories - The results of the checks on the signatories.
- ultimateParentCompany - The result of the check on the Ultimate Parent Company.
- Annotations
-
- @BuiltValue.new()
Constructors
- KYCVerificationResult([void updates(KYCVerificationResultBuilder b)])
-
factory
Properties
- accountHolder → KYCCheckResult?
-
The results of the checks on the account holder.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
legalArrangements
→ BuiltList<
KYCLegalArrangementCheckResult> ? -
The results of the checks on the legal arrangements.
no setter
-
legalArrangementsEntities
→ BuiltList<
KYCLegalArrangementEntityCheckResult> ? -
The results of the checks on the legal arrangement entities.
no setter
-
payoutMethods
→ BuiltList<
KYCPayoutMethodCheckResult> ? -
The results of the checks on the payout methods.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
The results of the checks on the shareholders.
no setter
-
signatories
→ BuiltList<
KYCSignatoryCheckResult> ? -
The results of the checks on the signatories.
no setter
-
ultimateParentCompany
→ BuiltList<
KYCUltimateParentCompanyCheckResult> ? -
The result of the check on the Ultimate Parent Company.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(KYCVerificationResultBuilder)) → KYCVerificationResult -
Rebuilds the instance.
inherited
-
toBuilder(
) → KYCVerificationResultBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
KYCVerificationResult> -
no setter