LegalArrangementDetailLegalFormEnum class
- Inheritance
-
- Object
- EnumClass
- LegalArrangementDetailLegalFormEnum
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
cashManagementTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
corporateUnitTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
deceasedEstate
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
discretionaryInvestmentTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
discretionaryServicesManagementTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
discretionaryTradingTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
familyPartnership
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
firstHomeSaverAccountsTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
fixedTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
fixedUnitTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
hybridTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
limitedPartnership
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
listedPublicUnitTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
otherPartnership
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
otherTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
pooledSuperannuationTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
publicTradingTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
unknownDefaultOpenApi
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership
-
unlistedPublicUnitTrust
→ const LegalArrangementDetailLegalFormEnum
-
The form of legal arrangement. Required if
type is Trust or Partnership. The possible values depend on the type. - For type Trust: CashManagementTrust, CorporateUnitTrust, DeceasedEstate, DiscretionaryInvestmentTrust, DiscretionaryServicesManagementTrust, DiscretionaryTradingTrust, FirstHomeSaverAccountsTrust, FixedTrust, FixedUnitTrust, HybridTrust, ListedPublicUnitTrust, OtherTrust, PooledSuperannuationTrust, PublicTradingTrust, or UnlistedPublicUnitTrust. - For type Partnership: LimitedPartnership, FamilyPartnership, or OtherPartnership