LegalArrangementEntityDetail class abstract
LegalArrangementEntityDetail
Properties:
- address - The address of the entity.
- businessDetails - Required when creating an entity with
legalEntityTypeBusiness, NonProfit, PublicCompany, or Partnership. - email - The e-mail address of the entity.
- fullPhoneNumber - The phone number of the contact provided as a single string. It will be handled as a landline phone. Examples: "0031 6 11 22 33 44", "+316/1122-3344", "(0031) 611223344"
- individualDetails - Required when creating an entity with
legalEntityTypeIndividual. - legalArrangementEntityCode - Adyen-generated unique alphanumeric identifier (UUID) for the entry, returned in the response when you create a legal arrangement entity. Use only when updating an account holder. If you include this field when creating an account holder, the request will fail.
- legalArrangementEntityReference - Your reference for the legal arrangement entity.
- legalArrangementMembers - An array containing the roles of the entity in the legal arrangement. The possible values depend on the legal arrangement
type. - FortypeAssociation: ControllingPerson and Shareholder. - FortypePartnership: Partner and Shareholder. - FortypeTrust: Trustee, Settlor, Protector, Beneficiary, and Shareholder. - legalEntityType - The legal entity type. Possible values: Business, Individual, NonProfit, PublicCompany, or Partnership.
- phoneNumber - The phone number of the entity.
- webAddress - The URL of the website of the contact.
- Annotations
-
- @BuiltValue.new()
Constructors
- LegalArrangementEntityDetail([void updates(LegalArrangementEntityDetailBuilder b)])
-
factory
Properties
- address → ViasAddress?
-
The address of the entity.
no setter
- businessDetails → BusinessDetails?
-
Required when creating an entity with
legalEntityTypeBusiness, NonProfit, PublicCompany, or Partnership.no setter - email → String?
-
The e-mail address of the entity.
no setter
- fullPhoneNumber → String?
-
The phone number of the contact provided as a single string. It will be handled as a landline phone. Examples: "0031 6 11 22 33 44", "+316/1122-3344", "(0031) 611223344"
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- individualDetails → IndividualDetails?
-
Required when creating an entity with
legalEntityTypeIndividual.no setter - legalArrangementEntityCode → String?
-
Adyen-generated unique alphanumeric identifier (UUID) for the entry, returned in the response when you create a legal arrangement entity. Use only when updating an account holder. If you include this field when creating an account holder, the request will fail.
no setter
- legalArrangementEntityReference → String?
-
Your reference for the legal arrangement entity.
no setter
-
legalArrangementMembers
→ BuiltList<
LegalArrangementEntityDetailLegalArrangementMembersEnum> ? -
An array containing the roles of the entity in the legal arrangement. The possible values depend on the legal arrangement
type. - FortypeAssociation: ControllingPerson and Shareholder. - FortypePartnership: Partner and Shareholder. - FortypeTrust: Trustee, Settlor, Protector, Beneficiary, and Shareholder.no setter - legalEntityType → LegalArrangementEntityDetailLegalEntityTypeEnum?
-
The legal entity type. Possible values: Business, Individual, NonProfit, PublicCompany, or Partnership.
no setter
- phoneNumber → ViasPhoneNumber?
-
The phone number of the entity.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webAddress → String?
-
The URL of the website of the contact.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(LegalArrangementEntityDetailBuilder)) → LegalArrangementEntityDetail -
Rebuilds the instance.
inherited
-
toBuilder(
) → LegalArrangementEntityDetailBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
LegalArrangementEntityDetail> -
no setter