UltimateParentCompany class abstract
UltimateParentCompany
Properties:
- address - Address of the ultimate parent company.
- businessDetails - Details about the ultimate parent company's business.
- ultimateParentCompanyCode - Adyen-generated unique alphanumeric identifier (UUID) for the entry, returned in the response when you create an ultimate parent company. Required when updating an existing entry in an
/updateAccountHolderrequest.
- Annotations
-
- @BuiltValue.new()
Constructors
- UltimateParentCompany([void updates(UltimateParentCompanyBuilder b)])
-
factory
Properties
- address → ViasAddress?
-
Address of the ultimate parent company.
no setter
- businessDetails → UltimateParentCompanyBusinessDetails?
-
Details about the ultimate parent company's business.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ultimateParentCompanyCode → String?
-
Adyen-generated unique alphanumeric identifier (UUID) for the entry, returned in the response when you create an ultimate parent company. Required when updating an existing entry in an
/updateAccountHolderrequest.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(UltimateParentCompanyBuilder)) → UltimateParentCompany -
Rebuilds the instance.
inherited
-
toBuilder(
) → UltimateParentCompanyBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
UltimateParentCompany> -
no setter